(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    537592,      14066]*)
(*NotebookOutlinePosition[    581968,      15628]*)
(*  CellTagsIndexPosition[    581175,      15604]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Fehlerrechnung und Interpolation", "Title",
  CounterAssignments->{{"Title", 7}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],

Cell[TextData[{
  CounterBox["Title"],
  ". ",
  "Vorlesung \[UDoubleDot]ber Grundlagen der Physik I"
}], "Subtitle"],

Cell[TextData[
"Auftraggeber:\t21.  7.2004\tProfessor Dr. Horst Nespeta\nBearbeitung:\t21.  \
9.2004 \[Dash]\t  6.10.2004\tDr. Norbert S\[UDoubleDot]dland\nLetzte \
Berechnung:\t  6.10.2004\tDr. Norbert S\[UDoubleDot]dland\nLetzte Korrektur:\t\
27.  4.2005\tDr. Norbert S\[UDoubleDot]dland"], "Subsubtitle",
  TextAlignment->Left],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Interpolation"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Definitionen"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Interpolation"
}], "Subsubsection"],

Cell["\<\
Die Interpolation ist die Kunst, nicht gemessene Zwischenwerte \
bestm\[ODoubleDot]glich zu gemessenen Funktionswerten anzugeben.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Extrapolation"
}], "Subsubsection"],

Cell[TextData[{
  "Bei der Extrapolation wird ein gemessener Zusammenhang ",
  StyleBox["f\[UDoubleDot]r einen Me\[SZ]bereich erweitert",
    FontSlant->"Italic"],
  ", der nicht explizit gemessen wurde."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Eindeutigkeit"
}], "Subsubsection"],

Cell[TextData[{
  "Die Interpolation gelingt im Rahmen gewisser Voraussetzungen recht \
eindeutig, also ",
  StyleBox["unabh\[ADoubleDot]ngig von der zugrundegelegten Auswertetheorie",
    FontSlant->"Italic"],
  ", w\[ADoubleDot]hrend Extrapolationen nie eindeutig sind und oft genug \
eine systematische Fehlerquelle darstellen."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Einstieg"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Einfachste Interpolation"
}], "Subsubsection"],

Cell["\<\
Der einfachste Fall der Interpolation ist die Interpolation \
zwischen zwei Me\[SZ]werten. Zwei Me\[SZ]werte (jeweils mit Abszisse und \
Ordinate) sind mindestens n\[ODoubleDot]tig, um in dem sich ergebenden \
Zwischenbereich der Abszissen interpolieren zu k\[ODoubleDot]nnen.\
\>", 
  "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Problem"
}], "Subsubsection"],

Cell[TextData[{
  "Die Abbildung ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  " zweier Me\[SZ]punkte lautet allgemein:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[f]\), 
    \(f[a] = A\), 
    \(f[b] = B\)}], "Input"],

Cell[BoxData[
    \(A\)], "Output"],

Cell[BoxData[
    \(B\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Gesucht ist eine Interpolation ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  " (Zwischenwertbildung) in analytischer Form. Eine ",
  Cell[BoxData[
      \(TraditionalForm\`If[\ ]\)]],
  "-Programmierung ist nicht allgemein genug, da unendlich viele verschiedene \
Zwischenwerte ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " vorkommen k\[ODoubleDot]nnen und sollen."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". L\[ODoubleDot]sungsidee"
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["Allgemeine",
    FontSlant->"Italic"],
  " ",
  StyleBox["Gleitschalter",
    FontSlant->"Italic"],
  "-Funktion (auch beim Programmieren verwendbar):"
}], "Text"],

Cell[BoxData[{
    \(Clear[f]\), 
    \(f[x_] := \((x - a)\)\/\(b - a\)\ B + \((x - b)\)\/\(a - b\)\ A\)}], 
  "Input"],

Cell["Diese Funktion ergibt:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[a], f[b], f[y]}\)], "Input"],

Cell[BoxData[
    \({A, B, 
      \(B\ \((\(-a\) + y)\)\)\/\(\(-a\) + b\) + 
        \(A\ \((\(-b\) + y)\)\)\/\(a - b\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Erweiterte ",
  "L\[ODoubleDot]sungsidee"
}], "Subsubsection"],

Cell["\<\
Nun l\[ADoubleDot]\[SZ]t sich ausnutzen, da\[SZ] die Zahl Null bei \
Potenzierung mit einer beliebigen positiven Zahl nicht ver\[ADoubleDot]ndert \
wird, die Zahl Eins ebenso:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({0\^n, 1\^n} /. n \[Rule] #&\)/@Range[20] // Union\)], "Input"],

Cell[BoxData[
    \({{0, 1}}\)], "Output"]
}, Open  ]],

Cell["\<\
Dadurch l\[ADoubleDot]\[SZ]t sich auch eine beliebige Potenzierung \
des Interpolationspolynoms mit einer positiven Zahl \
durchf\[UDoubleDot]hren:\
\>", "Text"],

Cell[BoxData[{
    \(Clear[f]\), 
    \(f[x_] := 
      \((\(x - a\)\/\(b - a\))\)\^m\ B + \((\(x - b\)\/\(a - b\))\)\^n\ A\)}],
   "Input"],

Cell[TextData[{
  "Diese Funktion ergibt f\[UDoubleDot]r positive ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[a], f[b], f[u]} /. {m \[Rule] 3, n \[Rule] \[Pi]}\)], "Input"],

Cell[BoxData[
    \({A, B, 
      \(B\ \((\(-a\) + u)\)\^3\)\/\((\(-a\) + b)\)\^3 + 
        A\ \((\(\(-b\) + u\)\/\(a - b\))\)\^\[Pi]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Interpolationsgerade kann also in der gew\[UDoubleDot]nschten Weise \
nach oben und unten ausgebeult werden, so wie es beim ",
  StyleBox["Raoultschen Gesetz",
    FontSlant->"Italic"],
  " (vgl. ",
  ButtonBox["[Mor1987]",
    ButtonData:>"[Mor1987]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 12.7, Seite 195-197) in der Chemie durch die Messung einer \
Eigenschaft, etwa des Schmelzpunktes bei der Mischung zweier Stoffe, z.B. der \
Legierung zweier Metalle, notwendig wird:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \($DefaultFont = {"\<Times\>", 12.}; \n
    kurve[1] = 
      Plot[Evaluate[
          Table[f[x] /. {a \[Rule] 0, A \[Rule] 1, b \[Rule] 1, 
                B \[Rule] 0}, {n, 1\/3, 3, 1\/3}]], {x, 0, 1}, 
        PlotStyle \[Rule] Table[Hue[\(\[Mu] - 1\)\/9], {\[Mu], 9}], 
        PlotRange \[Rule] All, 
        AxesLabel 
          \[Rule] {\*"\"\<\!\(x\/\([\\\ ]\)\)\>\"", 
            \*"\"\<\!\(f[x]\/\([\\\ ]\)\)\>\""}, 
        DisplayFunction \[Rule] Identity]; \n
    punkte[1] = 
      ListPlot[{{0, 1}, {1, 0}}, PlotStyle \[Rule] {PointSize[0.02], Hue[0]}, 
        DisplayFunction \[Rule] Identity]; \n
    Show[kurve[1], punkte[1], DisplayFunction \[Rule] $DisplayFunction]; \)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.21429 .00222 -9.5 -15 ]
[.21429 .00222 9.5 0 ]
[.40476 .00222 -9.5 -15 ]
[.40476 .00222 9.5 0 ]
[.59524 .00222 -9.5 -15 ]
[.59524 .00222 9.5 0 ]
[.78571 .00222 -9.5 -15 ]
[.78571 .00222 9.5 0 ]
[.97619 .00222 -5 -15 ]
[.97619 .00222 5 0 ]
[1.025 .01472 0 -13.5 ]
[1.025 .01472 19 13.5 ]
[.01131 .13244 -19 -7.5 ]
[.01131 .13244 0 7.5 ]
[.01131 .25016 -19 -7.5 ]
[.01131 .25016 0 7.5 ]
[.01131 .36788 -19 -7.5 ]
[.01131 .36788 0 7.5 ]
[.01131 .4856 -19 -7.5 ]
[.01131 .4856 0 7.5 ]
[.01131 .60332 -10 -7.5 ]
[.01131 .60332 0 7.5 ]
[.02381 .64303 -15 0 ]
[.02381 .64303 15 30 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -17.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 35 translate 1 -1 scale
63.000000 18.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
66.937500 10.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
0.687500 setlinewidth
0.000000 0.000000 0.000000 setrgbcolor
64.312500 15.187500 moveto
9.875000 0.000000 rlineto
stroke
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
66.062500 27.312500 moveto
(@) show
70.000000 27.312500 moveto
(D) show
77.062500 18.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.02381 .13244 m
.03006 .13244 L
s
gsave
.01131 .13244 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .25016 m
.03006 .25016 L
s
gsave
.01131 .25016 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .36788 m
.03006 .36788 L
s
gsave
.01131 .36788 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .4856 m
.03006 .4856 L
s
gsave
.01131 .4856 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -71 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -76 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 38 translate 1 -1 scale
63.000000 21.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
66.062500 13.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
71.187500 13.375000 moveto
(@) show
75.125000 13.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
81.250000 13.375000 moveto
(D) show
0.687500 setlinewidth
0.000000 0.000000 0.000000 setrgbcolor
64.312500 18.187500 moveto
21.125000 0.000000 rlineto
stroke
71.687500 30.312500 moveto
(@) show
75.625000 30.312500 moveto
(D) show
88.312500 21.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
1 0 0 r
.5 Mabswid
.02381 .60332 m
.06244 .59525 L
.10458 .58619 L
.14415 .5774 L
.18221 .56869 L
.22272 .5591 L
.26171 .54955 L
.30316 .539 L
.34309 .52842 L
.3815 .51781 L
.42237 .50601 L
.46172 .49409 L
.49955 .48204 L
.53984 .46848 L
.57861 .45462 L
.61984 .43886 L
.65954 .42248 L
.69774 .40538 L
.73838 .38536 L
.77751 .3638 L
.81909 .33752 L
.85916 .30734 L
.89771 .27085 L
.91765 .24701 L
.92782 .2327 L
.93871 .21492 L
.94885 .19494 L
.9581 .17178 L
.96255 .15767 L
.96489 .14895 L
.96739 .13824 L
.96956 .1271 L
.97072 .12016 L
.97196 .11147 L
.9731 .10187 L
.97414 .09069 L
.97514 .07553 L
.97619 .01676 L
s
1 .667 0 r
.02381 .60332 m
.06244 .58729 L
.10458 .56955 L
.14415 .55263 L
.18221 .5361 L
.22272 .51821 L
.26171 .50069 L
.30316 .48171 L
.34309 .46305 L
.3815 .44472 L
.42237 .42479 L
.46172 .40513 L
.49955 .38574 L
.53984 .36453 L
.57861 .34349 L
.61984 .32035 L
.65954 .2972 L
.69774 .274 L
.73838 .24811 L
.77751 .22175 L
.81909 .19175 L
.85916 .1602 L
.89771 .12617 L
.91726 .1068 L
.93871 .08281 L
.94807 .07095 L
.9581 .05662 L
.96296 .04874 L
.96756 .0403 L
.97169 .03128 L
.97283 .02837 L
.97403 .02488 L
.97506 .02133 L
.97619 .01472 L
s
.667 1 0 r
.02381 .60332 m
.06244 .57944 L
.10458 .5534 L
.14415 .52894 L
.18221 .50542 L
.22272 .48039 L
.26171 .45629 L
.30316 .43067 L
.34309 .406 L
.3815 .38225 L
.42237 .357 L
.46172 .33268 L
.49955 .30929 L
.53984 .2844 L
.57861 .26043 L
.61984 .23495 L
.65954 .21041 L
.69774 .18681 L
.73838 .16169 L
.77751 .13751 L
.81909 .11181 L
.85916 .08704 L
.89771 .06322 L
.93871 .03788 L
.97619 .01472 L
s
0 1 0 r
.02381 .60332 m
.06244 .5717 L
.10458 .53772 L
.14415 .5063 L
.18221 .47655 L
.22272 .44541 L
.26171 .41595 L
.30316 .38522 L
.34309 .3562 L
.3815 .32886 L
.42237 .30041 L
.46172 .27367 L
.49955 .2486 L
.53984 .22262 L
.57861 .19836 L
.61984 .17342 L
.65954 .15029 L
.69774 .12894 L
.73838 .10727 L
.77751 .08754 L
.81909 .06796 L
.85916 .05067 L
.89771 .03582 L
.91726 .02912 L
.93871 .02259 L
.94807 .02009 L
.9581 .0177 L
.96296 .01668 L
.96756 .01583 L
.97169 .01518 L
.97283 .01503 L
.97403 .01489 L
.97506 .01479 L
.97619 .01472 L
s
0 1 .667 r
.02381 .60332 m
.06244 .56406 L
.10458 .5225 L
.14415 .48466 L
.18221 .44938 L
.22272 .41305 L
.26171 .37929 L
.30316 .34473 L
.34309 .31275 L
.3815 .28322 L
.42237 .25318 L
.46172 .22562 L
.49955 .2004 L
.53984 .17499 L
.57861 .15196 L
.61984 .12908 L
.65954 .10864 L
.69774 .09053 L
.73838 .07299 L
.77751 .05791 L
.81909 .04392 L
.85916 .03259 L
.89771 .0239 L
.91765 .02035 L
.92782 .01882 L
.93871 .01739 L
.94885 .0163 L
.9581 .01551 L
.96255 .01521 L
.96489 .01508 L
.96739 .01495 L
.96956 .01486 L
.97072 .01482 L
.97196 .01479 L
.9731 .01476 L
.97414 .01474 L
.97514 .01472 L
.97619 .01472 L
s
0 .667 1 r
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 1 r
.02381 .60332 m
.06244 .5491 L
.10458 .49336 L
.14415 .44419 L
.18221 .39974 L
.22272 .35546 L
.26171 .31572 L
.30316 .27655 L
.34309 .24172 L
.3815 .21088 L
.42237 .18085 L
.46172 .1546 L
.49955 .13177 L
.53984 .10997 L
.57861 .09138 L
.61984 .0741 L
.65954 .05979 L
.69774 .04811 L
.73838 .03782 L
.77751 .02991 L
.81909 .0235 L
.83996 .02101 L
.85916 .01913 L
.8791 .01757 L
.89771 .01645 L
.91654 .01563 L
.92651 .01531 L
.9372 .01506 L
.94679 .01489 L
.95221 .01482 L
.95722 .01478 L
.96159 .01475 L
.96408 .01474 L
.96642 .01473 L
.96761 .01473 L
.96887 .01472 L
.96996 .01472 L
.97112 .01472 L
.97238 .01472 L
.97354 .01472 L
.97426 .01472 L
.97493 .01472 L
.97619 .01472 L
s
.667 0 1 r
.02381 .60332 m
.06244 .54178 L
.10458 .47943 L
.14415 .42528 L
.18221 .37709 L
.22272 .32986 L
.26171 .28822 L
.30316 .24793 L
.34309 .21284 L
.3815 .18238 L
.42237 .15339 L
.46172 .12864 L
.49955 .10765 L
.53984 .08815 L
.57861 .07201 L
.61984 .05751 L
.65954 .04594 L
.69774 .03688 L
.73838 .02927 L
.77751 .02373 L
.79749 .02151 L
.81909 .01953 L
.83819 .01812 L
.85916 .01691 L
.8791 .01605 L
.88999 .01569 L
.90016 .01541 L
.91062 .01518 L
.92052 .01502 L
.9294 .01491 L
.93439 .01486 L
.93907 .01482 L
.94354 .01479 L
.94763 .01477 L
.95217 .01475 L
.95471 .01474 L
.95707 .01473 L
.9594 .01473 L
.96152 .01472 L
.96387 .01472 L
.96518 .01472 L
.96638 .01472 L
.96754 .01472 L
.9688 .01472 L
.97008 .01472 L
.97078 .01472 L
.97143 .01472 L
.97263 .01472 L
.97372 .01472 L
.97499 .01472 L
Mistroke
.97619 .01472 L
Mfstroke
1 0 .667 r
.02381 .60332 m
.06244 .53455 L
.10458 .4659 L
.14415 .4072 L
.18221 .35577 L
.22272 .30619 L
.26171 .26324 L
.30316 .22245 L
.34309 .18762 L
.3815 .15802 L
.42237 .13046 L
.46172 .1075 L
.49955 .0885 L
.53984 .07133 L
.57861 .05754 L
.61984 .04555 L
.65954 .03635 L
.69774 .02943 L
.73838 .02388 L
.77751 .02006 L
.79892 .01851 L
.81909 .01736 L
.83917 .01647 L
.85765 .01585 L
.87647 .01539 L
.88716 .0152 L
.89713 .01505 L
.90758 .01494 L
.91748 .01485 L
.92637 .0148 L
.93139 .01478 L
.93604 .01476 L
.94067 .01475 L
.94567 .01473 L
.95038 .01473 L
.95471 .01472 L
.95719 .01472 L
.9595 .01472 L
.96203 .01472 L
.96345 .01472 L
.96474 .01472 L
.96601 .01472 L
.96735 .01472 L
.96805 .01472 L
.96882 .01472 L
.96953 .01472 L
.97018 .01472 L
.97145 .01472 L
.97216 .01472 L
.97283 .01472 L
Mistroke
.97401 .01472 L
.97531 .01472 L
.97619 .01472 L
Mfstroke
1 0 0 r
.02 w
.02381 .60332 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012QP00`40o`000?l0003ooooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
073oool400001?ooo`800002oooo1`0002Soool400001?ooo`800007oooo0P0002Soool400001?oo
o`800004oooo100002Woool400001?ooo`800004oooo100002koool60000BOooo`00Koooo`800002
oooo0P0000?oool200000oooo`L0000Voooo0P0000;oool200000oooo`800007oooo0P0002Ooool2
00000_ooo`800003oooo0P0000?oool200000_ooo`80000Woooo0P0000;oool200000oooo`800003
oooo0P0000?oool00`000?ooooooo`0]oooo0P0004_oool006ooool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000oooooooo00;oool00`000?ooooooo`0Toooo00<0003oooooool00_oo
o`030000oooooooo00[oool200009oooo`030000oooooooo00;oool00`000?ooooooo`05oooo0P00
00Coool200009_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo0P0000Coool20000;_oo
o`80000Goooo100000;oool40000:_ooo`00K_ooo`800004oooo0P0000Woool00`000?ooooooo`0W
oooo0P0000Coool200001_ooo`P0000Uoooo0P0000Coool200001_ooo`800004oooo0P0002Goool2
00001?ooo`800006oooo0P0000Coool20000;_ooo`80000Goooo00<0003oooooool01_ooo`030000
oooooooo02Soool006koool200001?ooo`80000:oooo00<0003oooooool09_ooo`800004oooo0P00
00Koool00`000?ooooooo`02oooo0P0002Koool200001?ooo`800006oooo0P0000Coool200009Ooo
o`800004oooo0P0000Ooool010000?ooooooooooo`80000_oooo0P0001Ooool00`000?ooooooo`06
oooo00<0003oooooool0:?ooo`00K_ooo`800004oooo0P0000[oool200009oooo`800004oooo0P00
00Ooool010000?ooooooooooo`80000Voooo0P0000Coool200001_ooo`800004oooo0P0002Goool2
00001?ooo`800008oooo1000033oool200005oooo`030000oooooooo00Koool00`000?ooooooo`0X
oooo001^oooo0P0000Coool200002oooo`030000oooooooo02Goool200001?ooo`800008oooo00<0
003oooooool00P0002Koool200001?ooo`800006oooo0`0000;oool200009_ooo`800004oooo0P00
00Soool30000<Oooo`80000Goooo00<0003oooooool01_ooo`030000oooooooo02Soool006koool2
00001?ooo`80000;oooo0P0002Koool200001?ooo`800008oooo00<0003oooooool00P0002Koool2
00001?ooo`800007oooo00<0003oool000000P0002Ooool200001?ooo`800007oooo0P0000;oool2
0000;oooo`80000Goooo00<0003oooooool01_ooo`030000oooooooo02Soool006koool200001?oo
o`80000;oooo0P0002Koool200001?ooo`800009oooo00@0003oool00000000Voooo0P0000Coool2
00001oooo`80000Zoooo0P0000Coool200001_ooo`800004oooo0P0002koool200005oooo`030000
oooooooo00Koool00`000?ooooooo`0Xoooo001_oooo00<0003oooooool00_ooo`030000oooooooo
00Goool00`000?ooooooo`02oooo0P0002Ooool00`000?ooooooo`02oooo00<0003oooooool02Ooo
o`<0000Woooo00<0003oooooool00_ooo`030000oooooooo00Ooool20000:_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo0P0000Coool20000;_ooo`80000Goooo00<0003oooooool01_oo
o`030000oooooooo02Soool006ooool200000_ooo`800008oooo00<0003oooooool00`0002Ooool2
00000_ooo`80000<oooo0P0002Ooool200000_ooo`80000:oooo0`0002Soool200000_ooo`800008
oooo0P0000?oool00`000?ooooooo`0[oooo100001Ooool00`000?ooooooo`06oooo00<0003ooooo
ool0:?ooo`00L?ooo`@0000:oooo100002Woool400003Oooo`80000Xoooo100000goool300009ooo
o`@0000:oooo1000033oool200005oooo`030000oooooooo00Koool00`000?ooooooo`0Xoooo003o
ooooOOooo`030000oooooooo00Koool00`000?ooooooo`0Xoooo003oooooOOooo`030000oooooooo
00Koool00`000?ooooooo`0Xoooo000noooo00<0003oooooool0oooooccoool00`000?ooooooo`06
oooo00<0003oooooool0:?ooo`00?_ooo`030000oooooooo0?oooolloooo00<0003oooooool01_oo
o`030000oooooooo02Soool003koool00`000?ooooooo`3ooooo??ooo`@00002oooo100002[oool0
03koool00`000?ooooooo`3oooooL?ooo`00?_ooo`030000oooooooo0?oooolRoooo1Ol004Woool0
03Oooooo00001`0002Go0:X5o`001P0004?oool003koool00`000?ooooooo`0<oooo00<0003ooooo
ool02oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00_oool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0;oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool02oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003o0:[o
0:X04?l0ZPNZ0?l;003o1P2Zo`H0ojX3oooo103o00Go0019oooo000noooo00<0003oooooool0>?oo
o`030000oooooooo03Soool00`000?ooooooo`0hoooo00<0003oooooool0;oooo`[o0:X6ZP3o1ooo
o`H00?l6oooo1@2Zo`Ooool50?nZ0oooo`H0o`03oooo00>Zo`3o003o00000ol004Woool003koool0
0`000?ooooooo`3Goooo2Ol0ZPVZ0?l7oooo1`00o`Koool60:[o1oooo`D0ojX5oooo0`3o00Soool0
0j[o0?ooooooo`03o`004ooooa00000Woooo000noooo00<0003oooooool0dOooo`Ko0:X00oooojX0
ojX0o`06ZP3o2_ooo`H00?l7oooo1P2Zo`Woool40?nZ1oooo`<0o`09oooo0Z[o00Coool00onZ0?l0
0?ooo`19oooo000noooo00<0003oooooool0boooo`Ko0:X3oooo1:X0o`_oool7003o1oooo`H0Z_l;
oooo103oZPWoool20?l02_ooo`:Zo`05oooo00?oZP3ooooo0000B_ooo`00?_ooo`030000oooooooo
0<Goool6o`2Z1Oooo`BZ0?l9oooo1P00o`[oool40:[o3Oooo`@0ojX;oooo0P3o00[oool2Z_l01ooo
o`03ojX0ooooo`0004[oool003koool00`000?ooooooo`30oooo1Ol0ZPOoool4ZP3o2?ooo`D00?l<
oooo102Zo`goool40?nZ3?ooo`<0o`0;oooo00>Zo`3oooooool01_ooo`04ojX0ooooooooo`00B_oo
o`00?_ooo`030000oooooooo0;coool4o`2Z2?ooo`BZ0?l8oooo1000o`coool50:[o3Oooo`@0ojX=
oooo0`3o00coool2Z_l02Oooo`04ojX0ooooooooo`00B_ooo`00?_ooo`80002ioooo1?l0ZPSoool4
ZP3o2?ooo`@00?l<oooo102Zo`koool40?nZ3oooo`80o`0=oooo0Z[o00_oool01?nZ0?ooooooool0
04[oool003koool00`000?ooooooo`2coooo1Ol0ZPSoool4ZP3o2Oooo`<00?l<oooo102Zo`ooool3
0?nZ4?ooo`<0o`0>oooo00>Zo`3oooooool02_ooo`05ojX0ooooooooooooo`0004[oool003koool0
0`000?ooooooo`2_oooo1?l0ZPWoool4ZP3o2_ooo`<00?l<oooo0`2Zo`ooool40?nZ4?ooo`<0o`0?
oooo0Z[o00goool01?nZ0?ooooooool004_oool003koool00`000?ooooooo`2[oooo1?l0ZPWoool4
ZP3o2oooo`<00?l=oooo0P2Zo`ooool30?nZ4_ooo`80o`0Aoooo00>Zo`3oooooool03?ooo`05ojX0
ooooooooooooo`0001Soool3000000?oool0000000000P0002_oool003koool00`000?ooooooo`2X
oooo0ol0ZPWoool4ZP3o3?ooo`<00?l>oooo0P2Zo`koool30?nZ4_ooo`<0o`0Aoooo0Z[o00koool0
0onZ0?ooooooo`02oooo00?o003oooooool05oooo`040000oooooooooooo0P0002coool003koool0
0`000?ooooooo`2Voooo0_l0ZP[oool2ZP3o3Oooo`<00?l>oooo0`2Zo`koool20?nZ4_ooo`<0o`0B
oooo0Z[o00ooool00onZ0?ooooooo`03oooo00?o003oooooool06?ooo`040000oooo00000000;Ooo
o`00?_ooo`030000oooooooo0:Coool2o`2Z2_ooo`:Z0?l<oooo0`00o`ooool20:[o3oooo`80ojXB
oooo0P3o01Coool00j[o0?ooooooo`0?oooo00?oZP3oooooool00oooo`03o`00oooooooo01Woool2
0000;_ooo`00?_ooo`030000oooooooo0:7oool3o`2Z2Oooo`>Z0?l:oooo1000o`ooool30:[o3_oo
o`<0ojXBoooo0P3o01Coool2Z_l04Oooo`03ojX0oooooooo00Coool00ol00?ooooooo`0Ioooo0P00
02koool003koool00`000?ooooooo`2Ooooo0_l0ZP[oool2ZP3o2_ooo`<00?l@oooo0`2Zo`ooool2
0?nZ4oooo`80o`0Eoooo00>Zo`3oooooool04?ooo`03ojX0oooooooo00Goool00ol00?ooooooo`0H
oooo0`0002koool003koool20000WOooo`?o0:X9oooo0jX0o`Woool3003o4?ooo`<0Z_l?oooo0`3o
ZQ?oool20?l05Oooo`:Zo`0Boooo00?oZP3oooooool01_ooo`03o`00oooooooo01Ooool200000_oo
o`030000oooooooo02_oool003koool00`000?ooooooo`2Joooo0_l0ZP[oool2ZP3o2_ooo`800?l@
oooo0`2Zoa3oool20?nZ5?ooo`80o`0Eoooo0Z[o01Coool00onZ0?ooooooo`06oooo00?o003ooooo
ool05_ooo`@000001?ooo`000000000002_oool003koool00`000?ooooooo`2Goooo0ol0ZP[oool2
ZP3o2_ooo`800?l?oooo0`2Zoa7oool20?nZ5?ooo`80o`0Foooo00>Zo`3oooooool04oooo`03ojX0
oooooooo00Ooool00ol00?ooooooo`19oooo000noooo00<0003oooooool0U?ooo`?o0:X:oooo0jX0
o`[oool2003o3oooo`80Z_lAoooo0`3oZQCoool20?l05_ooo`:Zo`0Eoooo00?oZP3oooooool02?oo
o`03o`00oooooooo04Woool003koool00`000?ooooooo`2Boooo0_l0ZP_oool2ZP3o2oooo`800?l?
oooo0P2Zoa7oool20?nZ5Oooo`80o`0Goooo00>Zo`3oooooool05?ooo`03ojX0oooooooo00Woool0
0ol00?ooooooo`19oooo000noooo00<0003oooooool0T?ooo`;o0:X:oooo0jX0o`_oool2003o3ooo
o`80Z_l@oooo0`3oZQGoool20?l05oooo`:Zo`0Foooo00?oZP3oooooool02_ooo`03o`00oooooooo
04Woool003koool00`000?ooooooo`2>oooo0_l0ZP[oool2ZP3o3?ooo`800?l?oooo0P2Zoa3oool2
0?nZ5_ooo`80o`0Goooo0Z[o01Ooool00onZ0?ooooooo`0;oooo00?o003oooooool0BOooo`00?_oo
o`030000oooooooo08coool2o`2Z2_ooo`:Z0?l<oooo0P00o`ooool20:[o4?ooo`80ojXFoooo0P3o
01Soool00j[o0?ooooooo`0Goooo00?oZP3oooooool02oooo`03o`00oooooooo04Woool003koool0
0`000?ooooooo`2:oooo0_l0ZP[oool2ZP3o3?ooo`800?l>oooo0`2Zoa3oool20?nZ5_ooo`80o`0H
oooo0Z[o01Woool00onZ0?ooooooo`0<oooo00?o003oooooool0BOooo`00?_ooo`800029oooo0_l0
ZP[oool2ZP3o2oooo`<00?l>oooo0P2Zoa7oool20?nZ5_ooo`80o`0Ioooo00>Zo`3oooooool06?oo
o`03ojX0oooooooo00goool00ol00?ooooooo`19oooo000noooo00<0003oooooool0Q_ooo`;o0:X:
oooo0ZX0o`_oool2003o3oooo`80Z_lAoooo0P3oZQKoool20?l06Oooo`:Zo`0Joooo00?oZP3ooooo
ool03_ooo`03o`00oooooooo04Woool003koool00`000?ooooooo`25oooo00?o0:[oooooool02?oo
o`:Z0?l;oooo0P00o`ooool20:[o4Oooo`80ojXFoooo0P3o01Woool2Z_l06oooo`03ojX0oooooooo
00koool00ol00?ooooooo`1:oooo000noooo00<0003oooooool0Poooo`;o0:X9oooo0ZX0o`_oool2
003o3oooo`80Z_lAoooo0P3oZQKoool20?l06_ooo`03Z_l0oooooooo01[oool00onZ0?ooooooo`0?
oooo00?o003oooooool0B_ooo`00?_ooo`030000oooooooo087oool2o`2Z2Oooo`:Z0?l;oooo0P00
o`ooool20:[o4Oooo`80ojXFoooo0P3o01[oool2Z_l06oooo`;oZP0Boooo00?o003oooooool0B_oo
o`00?_ooo`030000oooooooo07ooool2o`2Z2Oooo`:Z0?l;oooo0P00o`ooool20:[o4Oooo`80ojXF
oooo0P3o01[oool2Z_l07?ooo`03ojX0oooooooo01;oool00ol00?ooooooo`1:oooo000Soooo1000
00Coool200000_ooo`L00008oooo00<0003oooooool0OOooo`;o0:X9oooo0ZX0o`_oool2003o3ooo
o`80Z_lAoooo0P3oZQKoool20?l06oooo`03Z_l0oooooooo01_oool00onZ0?ooooooo`0Coooo00?o
003oooooool0B_ooo`008_ooo`800002oooo0P0000?oool200000oooo`L00007oooo00<0003ooooo
ool0Noooo`;o0:X9oooo0ZX0o`_oool2003o3oooo`80Z_lAoooo0P3oZQKoool20?l06oooo`:Zo`0M
oooo00?oZP3oooooool05?ooo`03o`00oooooooo04[oool002;oool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool0NOoo
o`;o0:X:oooo00>Z0?ooooooool02Oooo`800?l?oooo0P2Zoa7oool20?nZ5oooo`030?l0oooooooo
01[oool00j[o0?ooooooo`0Loooo00?oZP3oooooool05Oooo`03o`00oooooooo04[oool0027oool2
00001?ooo`800009oooo00<0003oooooool02Oooo`<0001hoooo00?o0:[oooooool02?ooo`:Z0?l;
oooo00<00?ooooooool03Oooo`80Z_lAoooo0P3oZQOoool20?l06oooo`:Zo`0Noooo00?oZP3ooooo
ool05_ooo`03o`00oooooooo04[oool0027oool200001?ooo`80000:oooo00<0003oooooool02?oo
o`030000oooooooo07Koool2o`2Z2Oooo`:Z0?l;oooo0P00o`koool20:[o4Oooo`80ojXGoooo0P3o
01_oool2Z_l07oooo`03ojX0oooooooo01Koool00ol00?ooooooo`1;oooo000Qoooo0P0000Coool2
00002_ooo`800009oooo00<0003oooooool0MOooo`03o`2Zoooooooo00Soool00jX0ooooooooo`0:
oooo00<00?ooooooool03Oooo`030:[ooooooooo013oool00`3oZ_ooooooo`0Foooo00<0o`3ooooo
ool06_ooo`03Z_l0oooooooo01koool00onZ0?ooooooo`0Goooo00?o003oooooool0Boooo`008Ooo
o`800004oooo0P0000_oool00`000?ooooooo`07oooo00<0003oooooool0Loooo`;o0:X9oooo0ZX0
o`_oool2003o3_ooo`80Z_lAoooo0P3oZQOoool20?l06oooo`:Zo`0Poooo00?oZP3oooooool06?oo
o`03o`00oooooooo04_oool0027oool200001?ooo`80000;oooo0P0000Soool00`000?ooooooo`1b
oooo00?o0:[oooooool02?ooo`03ZP3ooooooooo00Woool2003o3_ooo`80Z_lAoooo0P3oZQOoool2
0?l06oooo`:Zo`0Qoooo00?oZP3oooooool06Oooo`03o`00oooooooo04_oool0027oool200001?oo
o`80000;oooo0P0000Soool00`000?ooooooo`1`oooo0_l0ZPWoool2ZP3o2oooo`03003ooooooooo
00goool00`2Zooooooooo`0?oooo0P3oZQOoool20?l07?ooo`03Z_l0oooooooo023oool00onZ0?oo
ooooo`0Ioooo00?o003oooooool0C?ooo`008_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`800008oooo00<0003oooooool0Koooo`03o`2Zoooooooo00Ooool2
ZP3o2oooo`800?l>oooo0P2Zoa7oool00`3oZ_ooooooo`0Foooo00<0o`3oooooool06_ooo`:Zo`0R
oooo00?oZP3oooooool06_ooo`03o`00oooooooo04coool002;oool200000_ooo`800008oooo00<0
003oooooool00`0000Soool00`000?ooooooo`1]oooo0_l0ZPWoool00jX0ooooooooo`0:oooo00<0
0?ooooooool03Oooo`030:[ooooooooo00ooool20?nZ5oooo`80o`0Koooo0Z[o02?oool00onZ0?oo
ooooo`0Koooo00?o003oooooool0C?ooo`008oooo`@0000:oooo100000Woool00`000?ooooooo`1/
oooo00?o0:[oooooool02?ooo`03ZP3ooooooooo00Woool2003o3_ooo`80Z_lAoooo00<0oj[ooooo
ool05Oooo`80o`0Koooo0Z[o02Coool00onZ0?ooooooo`0Loooo00?o003oooooool0C?ooo`00?_oo
o`030000oooooooo06_oool00ol0Z_ooooooo`07oooo0ZX0o`[oool2003o3_ooo`80Z_lAoooo0P3o
ZQKoool20?l07?ooo`03Z_l0oooooooo02?oool00onZ0?ooooooo`0Moooo00?o003oooooool0C?oo
o`00?_ooo`80001[oooo00?o0:[oooooool01oooo`03ZP3ooooooooo00Woool00`00ooooooooo`0=
oooo00<0Z_ooooooool04?ooo`030?nZoooooooo01Coool20?l07?ooo`:Zo`0Uoooo00?oZP3ooooo
ool07Oooo`03o`00oooooooo04goool003koool00`000?ooooooo`1Xoooo0_l0ZPWoool00jX0oooo
ooooo`08oooo0P00o`koool20:[o4Oooo`80ojXEoooo0P3o01goool00j[o0?ooooooo`0Soooo0_nZ
023oool00ol00?ooooooo`1=oooo000noooo00<0003oooooool0Ioooo`03o`2Zoooooooo00Ooool2
ZP3o2_ooo`03003ooooooooo00goool00`2Zooooooooo`0@oooo00<0oj[oooooool04oooo`80o`0M
oooo0Z[o02Goool00onZ0?ooooooo`0Ooooo00?o003oooooool0C_ooo`00?_ooo`030000oooooooo
06Koool00ol0Z_ooooooo`07oooo00>Z0?ooooooool02?ooo`800?l>oooo0P2Zoa7oool20?nZ5Ooo
o`030?l0oooooooo01coool00j[o0?ooooooo`0Toooo00?oZP3oooooool08?ooo`03o`00oooooooo
04koool003koool00`000?ooooooo`1Uoooo00?o0:[oooooool01oooo`03ZP3ooooooooo00Ooool2
003o3_ooo`80Z_lBoooo00<0oj[oooooool04oooo`80o`0Moooo0Z[o02Goool2ojX08oooo`03o`00
oooooooo04koool003koool00`000?ooooooo`1Toooo00?o0:[oooooool01_ooo`:Z0?l9oooo00<0
0?ooooooool03Oooo`030:[ooooooooo013oool20?nZ5Oooo`030?l0oooooooo01coool00j[o0?oo
ooooo`0Toooo00?oZP3oooooool08_ooo`03o`00oooooooo04ooool003koool00`000?ooooooo`1R
oooo0_l0ZPSoool00jX0ooooooooo`08oooo00<00?ooooooool03?ooo`80Z_lAoooo0P3oZQGoool2
0?l07Oooo`:Zo`0Voooo00?oZP3oooooool08oooo`03o`00oooooooo04ooool003koool00`000?oo
ooooo`1Qoooo00?o0:[oooooool01oooo`03ZP3ooooooooo00Soool00`00ooooooooo`0<oooo00<0
Z_ooooooool03oooo`80ojXFoooo00<0o`3oooooool07?ooo`03Z_l0oooooooo02Coool2ojX09Ooo
o`03o`00oooooooo053oool003koool00`000?ooooooo`1Poooo00?o0:[oooooool01_ooo`:Z0?l9
oooo0P00o`goool20:[o4?ooo`80ojXFoooo0P3o01goool2Z_l09_ooo`03ojX0oooooooo02Goool0
0ol00?ooooooo`1@oooo000noooo0P00063oool00ol0Z_ooooooo`06oooo00>Z0?ooooooool02?oo
o`03003ooooooooo00coool00`2Zooooooooo`0>oooo0P3oZQOoool00`3o0?ooooooo`0Loooo00>Z
o`3oooooool09Oooo`03ojX0oooooooo02Goool00ol00?ooooooo`1Aoooo000noooo00<0003ooooo
ool0GOooo`;o0:X8oooo00>Z0?ooooooool02?ooo`03003ooooooooo00_oool20:[o3oooo`80ojXG
oooo0P3o01goool2Z_l09_ooo`;oZP0Xoooo00?o003oooooool0DOooo`00?_ooo`030000oooooooo
05coool00ol0Z_ooooooo`06oooo0ZX0o`[oool00`00ooooooooo`0;oooo00<0Z_ooooooool03_oo
o`030?nZoooooooo01Koool00`3o0?ooooooo`0Loooo00>Zo`3oooooool09Oooo`03ojX0oooooooo
02Soool00ol00?ooooooo`1Aoooo000noooo00<0003oooooool0Foooo`03o`2Zoooooooo00Koool0
0jX0ooooooooo`09oooo00<00?ooooooool02oooo`030:[ooooooooo00goool20?nZ5oooo`80o`0M
oooo0Z[o02Koool2ojX0:_ooo`03o`00oooooooo05;oool003koool00`000?ooooooo`1Ioooo0_l0
ZPSoool00jX0ooooooooo`08oooo0P00o`coool20:[o3oooo`030?nZoooooooo01Goool20?l07_oo
o`03Z_l0oooooooo02Goool00onZ0?ooooooo`0Zoooo00?o003oooooool0D_ooo`00?_ooo`030000
oooooooo05Soool00ol0Z_ooooooo`06oooo0ZX0o`[oool00`00ooooooooo`0;oooo00<0Z_oooooo
ool03_ooo`030?nZoooooooo01Goool00`3o0?ooooooo`0Loooo0Z[o02Ooool00onZ0?ooooooo`0Z
oooo00?o003oooooool0Doooo`00?_ooo`030000oooooooo05Ooool00ol0Z_ooooooo`06oooo00>Z
0?ooooooool02Oooo`03003ooooooooo00[oool20:[o3oooo`80ojXFoooo0P3o01koool00j[o0?oo
ooooo`0Uoooo0_nZ02goool00ol00?ooooooo`1Coooo000noooo00<0003oooooool0EOooo`;o0:X8
oooo00>Z0?ooooooool02Oooo`03003ooooooooo00[oool00`2Zooooooooo`0>oooo00<0oj[ooooo
ool05?ooo`80o`0Noooo0Z[o02Ooool00onZ0?ooooooo`0/oooo00?o003oooooool0E?ooo`00?_oo
o`030000oooooooo05Coool00ol0Z_ooooooo`07oooo00>Z0?ooooooool02?ooo`800?l<oooo00<0
Z_ooooooool03_ooo`030?nZoooooooo01?oool20?l07_ooo`:Zo`0Woooo0_nZ02koool00ol00?oo
ooooo`1Eoooo000noooo0P0005Coool00ol0Z_ooooooo`06oooo0ZX0o`[oool00`00ooooooooo`0:
oooo0P2Zo`ooool20?nZ5Oooo`030?l0oooooooo01coool2Z_l0:?ooo`03ojX0oooooooo02koool0
0ol00?ooooooo`1Eoooo000noooo00<0003oooooool0D_ooo`03o`2Zoooooooo00Koool00jX0oooo
ooooo`09oooo00<00?ooooooool02_ooo`030:[ooooooooo00koool00`3oZ_ooooooo`0Coooo0P3o
01goool2Z_l0:?ooo`;oZP0`oooo00?o003oooooool0E_ooo`00?_ooo`030000oooooooo057oool0
0ol0Z_ooooooo`06oooo00>Z0?ooooooool02?ooo`800?l<oooo00<0Z_ooooooool03Oooo`80ojXD
oooo0P3o01goool2Z_l0:Oooo`03ojX0oooooooo033oool00ol00?ooooooo`1Foooo000noooo00<0
003oooooool0D?ooo`03o`2Zoooooooo00Koool00jX0ooooooooo`08oooo00<00?ooooooool02_oo
o`80Z_l?oooo00<0oj[oooooool04oooo`030?l0oooooooo01_oool2Z_l0:Oooo`;oZP0boooo00?o
003oooooool0Eoooo`00?_ooo`030000oooooooo04ooool00ol0Z_ooooooo`06oooo00>Z0?oooooo
ool02?ooo`03003ooooooooo00[oool00`2Zooooooooo`0=oooo0P3oZQCoool20?l07Oooo`03Z_l0
oooooooo02Soool00onZ0?ooooooo`0aoooo00?o003oooooool0F?ooo`008oooo`@00004oooo0P00
00Ooool200002?ooo`030000oooooooo04koool00ol0Z_ooooooo`05oooo0ZX0o`Woool2003o3?oo
o`030:[ooooooooo00goool00`3oZ_ooooooo`0Coooo00<0o`3oooooool06oooo`:Zo`0Yoooo0_nZ
03Coool00ol00?ooooooo`1Hoooo000Roooo0P0000;oool200000oooo`800007oooo0P0000Soool0
0`000?ooooooo`1=oooo00?o0:[oooooool01Oooo`03ZP3ooooooooo00Soool00`00ooooooooo`0:
oooo0P2Zo`ooool00`3oZ_ooooooo`0Boooo0P3o01goool00j[o0?ooooooo`0Xoooo00?oZP3ooooo
ool0<oooo`03o`00oooooooo05Woool002;oool00`000?ooooooo`02oooo00<0003oooooool02_oo
o`800008oooo00<0003oooooool0COooo`03o`2Zoooooooo00Coool00jX0ooooooooo`08oooo00<0
0?ooooooool02_ooo`030:[ooooooooo00goool20?nZ4oooo`80o`0Moooo0Z[o02Woool2ojX0=_oo
o`03o`00oooooooo05Woool0027oool200001?ooo`800006oooo200000Ooool00`000?ooooooo`1<
oooo00?o0:[oooooool01?ooo`03ZP3ooooooooo00Soool00`00ooooooooo`0:oooo00<0Z_oooooo
ool03Oooo`030?nZoooooooo01;oool00`3o0?ooooooo`0Loooo00>Zo`3oooooool0:?ooo`03ojX0
oooooooo03Goool00ol00?ooooooo`1Joooo000Qoooo0P0000Coool200001_ooo`030000oooooooo
00;oool200002?ooo`<0001;oooo00?o0:[oooooool01?ooo`03ZP3ooooooooo00Ooool2003o3?oo
o`030:[ooooooooo00coool20?nZ4oooo`80o`0Moooo0Z[o02Woool2ojX0=oooo`03o`00oooooooo
05_oool0027oool200001?ooo`800007oooo00@0003oooooooooool200002?ooo`030000oooooooo
04[oool00ol0Z_ooooooo`04oooo00>Z0?ooooooool01oooo`03003ooooooooo00[oool20:[o3_oo
o`030?nZoooooooo01;oool00`3o0?ooooooo`0Loooo00>Zo`3oooooool0:?ooo`03ojX0oooooooo
03Koool00ol00?ooooooo`1Loooo000Qoooo0P0000Coool200002?ooo`030000oooooooo00800008
oooo00<0003oooooool0BOooo`03o`2Zoooooooo00Coool00jX0ooooooooo`07oooo00<00?oooooo
ool02_ooo`030:[ooooooooo00goool00`3oZ_ooooooo`0Boooo00<0o`3oooooool06oooo`:Zo`0Y
oooo0_nZ03Soool00ol00?ooooooo`1Moooo000Qoooo0P0000Coool200002?ooo`030000oooooooo
00800008oooo00<0003oooooool0B?ooo`03o`2Zoooooooo00Coool00jX0ooooooooo`07oooo00<0
0?ooooooool02_ooo`030:[ooooooooo00coool20?nZ4oooo`80o`0Moooo00>Zo`3oooooool0:?oo
o`03ojX0oooooooo03Ooool00ol00?ooooooo`1Noooo000Qoooo0P0000Coool200002Oooo`040000
oooo000000002?ooo`030000oooooooo04Ooool00ol0Z_ooooooo`04oooo00>Z0?ooooooool01ooo
o`03003ooooooooo00[oool00`2Zooooooooo`0<oooo00<0oj[oooooool04_ooo`030?l0oooooooo
01_oool2Z_l0:Oooo`;oZP0ioooo00?o003oooooool0Goooo`008_ooo`030000oooooooo00;oool0
0`000?ooooooo`09oooo0`0000Soool00`000?ooooooo`16oooo00?o0:[oooooool01?ooo`03ZP3o
oooooooo00Koool2003o3?ooo`030:[ooooooooo00coool00`3oZ_ooooooo`0Boooo00<0o`3ooooo
ool06_ooo`:Zo`0Zoooo00?oZP3oooooool0>?ooo`03o`00oooooooo063oool002;oool200000_oo
o`80000<oooo0P0000Soool00`000?ooooooo`15oooo00?o0:[oooooool01Oooo`03ZP3ooooooooo
00Goool00`00ooooooooo`0:oooo0P2Zo`goool20?nZ4oooo`80o`0Loooo00>Zo`3oooooool0:?oo
o`;oZP0joooo00?o003oooooool0HOooo`008oooo`@0000=oooo0P0000Soool00`000?ooooooo`14
oooo00?o0:[oooooool01Oooo`03ZP3ooooooooo00Goool00`00ooooooooo`0:oooo00<0Z_oooooo
ool03?ooo`030?nZoooooooo01;oool00`3o0?ooooooo`0Joooo0Z[o02[oool00onZ0?ooooooo`0i
oooo00?o003oooooool0H_ooo`00?_ooo`030000oooooooo04?oool00ol0Z_ooooooo`05oooo00>Z
0?ooooooool01Oooo`03003ooooooooo00[oool00`2Zooooooooo`0<oooo00<0oj[oooooool04Ooo
o`80o`0Koooo0Z[o02[oool2ojX0>oooo`03o`00oooooooo06?oool003koool20000@oooo`03o`2Z
oooooooo00Goool00jX0ooooooooo`05oooo00<00?ooooooool02_ooo`030:[ooooooooo00_oool2
0?nZ4_ooo`80o`0Koooo0Z[o02[oool2ojX0??ooo`03o`00oooooooo06Coool003koool00`000?oo
ooooo`11oooo00?o0:[oooooool01Oooo`03ZP3ooooooooo00Goool00`00ooooooooo`09oooo0P2Z
o`goool00`3oZ_ooooooo`0Aoooo00<0o`3oooooool06_ooo`03Z_l0oooooooo02Woool00onZ0?oo
ooooo`0koooo00?o003oooooool0IOooo`00?_ooo`030000oooooooo047oool00ol0Z_ooooooo`04
oooo00>Z0?ooooooool01Oooo`03003ooooooooo00Woool00`2Zooooooooo`0<oooo00<0oj[ooooo
ool04?ooo`80o`0Koooo0Z[o02[oool2ojX0?Oooo`03o`00oooooooo06Koool003koool00`000?oo
ooooo`10oooo00?o0:[oooooool01?ooo`03ZP3ooooooooo00Goool00`00ooooooooo`09oooo00<0
Z_ooooooool02oooo`80ojXBoooo00<0o`3oooooool06Oooo`:Zo`0Zoooo0_nZ03ooool00ol00?oo
ooooo`1Voooo000noooo00<0003oooooool0?oooo`03o`2Zoooooooo00Coool00jX0ooooooooo`05
oooo00<00?ooooooool02?ooo`80Z_l=oooo00<0oj[oooooool04?ooo`80o`0Koooo00>Zo`3ooooo
ool0:?ooo`;oZP10oooo00?o003oooooool0Ioooo`00?_ooo`030000oooooooo03koool00ol0Z_oo
ooooo`04oooo00>Z0?ooooooool01Oooo`03003ooooooooo00Soool00`2Zooooooooo`0<oooo00<0
oj[oooooool03oooo`80o`0Koooo0Z[o02[oool00onZ0?ooooooo`0ooooo00?o003oooooool0J?oo
o`00?_ooo`030000oooooooo03goool00ol0Z_ooooooo`04oooo00>Z0?ooooooool01Oooo`03003o
oooooooo00Soool00`2Zooooooooo`0;oooo0P3oZQ7oool00`3o0?ooooooo`0Joooo00>Zo`3ooooo
ool0:?ooo`;oZP11oooo00?o003oooooool0JOooo`00?_ooo`030000oooooooo03coool00ol0Z_oo
ooooo`04oooo00>Z0?ooooooool01Oooo`03003ooooooooo00Ooool20:[o3Oooo`030?nZoooooooo
013oool00`3o0?ooooooo`0Ioooo0Z[o02Woool2ojX0@_ooo`03o`00oooooooo06[oool003koool0
0`000?ooooooo`0koooo00?o0:[oooooool01?ooo`03ZP3ooooooooo00Goool00`00ooooooooo`07
oooo00<0Z_ooooooool03?ooo`030?nZoooooooo00ooool20?l06_ooo`:Zo`0Zoooo00?oZP3ooooo
ool0@Oooo`03o`00oooooooo06_oool003koool20000>oooo`03o`2Zoooooooo00Coool00jX0oooo
ooooo`05oooo00<00?ooooooool01oooo`030:[ooooooooo00_oool20?nZ4Oooo`030?l0oooooooo
01Woool00j[o0?ooooooo`0Xoooo0_nZ04?oool00ol00?ooooooo`1/oooo000noooo00<0003ooooo
ool0>Oooo`03o`2Zoooooooo00Goool00jX0ooooooooo`04oooo00<00?ooooooool01oooo`030:[o
oooooooo00_oool00`3oZ_ooooooo`0@oooo00<0o`3oooooool06?ooo`:Zo`0Zoooo00?oZP3ooooo
ool0@Oooo`;o001_oooo000noooo00<0003oooooool0>Oooo`03o`2Zoooooooo00Coool00jX0oooo
ooooo`04oooo00<00?ooooooool01oooo`030:[ooooooooo00_oool00`3oZ_ooooooo`0?oooo0P3o
01[oool00j[o0?ooooooo`0Xoooo0_nZ04?oool00ol00?ooooooo`1_oooo000noooo00<0003ooooo
ool0>?ooo`03o`2Zoooooooo00Coool00jX0ooooooooo`04oooo00<00?ooooooool01oooo`030:[o
oooooooo00[oool20?nZ4Oooo`030?l0oooooooo01Soool2Z_l0:Oooo`;oZP13oooo0_l007;oool0
03koool00`000?ooooooo`0goooo00?o0:[oooooool01?ooo`03ZP3ooooooooo00Coool00`00oooo
ooooo`07oooo00<0Z_ooooooool02_ooo`030?nZoooooooo013oool00`3o0?ooooooo`0Goooo0Z[o
02[oool00onZ0?ooooooo`12oooo00?o003oooooool0L_ooo`00?_ooo`030000oooooooo03Koool0
0ol0Z_ooooooo`04oooo00>Z0?ooooooool01?ooo`03003ooooooooo00Ooool00`2Zooooooooo`0:
oooo00<0oj[oooooool03oooo`80o`0Ioooo00>Zo`3oooooool0:?ooo`;oZP14oooo00?o003ooooo
ool0Loooo`00?_ooo`030000oooooooo03Goool00ol0Z_ooooooo`04oooo00>Z0?ooooooool01?oo
o`03003ooooooooo00Ooool00`2Zooooooooo`09oooo0P3oZQ7oool00`3o0?ooooooo`0Goooo0Z[o
02Woool2ojX0A?ooo`;o001foooo000noooo00<0003oooooool0=Oooo`03o`2Zoooooooo00?oool0
0jX0ooooooooo`04oooo00<00?ooooooool01oooo`030:[ooooooooo00Woool00`3oZ_ooooooo`0@
oooo00<0o`3oooooool05oooo`03Z_l0oooooooo02Soool00onZ0?ooooooo`13oooo00?o003ooooo
ool0M_ooo`00?_ooo`030000oooooooo03Coool00ol0Z_ooooooo`03oooo00>Z0?ooooooool01?oo
o`03003ooooooooo00Ooool00`2Zooooooooo`09oooo00<0oj[oooooool03oooo`80o`0Hoooo0Z[o
02Woool2ojX0A?ooo`;o001ioooo000noooo0P0003Coool00ol0Z_ooooooo`03oooo00>Z0?oooooo
ool01?ooo`03003ooooooooo00Ooool00`2Zooooooooo`08oooo0P3oZQ7oool00`3o0?ooooooo`0F
oooo0Z[o02Woool2ojX0AOooo`03o`00oooooooo07Woool003koool00`000?ooooooo`0boooo00?o
0:[oooooool00oooo`03ZP3ooooooooo00Coool00`00ooooooooo`07oooo00<0Z_ooooooool02?oo
o`030?nZoooooooo013oool00`3o0?ooooooo`0Foooo00>Zo`3oooooool09oooo`;oZP15oooo0_l0
07coool003koool00`000?ooooooo`0aoooo00?o0:[oooooool00oooo`03ZP3ooooooooo00Coool0
0`00ooooooooo`07oooo00<0Z_ooooooool02?ooo`030?nZoooooooo00ooool20?l05oooo`:Zo`0X
oooo0_nZ04Goool2o`00O_ooo`00?_ooo`030000oooooooo033oool00ol0Z_ooooooo`03oooo00>Z
0?ooooooool01?ooo`03003ooooooooo00Ooool00`2Zooooooooo`08oooo00<0oj[oooooool03ooo
o`030?l0oooooooo01Koool00j[o0?ooooooo`0Voooo0_nZ04Koool00ol00?ooooooo`1noooo000n
oooo00<0003oooooool0<?ooo`03o`2Zoooooooo00;oool00jX0ooooooooo`04oooo00<00?oooooo
ool01oooo`030:[ooooooooo00Soool00`3oZ_ooooooo`0?oooo00<0o`3oooooool05Oooo`:Zo`0W
oooo0_nZ04Koool2o`00POooo`00?_ooo`030000oooooooo02ooool00ol0Z_ooooooo`03oooo00>Z
0?ooooooool00oooo`03003ooooooooo00Ooool00`2Zooooooooo`08oooo00<0oj[oooooool03_oo
o`80o`0Foooo0Z[o02Ooool2ojX0Aoooo`03o`00oooooooo087oool002?oool400001?ooo`800004
oooo100000Woool00`000?ooooooo`0^oooo00?o0:[oooooool00oooo`03ZP3ooooooooo00?oool0
0`00ooooooooo`07oooo00<0Z_ooooooool02?ooo`030?nZoooooooo00koool00`3o0?ooooooo`0E
oooo00>Zo`3oooooool09Oooo`;oZP17oooo0_l008Coool002;oool200000_ooo`800003oooo0P00
00?oool200000_ooo`800008oooo00<0003oooooool0;Oooo`03o`2Zoooooooo00?oool00jX0oooo
ooooo`03oooo00<00?ooooooool01oooo`030:[ooooooooo00Soool00`3oZ_ooooooo`0=oooo0P3o
01Koool2Z_l09_ooo`;oZP17oooo0_l008Koool002;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`800004oooo0P0000Ooool00`000?ooooooo`0/oooo00?o0:[oooooool00oooo`03ZP3o
oooooooo00?oool00`00ooooooooo`07oooo00<0Z_ooooooool01oooo`80ojX?oooo00<0o`3ooooo
ool05Oooo`03Z_l0oooooooo02Goool00onZ0?ooooooo`16oooo00?o003oooooool0Q_ooo`008Ooo
o`800004oooo0P0000Koool200001?ooo`800007oooo0`0002coool00ol0Z_ooooooo`02oooo00>Z
0?ooooooool00oooo`03003ooooooooo00Koool20:[o2Oooo`030?nZoooooooo00goool20?l05_oo
o`:Zo`0Voooo0_nZ04Ooool2o`00ROooo`008Oooo`800004oooo0P0000Koool200001?ooo`800007
oooo00<0003oooooool0:oooo`03o`2Zoooooooo00;oool00jX0ooooooooo`03oooo00<00?oooooo
ool01_ooo`030:[ooooooooo00Soool00`3oZ_ooooooo`0=oooo00<0o`3oooooool05Oooo`03Z_l0
oooooooo02Coool2ojX0Aoooo`;o002;oooo000Qoooo0P0000Coool200001_ooo`800004oooo0P00
00Ooool00`000?ooooooo`0Zoooo00?o0:[oooooool00_ooo`03ZP3ooooooooo00?oool00`00oooo
ooooo`06oooo00<0Z_ooooooool02?ooo`030?nZoooooooo00goool00`3o0?ooooooo`0Doooo0Z[o
02Goool2ojX0B?ooo`03o`00oooooooo08_oool0027oool200001?ooo`800006oooo0`0000;oool2
00002?ooo`030000oooooooo02Woool00ol0Z_ooooooo`02oooo00>Z0?ooooooool01?ooo`03003o
oooooooo00Goool00`2Zooooooooo`08oooo00<0oj[oooooool03?ooo`80o`0Foooo00>Zo`3ooooo
ool08oooo`;oZP18oooo0_l008koool0027oool200001?ooo`800007oooo00<0003oool000000P00
00Woool00`000?ooooooo`0Xoooo00?o0:[oooooool00_ooo`03ZP3ooooooooo00Coool00`00oooo
ooooo`05oooo00<0Z_ooooooool02?ooo`030?nZoooooooo00coool00`3o0?ooooooo`0Doooo0Z[o
02Coool2ojX0B?ooo`;o002@oooo000Qoooo0P0000Coool200001oooo`80000<oooo00<0003ooooo
ool0:?ooo`05o`2ZooooooooooooZP3o00Koool00`00ooooooooo`05oooo00<0Z_ooooooool02?oo
o`030?nZoooooooo00_oool20?l05_ooo`03Z_l0oooooooo02;oool2ojX0B?ooo`;o002Boooo000R
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool200002oooo`030000oooooooo02Ooool0
0ol0Z_ooooooo`02oooo00>Z0?ooooooool00oooo`03003ooooooooo00Goool00`2Zooooooooo`08
oooo00<0oj[oooooool02oooo`030?l0oooooooo01Coool2Z_l09?ooo`03ojX0oooooooo04Koool2
o`00U?ooo`008_ooo`800002oooo0P0000[oool300002Oooo`030000oooooooo02Koool00ol0Z_oo
ooooo`02oooo00>Z0?ooooooool00oooo`03003ooooooooo00Goool00`2Zooooooooo`07oooo0P3o
ZPgoool00`3o0?ooooooo`0Coooo0Z[o02Coool2ojX0Aoooo`;o002Foooo000Soooo100000goool3
00001oooo`030000oooooooo02Goool00ol0Z_ooooooo`02oooo00>Z0?ooooooool00oooo`03003o
oooooooo00Goool00`2Zooooooooo`07oooo00<0oj[oooooool02oooo`80o`0Eoooo00>Zo`3ooooo
ool08_ooo`;oZP17oooo0_l009Soool003koool200009Oooo`03o`2Zoooooooo00;oool00jX0oooo
ooooo`03oooo00<00?ooooooool01Oooo`030:[ooooooooo00Ooool00`3oZ_ooooooo`0;oooo00<0
o`3oooooool04oooo`:Zo`0Soooo0_nZ04Ooool2o`00V_ooo`00?_ooo`030000oooooooo02Coool0
1Ol0Z_ooooooooooojX0o`05oooo00<00?ooooooool01Oooo`030:[ooooooooo00Ooool00`3oZ_oo
ooooo`0;oooo00<0o`3oooooool04_ooo`:Zo`0Soooo0_nZ04Ooool2o`00W?ooo`00?_ooo`030000
oooooooo02?oool00ol0Z_ooooooo`02oooo00>Z0?ooooooool00_ooo`03003ooooooooo00Goool0
0`2Zooooooooo`07oooo00<0oj[oooooool02_ooo`80o`0Coooo0Z[o02?oool2ojX0Aoooo`;o002N
oooo000noooo00<0003oooooool08_ooo`03o`2Zoooooooo00;oool00jX0ooooooooo`02oooo00<0
0?ooooooool01Oooo`030:[ooooooooo00Koool20?nZ3?ooo`030?l0oooooooo01;oool00j[o0?oo
ooooo`0Qoooo0_nZ04Ooool2o`00X?ooo`00?_ooo`030000oooooooo027oool00ol0Z_ooooooo`02
oooo00>Z0?ooooooool00_ooo`03003ooooooooo00Goool00`2Zooooooooo`06oooo00<0oj[ooooo
ool02oooo`030?l0oooooooo017oool2Z_l08_ooo`;oZP17oooo0_l00:;oool003koool00`000?oo
ooooo`0Qoooo00Go0:[ooooooooooonZ0?l01Oooo`03003ooooooooo00Coool00`2Zooooooooo`06
oooo00<0oj[oooooool02_ooo`80o`0Boooo0Z[o02;oool2ojX0Aoooo`;o002Toooo000noooo00<0
003oooooool08?ooo`05o`2ZooooooooooooZP3o00Goool00`00ooooooooo`04oooo00<0Z_oooooo
ool01_ooo`030?nZoooooooo00[oool00`3o0?ooooooo`0Aoooo00>Zo`3oooooool08?ooo`;oZP16
oooo0ol00:Koool003koool00`000?ooooooo`0Ooooo00?o0:[oooooool00_ooo`03ZP3ooooooooo
00;oool00`00ooooooooo`04oooo00<0Z_ooooooool01_ooo`030?nZoooooooo00[oool00`3o0?oo
ooooo`0@oooo0Z[o027oool2ojX0A_ooo`;o002Yoooo000noooo00<0003oooooool07oooo`05o`2Z
ooooooooooooZP3o00Coool00`00ooooooooo`04oooo00<0Z_ooooooool01_ooo`030?nZoooooooo
00Woool20?l04_ooo`03Z_l0oooooooo01ooool2ojX0AOooo`?o002[oooo000noooo00<0003ooooo
ool07_ooo`05o`2ZooooooooooooZP3o00Coool00`00ooooooooo`04oooo00<0Z_ooooooool01_oo
o`030?nZoooooooo00Woool00`3o0?ooooooo`0@oooo0Z[o01ooool3ojX0AOooo`;o002^oooo000n
oooo0P0001ooool01?l0Z_ooooooojX0o`Coool00`00ooooooooo`04oooo00<0Z_ooooooool01_oo
o`030?nZoooooooo00Woool00`3o0?ooooooo`0?oooo0Z[o01ooool2ojX0AOooo`?o002`oooo000n
oooo00<0003oooooool07Oooo`05o`2ZooooooooooooZP3o00?oool00`00ooooooooo`04oooo00<0
Z_ooooooool01Oooo`80ojX:oooo0P3o017oool00j[o0?ooooooo`0Moooo0_nZ04Coool3o`00/ooo
o`00?_ooo`030000oooooooo01coool01Ol0Z_ooooooooooojX0o`04oooo00<00?ooooooool00ooo
o`030:[ooooooooo00Goool00`3oZ_ooooooo`09oooo00<0o`3oooooool03oooo`:Zo`0Noooo0_nZ
04Coool2o`00]_ooo`00?_ooo`030000oooooooo01coool01?l0Z_ooooooojX0o`Coool00`00oooo
ooooo`03oooo00<0Z_ooooooool01Oooo`030?nZoooooooo00Woool00`3o0?ooooooo`0?oooo00>Z
o`3oooooool07?ooo`;oZP13oooo0ol00;Soool003koool00`000?ooooooo`0Koooo00Co0:[ooooo
oonZ0?l4oooo00<00?ooooooool00oooo`030:[ooooooooo00Goool00`3oZ_ooooooo`08oooo0P3o
013oool2Z_l07Oooo`;oZP13oooo0_l00;_oool003koool00`000?ooooooo`0Joooo00Go0:[ooooo
oooooonZ0?l00oooo`03003ooooooooo00?oool00`2Zooooooooo`05oooo00<0oj[oooooool02?oo
o`030?l0oooooooo00ooool00j[o0?ooooooo`0Koooo0_nZ04?oool2o`00_Oooo`00?_ooo`030000
oooooooo01[oool01?l0Z_ooooooojX0o`?oool00`00ooooooooo`03oooo00<0Z_ooooooool01Ooo
o`030?nZoooooooo00Soool00`3o0?ooooooo`0>oooo0Z[o01coool2ojX0@_ooo`?o002ooooo000n
oooo00<0003oooooool06Oooo`04o`2ZooooooooZP3o0oooo`03003ooooooooo00?oool00`2Zoooo
ooooo`05oooo00<0oj[oooooool01oooo`80o`0@oooo00>Zo`3oooooool06_ooo`;oZP12oooo0_l0
0<;oool003koool00`000?ooooooo`0Ioooo00Co0:[ooooooonZ0?l3oooo00<00?ooooooool00_oo
o`030:[ooooooooo00Goool00`3oZ_ooooooo`07oooo00<0o`3oooooool03_ooo`:Zo`0Koooo0_nZ
047oool3o`00a?ooo`00?_ooo`80000Ioooo00Co0:[ooooooonZ0?l3oooo00<00?ooooooool00_oo
o`030:[ooooooooo00Goool00`3oZ_ooooooo`07oooo00<0o`3oooooool03_ooo`03Z_l0oooooooo
01Woool2ojX0@?ooo`?o0037oooo000noooo00<0003oooooool05oooo`04o`2ZooooooooZP3o0ooo
o`03003ooooooooo00;oool00`2Zooooooooo`04oooo0P3oZPSoool20?l03oooo`:Zo`0Joooo0_nZ
03ooool3o`00b_ooo`00?_ooo`030000oooooooo01Ooool01?l0Z_ooooooojX0o`;oool00`00oooo
ooooo`02oooo00<0Z_ooooooool01?ooo`030?nZoooooooo00Ooool00`3o0?ooooooo`0=oooo0Z[o
01[oool2ojX0?_ooo`?o003=oooo000noooo00<0003oooooool05_ooo`04o`2ZooooooooZP3o0_oo
o`03003ooooooooo00;oool00`2Zooooooooo`04oooo00<0oj[oooooool01oooo`030?l0oooooooo
00goool00j[o0?ooooooo`0Hoooo0_nZ03goool3o`00d?ooo`00?_ooo`030000oooooooo01Goool0
1?l0Z_ooooooojX0o`?oool01@00ooooooooooooo`2Zo`06oooo00<0oj[oooooool01_ooo`80o`0>
oooo0Z[o01Woool2ojX0?Oooo`;o003Coooo000Soooo100000Coool200001?ooo`@00009oooo00<0
003oooooool05Oooo`03o`2ZooooZP3o00?oool01@00ooooooooooooo`2Zo`06oooo00<0oj[ooooo
ool01_ooo`030?l0oooooooo00coool2Z_l06Oooo`;oZP0loooo0ol00=Goool002;oool200000_oo
o`800003oooo0P0000?oool200000oooo`030000oooooooo00Koool00`000?ooooooo`0Doooo00Co
0:[ooooooonZ0?l2oooo00<00?ooooooool00_ooo`030:[ooooooooo00;oool20?nZ2?ooo`030?l0
oooooooo00_oool2Z_l06Oooo`;oZP0koooo0ol00=Soool002;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`800004oooo0P0000Ooool00`000?ooooooo`0Doooo00?o0:[ooonZ0?l00_oo
o`03003ooooooooo00;oool00`2Zooooooooo`02oooo00<0oj[oooooool01oooo`030?l0oooooooo
00_oool00j[o0?ooooooo`0Goooo0_nZ03_oool2o`00foooo`008Oooo`800004oooo0P0000Koool2
00001?ooo`800007oooo00<0003oooooool04oooo`03o`2ZooooZP3o00;oool00`00ooooooooo`02
oooo00<0Z_ooooooool00_ooo`030?nZoooooooo00Koool20?l03?ooo`:Zo`0Goooo0onZ03[oool3
o`00gOooo`008Oooo`800004oooo0P0000Ooool010000?ooooooooooo`800008oooo0`0001;oool0
1?l0Z_ooooooojX0o`;oool01@00ooooooooooooo`2Zo`04oooo00<0oj[oooooool01_ooo`030?l0
oooooooo00[oool2Z_l05oooo`;oZP0ioooo1?l00>3oool0027oool200001?ooo`800008oooo1000
00Woool00`000?ooooooo`0Boooo00?o0:[ooonZ0?l00_ooo`05003ooooooooooooo0:[o00Coool0
0`3oZ_ooooooo`06oooo00<0o`3oooooool02_ooo`03Z_l0oooooooo01Goool2ojX0=oooo`Co003T
oooo000Qoooo0P0000Coool200002?ooo`<0000:oooo00<0003oooooool04Oooo`03o`2ZooooZP3o
00;oool01@00ooooooooooooo`2Zo`04oooo00<0oj[oooooool01Oooo`80o`0;oooo0Z[o01Goool3
ojX0=_ooo`?o003Xoooo000Qoooo0P0000Coool200001oooo`800002oooo0P0000Soool00`000?oo
ooooo`0@oooo00Ko0:[ooooooonZ0?ooool00?l3oooo00<0Z_ooooooool00_ooo`030?nZoooooooo
00Goool00`3o0?ooooooo`0:oooo00>Zo`3oooooool04oooo`;oZP0foooo0ol00>_oool0027oool2
00001?ooo`800006oooo0P0000Coool200001oooo`030000oooooooo013oool01Ol0Z_ooojX0oooo
o`00o`04oooo00D0Z_ooooooooooool0ojX01oooo`030?l0oooooooo00Woool2Z_l04oooo`?oZP0d
oooo1?l00>koool002;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`800004oooo0P00
00Ooool00`000?ooooooo`0?oooo00?o0:[ooonZ0?l00_ooo`05003ooooooooooooo0:[o00?oool0
0`3oZ_ooooooo`04oooo0P3o00[oool2Z_l04oooo`;oZP0doooo0ol00?;oool002;oool200000_oo
o`800008oooo0P0000?oool00`000?ooooooo`06oooo00<0003oooooool03oooo`05o`2ZooooZP3o
oooo003o00?oool01@2Zooooooooooooo`3oZP06oooo00<0o`3oooooool02Oooo`03Z_l0oooooooo
017oool2ojX0<oooo`?o003eoooo000Soooo100000[oool400002Oooo`030000oooooooo00koool0
1Ol0Z_ooojX0ooooo`00o`03oooo00D0Z_ooooooooooool0ojX01_ooo`030?l0oooooooo00Soool2
Z_l04_ooo`;oZP0boooo0ol00?Soool003koool00`000?ooooooo`0=oooo00Go0:[ooonZ0?ooool0
0?l00oooo`050:[ooooooooooooo0?nZ00Koool00`3o0?ooooooo`07oooo0Z[o01;oool2ojX0<Ooo
o`?o003koooo000noooo0P0000koool01Ol0ZZX0ooooooooo`00o`02oooo00D0Z_ooooooooooool0
ojX01Oooo`80o`09oooo00>Zo`3oooooool04?ooo`;oZP0`oooo0ol00?koool003koool00`000?oo
ooooo`0<oooo00Go0:[ooonZ0?ooool00?l00_ooo`050:[ooooooooooooo0?nZ00Goool00`3o0?oo
ooooo`07oooo0Z[o017oool2ojX0;_ooo`Co003ooooo0_ooo`00?_ooo`030000oooooooo00_oool0
1Ol0Z_ooojX0ooooo`00o`03oooo00@0Z_ooooooool0ojX5oooo00<0o`3oooooool01_ooo`:Zo`0A
oooo0_nZ02coool4o`00ooooo`Koool003koool00`000?ooooooo`0;oooo00Co0:ZZ0?ooool00?l3
oooo00@0Z_ooooooool0ojX5oooo00<0o`3oooooool01Oooo`:Zo`0@oooo0onZ02[oool4o`00oooo
o`[oool003koool00`000?ooooooo`0:oooo00Go0:[ooonZ0?ooool00?l00_ooo`040:[ooooooooo
0?nZ1Oooo`030?l0oooooooo00Goool00j[o0?ooooooo`0=oooo0onZ02Woool4o`00ooooo`koool0
03koool00`000?ooooooo`0:oooo00Co0:ZZ0?ooool00?l2oooo00@0Z_ooooooool0ojX4oooo0P3o
00Koool2Z_l03_ooo`;oZP0Xoooo1?l00?oooolBoooo000noooo00<0003oooooool02Oooo`04o`2Z
ZP3ooooo003o0_ooo`040:[ooooooooo0?nZ1?ooo`030?l0oooooooo00Goool00j[o0?ooooooo`0;
oooo0onZ02Koool4o`00oooooaKoool003koool00`000?ooooooo`08oooo00Co0:[ooonZ0?l00?l2
oooo00@0Z_ooooooool0ojX4oooo00<0o`3oooooool01?ooo`:Zo`0<oooo0_nZ02Goool4o`00oooo
oa[oool003koool00`000?ooooooo`08oooo00Ko0:ZZ0?ooool00?ooool0Z_l2oooo00<0oj[ooooo
ool00_ooo`030?l0oooooooo00Coool00j[o0?ooooooo`0:oooo0_nZ02Coool3o`00oooooakoool0
03koool200002?ooo`06o`2ZZP3ooooo003ooooo0:[o0_ooo`040?nZoooooooooooo0P3o00Goool2
Z_l02oooo`;oZP0Soooo0ol00?oooolQoooo000noooo00<0003oooooool01oooo`03o`2ZZP3o003o
00;oool00`2Zooooo`3oZP03oooo00<0o`3oooooool01?ooo`03Z_l0oooooooo00Woool2ojX08_oo
o`?o003ooooo9?ooo`00?_ooo`030000oooooooo00Koool00ol0ZZX0o`00o`02oooo00<0Z_ooool0
ojX00oooo`030?l0oooooooo00?oool2Z_l02_ooo`;oZP0Poooo1?l00?oooolWoooo000noooo00<0
003oooooool01_ooo`07o`2Zoooo003ooooo0:[ooooo0?nZ00;oool20?l01Oooo`03Z_l0oooooooo
00Soool2ojX07_ooo`Co003ooooo:oooo`00?_ooo`030000oooooooo00Goool01ol0ZZX0o`00oooo
o`2Zooooo`3oZP02oooo00<0o`3oooooool00oooo`:Zo`09oooo0_nZ01coool4o`00ooooobooool0
03koool00`000?ooooooo`04oooo00Oo0:ZZ0?l00?ooool0Z_ooool0ojX00_ooo`030?l0oooooooo
00;oool2Z_l02Oooo`;oZP0Ioooo1Ol00?oooolcoooo000noooo00<0003oooooool01?ooo`07o`2Z
ZP3ooooo0:[ooooo0?nZoooo0080o`04oooo00>Zo`3oooooool01_ooo`?oZP0Eoooo1_l00?oooolh
oooo000noooo00<0003oooooool00oooo`08o`2ZZP3o003o0:[ooooo0?nZoooo0?l01?ooo`:Zo`07
oooo0_nZ01;oool6o`00ooooockoool003koool00`000?ooooooo`03oooo00Oo0:X00?ooool0Z_l0
oj[oool0o`001?ooo`03Z_l0oooooooo00Coool3ojX04?ooo`Co003oooooA?ooo`00?_ooo`800003
oooo00Oo0:ZZ0?ooool0Z_l0oj[oool0o`000oooo`:Zo`05oooo0_nZ00ooool4o`00ooooodSoool0
03koool00`000?ooooooo`02oooo00Ko0:X00?l0Z_l0oj[oool0o`02oooo0Z[o00Coool3ojX03Ooo
o`Co003oooooC?ooo`00?_ooo`080000ooooooooooooo`2Z003o0:[o0?nZ0P3o00;oool01:[o0?oo
ooooooooo`?oZP0<oooo1?l00?oooom@oooo000noooo00P0003ooooooooo0:ZZ0?l0Z_l0ojX0o`02
oooo0Z[o00;oool2ojX02oooo`Co003oooooE?ooo`00?_ooo`080000ooooooooo`2Z003o0?nZ0?l0
oooo0Z[o0004ooooojX0ojX0ojX02Oooo`Co003oooooF?ooo`00?_ooo`090000ooooo`2ZZP3o0?nZ
0?l0ooooZ_l0oooo00;oZP08oooo1?l00?oooomLoooo000_oooo1P0000Woool01@000?ooool0ZP2Z
o`3o0002Z_l00_nZ00Koool4o`00ooooof3oool0037oool200002oooo`050000o`2Z0:[o0?l0Z_l0
00;oZP02oooo1_l00?oooomToooo000aoooo0P0000Soool5o`0000>Zo`3oZP3o00001?l00?oooomZ
oooo000aoooo0P0000Soool6o`00ooooog3oool0037oool200002?ooo`Go003oooooLOooo`00<Ooo
o`800008oooo1Ol00?oooomaoooo000aoooo0P0000Woool3o`00ooooog;oool0037oool200002ooo
o`030000oooooooo0?oooom`oooo000aoooo0P0000_oool00`000?ooooooo`3oooooL?ooo`00<Ooo
o`80003oooooO_ooo`00;oooo`@0003oooooO_ooo`00<Oooo`80003oooooO_ooo`00oooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
03Woool4000000?oool0000000000P000?oooom_oooo000ioooo00<0003oooooool01Oooo`030000
oooooooo0?oooom]oooo000ioooo00<0003oooooool01Oooo`030000oooooooo0?oooom]oooo000i
oooo00<0003oooooool01Oooo`030000oooooooo0?oooom]oooo000ioooo00<0003oooooool01Ooo
o`030000oooooooo0?oooom]oooo000ioooo00<0003oooooool01Oooo`030000oooooooo0?oooom]
oooo000ioooo00<0003oooooool01Oooo`030000oooooooo0?oooom]oooo000ioooo00<0003ooooo
ool01Oooo`030000oooooooo0?oooom]oooo000ioooo00<0003oooooool01Oooo`030000oooooooo
0?oooom]oooo000ioooo00<0003oooooool01Oooo`030000oooooooo0?oooom]oooo000ioooo00<0
003oooooool01Oooo`030000oooooooo0?oooom]oooo000ioooo00<0003oooooool01Oooo`030000
oooooooo0?oooom]oooo000ioooo00<0003oooooool01Oooo`030000oooooooo0?oooom]oooo000i
oooo00<0003oooooool01Oooo`030000oooooooo0?oooom]oooo000ioooo10000003oooo00000000
0080003oooooKoooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooona
oooo000/oooo8@000?oooomToooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Ooo
o`00>?ooo`@0000;oooo10000?oooomVoooo000hoooo00<0003oooooool03oooo`030000oooooooo
0?oooomToooo000hoooo00<0003oooooool03oooo`030000oooooooo0?oooomToooo000`oooo1000
00Coool00`000?ooooooo`02oooo0`000003oooo0000000000800005oooo00<0003oooooool0oooo
ofCoool0037oool200001Oooo`030000oooooooo00?oool010000?ooooooooooo`800006oooo00<0
003oooooool0ooooofCoool0037oool200001Oooo`030000oooooooo00Coool010000?ooo`000000
00Ooool00`000?ooooooo`3oooooI?ooo`00<Oooo`800005oooo00<0003oooooool01Oooo`800008
oooo00<0003oooooool0ooooofCoool0037oool200001Oooo`030000oooooooo00Goool200002?oo
o`030000oooooooo0?oooomToooo000aoooo0P0000Goool00`000?ooooooo`04oooo0`0000Soool0
0`000?ooooooo`3oooooI?ooo`00<Oooo`800005oooo00<0003oooooool00oooo`800002oooo00<0
003oooooool01Oooo`030000oooooooo0?oooomToooo000`oooo1@0000?oool00`000?ooooooo`02
oooo10000004oooo0000000000001Oooo`030000oooooooo0?oooomToooo000aoooo0P0000Goool0
0`000?ooooooo`0?oooo00<0003oooooool0ooooofCoool0037oool200001Oooo`030000oooooooo
00ooool00`000?ooooooo`3oooooI?ooo`00<Oooo`800005oooo00<0003oooooool03oooo`030000
oooooooo0?oooomToooo000boooo00<0003oooooool00P000003oooo000000000080000;oooo1000
0?oooomVoooo000coooo0`000?oooomkoooo003ooooo/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.21188, -0.144716, 
  0.00508777, 0.00823218}}]
}, Open  ]],

Cell[TextData[{
  "Die ",
  StyleBox["Verbindungsgerade",
    FontSlant->"Italic"],
  " ist ein Polynom ",
  Cell[BoxData[
      \(TraditionalForm\`1.\)]],
  " Grades und durch zwei St\[UDoubleDot]tzpunkte eindeutig bestimmt. \
Polynome h\[ODoubleDot]heren Grades zur Anpassung nur zweier \
St\[UDoubleDot]tzpunkte f\[UDoubleDot]hren auf Probleme mit der \
Eindeutigkeit."
}], "Text"],

Cell["\<\
Diese M\[ODoubleDot]glichkeit der Potenzierung spielt vor allem \
eine Rolle, wenn eine Interpolation durch St\[UDoubleDot]tzpunkte angestrebt \
ist, die ihrerseits auf der Auswertung aus mehreren Me\[SZ]punkten bestehen. \
Auf diese Weise k\[ODoubleDot]nnen doppelte und mehrfache Nullstellen des \
Interpolationspolynoms an der gew\[UDoubleDot]nschten Stelle eingebaut \
werden.\
\>", "Text"],

Cell["\<\
Um die Verwirrung nicht zu gro\[SZ] zu machen, wird vorerst mit \
einfachen Nullstellen interpoliert.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Viele Wertepaare"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Balkendiagramm"
}], "Subsubsection"],

Cell["\<\
Die Me\[SZ]werte werden nebeneinander mit einem ziemlich breiten \
Strich (\"Balken\") dargestellt.\
\>", "Text"],

Cell["\<\
Besonders bei Darstellungen zur Entwicklung eines Unternehmens sind \
Balkendiagramme etabliert, wo zum Beispiel die j\[ADoubleDot]hrliche \
Produktivit\[ADoubleDot]t dargestellt wird.\
\>", "Text"],

Cell[TextData[{
  "Balkendiagramme k\[ODoubleDot]nnen bei perspektivischer Verzerrung zu \
scheinbaren \[CapitalUDoubleDot]berh\[ODoubleDot]hungen und anderen optischen \
T\[ADoubleDot]uschungen f\[UDoubleDot]hren, die in der Finanzstatistik sehr \
verbreitet sind. Mit den ",
  StyleBox["Regeln guter wissenschaftlicher Praxis",
    FontSlant->"Italic"],
  " (Vorgabe der DFG an Hochschulen ab sp\[ADoubleDot]testens 1. 7.2002) hat \
das gar nichts zu tun: Die Wissenschaft dient der Wahrheitsfindung \[Dash] \
nicht der Kundent\[ADoubleDot]uschung."
}], "Text"],

Cell["\<\
Besser als Balkendiagramme sind Wertetafeln (und prozentuale \
Wertetafeln statt \"Kuchenst\[UDoubleDot]ck\"-Diagrammen), da ein Ausmessen \
der fraglichen Werte aus der Zeichnung samt eventuellem \
R\[UDoubleDot]ckrechnen der perspektivischen Verzerrung entf\[ADoubleDot]llt.\
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Polygonzug"
}], "Subsubsection"],

Cell["\<\
Es werden je zwei benachbarte Punkte miteinander verbunden. Der \
entstehende Polygonzug ist wenig geschmeidig, aber eindeutig.\
\>", "Text"],

Cell[TextData[{
  "Diese Vorgehensweise ist auch bei mehrdimensionalen Darstellungen weit \
verbreitet und f\[UDoubleDot]hrt zu Knickstellen anstelle von optisch \
geschmeidigen Kurvenverl\[ADoubleDot]ufen, die bei der Interpolation von Hand \
oder mit einem ",
  StyleBox["Kurvenlineal",
    FontSlant->"Italic"],
  " vorkommen w\[UDoubleDot]rden."
}], "Text"],

Cell["\<\
Polygonz\[UDoubleDot]ge lassen sich sehr schnell berechnen und in \
CAD-Systemen darstellen.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Gesteigertes Problem"
}], "Subsubsection"],

Cell[TextData[{
  "Die Abbildung ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  " lautet nun:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[f]\), 
    \(f[a] = A\), 
    \(f[b] = B\), 
    \(f[c] = C\)}], "Input"],

Cell[BoxData[
    \(A\)], "Output"],

Cell[BoxData[
    \(B\)], "Output"],

Cell[BoxData[
    \(C\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Gesucht ist eine Interpolation ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  " (Zwischenwertbildung) in analytischer Form."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". L\[ODoubleDot]sungsidee"
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["Verallgemeinerte Schalter",
    FontSlant->"Italic"],
  "-Funktion (auch beim Programmieren verwendbar):"
}], "Text"],

Cell[BoxData[
    \(f[x_] := 
      \(\(\((x - b)\) \((x - c)\)\)\/\(\((a - b)\) \((a - c)\)\)\) A + 
        \(\(\((x - a)\) \((x - c)\)\)\/\(\((b - a)\) \((b - c)\)\)\) B + 
        \(\(\((x - a)\) \((x - b)\)\)\/\(\((c - a)\) \((c - b)\)\)\) C\)], 
  "Input"],

Cell["Diese Funktion ergibt:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[a], f[b], f[c], f[x]}\)], "Input"],

Cell[BoxData[
    \({A, B, C, 
      \(C\ \((\(-a\) + x)\)\ \((\(-b\) + x)\)\)\/\(\((\(-a\) + c)\)\ 
            \((\(-b\) + c)\)\) + 
        \(B\ \((\(-a\) + x)\)\ \((\(-c\) + x)\)\)\/\(\((\(-a\) + b)\)\ 
            \((b - c)\)\) + 
        \(A\ \((\(-b\) + x)\)\ \((\(-c\) + x)\)\)\/\(\((a - b)\)\ 
            \((a - c)\)\)}\)], "Output"]
}, Open  ]],

Cell["\<\
Zwischenwerte sind auch m\[ODoubleDot]glich, wie sich anhand einer \
Zeichnung ergibt:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kurve[2] = 
      Plot[Evaluate[
          f[x] /. {a \[Rule] 0, b \[Rule] 2, c \[Rule] 3, A \[Rule] 1, 
              B \[Rule] 0, C \[Rule] 2}], {x, 0, 3}, 
        PlotStyle \[Rule] {Hue[2\/3]}, 
        AxesLabel 
          \[Rule] {\*"\"\<\!\(x\/\([\\\ ]\)\)\>\"", 
            \*"\"\<\!\(f[x]\/\([\\\ ]\)\)\>\""}, 
        DisplayFunction \[Rule] Identity]; \n
    punkte[2] = 
      ListPlot[{{0, 1}, {2, 0}, {3, 2}}, 
        PlotStyle \[Rule] {PointSize[0.02], Hue[0]}, 
        DisplayFunction \[Rule] Identity]; \n
    Show[kurve[2], punkte[2], DisplayFunction \[Rule] $DisplayFunction]; \)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.114513 0.244403 [
[.18254 .10201 -9.5 -15 ]
[.18254 .10201 9.5 0 ]
[.34127 .10201 -5 -15 ]
[.34127 .10201 5 0 ]
[.5 .10201 -9.5 -15 ]
[.5 .10201 9.5 0 ]
[.65873 .10201 -5 -15 ]
[.65873 .10201 5 0 ]
[.81746 .10201 -9.5 -15 ]
[.81746 .10201 9.5 0 ]
[.97619 .10201 -5 -15 ]
[.97619 .10201 5 0 ]
[1.025 .11451 0 -13.5 ]
[1.025 .11451 19 13.5 ]
[.01131 .23671 -19 -7.5 ]
[.01131 .23671 0 7.5 ]
[.01131 .35892 -10 -7.5 ]
[.01131 .35892 0 7.5 ]
[.01131 .48112 -19 -7.5 ]
[.01131 .48112 0 7.5 ]
[.01131 .60332 -10 -7.5 ]
[.01131 .60332 0 7.5 ]
[.02381 .64303 -15 0 ]
[.02381 .64303 15 30 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18254 .11451 m
.18254 .12076 L
s
gsave
.18254 .10201 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.34127 .11451 m
.34127 .12076 L
s
gsave
.34127 .10201 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .11451 m
.5 .12076 L
s
gsave
.5 .10201 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.65873 .11451 m
.65873 .12076 L
s
gsave
.65873 .10201 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81746 .11451 m
.81746 .12076 L
s
gsave
.81746 .10201 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 .11451 m
.97619 .12076 L
s
gsave
.97619 .10201 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05556 .11451 m
.05556 .11826 L
s
.0873 .11451 m
.0873 .11826 L
s
.11905 .11451 m
.11905 .11826 L
s
.15079 .11451 m
.15079 .11826 L
s
.21429 .11451 m
.21429 .11826 L
s
.24603 .11451 m
.24603 .11826 L
s
.27778 .11451 m
.27778 .11826 L
s
.30952 .11451 m
.30952 .11826 L
s
.37302 .11451 m
.37302 .11826 L
s
.40476 .11451 m
.40476 .11826 L
s
.43651 .11451 m
.43651 .11826 L
s
.46825 .11451 m
.46825 .11826 L
s
.53175 .11451 m
.53175 .11826 L
s
.56349 .11451 m
.56349 .11826 L
s
.59524 .11451 m
.59524 .11826 L
s
.62698 .11451 m
.62698 .11826 L
s
.69048 .11451 m
.69048 .11826 L
s
.72222 .11451 m
.72222 .11826 L
s
.75397 .11451 m
.75397 .11826 L
s
.78571 .11451 m
.78571 .11826 L
s
.84921 .11451 m
.84921 .11826 L
s
.88095 .11451 m
.88095 .11826 L
s
.9127 .11451 m
.9127 .11826 L
s
.94444 .11451 m
.94444 .11826 L
s
.25 Mabswid
0 .11451 m
1 .11451 L
s
gsave
1.025 .11451 -61 -17.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 35 translate 1 -1 scale
63.000000 18.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
66.937500 10.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
0.687500 setlinewidth
0.000000 0.000000 0.000000 setrgbcolor
64.312500 15.187500 moveto
9.875000 0.000000 rlineto
stroke
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
66.062500 27.312500 moveto
(@) show
70.000000 27.312500 moveto
(D) show
77.062500 18.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.02381 .23671 m
.03006 .23671 L
s
gsave
.01131 .23671 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .35892 m
.03006 .35892 L
s
gsave
.01131 .35892 -71 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .48112 m
.03006 .48112 L
s
gsave
.01131 .48112 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -71 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.02381 .13895 m
.02756 .13895 L
s
.02381 .16339 m
.02756 .16339 L
s
.02381 .18783 m
.02756 .18783 L
s
.02381 .21227 m
.02756 .21227 L
s
.02381 .26115 m
.02756 .26115 L
s
.02381 .28559 m
.02756 .28559 L
s
.02381 .31004 m
.02756 .31004 L
s
.02381 .33448 m
.02756 .33448 L
s
.02381 .38336 m
.02756 .38336 L
s
.02381 .4078 m
.02756 .4078 L
s
.02381 .43224 m
.02756 .43224 L
s
.02381 .45668 m
.02756 .45668 L
s
.02381 .50556 m
.02756 .50556 L
s
.02381 .53 m
.02756 .53 L
s
.02381 .55444 m
.02756 .55444 L
s
.02381 .57888 m
.02756 .57888 L
s
.02381 .09007 m
.02756 .09007 L
s
.02381 .06563 m
.02756 .06563 L
s
.02381 .04119 m
.02756 .04119 L
s
.02381 .01675 m
.02756 .01675 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -76 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 38 translate 1 -1 scale
63.000000 21.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
66.062500 13.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
71.187500 13.375000 moveto
(@) show
75.125000 13.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
81.250000 13.375000 moveto
(D) show
0.687500 setlinewidth
0.000000 0.000000 0.000000 setrgbcolor
64.312500 18.187500 moveto
21.125000 0.000000 rlineto
stroke
71.687500 30.312500 moveto
(@) show
75.625000 30.312500 moveto
(D) show
88.312500 21.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .35892 m
.06244 .29749 L
.10458 .23737 L
.14415 .18745 L
.18221 .1454 L
.22272 .10708 L
.26171 .07646 L
.30316 .05065 L
.32392 .04033 L
.34309 .03235 L
.36292 .02566 L
.3815 .02083 L
.39128 .01885 L
.40022 .01738 L
.41016 .01612 L
.41564 .01559 L
.42085 .01521 L
.42344 .01506 L
.42588 .01494 L
.42809 .01486 L
.43044 .01479 L
.43166 .01476 L
.4323 .01475 L
.43299 .01474 L
.43421 .01473 L
.43535 .01472 L
.43603 .01472 L
.43677 .01472 L
.43747 .01472 L
.43812 .01472 L
.43935 .01473 L
.44066 .01475 L
.44179 .01477 L
.44282 .0148 L
.44516 .01487 L
.44723 .01495 L
.4494 .01505 L
.454 .01533 L
.45904 .01574 L
.46932 .01689 L
.47865 .0183 L
.4996 .02276 L
.51879 .0284 L
.53959 .03619 L
.5805 .05662 L
.61991 .08269 L
.65779 .11367 L
.69813 .15304 L
.73696 .19714 L
.77824 .25071 L
Mistroke
.818 .30882 L
.85624 .37075 L
.89694 .44314 L
.93612 .51916 L
.97619 .60332 L
Mfstroke
1 0 0 r
.02 w
.02381 .35892 Mdot
.65873 .11451 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012QP00`40o`000?l0003o;Oooo`030000
oooooooo0?oooon1oooo000]oooo00<0003oooooool0oooooh7oool002goool00`000?ooooooo`3o
ooooPOooo`00;Oooo`030000oooooooo0?oooon1oooo000]oooo00<0003oooooool0oooooh7oool0
02goool20000POoooaP00?oXoooo000]oooo00<0003oooooool0N_ooo`H00?lHoooo1P00on;oool0
02goool00`000?ooooooo`1eoooo1@00obCoool5003ogOooo`00;Oooo`030000oooooooo077oool4
003o;_ooo`<00?oJoooo000]oooo00<0003oooooool0Koooo`800?leoooo0`00omOoool002goool0
0`000?ooooooo`1]oooo0P00oc[oool2003oeOooo`00;Oooo`030000oooooooo06[oool3003o?_oo
o`800?oCoooo000]oooo00<0003oooooool0I_ooo`@00?m3oooo0`00om3oool002goool00`000?oo
ooooo`1Toooo0P00od[oool2003oc_ooo`00;Oooo`80001Soooo0P00odkoool2003oc?ooo`00;Ooo
o`030000oooooooo063oool2003oD_ooo`800?o:oooo000]oooo00<0003oooooool0G_ooo`800?mF
oooo0P00olSoool002goool00`000?ooooooo`1Moooo00<00?ooooooool0F?ooo`800?o6oooo000]
oooo00<0003oooooool0Foooo`800?mMoooo0P00olCoool002goool00`000?ooooooo`1Joooo00<0
0?ooooooool0Goooo`03003ooooooooo0<7oool002goool00`000?ooooooo`0[oooo100000Coool2
00000oooo`@0000Loooo0P00o`goool60000:_ooo`H00003oooo0P0000?oool400005?ooo`800?lD
oooo1`0002Woool700000oooo`800003oooo100002[oool50000>oooo`00;Oooo`030000oooooooo
02[oool200000_ooo`800003oooo0P0000?oool01@000?ooooooooooo`00000Joooo00<00?oooooo
ool03oooo`80000^oooo0P0000Goool200000oooo`050000oooooooooooo000001Goool00`00oooo
ooooo`0Boooo1`0002Woool700000_ooo`800003oooo00D0003oooooooooool00000:Oooo`800002
oooo0P0003[oool002goool20000:oooo`030000oooooooo00;oool00`000?ooooooo`0;oooo00<0
003oooooool05Oooo`800?lBoooo0P0002koool200003oooo`030000oooooooo01?oool2003o4ooo
o`030000oooooooo00;oool00`000?ooooooo`0Xoooo00<0003oooooool00_ooo`030000oooooooo
00[oool00`000?ooooooo`0[oooo0P0001Ooool400000_ooo`@0000Hoooo000]oooo00<0003ooooo
ool0:Oooo`800004oooo0P0000coool00`000?ooooooo`0Coooo0P00oaCoool20000;_ooo`80000?
oooo00<0003oooooool05Oooo`03003ooooooooo017oool00`000?ooooooo`0]oooo00<0003ooooo
ool03_ooo`030000oooooooo02_oool200005oooo`030000oooooooo00Koool00`000?ooooooo`0F
oooo000]oooo00<0003oooooool0:Oooo`800004oooo0P0000coool00`000?ooooooo`0Boooo00<0
0?ooooooool05?ooo`80000^oooo0P0000ooool00`000?ooooooo`0Foooo0P00oa;oool00`000?oo
ooooo`0]oooo00<0003oooooool03Oooo`030000oooooooo02_oool200005oooo`030000oooooooo
00Koool00`000?ooooooo`0Foooo000]oooo00<0003oooooool0:Oooo`800004oooo0P0000_oool2
00004_ooo`800?lGoooo0P0002koool200003_ooo`80000Joooo0P00oa3oool20000;_ooo`80000=
oooo0P0002coool300005oooo`030000oooooooo00Koool00`000?ooooooo`0Foooo000]oooo00<0
003oooooool0:Oooo`800004oooo0P0000[oool300004Oooo`03003ooooooooo01Ooool20000;_oo
o`80000=oooo0`0001coool00`00ooooooooo`0>oooo00<0003oooooool0;Oooo`030000oooooooo
00[oool30000:oooo`<0000Hoooo00<0003oooooool01_ooo`030000oooooooo01Koool002goool0
0`000?ooooooo`0Yoooo0P0000Coool200001oooo`D0000Aoooo00<00?ooooooool06?ooo`80000^
oooo0P0000[oool500007_ooo`800?l>oooo0P0002koool200002?ooo`D0000]oooo0P0001Soool0
0`000?ooooooo`06oooo00<0003oooooool05_ooo`00;Oooo`030000oooooooo02Woool200001?oo
o`800008oooo0`00013oool2003o6oooo`80000^oooo0P0000_oool300008Oooo`03003ooooooooo
00_oool20000;_ooo`800009oooo0`0002ooool200005oooo`030000oooooooo00Koool00`000?oo
ooooo`0Foooo000]oooo00<0003oooooool0:_ooo`030000oooooooo00;oool00`000?ooooooo`07
oooo00<0003oooooool03oooo`03003ooooooooo01_oool20000;_ooo`80000;oooo00<0003ooooo
ool08_ooo`03003ooooooooo00Goool00`000?ooooooo`02oooo0P0002Woool00`000?ooooooo`02
oooo0P0000Woool00`000?ooooooo`0Zoooo00<0003oooooool00_ooo`80000Goooo00<0003ooooo
ool01_ooo`030000oooooooo01Koool002goool00`000?ooooooo`0Zoooo0P0000;oool200002_oo
o`@0000<oooo00<00?ooooooool06_ooo`@0000/oooo100000coool400008Oooo`03003ooooooooo
00Goool00`000?ooooooo`030000:_ooo`030000oooooooo00<0000:oooo100002Soool200000_oo
o`<0000Goooo00<0003oooooool01_ooo`030000oooooooo01Koool002goool20000;?ooo`@0000;
oooo100000[oool2003o7oooo`80000^oooo0P0000coool400008_ooo`800?l6oooo100002coool4
00002oooo`@0000Zoooo100001Soool00`000?ooooooo`06oooo00<0003oooooool05_ooo`00;Ooo
o`030000oooooooo04Ooool00`00ooooooooo`25oooo00<00?ooooooool0S?ooo`030000oooooooo
00Koool00`000?ooooooo`0Foooo000]oooo00<0003oooooool0A_ooo`03003ooooooooo08Ooool0
0`00ooooooooo`2;oooo00<0003oooooool01_ooo`030000oooooooo01Koool002goool00`000?oo
ooooo`14oooo0P00oh_oool00`00ooooooooo`2:oooo00<0003oooooool01_ooo`030000oooooooo
01Koool002goool00`000?ooooooo`13oooo00<00?ooooooool0S?ooo`03003ooooooooo08Woool0
0`000?ooooooo`06oooo00<0003oooooool05_ooo`00;Oooo`030000oooooooo04;oool00`00oooo
ooooo`2>oooo0P00ohWoool400000_ooo`@0000Hoooo000]oooo00<0003oooooool0@Oooo`03003o
oooooooo097oool00`00ooooooooo`2Xoooo000]oooo00<0003oooooool0@?ooo`03003ooooooooo
097oool5o`00Yoooo`009OooodX000000`00o`000000002B00001Ol007D0000boooo000]oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`07oooo00<00?l0003oool02Oooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Goool5o`002Oooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo
03Woool002goool00`000?ooooooo`0doooo00<0003oooooool01_ooo`03003ooooooooo02[oool0
0`000?ooooooo`0doooo00<0003oooooool0<?ooo`Go00000`00ooooooooo`0boooo00<0003ooooo
ool0<oooo`030000oooooooo03Woool002goool00`000?ooooooo`0loooo00<00?ooooooool0U_oo
o`?o0002oooo00<00?ooooooool0OOoooa00000Foooo000]oooo00<0003oooooool0>oooo`03003o
oooooooo09goool00`00ooooooooo`2Roooo000]oooo00<0003oooooool0>_ooo`03003ooooooooo
09ooool00`00ooooooooo`2Qoooo000]oooo00<0003oooooool0>Oooo`03003ooooooooo0:7oool0
0`00ooooooooo`2Poooo000]oooo00<0003oooooool0>?ooo`03003ooooooooo0:?oool2003oX?oo
o`00;Oooo`80000hoooo00<00?ooooooool0Y_ooo`03003ooooooooo09goool002goool00`000?oo
ooooo`0foooo00<00?ooooooool0Z?ooo`03003ooooooooo09coool002goool00`000?ooooooo`0e
oooo00<00?ooooooool0Z_ooo`03003ooooooooo09_oool002goool00`000?ooooooo`0doooo00<0
0?ooooooool0[?ooo`03003ooooooooo09[oool002goool00`000?ooooooo`0coooo00<00?oooooo
ool0[_ooo`03003ooooooooo07Ooool3000000?oool0000000000P0001[oool002goool00`000?oo
ooooo`0boooo00<00?ooooooool0/?ooo`03003ooooooooo07Ooool010000?ooooooooooo`80000K
oooo000]oooo00<0003oooooool0<Oooo`03003ooooooooo0;;oool00`00ooooooooo`1goooo00@0
003oool00000000Loooo000]oooo00<0003oooooool0<?ooo`03003ooooooooo0;Coool00`00oooo
ooooo`1goooo0P0001goool002goool00`000?ooooooo`0_oooo00<00?ooooooool0]_ooo`03003o
oooooooo07Koool200007Oooo`00;Oooo`80000_oooo00<00?ooooooool0]oooo`03003ooooooooo
07Goool300007Oooo`00;Oooo`030000oooooooo02koool00`00ooooooooo`2hoooo00<00?oooooo
ool0Loooo`800002oooo00<0003oooooool06_ooo`00;Oooo`030000oooooooo02goool00`00oooo
ooooo`2joooo00<00?ooooooool0LOooo`@000001?ooo`000000000001[oool002goool00`000?oo
ooooo`0/oooo00<00?ooooooool0_?ooo`03003ooooooooo09;oool002goool00`000?ooooooo`0[
oooo00<00?ooooooool0__ooo`03003ooooooooo097oool002goool00`000?ooooooo`0Zoooo00<0
0?ooooooool0`?ooo`03003ooooooooo093oool002goool00`000?ooooooo`0Yoooo00<00?oooooo
ool0`_ooo`03003ooooooooo08ooool002goool00`000?ooooooo`0Xoooo00<00?ooooooool0a?oo
o`03003ooooooooo08koool002goool20000:?ooo`03003ooooooooo0<Goool00`00ooooooooo`2>
oooo000]oooo00<0003oooooool09_ooo`03003ooooooooo0<Ooool00`00ooooooooo`2=oooo000]
oooo00<0003oooooool09Oooo`03003ooooooooo0<Woool00`00ooooooooo`2<oooo000]oooo00<0
003oooooool09Oooo`03003ooooooooo0<[oool00`00ooooooooo`2;oooo000]oooo00<0003ooooo
ool09?ooo`03003ooooooooo0<coool00`00ooooooooo`2:oooo000]oooo00<0003oooooool08ooo
o`03003ooooooooo0<goool00`00ooooooooo`2:oooo000]oooo00<0003oooooool08_ooo`03003o
oooooooo0<ooool00`00ooooooooo`29oooo000]oooo00<0003oooooool08Oooo`03003ooooooooo
0=7oool00`00ooooooooo`28oooo000]oooo00<0003oooooool08?ooo`03003ooooooooo0=?oool0
0`00ooooooooo`27oooo000]oooo0P00027oool00`00ooooooooo`3Coooo00<00?ooooooool0Qooo
o`00;Oooo`030000oooooooo01ooool00`00ooooooooo`3Eoooo00<00?ooooooool0Q_ooo`00;Ooo
o`030000oooooooo01koool00`00ooooooooo`3Goooo00<00?ooooooool0QOooo`00;Oooo`030000
oooooooo01goool00`00ooooooooo`3Ioooo00<00?ooooooool0Q?ooo`004Oooo`@00004oooo0P00
00?oool400002oooo`030000oooooooo01coool00`00ooooooooo`3Joooo00<00?ooooooool0Q?oo
o`004?ooo`800002oooo0P0000?oool200000oooo`050000oooooooooooo000000[oool00`000?oo
ooooo`0Koooo00<00?ooooooool0g?ooo`03003ooooooooo08?oool0013oool00`000?ooooooo`02
oooo00<0003oooooool02oooo`030000oooooooo00Ooool00`000?ooooooo`0Koooo00<00?oooooo
ool0gOooo`03003ooooooooo08;oool000ooool200001?ooo`80000<oooo00<0003oooooool01ooo
o`030000oooooooo01[oool00`00ooooooooo`3Ooooo00<00?ooooooool0POooo`003oooo`800004
oooo0P0000coool00`000?ooooooo`07oooo0`0001Woool00`00ooooooooo`3Poooo00<00?oooooo
ool0POooo`003oooo`800004oooo0P0000_oool200002Oooo`030000oooooooo01Soool00`00oooo
ooooo`3Roooo00<00?ooooooool0P?ooo`003oooo`800004oooo0P0000[oool300002Oooo`030000
oooooooo01Soool00`00ooooooooo`3Soooo00<00?ooooooool0Ooooo`003oooo`800004oooo0P00
00Ooool500002_ooo`030000oooooooo01Ooool00`00ooooooooo`3Uoooo00<00?ooooooool0O_oo
o`003oooo`800004oooo0P0000Soool300002oooo`030000oooooooo01Koool00`00ooooooooo`3V
oooo00<00?ooooooool0O_ooo`004?ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0
003oooooool02oooo`030000oooooooo01Goool00`00ooooooooo`3Xoooo00<00?ooooooool0OOoo
o`004?ooo`800002oooo0P0000[oool400002Oooo`030000oooooooo01Goool00`00ooooooooo`3Y
oooo00<00?ooooooool0O?ooo`004Oooo`@0000;oooo100000Woool00`000?ooooooo`0Doooo00<0
0?ooooooool0j_ooo`03003ooooooooo07coool002goool200005?ooo`03003ooooooooo0>coool0
0`00ooooooooo`1koooo000]oooo00<0003oooooool04oooo`03003ooooooooo0>goool00`00oooo
ooooo`1joooo000]oooo00<0003oooooool04_ooo`03003ooooooooo0>koool00`00ooooooooo`1j
oooo000]oooo00<0003oooooool04Oooo`03003ooooooooo0?3oool00`00ooooooooo`1ioooo000]
oooo00<0003oooooool04?ooo`03003ooooooooo0?;oool00`00ooooooooo`1hoooo000]oooo00<0
003oooooool04?ooo`03003ooooooooo0??oool00`00ooooooooo`1goooo000]oooo00<0003ooooo
ool03oooo`03003ooooooooo0?Coool00`00ooooooooo`1goooo000]oooo00<0003oooooool03_oo
o`03003ooooooooo0?Koool00`00ooooooooo`1foooo000]oooo00<0003oooooool03_ooo`03003o
oooooooo0?Ooool00`00ooooooooo`1eoooo000]oooo0P0000koool00`00ooooooooo`3hoooo00<0
0?ooooooool0MOooo`00;Oooo`030000oooooooo00coool00`00ooooooooo`3joooo00<00?oooooo
ool0M?ooo`00;Oooo`030000oooooooo00_oool00`00ooooooooo`3loooo00<00?ooooooool0Looo
o`00;Oooo`030000oooooooo00_oool00`00ooooooooo`3loooo00<00?ooooooool0Loooo`00;Ooo
o`030000oooooooo00[oool00`00ooooooooo`3noooo00<00?ooooooool0L_ooo`00;Oooo`030000
oooooooo00Woool00`00ooooooooo`3ooooo0Oooo`03003ooooooooo077oool002goool00`000?oo
ooooo`09oooo00<00?ooooooool0ooooo`;oool00`00ooooooooo`1`oooo000]oooo00<0003ooooo
ool02?ooo`03003ooooooooo0?ooool3oooo00<00?ooooooool0L?ooo`00;Oooo`800009oooo00<0
0?ooooooool0ooooo`Coool00`00ooooooooo`1_oooo000]oooo00<0003oooooool01oooo`03003o
oooooooo0?ooool6oooo00<00?ooooooool0K_ooo`00;Oooo`030000oooooooo00Koool00`00oooo
ooooo`3ooooo1oooo`03003ooooooooo06koool002goool00`000?ooooooo`06oooo00<00?oooooo
ool0ooooo`Soool00`00ooooooooo`1]oooo000]oooo00<0003oooooool01Oooo`03003ooooooooo
0?ooool9oooo00<00?ooooooool0KOooo`00;Oooo`030000oooooooo00Coool00`00ooooooooo`3o
oooo2oooo`03003ooooooooo06coool002goool00`000?ooooooo`04oooo00<00?ooooooool0oooo
o`coool00`00ooooooooo`1[oooo000]oooo00<0003oooooool00oooo`03003ooooooooo0?ooool=
oooo00<00?ooooooool0Joooo`00;Oooo`030000oooooooo00?oool00`00ooooooooo`3ooooo3_oo
o`03003ooooooooo06[oool002goool200000oooo`03003ooooooooo0?ooool@oooo00<00?oooooo
ool0JOooo`00;Oooo`050000oooooooooooo003o0?oooolCoooo00<00?ooooooool0JOooo`00;Ooo
o`050000oooooooooooo003o0?oooolDoooo00<00?ooooooool0J?ooo`00;Oooo`040000oooooooo
003ooooooaGoool00`00ooooooooo`1Xoooo000Noooo1P0000Woool00`000?ooo`00o`3ooooo5ooo
o`03003ooooooooo06Ooool0023oool200002oooo`030000oooo003o0?oooolHoooo00<00?oooooo
ool0I_ooo`008?ooo`80000;oooo00<000000?ooool0oooooaSoool00`00ooooooooo`1Voooo000P
oooo0P0000Soool5o`00oooooa[oool00`00ooooooooo`1Uoooo000Poooo0P0000Soool5o`0000<0
003oooooool0oooooaSoool00`00ooooooooo`1Toooo000Poooo0P0000Soool5o`00oooooa_oool0
0`00ooooooooo`1Toooo000Poooo0P0000Soool5o`00oooooacoool00`00ooooooooo`1Soooo000P
oooo0P0000Woool3o`00oooooagoool00`00ooooooooo`1Soooo000Poooo0P0000_oool00`000?oo
ooooo`3ooooo7?ooo`03003ooooooooo06;oool0023oool200002oooo`030000oooooooo0?oooolM
oooo00<00?ooooooool0HOooo`007_ooo`@0000;oooo00<0003oooooool0oooooagoool00`00oooo
ooooo`1Qoooo000Poooo0P0000_oool00`000?ooooooo`3ooooo7_ooo`03003ooooooooo063oool0
02goool20000oooooaooool00`00ooooooooo`1Poooo000]oooo00<0003oooooool0oooooaooool0
0`00ooooooooo`1Ooooo000]oooo00<0003oooooool0oooooaooool00`00ooooooooo`1Ooooo000]
oooo00<0003oooooool0ooooob3oool00`00ooooooooo`1Noooo000]oooo00<0003oooooool0oooo
ob3oool00`00ooooooooo`1Noooo000]oooo00<0003oooooool0ooooob7oool00`00ooooooooo`1M
oooo000]oooo00<0003oooooool0ooooob;oool00`00ooooooooo`1Loooo000]oooo00<0003ooooo
ool0ooooob;oool00`00ooooooooo`1Loooo000]oooo00<0003oooooool0ooooob?oool00`00oooo
ooooo`1Koooo000]oooo0P000?oooolToooo00<00?ooooooool0Foooo`00;Oooo`030000oooooooo
0?oooolToooo00<00?ooooooool0F_ooo`00;Oooo`030000oooooooo0?oooolToooo00<00?oooooo
ool0F_ooo`00;Oooo`030000oooooooo0?oooolUoooo00<00?ooooooool0FOooo`00;Oooo`030000
oooooooo0?oooolVoooo00<00?ooooooool0F?ooo`00;Oooo`030000oooooooo0?oooolVoooo00<0
0?ooooooool0F?ooo`00;Oooo`030000oooooooo0?oooolWoooo00<00?ooooooool0Eoooo`00;Ooo
o`030000oooooooo0?oooolWoooo00<00?ooooooool0Eoooo`00;Oooo`80003ooooo:Oooo`03003o
oooooooo05Koool002goool00`000?ooooooo`3ooooo:?ooo`03003ooooooooo05Koool002goool0
0`000?ooooooo`3ooooo:Oooo`03003ooooooooo05Goool002goool00`000?ooooooo`3ooooo:Ooo
o`03003ooooooooo05Goool002goool00`000?ooooooo`3ooooo:_ooo`03003ooooooooo05Coool0
02goool00`000?ooooooo`3ooooo:oooo`03003ooooooooo05?oool002goool00`000?ooooooo`3o
oooo:oooo`03003ooooooooo05?oool002goool00`000?ooooooo`3ooooo;?ooo`03003ooooooooo
05;oool002goool20000ooooobgoool00`00ooooooooo`1Boooo000]oooo00<0003oooooool0oooo
obgoool00`00ooooooooo`1Aoooo000]oooo00<0003oooooool0ooooobgoool00`00ooooooooo`1A
oooo000]oooo00<0003oooooool0ooooobkoool00`00ooooooooo`1@oooo000]oooo00<0003ooooo
ool0ooooobkoool00`00ooooooooo`1@oooo000@oooo1P0000?oool200000oooo`@0000;oooo00<0
003oooooool0ooooobooool00`00ooooooooo`1?oooo000Boooo0P0000Goool200000oooo`050000
oooooooooooo000000[oool00`000?ooooooo`3ooooo;oooo`03003ooooooooo04ooool001;oool2
00003oooo`030000oooooooo00Ooool00`000?ooooooo`3ooooo<?ooo`03003ooooooooo04koool0
01;oool200003oooo`030000oooooooo00Ooool00`000?ooooooo`3ooooo<?ooo`03003ooooooooo
04koool001;oool200003oooo`030000oooooooo00Ooool30000oooooc7oool00`00ooooooooo`1=
oooo000Boooo0P0000koool200002Oooo`030000oooooooo0?oooolboooo00<00?ooooooool0C?oo
o`004_ooo`80000=oooo0`0000Woool00`000?ooooooo`3ooooo<_ooo`03003ooooooooo04coool0
01;oool200002_ooo`D0000:oooo00<0003oooooool0oooooc?oool00`00ooooooooo`1;oooo000B
oooo0P0000_oool300002oooo`030000oooooooo0?oooolcoooo00<00?ooooooool0Boooo`004_oo
o`80000;oooo00<0003oooooool02oooo`030000oooooooo0?ooooldoooo00<00?ooooooool0B_oo
o`004?ooo`@0000<oooo100000Woool00`000?ooooooo`3ooooo=?ooo`03003ooooooooo04[oool0
01;oool200003?ooo`@00009oooo00<0003oooooool0ooooocGoool00`00ooooooooo`19oooo000]
oooo0P000?oooolfoooo00<00?ooooooool0BOooo`00;Oooo`030000oooooooo0?oooolfoooo00<0
0?ooooooool0B?ooo`00;Oooo`030000oooooooo0?oooolfoooo00<00?ooooooool0B?ooo`00;Ooo
o`030000oooooooo0?oooolgoooo00<00?ooooooool0Aoooo`00;Oooo`030000oooooooo0?oooolg
oooo00<00?ooooooool0Aoooo`00;Oooo`030000oooooooo0?oooolhoooo00<00?ooooooool0A_oo
o`00;Oooo`030000oooooooo0?oooolhoooo00<00?ooooooool0A_ooo`00;Oooo`030000oooooooo
0?oooolioooo00<00?ooooooool0AOooo`00;Oooo`030000oooooooo0?oooolioooo00<00?oooooo
ool0AOooo`00;Oooo`80003ooooo>oooo`03003ooooooooo04Coool002goool00`000?ooooooo`3o
oooo>_ooo`03003ooooooooo04Coool002goool00`000?ooooooo`3ooooo>oooo`03003ooooooooo
04?oool002goool00`000?ooooooo`3ooooo>oooo`03003ooooooooo04?oool002goool00`000?oo
ooooo`3ooooo??ooo`03003ooooooooo04;oool002goool00`000?ooooooo`3ooooo??ooo`03003o
oooooooo04;oool002goool00`000?ooooooo`3ooooo??ooo`03003ooooooooo04;oool002goool0
0`000?ooooooo`3ooooo?Oooo`03003ooooooooo047oool002goool20000ooooockoool00`00oooo
ooooo`11oooo000]oooo00<0003oooooool0ooooockoool00`00ooooooooo`10oooo000]oooo00<0
003oooooool0ooooockoool00`00ooooooooo`10oooo000]oooo00<0003oooooool0ooooocooool0
0`00ooooooooo`0ooooo000]oooo00<0003oooooool0ooooocooool00`00ooooooooo`0ooooo000]
oooo00<0003oooooool0oooood3oool00`00ooooooooo`0noooo000]oooo00<0003oooooool0oooo
od3oool00`00ooooooooo`0noooo000]oooo00<0003oooooool0oooood7oool00`00ooooooooo`0m
oooo000]oooo0P000?oooom2oooo00<00?ooooooool0?Oooo`00;Oooo`030000oooooooo0?oooom1
oooo00<00?ooooooool0?Oooo`00;Oooo`030000oooooooo0?oooom2oooo00<00?ooooooool0??oo
o`00;Oooo`030000oooooooo0?oooom2oooo00<00?ooooooool0??ooo`00;Oooo`030000oooooooo
0?oooom3oooo00<00?ooooooool0>oooo`007Oooo`L00009oooo00<0003oooooool0oooood?oool0
0`00ooooooooo`0koooo000Noooo1`0000Soool00`000?ooooooo`3oooooA?ooo`03003ooooooooo
03[oool001ooool00`000?ooooooo`02oooo00<0003oooooool01_ooo`030000oooooooo0?oooom4
oooo00<00?ooooooool0>_ooo`008?ooo`030000oooooooo00[oool00`000?ooooooo`3ooooo@_oo
o`Go000joooo000Qoooo00<0003oooooool02Oooo`<0003ooooo@_ooo`Go000joooo000Qoooo0P00
00[oool00`000?ooooooo`3ooooo@_ooo`Go000joooo000Roooo00<0003oooooool02?ooo`030000
oooooooo0?oooom2oooo1Ol003[oool002;oool200002Oooo`030000oooooooo0?oooom3oooo0ol0
03_oool002;oool200002Oooo`030000oooooooo0?oooon1oooo000Moooo00<0003oooooool00_oo
o`800009oooo00<0003oooooool0oooooh7oool001koool00`000?ooooooo`030000ooooohgoool0
01ooool40000ooooohkoool00?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003o
oooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool002Soool400000_oo
o`@0003oooooOoooo`00:?ooo`030000oooooooo00Koool00`000?ooooooo`3oooooOOooo`00:?oo
o`030000oooooooo00Koool00`000?ooooooo`3oooooOOooo`00:?ooo`030000oooooooo00Koool0
0`000?ooooooo`3oooooOOooo`00:?ooo`030000oooooooo00Koool00`000?ooooooo`3oooooOOoo
o`00:?ooo`030000oooooooo00Koool00`000?ooooooo`3oooooOOooo`00:?ooo`030000oooooooo
00Koool00`000?ooooooo`3oooooOOooo`00:?ooo`030000oooooooo00Koool00`000?ooooooo`3o
ooooOOooo`00:?ooo`030000oooooooo00Koool00`000?ooooooo`3oooooOOooo`00:?ooo`030000
oooooooo00Koool00`000?ooooooo`3oooooOOooo`00:?ooo`030000oooooooo00Koool00`000?oo
ooooo`3oooooOOooo`00:?ooo`030000oooooooo00Koool00`000?ooooooo`3oooooOOooo`00:?oo
o`030000oooooooo00Koool00`000?ooooooo`3oooooOOooo`00:?ooo`030000oooooooo00Koool0
0`000?ooooooo`3oooooOOooo`00:?ooo`@00002oooo10000?oooomooooo003ooooo/Oooo`00oooo
ok7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool001cooolP0000ooooogGoool00?oooona
oooo003ooooo/Oooo`00oooook7oool00?oooonaoooo000Woooo100000_oool40000ooooogOoool0
02Ooool00`000?ooooooo`0?oooo00<0003oooooool0ooooogGoool002Ooool00`000?ooooooo`0?
oooo00<0003oooooool0ooooogGoool001ooool400001?ooo`030000oooooooo00;oool3000000?o
ool0000000000P0000Goool00`000?ooooooo`3oooooMOooo`008?ooo`800005oooo00<0003ooooo
ool00oooo`040000oooooooooooo0P0000Koool00`000?ooooooo`3oooooMOooo`008?ooo`800005
oooo00<0003oooooool01?ooo`040000oooo000000001oooo`030000oooooooo0?oooomeoooo000P
oooo0P0000Goool00`000?ooooooo`05oooo0P0000Soool00`000?ooooooo`3oooooMOooo`008?oo
o`800005oooo00<0003oooooool01Oooo`800008oooo00<0003oooooool0ooooogGoool0023oool2
00001Oooo`030000oooooooo00Coool300002?ooo`030000oooooooo0?oooomeoooo000Poooo0P00
00Goool00`000?ooooooo`03oooo0P0000;oool00`000?ooooooo`05oooo00<0003oooooool0oooo
ogGoool001ooool500000oooo`030000oooooooo00;oool4000000Coool0000000000005oooo00<0
003oooooool0ooooogGoool0023oool200001Oooo`030000oooooooo00ooool00`000?ooooooo`3o
ooooMOooo`008?ooo`800005oooo00<0003oooooool03oooo`030000oooooooo0?oooomeoooo000P
oooo0P0000Goool00`000?ooooooo`0?oooo00<0003oooooool0ooooogGoool0027oool00`000?oo
ooooo`02000000?oool0000000000P0000_oool40000ooooogOoool002;oool30000ooooohcoool0
0?oooonaoooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.419085, -0.468555, 
  0.013756, 0.0178679}}]
}, Open  ]],

Cell[TextData[{
  "Die Funktion, die die Punkte analytisch verbindet, ist also gefunden. Es \
handelt sich um ein Polynom ",
  Cell[BoxData[
      \(TraditionalForm\`2.\)]],
  " Grades in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", eine ",
  StyleBox["Verbindungsparabel",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Verallgemeinertes Problem"
}], "Subsubsection"],

Cell[TextData[{
  "Die interpolierende Abbildung ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  " f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " Wertepaare ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[Mu] \[Rule] A\_\[Mu]\)]],
  " mit verschiedenen St\[UDoubleDot]tzpunkten ist zu finden."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". L\[ODoubleDot]sungsidee"
}], "Subsubsection"],

Cell["\<\
Summe mit Summenzeichen schreiben, damit das Programm gleich fertig \
ist:\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[BoxData[{
    \(Clear[f]\), 
    \(f[x_, N_] := 
      \[Sum]\+\(\[Mu]\  = \ 1\)\%N
          \(\(\[Product]\+\(j = 1\)\%\(\[Mu] - 1\)\((x - a\_j)
                  \)\)\/\(\[Product]\+\(j = 1\)\%\(\[Mu] - 1\)\((
                  a\_\[Mu] - a\_j)\)\)\) A\_\[Mu]\ 
          \(\[Product]\+\(j = \[Mu] + 1\)\%N\((x - a\_j)
                \)\)\/\(\[Product]\+\(j = \[Mu] + 1\)\%N\((a\_\[Mu] - a\_j)
                \)\)\)}], "Input"],

Cell[TextData[{
  "Aufgrund der Konstruktion ergibt sich ein Polynom ",
  Cell[BoxData[
      \(TraditionalForm\`\((N - 1)\)\)]],
  "-ten Grades in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". Die hier vorgenommene Darstellung schafft auch f\[UDoubleDot]r den \
Rechner Eindeutigkeit."
}], "Text"],

Cell["\<\
Die ersten vier allgemeinen Interpolationsfunktionen ergeben:\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Range[4]\), 
    \(\(f[x, #]&\)/@Range[4]\)}], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output"],

Cell[BoxData[
    \({A\_1, 
      \(\((x - a\_2)\)\ A\_1\)\/\(a\_1 - a\_2\) + 
        \(\((x - a\_1)\)\ A\_2\)\/\(\(-a\_1\) + a\_2\), 
      \(\((x - a\_2)\)\ \((x - a\_3)\)\ A\_1\)\/\(\((a\_1 - a\_2)\)\ 
            \((a\_1 - a\_3)\)\) + 
        \(\((x - a\_1)\)\ \((x - a\_3)\)\ A\_2\)\/\(\((\(-a\_1\) + a\_2)\)\ 
            \((a\_2 - a\_3)\)\) + 
        \(\((x - a\_1)\)\ \((x - a\_2)\)\ A\_3\)\/\(\((\(-a\_1\) + a\_3)\)\ 
            \((\(-a\_2\) + a\_3)\)\), 
      \(\((x - a\_2)\)\ \((x - a\_3)\)\ \((x - a\_4)\)\ 
            A\_1\)\/\(\((a\_1 - a\_2)\)\ \((a\_1 - a\_3)\)\ 
            \((a\_1 - a\_4)\)\) + 
        \(\((x - a\_1)\)\ \((x - a\_3)\)\ \((x - a\_4)\)\ 
            A\_2\)\/\(\((\(-a\_1\) + a\_2)\)\ \((a\_2 - a\_3)\)\ 
            \((a\_2 - a\_4)\)\) + 
        \(\((x - a\_1)\)\ \((x - a\_2)\)\ \((x - a\_4)\)\ 
            A\_3\)\/\(\((\(-a\_1\) + a\_3)\)\ \((\(-a\_2\) + a\_3)\)\ 
            \((a\_3 - a\_4)\)\) + 
        \(\((x - a\_1)\)\ \((x - a\_2)\)\ \((x - a\_3)\)\ 
            A\_4\)\/\(\((\(-a\_1\) + a\_4)\)\ \((\(-a\_2\) + a\_4)\)\ 
            \((\(-a\_3\) + a\_4)\)\)}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Programmierung der Interpolation"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Problem"
}], "Subsubsection"],

Cell[TextData[{
  "Die interpolierende Abbildung ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  " f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " Wertepaare soll so programmiert werden, da\[SZ] Wertepaare beliebiger L\
\[ADoubleDot]nge verwertet werden k\[ODoubleDot]nnen. Au\[SZ]erdem soll nun \
die M\[ODoubleDot]glichkeit einer individuellen Gewichtung einer St\
\[UDoubleDot]tzstelle dadurch m\[ODoubleDot]glich sein, da\[SZ] die Potenz \
der entsprechenden Nullstelle jeweils ausgew\[ADoubleDot]hlt werden kann."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". L\[ODoubleDot]sungsidee"
}], "Subsubsection"],

Cell["\<\
Eine Liste mit Wertepaaren wird \[UDoubleDot]bergeben, die \
Interpolationsvariable ist zu benennen:\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[BoxData[{
    \(Clear[LagrangeInterpolation]\), 
    \(LagrangeInterpolation[wertepaarliste : {{_, _, _ : 1}..}, var_] := \n\t
      Block[{\n\t\t\tN = Length[wertepaarliste], \n\t\t\tdaten\ , \n\t\t\tab
          \ , \ ord\ , \ pot\ , \ \ \ \ \ \ \ 
           (*\ Abszisse, \ Ordinate, \ Potenz\ *) \n\t\t\t\[Mu]\ , \ \[Nu]\n
          \t\t}\ , \n\t\t\n\t\t
        daten = wertepaarliste /. {a_, b_} \[RuleDelayed] {a, b, 1}\ ; \n
        \t\t{ab, ord, \ pot} = Transpose[daten]\ ; \n\t\t
        \[Sum]\+\(\[Mu]\  = \ 1\)\%N
            \((\[Product]\+\(\[Nu]\  = \ 1\)\%\(\[Mu] - 1\)\((
                    \(var\  - \ 
                        ab\[LeftDoubleBracket]\[Nu]\[RightDoubleBracket]\)\/\(\
ab\[LeftDoubleBracket]\[Mu]\[RightDoubleBracket]\  - \ 
                        ab\[LeftDoubleBracket]\[Nu]\[RightDoubleBracket]\))
                    \)\^pot\[LeftDoubleBracket]\[Nu]\[RightDoubleBracket])\) 
            ord\[LeftDoubleBracket]\[Mu]\[RightDoubleBracket]\ 
            \((\[Product]\+\(\[Nu]\  = \ \[Mu] + 1\)\%N
                  \((\(var\  - \ 
                        ab\[LeftDoubleBracket]\[Nu]\[RightDoubleBracket]\)\/\(\
ab\[LeftDoubleBracket]\[Mu]\[RightDoubleBracket]\  - \ 
                        ab\[LeftDoubleBracket]\[Nu]\[RightDoubleBracket]\))
                    \)\^pot\[LeftDoubleBracket]\[Nu]\[RightDoubleBracket])
              \)\n]\)}], "Input"],

Cell["Die interne Programmierung besitzt nun folgende Gestalt:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?LagrangeInterpolation\)\)], "Input"],

Cell[BoxData[
    \("Global`LagrangeInterpolation"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      StyleBox[
        \(LagrangeInterpolation[wertepaarliste : {{_, \ _, \ _ : 1}..}, \ 
            var_]\  := \ 
          Block[{N\  = \ Length[wertepaarliste], \ daten, \ ab, \ ord, \ pot, 
              \ \[Mu], \ \[Nu]}, \ 
            daten\  = \ 
              wertepaarliste\  /. \ {a_, \ b_}\  :> \ {a, \ b, \ 1}; 
            \ {ab, \ ord, \ pot}\  = \ Transpose[daten]; \ 
            Sum[Product[
                  \((\((var\  - \ ab[\([\[Nu]]\)])\)/
                        \((ab[\([\[Mu]]\)]\  - \ ab[\([\[Nu]]\)])\))\)^
                    pot[\([\[Nu]]\)], \ {\[Nu], \ 1, \ \[Mu]\  - \ 1}]*
                ord[\([\[Mu]]\)]*
                Product[
                  \((\((var\  - \ ab[\([\[Nu]]\)])\)/
                        \((ab[\([\[Mu]]\)]\  - \ ab[\([\[Nu]]\)])\))\)^
                    pot[\([\[Nu]]\)], \ {\[Nu], \ \[Mu]\  + \ 1, \ N}], 
              \ {\[Mu], \ 1, \ N}]]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      InputForm[ 
        Definition[ LagrangeInterpolation]],
      Editable->True,
      AutoDelete->True]], "Print"]
}, Open  ]],

Cell["Damit ergibt sich folgendes Interpolationsbeispiel:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LagrangeInterpolation[{{a, A[x, y]}, {b, B[x, y]}, {c, C[x, y]}}, z]\)],
   "Input"],

Cell[BoxData[
    \(\(\((\(-b\) + z)\)\ \((\(-c\) + z)\)\ A[x, y]\)\/\(\((a - b)\)\ 
          \((a - c)\)\) + 
      \(\((\(-a\) + z)\)\ \((\(-c\) + z)\)\ B[x, y]\)\/\(\((\(-a\) + b)\)\ 
          \((b - c)\)\) + 
      \(\((\(-a\) + z)\)\ \((\(-b\) + z)\)\ C[x, y]\)\/\(\((\(-a\) + c)\)\ 
          \((\(-b\) + c)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Dadurch ist die analytische Interpolation zwischen unbekannten Funktionen \
mehrerer Ver\[ADoubleDot]nderlicher gegl\[UDoubleDot]ckt. All diese \
Einsichten finden sich letztlich bereits in einer einzigen Formel (vgl. ",
  ButtonBox["[BrS1987]",
    ButtonData:>"[BrS1987]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 7.1.2.6., Seite 755) von Lagrange (1736-1813)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Mehrdimensionales Beispiel"
}], "Subsubsection"],

Cell[TextData[{
  "Sind die noch unbekannten Funktionen mehrerer Ver\[ADoubleDot]nderlicher \
ebenfalls Interpolationspolynome, so lassen sich ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-dimensionale Datenfelder aus Me\[SZ]daten interpolieren."
}], "Text"],

Cell["\<\
Als Beispiel f\[UDoubleDot]r eine Reliefzeichnung gelingt folgende \
Interpolation:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(funktion = 
      LagrangeInterpolation[
        Transpose[{Range[4], {Sin[x], Log[x], Exp[\(-x\)], Cos[x]}}], y]\)], 
  "Input"],

Cell[BoxData[
    \(1\/2\ E\^\(-x\)\ \((4 - y)\)\ \((\(-2\) + y)\)\ \((\(-1\) + y)\) + 
      1\/6\ \((\(-3\) + y)\)\ \((\(-2\) + y)\)\ \((\(-1\) + y)\)\ Cos[x] + 
      1\/2\ \((3 - y)\)\ \((4 - y)\)\ \((\(-1\) + y)\)\ Log[x] + 
      1\/6\ \((2 - y)\)\ \((3 - y)\)\ \((4 - y)\)\ Sin[x]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[Evaluate[funktion], {x, 1\/30, 3}, {y, 1, 4}, 
      AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<f[x, y]\>"}, 
      PlotPoints \[Rule] 7]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.2234 .16912 -9.67427 -15 ]
[.2234 .16912 .32573 0 ]
[.44281 .08283 -8.97149 -15 ]
[.44281 .08283 1.02851 0 ]
[.68156 -0.01098 -8.26871 -15 ]
[.68156 -0.01098 1.73129 0 ]
[.29165 .07573 -10.2423 -15 ]
[.29165 .07573 .75771 0 ]
[.70096 -0.00478 0 -10.4368 ]
[.70096 -0.00478 10 4.56323 ]
[.80849 .15988 0 -10.1686 ]
[.80849 .15988 10 4.83137 ]
[.90119 .30183 0 -9.94535 ]
[.90119 .30183 10 5.05465 ]
[.98191 .42546 0 -9.75656 ]
[.98191 .42546 10 5.24344 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.01573 .31767 -19 -4.64459 ]
[.01573 .31767 0 10.3554 ]
[.0034 .39492 -10 -4.75391 ]
[.0034 .39492 0 10.2461 ]
[-0.00955 .47609 -10 -4.86934 ]
[-0.00955 .47609 0 10.1307 ]
[-0.05457 .39542 -35 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.23236 .1787 m
.23684 .18349 L
s
gsave
.2234 .16912 -70.6743 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.45097 .0931 m
.45505 .09824 L
s
gsave
.44281 .08283 -69.9715 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -69.2687 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06977 .24237 m
.07261 .24509 L
s
.10946 .22683 m
.11227 .22959 L
s
.14978 .21104 m
.15255 .21384 L
s
.19074 .195 m
.19347 .19784 L
s
.27466 .16214 m
.27731 .16505 L
s
.31766 .1453 m
.32026 .14826 L
s
.36136 .12819 m
.36391 .13119 L
s
.40579 .11079 m
.40829 .11383 L
s
.49691 .07511 m
.49931 .07824 L
s
.54364 .05682 m
.54598 .05998 L
s
.59117 .0382 m
.59345 .04141 L
s
.63953 .01927 m
.64175 .02252 L
s
gsave
.29165 .07573 -71.2423 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.125000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -14.4368 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.79613 .16428 m
.78995 .16648 L
s
gsave
.80849 .15988 -61 -14.1686 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88871 .30589 m
.88247 .30793 L
s
gsave
.90119 .30183 -61 -13.9453 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -13.7566 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.71157 .03492 m
.70789 .03634 L
s
.73369 .06877 m
.73001 .07015 L
s
.75514 .10158 m
.75145 .10294 L
s
.77594 .1334 m
.77224 .13474 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.87123 .27915 m
.8675 .28039 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.95406 .40586 m
.9503 .40701 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
68.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02799 .313 m
.03412 .31066 L
s
gsave
.01573 .31767 -80 -8.64459 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.01572 .39041 m
.02188 .38816 L
s
gsave
.0034 .39492 -71 -8.75391 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.00283 .47174 m
.00903 .46957 L
s
gsave
-0.00955 .47609 -71 -8.86934 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.02498 .332 m
.02866 .33061 L
s
.02193 .35123 m
.02562 .34986 L
s
.01885 .3707 m
.02254 .36934 L
s
.01256 .41037 m
.01626 .40902 L
s
.00936 .43057 m
.01306 .42924 L
s
.00612 .45103 m
.00983 .44971 L
s
.03097 .29422 m
.03464 .29281 L
s
.03391 .27567 m
.03758 .27425 L
s
.03681 .25734 m
.04048 .25591 L
s
gsave
-0.05457 .39542 -96 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
68.125000 14.625000 moveto
(@) show
72.062500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
78.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
89.812500 14.625000 moveto
(D) show
93.750000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.804 .968 .909 r
.34245 .76066 .39972 .7582 .49023 .72864 .43727 .68811 Metetra
.725 .802 .912 r
.43727 .68811 .49023 .72864 .58343 .69051 .53295 .64188 Metetra
.708 .774 .903 r
.53295 .64188 .58343 .69051 .67897 .64672 .63111 .59886 Metetra
.7 .783 .915 r
.63111 .59886 .67897 .64672 .77685 .60137 .73211 .5572 Metetra
.69 .804 .936 r
.73211 .5572 .77685 .60137 .87756 .55865 .83632 .51693 Metetra
.674 .819 .953 r
.83632 .51693 .87756 .55865 .98201 .52188 .94421 .47855 Metetra
.676 .632 .797 r
.28662 .66198 .34245 .76066 .43727 .68811 .38161 .61971 Metetra
.681 .706 .866 r
.38161 .61971 .43727 .68811 .53295 .64188 .47916 .58185 Metetra
.674 .736 .897 r
.47916 .58185 .53295 .64188 .63111 .59886 .57984 .54624 Metetra
.666 .768 .926 r
.57984 .54624 .63111 .59886 .73211 .5572 .68409 .51151 Metetra
.656 .801 .953 r
.68409 .51151 .73211 .5572 .83632 .51693 .79221 .47683 Metetra
.642 .831 .973 r
.79221 .47683 .83632 .51693 .94421 .47855 .9045 .44164 Metetra
.494 .477 .767 r
.23224 .51953 .28662 .66198 .38161 .61971 .3233 .53829 Metetra
.619 .659 .867 r
.3233 .53829 .38161 .61971 .47916 .58185 .42193 .51624 Metetra
.629 .716 .909 r
.42193 .51624 .47916 .58185 .57984 .54624 .52489 .49013 Metetra
.627 .756 .94 r
.52489 .49013 .57984 .54624 .68409 .51151 .63225 .46225 Metetra
.62 .789 .963 r
.63225 .46225 .68409 .51151 .79221 .47683 .74426 .43279 Metetra
.611 .817 .979 r
.74426 .43279 .79221 .47683 .9045 .44164 .86116 .40145 Metetra
.173 .306 .76 r
.17548 .39055 .23224 .51953 .3233 .53829 .26136 .45929 Metetra
.547 .648 .901 r
.26136 .45929 .3233 .53829 .42193 .51624 .36068 .45114 Metetra
.586 .716 .933 r
.36068 .45114 .42193 .51624 .52489 .49013 .46577 .43189 Metetra
.6 .754 .952 r
.46577 .43189 .52489 .49013 .63225 .46225 .5761 .40712 Metetra
.606 .777 .962 r
.5761 .40712 .63225 .46225 .74426 .43279 .69169 .37857 Metetra
.61 .791 .968 r
.69169 .37857 .74426 .43279 .86116 .40145 .81272 .34698 Metetra
0 .102 .595 r
.10832 .32736 .17548 .39055 .26136 .45929 .1934 .39848 Metetra
.483 .699 .964 r
.1934 .39848 .26136 .45929 .36068 .45114 .29423 .39303 Metetra
.564 .75 .964 r
.29423 .39303 .36068 .45114 .46577 .43189 .40181 .37294 Metetra
.606 .77 .959 r
.40181 .37294 .46577 .43189 .5761 .40712 .51519 .34359 Metetra
.632 .773 .948 r
.51519 .34359 .5761 .40712 .69169 .37857 .634 .30732 Metetra
.646 .762 .934 r
.634 .30732 .69169 .37857 .81272 .34698 .75816 .26614 Metetra
.188 0 0 r
.01551 .39173 .10832 .32736 .1934 .39848 .11506 .37336 Metetra
.49 .845 .994 r
.11506 .37336 .1934 .39848 .29423 .39303 .22051 .34901 Metetra
.604 .831 .986 r
.22051 .34901 .29423 .39303 .40181 .37294 .33203 .31481 Metetra
.664 .809 .953 r
.33203 .31481 .40181 .37294 .51519 .34359 .44917 .2689 Metetra
.697 .777 .913 r
.44917 .2689 .51519 .34359 .634 .30732 .57114 .21191 Metetra
.705 .733 .873 r
.57114 .21191 .634 .30732 .75816 .26614 .69726 .14687 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.23236 .1787 m
.23684 .18349 L
s
gsave
.2234 .16912 -70.6743 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.45097 .0931 m
.45505 .09824 L
s
gsave
.44281 .08283 -69.9715 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -69.2687 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06977 .24237 m
.07261 .24509 L
s
.10946 .22683 m
.11227 .22959 L
s
.14978 .21104 m
.15255 .21384 L
s
.19074 .195 m
.19347 .19784 L
s
.27466 .16214 m
.27731 .16505 L
s
.31766 .1453 m
.32026 .14826 L
s
.36136 .12819 m
.36391 .13119 L
s
.40579 .11079 m
.40829 .11383 L
s
.49691 .07511 m
.49931 .07824 L
s
.54364 .05682 m
.54598 .05998 L
s
.59117 .0382 m
.59345 .04141 L
s
.63953 .01927 m
.64175 .02252 L
s
gsave
.29165 .07573 -71.2423 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.125000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GQP00`40o`000?l0003ooooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
0?oooonaoooo003ooooo/Oooo`00ooooobkoool50000O_ooo`00ooooobkoool200000_ooo`80001m
oooo003ooooo<oooo`80001loooo003ooooo<oooo`80001loooo003ooooo<oooo`80001loooo003o
oooo<_ooo`<0001loooo003ooooo<Oooo`<0001moooo003ooooo<_ooo`80001moooo003ooooo<ooo
o`80001loooo003ooooo;_ooo`030000oooooooo00;oool200003Oooo`H0001Yoooo003ooooo;_oo
o`800002oooo0`0000ooool20000Joooo`00oooooc3oool400004?ooo`80001[oooo003oooooA?oo
o`80001[oooo003oooooA?ooo`80001[oooo003oooooA?ooo`80001[oooo003oooooA?ooo`80001[
oooo003oooooA?ooo`80001[oooo003oooooA?ooo`80001[oooo003oooooA?ooo`80001[oooo003o
oooo>Oooo`800007oooo100006_oool00?oooolgoooo0P000003oooo0000000000Soool20000Jooo
o`00ooooocCoool300000oooo`80001eoooo003ooooo<Oooo`<00006oooo00<0003oool00000M?oo
o`00ooooobooool200002Oooo`040000oooooooo0000Loooo`00ooooobcoool300002oooo`040000
oooooooo0000Loooo`00ooooob[oool200003_ooo`050000oooooooooooo000007;oool00?oooolW
oooo0`00013oool00`000?ooooooo`02oooo00<0003oooooool0Koooo`00ooooobGoool200000_oo
o`030000oooooooo00koool00`000?ooooooo`02oooo00<0003oooooool0Koooo`00ooooob;oool3
00005_ooo`030000oooooooo00;oool00`000?ooooooo`1^oooo003ooooo7oooo`<0000Ioooo00<0
003oooooool00oooo`030000oooooooo06goool00:7oool3000000?oool0000000000P0007?oool2
00007?ooo`030000oooooooo00?oool00`000?ooooooo`1]oooo002Roooo00@0003oooooooooool2
0000LOooo`<0000Noooo00<0003oooooool00oooo`80001^oooo002Soooo00@0003oool00000001_
oooo0`00027oool00`000?ooooooo`02oooo00<0003oool00000K_ooo`00Y?ooo`80000boooo1`00
03Goool400008_ooo`030000oooooooo00Goool00`000?ooooooo`1[oooo002Toooo0P0003?oool7
0000<_ooo`80000Voooo00<0003oooooool01_ooo`030000oooooooo06[oool00:?oool30000=?oo
o`030000oooooooo00;oool00`000?ooooooo`0]oooo0`0002Soool00`000?ooooooo`06oooo00<0
003oooooool0J_ooo`00X_ooo`800002oooo00<0003oooooool0<_ooo`030000oooooooo02koool3
0000:oooo`030000oooooooo00Ooool00`000?ooooooo`1Yoooo002Qoooo10000004oooo00000000
0000<oooo`030000oooooooo02_oool20000;_ooo`030000oooooooo00Soool00`000?ooooooo`1X
oooo003Loooo0P0002Woool30000<?ooo`030000oooooooo00Soool00`000?ooooooo`1Xoooo003M
oooo00<0003oooooool09Oooo`80000coooo00<0003oooooool02Oooo`030000oooooooo06Ooool0
0=goool200008oooo`<00002oooo00<0003oooooool0<?ooo`030000oooooooo00[oool00`000?oo
ooooo`1Voooo003Moooo0P00027oool20000>?ooo`030000oooooooo00[oool00`000?ooooooo`1V
oooo003Hoooo00<0003oooooool00_ooo`80000Noooo0`0003[oool00`000?ooooooo`0;oooo00<0
003oooooool0IOooo`00fOooo`030000oooooooo00<0000Koooo0`0003goool00`000?ooooooo`0:
oooo0`0006Koool00=[oool400006_ooo`800010oooo00<0003oooooool03?ooo`030000oooooooo
06Coool00?Goool30000@oooo`030000oooooooo00coool00`000?ooooooo`1Soooo003coooo0P00
0003oooo0000oooo04?oool00`000?ooooooo`0=oooo00<0003oooooool0H_ooo`00l?ooo`<00018
oooo00<0003oooooool03Oooo`030000oooooooo06;oool00>koool20000Boooo`030000oooooooo
00koool00`000?ooooooo`1Qoooo003[oooo0`0004goool00`000?ooooooo`0?oooo00<0003ooooo
ool0H?ooo`00j?ooo`<0001@oooo00<0003oooooool03oooo`030000oooooooo063oool00>Goool3
0000Doooo`030000oooooooo013oool00`000?ooooooo`1Ooooo003Soooo100005Coool00`000?oo
ooooo`0Aoooo00<0003oooooool0G_ooo`00hOooo`800004oooo00<0003oooooool0DOooo`030000
oooooooo017oool00`000?ooooooo`1Noooo003Noooo0`0005[oool00`000?ooooooo`0Boooo00<0
003oooooool0GOooo`00g?ooo`80001Moooo00<0003oooooool04Oooo`030000oooo000005koool0
0=Woool30000Goooo`030000oooooooo01?oool00`000?ooooooo`1Loooo003Foooo0`0006;oool0
0`000?ooooooo`0Doooo00<0003oooooool0Foooo`00e?ooo`80001Uoooo00<0003oooooool05?oo
o`030000oooooooo05_oool00=7oool300000_ooo`030000oooooooo06;oool00`000?ooooooo`0E
oooo00<0003oooooool0F_ooo`00coooo`80001Zoooo00<0003oooooool05_ooo`030000oooooooo
05Woool00<coool30000K?ooo`030000oooooooo01Koool00`000?ooooooo`1Ioooo003:oooo0P00
06ooool00`000?ooooooo`0Goooo00<0003oooooool0F?ooo`00Roooo`H0000foooo0`0007;oool0
0`000?ooooooo`0Goooo00<0003oooooool0Eoooo`00SOooo`80000eoooo0`0007Goool00`000?oo
ooooo`0Goooo00<0003oooooool0Eoooo`00SOooo`80000coooo0P0000?oool00`000?ooooooo`1b
oooo00<0003oooooool06?ooo`030000oooooooo05Koool008goool20000<?ooo`<0001joooo00<0
003oooooool05oooo`<0001Goooo002=oooo0P0002koool20000OOooo`030000oooooooo01Woool0
0`000?ooooooo`0;oooo1`0004?oool008goool20000:oooo`<0001ooooo00<0003oooooool06_oo
o`030000oooooooo00_oool70000@_ooo`00SOooo`80000Yoooo0P0008;oool00`000?ooooooo`0K
oooo00<0003oooooool02oooo`030000oooooooo00;oool00`000?ooooooo`10oooo002=oooo0P00
02Koool30000Q?ooo`030000oooooooo01_oool00`000?ooooooo`0<oooo00<0003oooooool0A?oo
o`00SOooo`80000Soooo0`0000;oool00`000?ooooooo`20oooo100001goool00`000?ooooooo`0<
oooo00<0003oooooool0@oooo`00SOooo`80000Qoooo0P0008Koool200000[Bkg`80000Noooo00<0
003oooooool02oooo`800014oooo002;oooo100001koool30000Q_ooo`800004];_O00<0002d^ml0
00007Oooo`030000oooooooo00coool00`000?ooooooo`12oooo002=oooo0P0001coool20000Qooo
o`800006];_O00<0002d^ml000007_ooo`030000oooooooo00_oool20000@oooo`00Z?ooo`<00027
oooo0P0000Rd^ml010000;BkgkBkg`0001koool00`000?ooooooo`0:oooo0P0004?oool00:Koool2
0000R?ooo`80000:];_O00@0002d^mnd^ml0000Moooo0P0000Ooool00`000?ooooooo`02oooo0P00
04?oool00:?oool300000_ooo`030000oooooooo08?oool200003;Bkg`050000];_O];_O];_O0000
01_oool010000?ooooooo`0000Ooool00`000?ooooooo`030000@oooo`00X?ooo`<00029oooo0P00
00jd^ml01@000;BkgkBkgkBkg`00000Ooooo00<0003oooooool01Oooo`@00014oooo002Noooo0P00
08[oool200004;Bkg`030000];_O];_O00:d^ml00`000?ooooooo`0Loooo00<0003oooooool0COoo
o`00Voooo`<0002:oooo0P0001>d^ml01@000;BkgkBkgkBkg`00000Ooooo00<0003oooooool0C?oo
o`00VOooo`80002;oooo0P0001Fd^ml00`000;BkgkBkg`02];_O00<0003oooooool07Oooo`030000
oooooooo04_oool009Koool3000000?oool0003oool0R?ooo`80000G];_O00<0002d^mnd^ml00[Bk
g`030000oooooooo01goool00`000?ooooooo`0Xoooo0P00027oool009Coool200001?ooo`030000
oooooooo08Goool200006KBkg`030000];_O];_O00>d^ml00`000?ooooooo`0Moooo00<0003ooooo
ool09oooo`<0000Poooo002Aoooo0`0008coool200006kBkg`030000];_O];_O00>d^ml00`000?oo
ooooo`0Moooo00<0003oooooool0:Oooo`030000oooooooo01koool008koool30000SOooo`80000M
];_O00<0002d^mnd^ml01;Bkg`030000oooooooo01goool00`000?ooooooo`0Yoooo00<0003ooooo
ool07Oooo`00S?ooo`80002>oooo0P0001nd^ml00`000;BkgkBkg`04];_O00<0003oooooool07_oo
o`030000oooooooo02Soool00`000?ooooooo`0Moooo0029oooo0`0008koool200008KBkg`030000
];_O];_O00Fd^ml00`000?ooooooo`0Loooo0P0002Woool300007_ooo`00Qoooo`800002oooo00<0
003oooooool0R_ooo`80000S];_O00<0002d^mnd^ml01KBkg`030000oooooooo01koool00`000?oo
ooooo`0Voooo0`0001koool008Coool30000Soooo`80000U];_O00<0002d^mnd^ml01[Bkg`030000
oooooooo01koool00`000?ooooooo`0Toooo0P0000;oool00`000?ooooooo`0Koooo0022oooo0P00
093oool200009kBkg`030000];_O];_O00Jd^ml00`000?ooooooo`0Noooo00<0003oooooool09?oo
o`800002oooo00<0003oooooool06oooo`00Ooooo`<0002@oooo0P0002Vd^ml00`000;BkgkBkg`07
];_O00<0003oooooool07_ooo`030000oooooooo02;oool200001?ooo`030000oooooooo01[oool0
07coool30000TOooo`80000[];_O00<0002d^mnd^ml01kBkg`030000oooooooo01ooool00`000?oo
ooooo`0Qoooo0P0000Coool00`000?ooooooo`0Joooo001joooo0`00097oool20000;KBkg`030000
];_O];_O00Rd^ml00`000?ooooooo`0Noooo00<0003oooooool08?ooo`@00002oooo0`0001_oool0
07Ooool300000oooo`030000oooooooo08coool200000[;6j@030000];_O];_O02Zd^ml00`000;Bk
gkBkg`08];_O00<0003oooooool07oooo`030000oooooooo04?oool007Goool20000Toooo`800004
//KY00<0002d^mnd^ml0:[Bkg`030000];_O];_O00Vd^ml00`000?ooooooo`0Ooooo00<0003ooooo
ool0@_ooo`00L_ooo`<0002Coooo0P0000Nba^T00`000;BkgkBkg`0Y];_O00<0002d^mnd^ml02KBk
g`030000oooooooo01ooool00`000?ooooooo`12oooo001`oooo0P0009Coool200002[;6j@030000
];_O];_O02Vd^ml00`000;BkgkBkg`09];_O00<0003oooooool07oooo`030000oooooooo047oool0
06goool30000U?ooo`80000<//KY00<0002d^mnd^ml0:KBkg`030000];_O];_O00Vd^ml00`000?oo
ooooo`0Noooo00<0003oool00000@_ooo`00J_ooo`<00002oooo00<0003oooooool0T?ooo`80000?
//KY00<0002d^mnd^ml0:;Bkg`030000];_O];_O00Zd^ml00`000?ooooooo`0Ooooo00<0003ooooo
ool0@?ooo`00J?ooo`80002Foooo0P0001:ba^T00`000;BkgkBkg`0W];_O00<0002d^mnd^ml02[Bk
g`030000oooooooo023oool00`000?ooooooo`0ooooo001Uoooo0`0009Koool200005;;6j@030000
];_O];_O02Nd^ml00`000;BkgkBkg`0;];_O00<0003oooooool08?ooo`030000oooooooo03koool0
06?oool20000Uoooo`80000G//KY00<0002d^mnd^ml09[Bkg`030000];_O];_O00^d^ml00`000?oo
ooooo`0Poooo00<0003oooooool0?_ooo`00H?ooo`<0002Foooo0`0001Vba^T00`000;BkgkBkg`0V
];_O00<0002d^mnd^ml03;Bkg`030000oooooooo023oool00`000?ooooooo`0moooo001Noooo0`00
09Koool200007K;6j@030000];_O];_O02Fd^ml00`000;BkgkBkg`0<];_O00<0003oooooool08Ooo
o`030000oooooooo03coool005_oool300000oooo`030000oooooooo097oool200008;;6j@030000
];_O];_O02>d^ml200003kBkg`030000oooooooo023oool00`000?ooooooo`0loooo001Hoooo0`00
09Soool200008[;6j@030000];_O];_O022d^ml300000[Bkg`030000];_O];_O00bd^ml00`000?oo
ooooo`0Qoooo00<0003oooooool0>oooo`00E_ooo`80002Ioooo0P0002Fba^T00`000;BkgkBkg`0L
];_O0`0000Fd^ml00`000;BkgkBkg`0=];_O00<0003oooooool07oooo`80000moooo001Doooo0P00
09Woool20000:;;6j@030000];_O];_O01Rd^ml300002KBkg`030000];_O];_O00bd^ml00`000?oo
ooooo`0Qoooo00<0003oooooool0>_ooo`00E?ooo`80002Goooo0P0002Zba^T00`000;BkgkBkg`0E
];_O0`0000fd^ml00`000;BkgkBkg`0<];_O00<0003oooooool08Oooo`030000oooooooo03Woool0
05Coool00`000?ooo`00002Doooo0P0002fba^T00`000;BkgkBkg`0B];_O0P00016d^ml00`000;Bk
gkBkg`0;];_O00<0003oooooool08Oooo`030000oooooooo03Woool005Coool010000?ooooooo`00
097oool20000<;;6j@030000];_O];_O00jd^ml300004kBkg`030000];_O];_O00bd^ml00`000?oo
ooooo`0Qoooo00<0003oooooool0>?ooo`00Doooo`030000oooooooo00;oool00`000?ooooooo`2<
oooo0P0003:ba^T00`000;BkgkBkg`0;];_O0`0001Nd^ml00`000;BkgkBkg`0:];_O0P0002Coool0
0`000?ooooooo`0goooo001Coooo00<0003oooooool00oooo`030000oooooooo08Soool30000=K;6
j@030000];_O];_O00Nd^ml300006kBkg`030000];_O];_O00Jd^ml300000ZG3k`030000oooooooo
027oool00`000?ooooooo`0goooo001Coooo00<0003oooooool01?ooo`030000oooooooo08Goool2
00000ZW?l`030000//KY//KY03Bba^T00`000;BkgkBkg`03];_O0`0001nd^ml00`000;BkgkBkg`02
];_O0`0000FU`nl00`000?ooooooo`0Roooo00<0003oooooool0=_ooo`00Doooo`800006oooo00<0
003oooooool0POooo`<00005ZLoc00<0002ba^Vba^T0<k;6j@030000];_O];_O00<0000R];_O00<0
002d^ml000000P0000VU`nl00`000?ooooooo`0Roooo00<0003oooooool0=Oooo`00Doooo`030000
oooooooo00Koool20000Ooooo`800009ZLoc00<0002ba^Vba^T0<[;6j@<0000T];_O0`0000fU`nl0
0`000?ooooooo`0Qoooo00<0003oooooool0=Oooo`00Doooo`030000oooooooo00Soool00`000?oo
ooooo`1ioooo0`0000bYco<00`000;;6jK;6j@0^//KY0`0000:ba^T00`000;BkgkBkg`0O];_O0`00
00>U`nl00`000:G3kjG3k`0:YL?_00<0003oooooool08?ooo`<0000<oooo1@0002Goool005;oool0
0`000?ooooooo`0:oooo00<0003oooooool0MOooo`<0000?ZLoc00<0002ba^Vba^T0:k;6j@<00005
//KY00<0002d^mnd^ml07;Bkg`<00006YL?_00<0002U`nnU`nl02jG3k`030000oooooooo02;oool0
0`000?ooooooo`09oooo0P0000;oool200009?ooo`00D_ooo`030000oooooooo00_oool00`000?oo
ooooo`1boooo0P0001>Yco<00`000;;6jK;6j@0W//KY0`0000Vba^T00`000;BkgkBkg`0I];_O0P00
00ZU`nl00`000:G3kjG3k`0;YL?_00<0003oooooool08Oooo`030000oooooooo00koool200008ooo
o`00D_ooo`030000oooooooo00coool00`000?ooooooo`1^oooo0`0001JYco<00`000;;6jK;6j@0S
//KY0`0000bba^T00`000;BkgkBkg`0F];_O0`0000fU`nl00`000:G3kjG3k`0:YL?_00<0003ooooo
ool08_ooo`030000oooooooo00goool200008oooo`00D_ooo`80000>oooo00<0003oooooool0Jooo
o`80000JZLoc00<0002ba^Vba^T08;;6j@80000@//KY00<0002d^mnd^ml04[Bkg`<0000AYL?_00<0
002U`nnU`nl02ZG3k`030000oooooooo02;oool00`000?ooooooo`0<oooo0P0002?oool005;oool0
0`000?ooooooo`0>oooo00<0003oooooool0Ioooo`<0000MZLoc00<0002ba^Vba^T07;;6j@<0000C
//KY00<0002d^mnd^ml03[Bkg`<0000DYL?_00<0002U`nnU`nl02jG3k`030000oooooooo027oool0
0`000?ooooooo`0;oooo0`0002?oool005;oool00`000?ooooooo`0?oooo00<0003oooooool0I?oo
o`80000QZLoc00<0002ba^Vba^T06;;6j@<0000F//KY00<0002d^mnd^ml02kBkg`<0000HYL?_00<0
002U`nnU`nl02ZG3k`030000oooooooo02;oool00`000?ooooooo`09oooo0`0002Coool0057oool0
0`000?ooooooo`0Aoooo00<0003oooooool0H?ooo`<0000TZLoc00<0002ba^Vba^T05;;6j@<0000J
//KY00<0002d^mnd^ml01kBkg`<0000LYL?_00<0002U`nnU`nl02ZG3k`030000oooooooo02;oool0
0`000?ooooooo`09oooo0P0002Coool0057oool00`000?ooooooo`0Boooo00<0003oooooool0G?oo
o`<0000XZLoc00<0002ba^Vba^T04;;6j@<0000N//KY00<0002d^mnd^ml00kBkg`<0000PYL?_00<0
002U`nnU`nl02ZG3k`030000oooooooo027oool00`000?ooooooo`0:oooo0P0002?oool0057oool0
0`000?ooooooo`0Coooo00<0003oooooool0FOooo`80000[ZLoc00<0002ba^Vba^T03K;6j@<0000Q
//KY00<0002d^mnd^ml00`0002>U`nl00`000:G3kjG3k`0:YL?_00<0003oooooool08Oooo`800006
oooo00<0003oooooool00_ooo`80000Soooo001Aoooo00<0003oooooool05?ooo`030000oooooooo
05Goool30000;ZW?l`030000//KY//KY00Vba^T300009;;6j@<0000WYL?_00<0002U`nnU`nl02ZG3
k`030000oooooooo01ooool010000?ooooooo`0000Goool200000_ooo`<0000Soooo001Aoooo0`00
01Goool00`000?ooooooo`1Boooo0P0003:Yco<00`000;;6jK;6j@05//KY0`0002>ba^T400000Z75
lP030000YL?_YL?_02JU`nl00`000:G3kjG3k`0:YL?_00<0003oooooool08Oooo`030000oooooooo
00Goool400009?ooo`00DOooo`030000oooooooo01Koool00`000?ooooooo`1>oooo0`0003FYco<0
10000;;6jK;6jK;6j@<0000S//KY0`0000NQaO800`000:G3kjG3k`0UYL?_00<0002U`nnU`nl02jG3
k`030000oooooooo027oool00`000?ooooooo`0/oooo001Aoooo00<0003oooooool05oooo`030000
oooooooo04[oool300000Y[Do0030000ZLocZLoc03BYco<300008k;6j@<0000;XLGb00<0002U`nnU
`nl09JG3k`030000YL?_YL?_00ZU`nl00`000?ooooooo`0Roooo00<0003oooooool0:oooo`00@?oo
o`L00009oooo00<0003oooooool06Oooo`800016oooo100000JJe?`00`000:W?ljW?l`0`ZLoc0`00
0003ZLoc0000//KY01nba^T400003Z75lP030000YL?_YL?_02JU`nl00`000:G3kjG3k`0:YL?_00<0
003oooooool08Oooo`030000oooooooo02_oool0047oool700002?ooo`030000oooooooo01_oool0
0`000?ooooooo`10oooo0`0000^Je?`00`000:W?ljW?l`0]ZLoc0P0000FYco<00`000;;6jK;6j@0J
//KY0`0001>QaO800`000:G3kjG3k`0VYL?_00<0002U`nnU`nl02ZG3k`030000oooooooo027oool0
0`000?ooooooo`0Zoooo0012oooo00<0003oooooool00_ooo`030000oooooooo00Koool00`000?oo
ooooo`0Loooo00<0003oooooool0??ooo`<0000?V]Cl0P0002ZYco<300002:W?l`030000//KY//KY
01Fba^T400005j75lP030000YL?_YL?_02FU`nl00`000:G3kjG3k`0:YL?_00<0003oooooool08Ooo
o`030000oooooooo02[oool004?oool00`000?ooooooo`0:oooo00<0003oooooool06_ooo`040000
oooooooo0000>Oooo`@0000DV]Cl00<0002Yco>Yco<09:W?l`<0000<ZLoc00<0002ba^Vba^T04K;6
j@<0000LXLGb00<0002U`nnU`nl09JG3k`030000YL?_YL?_00ZU`nl00`000?ooooooo`0Qoooo00<0
003oooooool0:Oooo`00=?ooo`T00007oooo00<0003oooooool02Oooo`80000Ioooo0P000005<000
0000oooooooo000003Goool300006I[Do0030000ZLocZLoc022Yco<300003jW?l`030000//KY//KY
00fba^T400008:75lP030000YL?_YL?_02FU`nl00`000:G3kjG3k`0:YL?_00<0003oooooool08?oo
o`80000Zoooo0014oooo0P0000[oool00`000?ooooooo`0Goooo00<0000`000`00000S0000800000
0oooo`000?ooo`0`oooo0`0001fJe?`00`000:W?ljW?l`0LZLoc0`0001>Yco<00`000;;6jK;6j@09
//KY0`0002FQaO800`000:G3kjG3k`0UYL?_00<0002U`nnU`nl02JG3k`030000oooooooo01ooool0
0`000?ooo`00000Zoooo0015oooo00<0003oooooool01oooo`030000oooooooo01Koool200001c00
00030000oooo000002coool400008I[Do0030000ZLocZLoc01RYco<300005jW?l`030000//KY//KY
00Fba^T30000::75lP030000YL?_YL?_02FU`nl00`000:G3kjG3k`0:YL?_00<0003oooooool08Ooo
o`030000oooooooo02Ooool004Goool200002?ooo`030000oooooooo01Goool00`00030003000008
<00000<0003oool00000:?ooo`<0000VV]Cl00<0002Yco>Yco<05:W?l`<0000KZLoc00<0002ba^Vb
a^T0100002bQaO800`000:G3kjG3k`0UYL?_00<0002U`nnU`nl02ZG3k`030000oooooooo027oool0
0`000?ooooooo`0Voooo0015oooo0P0000Soool00`000?ooooooo`0Doooo00<0000`000`00002S00
00030000oooo000002Coool30000:Y[Do0030000ZLocZLoc012Yco<300007ZW?l`<0000aXLGb00<0
002U`nnU`nl09JG3k`030000YL?_YL?_00VU`nl00`000?ooooooo`0Qoooo00<0003oooooool09_oo
o`00@?ooo`030000oooooooo00;oool200002?ooo`030000oooooooo01;oool200003S0000030000
oooo000001ooool40000;Y[Do080000=ZLoc0`0001fYco<400000Y_5m@030000XLGbXLGb032QaO80
0`000:G3kjG3k`0TYL?_00<0002U`nnU`nl02JG3k`80000Soooo00<0003oooooool09Oooo`00@Ooo
o`030000oooooooo00<00008oooo0P0001;oool00`0003000300000?<00000<0003oool000006_oo
o`@0000dV]Cl00<0002Yco>Yco<01jW?l`<0000LZLoc100000NKaOD00`000:75lZ75lP0`XLGb00<0
002U`nnU`nl09:G3k`030000YL?_YL?_00BU`nl400000Yc:m`030000oooooooo027oool00`000?oo
ooooo`0Toooo0012oooo100000Woool00`000?ooooooo`0?oooo0P0001<`000300005Oooo`@00003
OMSn0P0003BJe?`00`000:W?ljW?l`04ZLoc0P0001bYco<3000039_5m@030000XLGbXLGb032QaO80
0`000:G3kjG3k`0TYL?_00<0002U`nnU`nl00`0000NLb_L00`000?ooooooo`0Poooo00<0003ooooo
ool09?ooo`00C_ooo`030000oooooooo00ooool00`0003000300000E<0000P00013oool400002GgH
oP80000cV]Cl00<0002Yco>Yco<00`0001ZYco<4000049_5m@030000XLGbXLGb02nQaO800`000:G3
kjG3k`0SYL?_100000^Lb_L00`000?ooooooo`0Poooo00<0003oooooool08oooo`00C_ooo`030000
oooooooo00goool200006C000080000;oooo100000mmf?h00`0009[Do9[Do00`V]Cl0`0001ZYco<3
00005I_5m@030000XLGbXLGb02nQaO800`000:G3kjG3k`0OYL?_0`0000:Lb_L00`0009c:mic:m`0:
W<[g00<0003oooooool07oooo`<0000Toooo001>oooo00<0003oooooool03?ooo`030000<000<000
01X`000200001_ooo`@0000DOMSn0P0002fJe?`300000Y[Do0030000ZLocZLoc01BYco<4000069_5
m@030000XLGbXLGb032QaO800`000:G3kjG3k`0JYL?_100000JLb_L00`0009c:mic:m`0:W<[g00<0
003oooooool08?ooo`030000oooooooo02;oool004koool00`000?ooooooo`0:oooo0P0001h`0007
00006WgHoP030000V]ClV]Cl02NJe?`300001Y[Do0030000ZLocZLoc00nYco<400007I_5m@030000
XLGbXLGb032QaO800`000:G3kjG3k`0FYL?_0`0000^Lb_L00`0009c:mic:m`0:W<[g00<0003ooooo
ool08?ooo`030000oooooooo027oool004koool00`000?ooooooo`09oooo00<0000`000`00007C00
00@0000OOMSn0P0002BJe?`300002Y[Do080000<ZLoc0`0002:KaOD00`000:75lZ75lP0`XLGb00<0
002U`nnU`nl04JG3k`@0000?W<[g00<0002Lb_NLb_L02Yc:m`030000oooooooo023oool00`000?oo
ooooo`0Poooo001>oooo0P0000Soool20000730000@0000UOMSn0P0001nJe?`300003i[Do0030000
ZLocZLoc00FYco<400009Y_5m@030000XLGbXLGb032QaO800`000:G3kjG3k`0=YL?_0`0001>Lb_L0
0`0009c:mic:m`0;W<[g00<0003oooooool07oooo`030000oooooooo023oool004koool00`000?oo
ooooo`06oooo00<0000`000`0000630000@0000[OMSn00<0002Je?bJe?`06I[Do0<0000CV]Cl00<0
002Yco>Yco<0100002^KaOD00`000:75lZ75lP0_XLGb00<0002U`nnU`nl02JG3k`@0000GW<[g00<0
002Lb_NLb_L02ic:m`030000oooooooo01ooool00`000?ooooooo`0Ooooo001=oooo00<0003ooooo
ool01_ooo`030000<000<00001@`00050000<7gHoP80000FV]Cl0`0001FJe?`40000<9_5m@030000
XLGbXLGb02nQaO800`000:G3kjG3k`05YL?_0`0001bLb_L00`0009c:mic:m`0:W<[g00<0003ooooo
ool08?ooo`030000oooooooo01koool004goool00`000?ooooooo`04oooo0P00014`000600001?oo
o`<0000`OMSn0P00016Je?`300004Y[Do0H00003T;of00<0002KaOFKaOD0;i_5m@030000XLGbXLGb
02nQaO800`000:G3kjG3k`0400007ic:m`030000W<[gW<[g00^Lb_L00`000?ooooooo`0Ooooo00<0
003oooooool07_ooo`00COooo`030000oooooooo00?oool00`0003000300000;<0001P0000goool3
0000;ggHoP030000V]ClV]Cl00^Je?`3000049[Do0D0000:T;of00<0002KaOFKaOD0;i_5m@030000
XLGbXLGb02fQaO84000099c:m`030000W<[gW<[g00^Lb_L00`000?ooooooo`0Ooooo00<0003ooooo
ool07Oooo`00COooo`040000oooooooooooo0P0000T`000500005_ooo`<0000]OMSn0P0000VJe?`2
00003Y[Do0D0000@T;of00<0002KaOFKaOD0;i_5m@030000XLGbXLGb02RQaO8400000i_6mP030000
W<[gW<[g02>Lb_L00`0009c:mic:m`0;W<[g00<0003oooooool07Oooo`<0000Noooo000Soooo0P00
02Soool010000?ooooooo`0000D`000600007_ooo`<0000/OMSn00<0002Je?bJe?`00i[Do0<0000:
V]Cl1P0001J@_oH00`0009_5mI_5m@0_VlGe00<0002QaO:QaO808j75lP@00008VlKf00<0002Lb_NL
b_L08ic:m`030000W<[gW<[g00^Lb_L00`000?ooooooo`0Noooo00<0003oooooool07?ooo`002ooo
o`@0000;oooo00<0003oooooool01_ooo`<00006oooo100001goool900009oooo`@0000YOMSn1@00
00RJe?`500007I2omP80000`VlGe00<0002QaO:QaO807Z75lP@0000=VlKf00<0002Lb_NLb_L08Yc:
m`030000W<[gW<[g00bLb_L00`000?ooooooo`0Noooo00<0003oooooool06oooo`002oooo`030000
oooooooo00goool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01[oool4
0000<Oooo`<0000UOMSn1@0000>Je?`60000992omP030000VlGeVlGe02jKaOD00`000:75lZ75lP0I
XLGb100001:Ka_H00`0009c:mic:m`0RW<[g00<0002Lb_NLb_L039c:m`030000oooooooo01koool0
0`000?ooooooo`0Joooo000;oooo00<0003oooooool03_ooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool06_ooo`030000oooooooo03Goool300007ggHoP/0000[T;of00<0
002KaOFKaOD0;I_5m@030000XLGbXLGb01FQaO8400005i_6mP030000W<[gW<[g02:Lb_L00`0009c:
mic:m`0;W<[g00<0003oooooool07_ooo`030000oooooooo01[oool000Coool400000oooo`030000
oooooooo00;oool3000000?oool0000000000P0000;oool300002Oooo`030000oooooooo00Koool0
0`000?ooooooo`0<oooo100000[oool00`000?ooooooo`0goooo100000Ymf?hB00002G^bmP030000
T;ofT;of02^@_oH00`0009_5mI_5m@0]VlGe00<0002QaO:QaO804:75lP@0000LVlKf00<0002Lb_NL
b_L08Yc:m`030000W<[gW<[g00^Lb_L00`000?ooooooo`0Noooo00<0003oooooool06Oooo`001Ooo
o`800004oooo00<0003oooooool00oooo`040000oooooooooooo0P0000?oool200002Oooo`<00007
oooo00<0003oooooool02oooo`800002oooo0P0000Woool00`000?ooooooo`0goooo00<0000/C/8/
C/802`0000ak/_H300003G^bmP80000/T;of00<0002KaOFKaOD0;I_5m@030000XLGbXLGb00^QaO84
00008I_6mP030000W<[gW<[g026Lb_L00`0009c:mic:m`0<W<[g00<0003oooooool07Oooo`030000
oooooooo01Woool000Goool200001?ooo`030000oooooooo00Coool010000?ooo`00000000ooool3
00001oooo`030000oooooooo00_oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000
oooooooo03Soool01P0002a>`Ra>`P00000JV000011k/_H300004W^bmP030000T;ofT;of02Z@_oH0
0`0009_5mI_5m@0]VlGe00<0002QaO:QaO801Z75lP@0000VVlKf00<0002Lb_NLb_L08Ic:m`030000
W<[gW<[g00^Lb_L200007oooo`030000oooooooo01Soool000Goool200001?ooo`030000oooooooo
00Goool200003oooo`800002oooo00<0003oooooool01?ooo`030000oooooooo00[oool200001?oo
o`800008oooo00<0003oooooool0>?ooo`070000;4k2;4k2;4k2000001ZH000000ak/_H300005W^b
mP030000T;ofT;of02Z@_oH00`0009_5mI_5m@0]VlGe00@0002QaO:QaO:QaO840000:i_6mP030000
W<[gW<[g026Lb_L00`0009c:mic:m`06W<[g100000:LdOX00`000?ooooooo`0Loooo0P00017oool2
00001_ooo`001Oooo`800004oooo00<0003oooooool01Oooo`80000?oooo0P0000;oool00`000?oo
ooooo`04oooo00<0003oooooool02_ooo`800004oooo0P0000Ooool00`000?ooo`00000joooo00@0
000/C/8/C/8/C/83000027^bmP<0000JNk;f00<0002@_oJ@_oH0:Y2omP030000VlGeVlGe02^KaOD5
0000;i_6mP030000W<[gW<[g026Lb_L00`0009c:mic:m`02W<[g100000NLdOX00`000?ooooooo`0J
oooo00<0003oool000004Oooo`800006oooo0005oooo0P0000Coool00`000?ooooooo`04oooo0`00
00koool200001?ooo`030000oooooooo00?oool00`000?ooooooo`0:oooo0P0000Coool200001ooo
o`80000koooo00<0000/C/8/C/800ba>`P<00004Nk;f0P0001ik/_H00`00092omY2omP0ZT;of00<0
002KaOFKaOD09I_5m@D00003VL7c00<0002Ka_JKa_H0;i_6mP030000W<[gW<[g026Lb_L4000039cA
nP030000oooooooo01coool00`000?ooooooo`0>oooo0P0000Koool000Goool200001?ooo`030000
oooooooo00?oool200000_ooo`030000oooooooo00_oool200001?ooo`030000oooooooo00?oool0
0`000?ooooooo`0:oooo0P0000Coool200001oooo`030000oooooooo03_oool00`0002a>`Ra>`P03
;4k200<000006YP000000`00025k/_H00`00092omY2omP0ZT;of00<0002KaOFKaOD07i_5m@D00009
VL7c00<0002Ka_JKa_H0;i_6mP030000W<[gW<[g01fLb_L3000000>LdOX0002LdOX03YcAnP030000
oooooooo01coool00`000?ooooooo`08oooo200000Goool000Coool500000_ooo`030000oooooooo
00;oool4000000Coool000000000000:oooo100000;oool300001?ooo`030000oooooooo00[oool2
00001?ooo`800007oooo00<0003oooooool0>oooo`030000;4k2;4k200</C/84000097^bmP80000[
T;of0P0001ZKaOD500003iW1l`030000VlKfVlKf02nKa_H00`0009c:mic:m`0HW<[g100000FLdOX0
0`0009cAnYcAnP0=W=7j00<0003oooooool06oooo`030000oooooooo00Soool00`000?ooooooo`02
oooo0P0000Koool000Goool200001?ooo`030000oooooooo027oool00`000?ooooooo`0:oooo0P00
00Coool200001oooo`030000oooooooo03_oool00`0002a>`Ra>`P0300000Ra>`P<0000UNk;f00<0
002@_oJ@_oH0:Y2omP030000VlGeVlGe01>KaOD400005IW1l`030000VlKfVlKf02nKa_H00`0009c:
mic:m`0CW<[g100000VLdOX00`0009cAnYcAnP0>W=7j00<0003oooooool06oooo`030000oooooooo
00Soool010000?ooooooooooo`800006oooo0005oooo0P0000Coool00`000?ooooooo`0Qoooo00<0
003oooooool02oooo`030000oooooooo00;oool00`000?ooooooo`06oooo00<0003oooooool0>ooo
o`<00007;4k20P0002Ek/_H00`00092omY2omP0ZT;of00<0002KaOFKaOD03I_5m@D0000JVL7c00<0
002Ka_JKa_H0;i_6mP030000W<[gW<[g00nLb_L300003YcAnP030000W=7jW=7j00jLdOX200007?oo
o`030000oooooooo00Soool00`000?ooooooo`0200001_ooo`001Oooo`800004oooo00<0003ooooo
ool08Oooo`030000oooooooo00_oool200000_ooo`800007oooo00<0003oooooool0>Oooo`<00000
0oooo`0002a>`P08;4k20P0002Ek/_H00`00092omY2omP0ZT;of00<0002KaOFKaOD01i_5m@D0000P
VL7c00<0002Ka_JKa_H0;i_6mP030000W<[gW<[g00ZLb_L400004YcAnP030000W=7jW=7j00nLdOX0
0`000?ooooooo`0Ioooo00<0003oooooool02?ooo`030000oooooooo00800006oooo0006oooo00<0
003oooooool01P0001goool400003_ooo`@00008oooo0`0003Koool300001Oooo`030000;4k2;4k2
00L/C/8200009G^bmP030000T;ofT;of02Z@_oH0100009_5mI_5mI_5m@D0000VVL7c00<0002Ka_JK
a_H0;i_6mP030000W<[gW<[g00FLb_L400005icAnP030000W=7jW=7j00nLdOX00`000?ooooooo`0H
oooo0P0000[oool010000?ooo`00000000Koool000Ooool30000@?ooo`030000oooooooo03?oool3
00002?ooo`030000;4k2;4k200P/C/83000097^bmP80000YT;of1@0002bI`O<00`0009_6mY_6mP0_
VlKf00<0002Lb_NLb_L0100001^LdOX00`0009cAnYcAnP0@W=7j00<0003oooooool05?ooo`<00000
0oooo`000?ooo`0:oooo0`0000Koool004[oool00`000?ooooooo`0`oooo0`0000coool00`0002a>
`Ra>`P09;4k20P0002Ek/_H00`00092omY2omP0QT;of1@0000>F]nh00`0009W1liW1l`0/VL7c00<0
002Ka_JKa_H0;Y_6mP<0000PW=7j00<0002LdOZLdOX049cAnP030000oooooooo00ooool400001?oo
o`030000oooooooo00[oool200001_ooo`00B_ooo`030000oooooooo02goool300003oooo`030000
;4k2;4k200X/C/8200009G^bmP030000T;ofT;of01^@_oH500002IJgkP030000VL7cVL7c02bI`O<2
0000:Y_6mP@00002W/Wf00<0002LdOZLdOX07icAnP030000W=7jW=7j012LdOX00`000?ooooooo`0;
oooo0`0000Soool00`000?ooooooo`0:oooo0P0000Koool004[oool00`000?ooooooo`0Zoooo0`00
01?oool00`0002a>`Ra>`P0:;4k20P0002Ek/_H00`00092omY2omP0ET;of1@0000nF]nh00`0009W1
liW1l`0]VL7c00<0002Ka_JKa_H08i_6mP@00007W/Wf00<0002LdOZLdOX07YcAnP030000W=7jW=7j
016LdOX00`000?ooooooo`07oooo0`0000coool00`000?ooooooo`0Aoooo001:oooo00<0003ooooo
ool0:?ooo`80000Foooo00<0000/C/8/C/802ba>`P80000UNk;f00<0002@_oJ@_oH03Y2omPH0000E
U[O^00<0002I`O>I`O<0;IW1l`030000VlKfVlKf01jKa_H4000039k9mP030000W=7jW=7j01jLdOX0
0`0009cAnYcAnP0@W=7j0P0000Coool400003oooo`030000oooooooo017oool004Woool00`000?oo
ooooo`0Voooo0`0001Soool00`0002a>`Ra>`P0=;4k200<0001k/_Ik/_H08g^bmP800009T;of1@00
01bF]nh00`0009W1liW1l`0]VL7c00<0002Ka_JKa_H06I_6mP@0000AW/Wf0P0001nLdOX00`0009cA
nYcAnP0<W=7j0`0000:Te?T400004oooo`030000oooooooo017oool004Woool300008oooo`<0000L
oooo00<0000/C/8/C/803Ba>`P030000Nk;fNk;f02Ak/_H01000092omY2omY2omPD0000RU[O^00<0
002I`O>I`O<0;IW1l`030000VlKfVlKf01BKa_H400005ik9mP030000W=7jW=7j01fLdOX00`0009cA
nYcAnP07W=7j100000JTe?T00`000?ooooooo`0Coooo00<0003oooooool04Oooo`00BOooo`030000
oooooooo023oool300007oooo`030000;4k2;4k200h/C/82000087^bmPP0000XU[O^00<0002I`O>I
`O<0;IW1l`030000VlKfVlKf00nKa_H4000079k9mP030000W=7jW=7j01bLdOX00`0009cAnYcAnP04
W=7j0`0000^Te?T00`000?ooooooo`0Boooo00<0003oooooool04Oooo`00BOooo`030000oooooooo
01goool300008oooo`030000;4k2;4k200h/C/8200004g^bmP`00006S:GV00<0002F]njF]nh0:9Jg
kP030000VL7cVL7c02fI`O<00`0009_6mY_6mP0:VlKf1000026NbOH00`0009cAnYcAnP0LW=7j00<0
002LdOZLdOX00`0000nTe?T00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`00BOooo`030000
oooooooo01[oool300009_ooo`030000;4k2;4k2010/C/800`0007^bmW^bmP04Nk;f300001><YNH0
0`0009JgkYJgkP0XU[O^00<0002I`O>I`O<0;IW1l`030000VlKfVlKf00FKa_H400009Yk9mP030000
W=7jW=7j01^LdOX300004jCDn@030000oooooooo013oool00`000?ooooooo`0Aoooo0019oooo00<0
003oooooool05oooo`<0000Zoooo00<0000/C/8/C/8042a>`PH0000PS:GV00<0002F]njF]nh0:9Jg
kP030000VL7cVL7c02fI`O<00`0009_6mY_6mP040000:ik9mP030000W=7jW=7j01JLdOX400000ZCD
n@030000Y=CiY=Ci01:Te?T00`000?ooooooo`0@oooo00<0003oooooool04?ooo`00B?ooo`030000
oooooooo01Goool30000;Oooo`030000;4k2;4k2014/C/800`0008bUiXbUiP0SS:GV00<0002F]njF
]nh0:9JgkP030000VL7cVL7c02bI`O<30000<9k9mP030000W=7jW=7j01:LdOX300001ZCDn@030000
Y=CiY=Ci01>Te?T200004?ooo`030000oooooooo013oool004Soool00`000?ooooooo`0Boooo0`00
037oool00`0002a>`Ra>`P0A;4k200<0002<YNJ<YNH08hbUiP030000U[O^U[O^02RF]nh00`0009W1
liW1l`0WVL7c100000:P`O000`0009k9mYk9mP0_W/Wf0P0000nLdOX300002ZCDn@030000Y=CiY=Ci
01BTe?T00`000?ooooooo`0=oooo00<0003oooooool04?ooo`00B?ooo`<0000?oooo0`0003Coool0
0`0002a>`Ra>`P0A;4k200<0002<YNJ<YNH08hbUiP030000U[O^U[O^02VF]nh00`0009W1liW1l`0R
VL7c100000NP`O000`0009k9mYk9mP0`W/Wf00<0002LdOZLdOX02IcAnP<0000>Y=Ci00<0002Te?VT
e?T05:CDn@030000oooooooo00coool00`000?ooooooo`0@oooo0018oooo00<0003oooooool03?oo
o`<0000goooo00<0000/C/8/C/804Ra>`P030000S:GVS:GV02><YNH00`0009JgkYJgkP0YU[O^00<0
002I`O>I`O<07IW1l`@0000<X<7`00<0002NbOJNbOH0<9k9mP030000W=7jW=7j00BLdOX400004JCD
n@030000Y=CiY=Ci01FTe?T00`000?ooooooo`0;oooo00<0003oooooool04?ooo`00B?ooo`030000
oooooooo00[oool20000>oooo`030000;4k2;4k2018/C/800`0008bUiXbUiP0SS:GV00<0002F]njF
]nh0:IJgkP030000VL7cVL7c01RI`O<400004J31l0030000W/WfW/Wf032NbOH00`0009cAnYcAnP03
00005ZCDn@030000Y=CiY=Ci01FTe?T00`000?ooooooo`0:oooo00<0003oooooool04?ooo`00>?oo
o`L00009oooo00<0003oooooool01oooo`<0000moooo00<0000/C/8/C/804ba>`P030000S:GVS:GV
02><YNH00`0009JgkYJgkP0YU[O^00<0002I`O>I`O<059W1l`<0000FX<7`00<0002NbOJNbOH0;ik9
mP<0000JY=Ci00<0002Te?VTe?T05JCDn@030000oooooooo00Woool00`000?ooooooo`0@oooo000i
oooo1`0000Ooool00`000?ooooooo`05oooo0`00047oool00`0002a>`Ra>`P0B;4k200<0002<YNJ<
YNH098bUiP030000U[O^U[O^02VF]nh00`0009W1liW1l`0?VL7c100001ZP`O000`0009k9mYk9mP0[
W/Wf0`0000:WcO<00`000:CDnJCDn@0IY=Ci00<0002Te?VTe?T05:CDn@80000;oooo00<0003ooooo
ool03oooo`00>_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool00_oo
o`<00014oooo00<0000/C/8/C/804ba>`P030000S:GVS:GV02B<YNH00`0009JgkYJgkP0YU[O^00<0
002I`O>I`O<02YW1l`@0000OX<7`00<0002NbOJNbOH09ik9mP<00006Ylgc00<0002Te?VTe?T06:CD
n@030000Y=CiY=Ci016Te?T300000ZcAl`030000oooooooo00Soool00`000?ooooooo`0?oooo000k
oooo00<0003oooooool02Oooo`030000oooo000000800018oooo00<0000/C/8/C/804ba>`P030000
S:GVS:GV02B<YNH00`0009JgkYJgkP0YU[O^00<0002I`O>I`O<01IW1l`@0000TX<7`00<0002NbOJN
bOH08Yk9mP@0000:Ylgc00<0002Te?VTe?T06:CDn@030000Y=CiY=Ci00fTe?T300001ZcAl`030000
oooooooo00Ooool00`000?ooooooo`0?oooo000loooo00<0003oooooool02?ooo`80001;oooo00<0
000/C/8/C/8052a>`P030000S:GVS:GV02B<YNH00`0009JgkYJgkP0YU[O^00<0002I`O>I`O<01000
02VP`O0200007ik9mP<0000?Ylgc00<0002Te?VTe?T06:CDn@030000Y=CiY=Ci00VTe?T300002ZcA
l`030000oooooooo00Koool00`000?ooooooo`0?oooo000loooo0P0000[oool00`000?ooooooo`1:
oooo00<0000/C/8/C/8052a>`P030000S:GVS:GV02B<YNH00`0009JgkYJgkP0WU[O^100002nP`O00
0`0009k9mYk9mP0IW/Wf0`0001>WcO<00`000:CDnJCDn@0HY=Ci00<0002Te?VTe?T01JCDn@<0000>
[=7c00<0003oooooool01Oooo`030000oooooooo00ooool003goool00`000?ooooooo`09oooo0P00
04[oool00`0002a>`Ra>`P0D;4k200<0002<YNJ<YNH09HbUiP030000U[O^U[O^02:F]nh400000j6g
j0030000X<7`X<7`02jP`O000`0009k9mYk9mP0EW/Wf0`0001NWcO<00`000:CDnJCDn@0GY=Ci00<0
002Te?VTe?T00ZCDn@<0000B[=7c00<0003oooooool01?ooo`030000oooooooo00ooool003goool2
00003?ooo`030000oooooooo04Ooool00`0002a>`Ra>`P0E;4k200<0002<YNJ<YNH09HbUiP030000
U[O^U[O^01fF]nh400002:6gj0030000X<7`X<7`02jP`O000`0009k9mYk9mP0AW/Wf0`0001^WcO<2
00006:CDn@040000Y=Ci000000005ZcAl`030000oooooooo00?oool00`000?ooooooo`0?oooo000m
oooo0P0000goool00`000?ooooooo`17oooo00<0000/C/8/C/805Ba>`P030000S:GVS:GV02F<YNH0
0`0009JgkYJgkP0HU[O^100000fQ]nP00`000:31l:31l00^X<7`00<0002NbOJNbOH03Ik9mP<0000P
Ylgc00<0002Te?VTe?T05:CDn@<0000I[=7c00<0003oooooool00_ooo`030000oooooooo00ooool0
03Soool00`000?ooooooo`02oooo0P0000koool00`000?ooooooo`16oooo00<0000/C/8/C/805Ra>
`P030000S:GVS:GV02B<YNH00`0009JgkYJgkP0DU[O^100001:Q]nP00`000:31l:31l00^X<7`00<0
002NbOJNbOH029k9mP@0000TYlgc00<0002Te?VTe?T04:CDn@<00002[=7c00<0002/dO>/dO<05jcA
l`030000oooooooo00?oool00`000?ooooooo`0>oooo000ioooo00<0003oooooool00`0000ooool2
0000Aoooo`030000;4k2;4k201H/C/800`0008bUiXbUiP0TS:GV00<0002F]njF]nh03iJgkP@0000G
XKOX00<0002P`O2P`O00;Z31l0030000W/WfW/Wf00BNbOH30000:JO=l`030000Y=CiY=Ci00bTe?T3
00001ZcAl`030000[=7c[=7c01N/dO<00`000?ooooooo`02oooo00<0003oooooool03_ooo`00>_oo
o`@0000Boooo00<0003oooooool0A?ooo`030000;4k2;4k201H/C/800`0008bUiXbUiP0US:GV00<0
002F]njF]nh02YJgkP@0000LXKOX00<0002P`O2P`O00;Z31l0030000W/WfW/Wf00<0000]Ylgc00<0
002Te?VTe?T02:CDn@<0000:[=7c00<0002/dO>/dO<05jcAl`050000oooooooooooo0000013oool0
057oool00`000?ooooooo`14oooo00<0000/C/8/C/805Ra>`P030000S:GVS:GV02F<YNH00`0009Jg
kYJgkP05U[O^1000026Q]nP00`000:31l:31l00]X<7`0`00036WcO<00`000:CDnJCDn@04Y=Ci0`00
00j/dO<00`000:cAljcAl`0G[=7c00@0003oooooool0000@oooo001Boooo00<0003oooooool0@ooo
o`030000;4k2;4k201L/C/800`0008bUiXbUiP0US:GV00<0002F]njF]nh0100002JQ]nP00`000:31
l:31l00YX<7`0`0000:Za>d00`000:O=ljO=l`0`Ylgc00<0002Te?VTe?T00`00016/dO<00`000:cA
ljcAl`0H[=7c00<0003oool000004?ooo`00Doooo`800014oooo00<0000/C/8/C/805ba>`P030000
S:GVS:GV02><YNH40000:j6gj0030000X<7`X<7`02FP`O0300001Z[4k@030000YlgcYlgc02nWcO<3
00005JcAl`030000[=7c[=7c01R/dO<200004?ooo`00EOooo`030000oooooooo047oool300005ba>
`P030000S:GVS:GV01n<YNH400000ijXg@030000XKOXXKOX02ZQ]nP00`000:31l:31l00QX<7`0`00
00ZZa>d00`000:O=ljO=l`0/Ylgc0P0000:`cNl00`000:cAljcAl`0D[=7c00<0002/dO>/dO<06:cA
l`030000oooooooo00koool005Koool00`000?ooooooo`10oooo00<0001nN/AnN/@0100001@/C/80
0`0008bUiXbUiP0JS:GV100000RNZ=d00`000:6gj:6gj00ZXKOX00<0002P`O2P`O007J31l0<0000>
Z/C]00<0002WcO>WcO<0::O=l`<00005/<g_00<0002/dO>/dO<05:cAl`030000[=7c[=7c01N/dO<2
00003oooo`00Eoooo`030000oooooooo043oool00`0007ija7ija003OW[41@00010/C/800`0008bU
iXbUiP0ES:GV100000fNZ=d00`000:6gj:6gj00ZXKOX00<0002P`O2P`O006J31l0<0000BZ/C]00<0
002WcO>WcO<09JO=l`800009/<g_00<0002/dO>/dO<04jcAl`030000[=7c[=7c01B/dO<3000000?o
ool0003oool03_ooo`00F?ooo`030000oooooooo03ooool00`0007ija7ija008OW[4100000d/C/80
0`0008bUiXbUiP0?S:GV1@00016NZ=d00`000:6gj:6gj00[XKOX00<0002P`O2P`O005:31l0@0000F
Z/C]00<0002WcO>WcO<08JO=l`<0000</<g_00<0002/dO>/dO<04jcAl`030000[=7c[=7c012/dO<3
00001?ooo`030000oooooooo00goool005Woool20000@?ooo`030000OW[4OW[400]nN/@500002Ba>
`P030000S:GVS:GV00Z<YNH400005ijXg@030000XKOXXKOX02^Q]nP00`000:31l:31l00@X<7`0`00
01^Za>d00`000:O=ljO=l`0MYlgc0`00012`cNl00`000:cAljcAl`0C[=7c00<0002/dO>/dO<03JcA
l`800007oooo00<0003oooooool03Oooo`00Foooo`030000oooooooo03goool00`0007ija7ija00@
OW[41@0000@/C/800`0008bUiXbUiP06S:GV100001bNZ=d00`000:6gj:6gj00[XKOX00<0002P`O2P
`O003:31l0<0000OZ/C]0P0001^WcO<200005;3=k`030000[=7c[=7c01:/dO<00`000:cAljcAl`0:
[=7c0`0000Woool00`000?ooooooo`0=oooo001Loooo00<0003oooooool0??ooo`030000OW[4OW[4
01EnN/@4000000</C/80002<YNH00XbUiP@0000QWZSM00<0002Q]nRQ]nP0:j6gj0030000X<7`X<7`
00RP`O0300009:[4k@030000YlgcYlgc01FWcO<300005k3=k`030000[=7c[=7c01:/dO<00`000:cA
ljcAl`06[=7c0`0000coool00`000?ooooooo`0=oooo001Moooo00<0003oooooool0??ooo`030000
OW[4OW[401QnN/@500009YjXg@030000XKOXXKOX02^Q]nP00`000:31l:31l004X<7`0`0002RZa>d0
0`000:O=ljO=l`0BYlgc0P0001^`cNl00`000:cAljcAl`0B[=7c00<0002/dO>/dO<00ZcAl`<0000?
oooo00<0003oooooool03Oooo`00G_ooo`80000loooo00<0001nN/AnN/@06gija0030000WZSMWZSM
02JNZ=d00`000:6gj:6gj00[XKOX00<0002P`O2P`O000`0002bZa>d00`000:O=ljO=l`0>Ylgc0`00
01j`cNl00`000:cAljcAl`0B[=7c100001?oool00`000?ooooooo`0<oooo001Poooo00<0003ooooo
ool0>Oooo`030000OW[4OW[401]nN/@00`0009jXgIjXg@0WWZSM00<0002Q]nRQ]nP0:Z6gj0<0000`
Z/C]00<0002WcO>WcO<02jO=l`80000R/<g_00<0002/dO>/dO<03jcAl`<0000Foooo00<0003ooooo
ool03?ooo`00HOooo`030000oooooooo03Woool00`0007ija7ija00KOW[400<0002NZ=fNZ=d09ijX
g@030000XKOXXKOX02JQ]nP300000Zbli@030000Z/C]Z/C]02nZa>d00`000:O=ljO=l`07Ylgc0`00
02F`cNl00`000:cAljcAl`0;[=7c0`0000?oool00`000?ooooooo`0Coooo00<0003oooooool03?oo
o`00H_ooo`030000oooooooo03Soool00`0007ija7ija00LOW[400<0002NZ=fNZ=d09YjXg@030000
XKOXXKOX02BQ]nP200001Zbli@030000Z/C]Z/C]02nZa>d00`000:O=ljO=l`03Ylgc0`0002V`cNl0
0`000:cAljcAl`08[=7c0P0000Ooool00`000?ooooooo`0Boooo00<0003oooooool03?ooo`00Hooo
o`80000ioooo00<0001nN/AnN/@077ija0030000WZSMWZSM02JNZ=d00`000:6gj:6gj00PXKOX0`00
00V/_>D00`000:[4kJ[4k@0_Z/C]00<0002WcO>WcO<00P0002f`cNl00`000:cAljcAl`04[=7c0`00
00[oool00`000?ooooooo`0Aoooo00<0003oooooool03?ooo`00IOooo`030000oooooooo03Koool0
0`0007ija7ija00LOW[400<0002NZ=fNZ=d09ijXg@030000XKOXXKOX01bQ]nP300003Jbli@030000
Z/C]Z/C]02jZa>d30000<;3=k`030000[=7c[=7c00<0000=oooo00<0003oooooool04Oooo`030000
oooooooo00coool006Koool00`000?ooooooo`0eoooo00<0001nN/AnN/@07Gija0030000WZSMWZSM
02NNZ=d00`000:6gj:6gj00IXKOX0P00016/_>D00`000:[4kJ[4k@0[Z/C]0P0000:cb>X00`000;3=
kk3=k`0^/<g_0`00017oool00`000?ooooooo`0@oooo00<0003oooooool03?ooo`00Ioooo`030000
oooooooo03Goool00`0007ija7ija00MOW[400<0002NZ=fNZ=d09ijXg@030000XKOXXKOX01FQ]nP3
00005:bli@030000Z/C]Z/C]02RZa>d200001K?8jP030000/<g_/<g_02^`cNl200005Oooo`030000
oooooooo013oool00`000?ooooooo`0;oooo001Xoooo0P0003Goool00`0007ija7ija00MOW[400<0
002NZ=fNZ=d0:9jXg@030000XKOXXKOX016Q]nP300006:bli@030000Z/C]Z/C]02BZa>d300002;?8
jP030000/<g_/<g_02R`cNl200005oooo`030000oooooooo013oool00`000?ooooooo`0;oooo001Z
oooo00<0003oooooool0<_ooo`030000OW[4OW[401inN/@00`0009jXgIjXg@0XWZSM00<0002Q]nRQ
]nP03Z6gj080000L[;cU00<0002Za>fZa>d08J[4k@80000</lSZ00<0002`cNn`cNl09;3=k`<0000J
oooo00<0003oooooool03oooo`030000oooooooo00_oool006_oool00`000?ooooooo`0boooo00<0
001nN/AnN/@07Wija0030000WZSMWZSM02RNZ=d00`000:6gj:6gj00:XKOX0`0001n/_>D00`000:[4
kJ[4k@0MZ/C]0`0000ncb>X00`000;3=kk3=k`0Q/<g_0P0001koool00`000?ooooooo`0>oooo00<0
003oooooool02oooo`00K?ooo`030000oooooooo037oool00`0007ija7ija00OOW[400<0002NZ=fN
Z=d09ijXg@030000XKOXXKOX00NQ]nP300008Zbli@030000Z/C]Z/C]01^Za>d200004k?8jP030000
/<g_/<g_01j`cNl200008Oooo`030000oooooooo00goool00`000?ooooooo`0;oooo001]oooo0P00
03;oool00`0007ija7ija00NOW[400<0002NZ=fNZ=d0:9jXg@030000XKOXXKOX00BQ]nP200009Zbl
i@030000Z/C]Z/C]01RZa>d200005[?8jP030000/<g_/<g_01Z`cNl300008oooo`030000oooooooo
00goool00`000?ooooooo`0;oooo001_oooo00<0003oooooool0;oooo`030000OW[4OW[401mnN/@0
0`0009jXgIjXg@0XWZSM00<0002Q]nRQ]nP00`0002V/_>D00`000:[4kJ[4k@0DZ/C]0`0001Vcb>X0
0`000;3=kk3=k`0G/<g_0P0002Ooool00`000?ooooooo`0<oooo00<0003oooooool02oooo`00L?oo
o`030000oooooooo02koool00`0007ija7ija00POW[400<0002NZ=fNZ=d09ijXg@<0000][;cU00<0
002Za>fZa>d04J[4k@80000M/lSZ00<0002`cNn`cNl05;3=k`80000Zoooo00<0003oooooool03?oo
o`030000oooooooo00[oool0077oool00`000?ooooooo`0^oooo00<0001nN/AnN/@07gija0030000
WZSMWZSM02FNZ=d200000Zjdg@030000[;cU[;cU02b/_>D00`000:[4kJ[4k@0=Z/C]0`00022cb>X0
0`000;3=kk3=k`0@/<g_0`0002goool00`000?ooooooo`0;oooo00<0003oooooool02_ooo`00L_oo
o`030000oooooooo02goool00`0007ija7ija00POW[400<0002NZ=fNZ=d08IjXg@<00005[[CM00<0
002/_>F/_>D0;:bli@030000Z/C]Z/C]00ZZa>d200009;?8jP030000/<g_/<g_00f`cNl20000<?oo
o`030000oooooooo00_oool00`000?ooooooo`0:oooo001coooo0P0002goool00`0007ija7ija00Q
OW[400<0002NZ=fNZ=d07IjXg@<00009[[CM00<0002/_>F/_>D0;:bli@030000Z/C]Z/C]00NZa>d2
00009k?8jP030000/<g_/<g_00Z`cNl20000<oooo`030000oooooooo00[oool00`000?ooooooo`0:
oooo001eoooo00<0003oooooool0:oooo`030000OW[4OW[4025nN/@00`0009jXgIjXg@0JWZSM0P00
00f^]=d00`000:bliJbli@0/[;cU00<0002Za>fZa>d00j[4k@<0000Z/lSZ00<0002`cNn`cNl01[3=
k`<0000foooo00<0003oooooool02Oooo`030000oooooooo00[oool007Koool00`000?ooooooo`0Z
oooo00<0001nN/AnN/@08Gija0030000WZSMWZSM01NNZ=d300004:jdg@030000[;cU[;cU02b/_>D0
0`000:[4kJ[4k@020000;[?8jP030000/<g_/<g_00>`cNl20000>Oooo`030000oooooooo00Woool0
0`000?ooooooo`0:oooo001goooo00<0003oooooool0:_ooo`030000OW[4OW[4025nN/@00`0009jX
gIjXg@0DWZSM0P0001>^]=d00`000:bliJbli@0/[;cU0`00036cb>X00`000;3=kk3=k`020000??oo
o`030000oooooooo00Soool00`000?ooooooo`0:oooo001hoooo0P0002[oool00`0007ija7ija00R
OW[400<0002NZ=fNZ=d049jXg@<0000F[[CM00<0002/_>F/_>D0:Jbli@800002]LKW00<0002cb>Zc
b>X0;k?8jP<0000ooooo00<0003oooooool01oooo`030000oooooooo00[oool007[oool00`000?oo
ooooo`0Woooo00<0001nN/AnN/@08Wija0030000WZSMWZSM00fNZ=d300006Zjdg@030000[;cU[;cU
02J/_>D200001KG6i`030000/lSZ/lSZ02bcb>X20000@oooo`030000oooooooo00Ooool00`000?oo
ooooo`09oooo001koooo00<0003oooooool09oooo`030000OW[4OW[4029nN/@00`0009jXgIjXg@0:
WZSM0P0001j^]=d00`000:bliJbli@0S[;cU0P0000Rea^L00`000;?8j[?8jP0Y/lSZ0P0004Goool0
0`000?ooooooo`07oooo00<0003oooooool02Oooo`00O?ooo`030000oooooooo02Koool00`0007ij
a7ija00SOW[400<0002NZ=fNZ=d01YjXg@<0000Q[[CM00<0002/_>F/_>D07jbli@<0000;]LKW00<0
002cb>Zcb>X09[?8jP800018oooo00<0003oooooool01_ooo`030000oooooooo00Woool007goool2
00009oooo`030000OW[4OW[402=nN/@00`0009jXgIjXg@02WZSM0`0002F^]=d00`000:bliJbli@0L
[;cU0P0000nea^L00`000;?8j[?8jP0S/lSZ0P0004_oool00`000?ooooooo`05oooo00<0003ooooo
ool02Oooo`00Ooooo`030000oooooooo02Coool00`0007ija7ija00SOW[400<0002NZ=fNZ=d00P00
02V^]=d00`000:bliJbli@0I[;cU0P0001:ea^L00`000;?8j[?8jP0O/lSZ0`0004koool00`000?oo
ooooo`04oooo00<0003oooooool02Oooo`00P?ooo`030000oooooooo02?oool00`0007ija7ija00S
OW[40`0002b^]=d00`000:bliJbli@0F[;cU0P0001Fea^L00`000;?8j[?8jP0L/lSZ0P00057oool0
0`000?ooooooo`04oooo00<0003oooooool02Oooo`00POooo`030000oooooooo02?oool00`0007ij
a7ija00POW[40P0000:]XL`00`000:jdgJjdg@0[[[CM00<0002/_>F/_>D04Zbli@<0000H]LKW00<0
002cb>Zcb>X06K?8jP80001Doooo00<0003oooooool00oooo`030000oooooooo00Woool008;oool2
00008oooo`030000OW[4OW[401inN/@200001JfQc0030000[[CM[[CM02^^]=d00`000:bliJbli@0?
[;cU0P0001bea^L00`000;?8j[?8jP0F/lSZ0P0005Ooool00`000?ooooooo`03oooo00<0003ooooo
ool02?ooo`00Q?ooo`030000oooooooo023oool00`0007ija7ija00LOW[40P0000N]XL`00`000:jd
gJjdg@0[[[CM00<0002/_>F/_>D03Jbli@80000O]LKW00<0002cb>Zcb>X04k?8jP80001Ioooo00<0
003oooooool00oooo`030000oooooooo00Soool008Goool00`000?ooooooo`0Poooo00<0001nN/An
N/@06Gija080000:[J7<00<0002^]=f^]=d0:jjdg@030000[;cU[;cU00V/_>D300008[G6i`030000
/lSZ/lSZ012cb>X20000G?ooo`030000oooooooo00;oool00`000?ooooooo`08oooo0026oooo00<0
003oooooool07oooo`030000OW[4OW[401InN/@300003JfQc0030000[[CM[[CM02^^]=d00`000:bl
iJbli@06[;cU0P0002Jea^L00`000;?8j[?8jP0</lSZ0`0005ooool01@000?ooooooooooo`00000:
oooo0027oooo0P00023oool00`0007ija7ija00COW[40P00016]XL`00`000:jdgJjdg@0[[[CM00<0
002/_>F/_>D00jbli@80000Y]LKW00<0002cb>Zcb>X02K?8jP80001Soooo00@0003oooooool0000:
oooo0029oooo00<0003oooooool07Oooo`030000OW[4OW[4015nN/@200005:fQc0030000[[CM[[CM
02^^]=d00`000:bliJbli@020000;;G6i`030000/lSZ/lSZ00Jcb>X20000IOooo`040000oooooooo
00002_ooo`00R_ooo`030000oooooooo01coool00`0007ija7ija00?OW[40P0001J]XL`00`000:jd
gJjdg@0[[[CM0`0002nea^L00`000;?8j[?8jP03/lSZ0P0006Soool00`000?ooo`00000:oooo002;
oooo00<0003oooooool07?ooo`030000OW[4OW[400anN/@200006JfQc0030000[[CM[[CM02R^]=d2
00000[W=j@030000]LKW]LKW02jea^L00`000;?8j[?8jP020000Joooo`030000oooo000000Woool0
08coool00`000?ooooooo`0Koooo00<0001nN/AnN/@02Gija0<0000L[J7<00<0002^]=f^]=d09Jjd
g@800005^LgY00<0002ea^Nea^L0;KG6i`<0001^oooo0P0000Woool008goool200006oooo`030000
OW[4OW[400MnN/@200008:fQc0030000[[CM[[CM02:^]=d200002;W=j@030000]LKW]LKW02Zea^L2
0000LOooo`800009oooo002?oooo00<0003oooooool06Oooo`030000OW[4OW[400AnN/@200008ZfQ
c0030000[[CM[[CM022^]=d200002kW=j@030000]LKW]LKW02Nea^L20000Loooo`800009oooo002@
oooo00<0003oooooool06?ooo`030000OW[4OW[4009nN/@200009JfQc0030000[[CM[[CM01f^]=d2
00003[W=j@030000]LKW]LKW02Bea^L20000LOooo`@0000;oooo002Aoooo00<0003oooooool06?oo
o`040000OW[400000000::fQc0030000[[CM[[CM01Z^]=d200004KW=j@030000]LKW]LKW026ea^L2
0000Koooo`@0000?oooo002Boooo0P0001Soool20000:jfQc0030000[[CM[[CM01N^]=d200005;W=
j@030000]LKW]LKW01fea^L30000KOooo`@0000Coooo002Doooo00<0003oooooool05_ooo`030000
[J7<[J7<02Z]XL`00`000:jdgJjdg@0C[[CM0`0001NicNT00`000;G6ikG6i`0J]LKW0P0006coool4
00005oooo`00UOooo`030000oooooooo01Goool00`000:fQc:fQc00Z[J7<00<0002^]=f^]=d04Jjd
g@80000K^LgY0P0001Rea^L20000J_ooo`@0000Koooo002Foooo00<0003oooooool05Oooo`030000
[J7<[J7<02Z]XL`00`000:jdgJjdg@0>[[CM0P0001nicNT00`000;G6ikG6i`0C]LKW0P0006Woool3
00007oooo`00Uoooo`80000Eoooo00<0002]XLb]XL`0:jfQc0030000[[CM[[CM00^^]=d200008[W=
j@030000]LKW]LKW012ea^L20000Ioooo`@0000Roooo002Ioooo00<0003oooooool04oooo`030000
[J7<[J7<02^]XL`00`000:jdgJjdg@08[[CM0P0002FicNT00`000;G6ikG6i`0<]LKW0`0006Goool4
00009_ooo`00V_ooo`030000oooooooo01;oool00`000:fQc:fQc00/[J7<00<0002^]=f^]=d01Jjd
g@80000X^LgY00<0002ea^Nea^L02KG6i`80001Toooo100002[oool009_oool00`000?ooooooo`0B
oooo00<0002]XLb]XL`0:jfQc0030000[[CM[[CM00>^]=d20000:kW=j@030000]LKW]LKW00Jea^L2
0000H_ooo`@0000^oooo002Loooo0P0001;oool00`000:fQc:fQc00/[J7<00<0002^]=f^]=d00P00
02jicNT00`000;G6ikG6i`03]LKW0P00063oool40000<_ooo`00W_ooo`030000oooooooo013oool0
0`000:fQc:fQc00/[J7<0P00036icNT00`000;G6ikG6i`020000Goooo`<0000foooo002Ooooo00<0
003oooooool03oooo`030000[J7<[J7<02^]XL`010000<ggj0000000032icNT30000GOooo`@0000i
oooo002Poooo00<0003oooooool03oooo`030000[J7<[J7<02R]XL`200001<ggj0030000^LgY^LgY
02^icNT20000G?ooo`@0000moooo002Qoooo0P00013oool00`000:fQc:fQc00V[J7<00<0003=mnS=
mnP01Lggj0030000^LgY^LgY02NicNT30000F_ooo`@00011oooo002Soooo00<0003oooooool03Ooo
o`030000[J7<[J7<02F]XL`00`000<ggj<ggj007cOOX0P0002FicNT20000FOooo`@00015oooo002T
oooo00<0003oooooool03Oooo`030000[J7<[J7<02>]XL`00`000<ggj<ggj00:cOOX00<0002icNVi
cNT07kW=j@<0001Goooo100004Woool00:Goool00`000?ooooooo`0<oooo00<0002]XLb]XL`08JfQ
c080000>cOOX00<0002icNVicNT07;W=j@80001Goooo0`0004goool00:Koool200003Oooo`030000
[J7<[J7<01n]XL`00`000<ggj<ggj00?cOOX0P0001VicNT30000EOooo`@0001@oooo002Xoooo00<0
003oooooool02_ooo`030000[J7<[J7<01j]XL`00`000<ggj<ggj00BcOOX00<0002icNVicNT04kW=
j@<0001Doooo100005Coool00:Woool00`000?ooooooo`0:oooo00<0002]XLb]XL`06jfQc080000F
cOOX00<0002icNVicNT04;W=j@80001Coooo100005Soool00:[oool00`000?ooooooo`09oooo00<0
002]XLb]XL`06ZfQc0030000cOOXcOOX01O=mnP200003KW=j@<0001Aoooo100005coool00:_oool0
0`000?ooooooo`09oooo00<0002]XLb]XL`06:fQc0030000cOOXcOOX01[=mnP00`000;W=jKW=j@08
^LgY0P00053oool40000H?ooo`00[?ooo`800009oooo00<0002]XLb]XL`05jfQc0030000cOOXcOOX
01c=mnP00`000;W=jKW=j@04^LgY0`0004ooool30000I?ooo`00[_ooo`030000oooooooo00Ooool0
0`000:fQc:fQc00D[J7<0P00023=mnP200000[W=j@80001>oooo100006Ooool00:ooool00`000?oo
ooooo`06oooo00<0002]XLb]XL`04jfQc0030000cOOXcOOX027=mnP30000C?ooo`@0001[oooo002`
oooo00<0003oooooool01_ooo`030000[J7<[J7<016]XL`00`000<ggj<ggj00OcOOX0`0004_oool4
0000Koooo`00/Oooo`800007oooo00<0002]XLb]XL`03jfQc0030000cOOXcOOX01g=mnP30000B_oo
o`@0001coooo002coooo00<0003oooooool01?ooo`030000[J7<[J7<00f]XL`200007Lggj0<00019
oooo100007Ooool00;Coool00`000?ooooooo`04oooo00<0002]XLb]XL`02jfQc0030000cOOXcOOX
01[=mnP30000B?ooo`@0001koooo002eoooo00<0003oooooool00oooo`030000[J7<[J7<00Z]XL`0
0`000<ggj<ggj00IcOOX0P0004Soool30000Ooooo`00]_ooo`800004oooo00<0002]XLb]XL`01jfQ
c080000IcOOX0`0004Koool40000P_ooo`00^?ooo`050000oooooooooooo000000R]XL`00`000<gg
j<ggj00FcOOX0`0004Goool40000Q_ooo`00^Oooo`050000oooooooooooo000000J]XL`00`000<gg
j<ggj00DcOOX0`0004Coool40000R_ooo`00^_ooo`040000oooooooo00001JfQc0030000cOOXcOOX
01;=mnP30000@oooo`@0002>oooo002koooo0P000004oooo0000[J7<[J7<0P0001;=mnP30000@_oo
o`@0002Boooo002moooo0P000003[J7<0000cOOX00O=mnP<0000@_ooo`<0002Foooo002noooo2`00
00[oool00`000?ooooooo`0moooo100009Woool00;ooool00`000?ooooooo`0Aoooo00<0003ooooo
ool0>Oooo`@0002Moooo0030oooo0P00017oool00`000?ooooooo`0eoooo10000:7oool00<;oool0
0`000?ooooooo`0>oooo00<0003oooooool0<Oooo`@0002Uoooo0033oooo00<0003oooooool03Ooo
o`030000oooooooo02goool40000ZOooo`00a?ooo`030000oooooooo00coool00`000?ooooooo`0Z
oooo0`000:goool00<Goool00`000?ooooooo`0;oooo00<0003oooooool09_ooo`@0002`oooo0036
oooo0P0000_oool00`000?ooooooo`0Roooo10000;Coool00<Soool00`000?ooooooo`08oooo00<0
003oooooool07_ooo`@0002hoooo0039oooo00<0003oooooool01oooo`030000oooooooo01[oool4
0000_?ooo`00b_ooo`030000oooooooo00Koool00`000?ooooooo`0Foooo10000<3oool00<_oool2
00001_ooo`030000oooooooo01?oool30000a?ooo`00cOooo`030000oooooooo00?oool00`000?oo
ooooo`0?oooo10000<Ooool00<koool00`000?ooooooo`02oooo00<0003oooooool02oooo`@0003;
oooo003?oooo00D0003oooooooooool000002Oooo`@0003?oooo003@oooo0P000003oooo0000oooo
00Coool40000doooo`00d_ooo`8000000oooo`00000000020000eoooo`00doooo`80003Koooo003o
oooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003o
oooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003o
oooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003o
oooo/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {349.313, 0}} -> {-0.19459, -0.0591155, 
  0.00407435, 0.00407435}}]
}, Open  ]],

Cell["\<\
Hier zeigt sich, da\[SZ] auch bei handels\[UDoubleDot]blichen \
Zeichenprogrammen die Methode der Interpolationspolynome nicht bekannt ist.\
\
\>", "Text"],

Cell["\<\
Die Oberfl\[ADoubleDot]chenkontur eines ausgeschnittenen \
Viertelkreises besitzt folgende Funktion:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
      Evaluate[funktion /. {x \[Rule] 1 + \@\(1 - \((y - 1)\)\^2\)}], {y, 1, 
        2}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.0147151 0.643862 [
[.21429 .00222 -9.5 -15 ]
[.21429 .00222 9.5 0 ]
[.40476 .00222 -9.5 -15 ]
[.40476 .00222 9.5 0 ]
[.59524 .00222 -9.5 -15 ]
[.59524 .00222 9.5 0 ]
[.78571 .00222 -9.5 -15 ]
[.78571 .00222 9.5 0 ]
[.97619 .00222 -5 -15 ]
[.97619 .00222 5 0 ]
[.01131 .14349 -19 -7.5 ]
[.01131 .14349 0 7.5 ]
[.01131 .27226 -19 -7.5 ]
[.01131 .27226 0 7.5 ]
[.01131 .40103 -19 -7.5 ]
[.01131 .40103 0 7.5 ]
[.01131 .5298 -19 -7.5 ]
[.01131 .5298 0 7.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -70.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14349 m
.03006 .14349 L
s
gsave
.01131 .14349 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .27226 m
.03006 .27226 L
s
gsave
.01131 .27226 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .40103 m
.03006 .40103 L
s
gsave
.01131 .40103 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .5298 m
.03006 .5298 L
s
gsave
.01131 .5298 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.02381 .04691 m
.02756 .04691 L
s
.02381 .0791 m
.02756 .0791 L
s
.02381 .11129 m
.02756 .11129 L
s
.02381 .17568 m
.02756 .17568 L
s
.02381 .20787 m
.02756 .20787 L
s
.02381 .24007 m
.02756 .24007 L
s
.02381 .30445 m
.02756 .30445 L
s
.02381 .33665 m
.02756 .33665 L
s
.02381 .36884 m
.02756 .36884 L
s
.02381 .43323 m
.02756 .43323 L
s
.02381 .46542 m
.02756 .46542 L
s
.02381 .49761 m
.02756 .49761 L
s
.02381 .562 m
.02756 .562 L
s
.02381 .59419 m
.02756 .59419 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60018 m
.04262 .60104 L
.06244 .60184 L
.08255 .6025 L
.09409 .6028 L
.10458 .60302 L
.1094 .6031 L
.11464 .60318 L
.11917 .60323 L
.12415 .60328 L
.12688 .60329 L
.12944 .60331 L
.13085 .60331 L
.13213 .60331 L
.13285 .60332 L
.13362 .60332 L
.13436 .60332 L
.13504 .60332 L
.13635 .60332 L
.13759 .60332 L
.1387 .60332 L
.1399 .60331 L
.14122 .60331 L
.1426 .60331 L
.14509 .60329 L
.14763 .60328 L
.15005 .60326 L
.15457 .60321 L
.15943 .60314 L
.16473 .60305 L
.17425 .60283 L
.18306 .60256 L
.20172 .6018 L
.22233 .60063 L
.24167 .59918 L
.26253 .59724 L
.30367 .59213 L
.34329 .58551 L
.3814 .57746 L
.42196 .56698 L
.46101 .55494 L
.50251 .53995 L
.54249 .52328 L
.58095 .50511 L
.62187 .48336 L
.66128 .45994 L
.69916 .43496 L
.7395 .40546 L
.77833 .37385 L
.8196 .33605 L
Mistroke
.85936 .29421 L
.89761 .24632 L
.91897 .21419 L
.93831 .17909 L
.94769 .15855 L
.95783 .13171 L
.96248 .11663 L
.9674 .09729 L
.96942 .08759 L
.97159 .07527 L
.97284 .06673 L
.97397 .0573 L
.97511 .04468 L
.97619 .0149 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012QP00`40o`000?l0003ooooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
06Soool600000oooo`800002oooo1`0003Ooool600000oooo`800007oooo0P0003Ooool600000ooo
o`800004oooo100003Woool600000oooo`800004oooo100003koool700003_ooo`00J_ooo`800005
oooo0P0000?oool70000>?ooo`800005oooo0P0000Ooool20000>Oooo`800005oooo0P0000?oool2
00000_ooo`80000joooo0P0000Goool200000oooo`800003oooo00<0003oooooool0??ooo`L0000=
oooo001Zoooo0P0000_oool00`000?ooooooo`02oooo00<0003oooooool0=_ooo`80000>oooo0P00
03Woool200002Oooo`800004oooo0P0003Woool200002Oooo`800004oooo0P0003koool00`000?oo
ooooo`02oooo00<0003oooooool02oooo`00J_ooo`80000<oooo00<0003oooooool0>_ooo`800009
oooo200003Soool200002Oooo`800004oooo0P0003Woool200002Oooo`800004oooo0P0003ooool0
0`000?ooooooo`0?oooo001Zoooo0P0000goool00`000?ooooooo`0ioooo0P0000Woool00`000?oo
ooooo`02oooo0P0003Woool200002Oooo`800004oooo0P0003Woool200002_ooo`040000oooooooo
oooo0P00047oool00`000?ooooooo`0>oooo001Zoooo0P0000goool20000>_ooo`80000:oooo00@0
003oooooooooool20000>Oooo`800009oooo0P0000Coool20000>Oooo`80000;oooo100004;oool2
00003oooo`00J_ooo`80000>oooo00<0003oooooool0>?ooo`80000;oooo00<0003oooooool00P00
03Woool200002Oooo`<00002oooo0P0003[oool200002oooo`<00014oooo00<0003oooooool03Ooo
o`00J_ooo`80000>oooo0P0003Woool200002oooo`030000oooooooo0080000ioooo0P0000[oool0
0`000?ooo`0000020000>oooo`80000:oooo0P0000;oool20000@_ooo`80000>oooo001Zoooo0P00
00koool20000>Oooo`80000<oooo00@0003oool00000000ioooo0P0000[oool20000?_ooo`800009
oooo0P0000Coool20000@Oooo`80000>oooo001Zoooo0P0000Woool00`000?ooooooo`02oooo0P00
03Woool200003Oooo`<0000ioooo0P0000_oool20000?Oooo`800009oooo0P0000Coool20000??oo
o`030000oooooooo00;oool200003_ooo`00J?ooo`@0000:oooo00<0003oooooool00`0003Ooool4
00003_ooo`80000goooo100000coool30000>Oooo`@0000:oooo0P0000?oool00`000?ooooooo`0l
oooo00<0003oooooool00`0000koool006[oool200002oooo`@0000joooo0P0000koool20000>Ooo
o`80000>oooo0`0003Woool200002oooo`@00010oooo100000ooool00?oooonaoooo003ooooo/Ooo
o`009oooo`030000oooooooo0?oooon7oooo000Woooo00<0003oooooool0ooooohOoool002Ooool0
0`000?ooooooo`3oooooQoooo`009oooo`030000oooooooo0?oooon7oooo000Woooo00<0003ooooo
ool0ooooohOoool002Ooool00`000?ooooooo`3oooooQoooo`007Oooool0002>00001_ooo`009ooo
o`030000oooooooo013oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo
013oool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?oo
ooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0@oooo00<0
003oooooool04?ooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04?oo
o`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo
00ooool00`000?ooooooo`0@oooo00<0003oooooool03_ooo`009oooo`030000oooooooo013oool0
0`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0@
oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0?oooo00<0003ooooo
ool04?ooo`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000
oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo013oool0
0`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00ooool00`000?ooooooo`0@
oooo00<0003oooooool03_ooo`009oooo`030000oooooooo04Soool00`000?ooooooo`18oooo00<0
003oooooool0BOooo`030000oooooooo04Soool00`000?ooooooo`18oooo00<0003oooooool03_oo
o`009oooo`030000oooooooo0?oooomfoooo00<0003oooooool03_ooo`009oooo`030000oooooooo
0?oooomfoooo00<0003oooooool03_ooo`009oooo`030000oooooooo0?oooomfoooo00<0003ooooo
ool03_ooo`009oooo`030000oooooooo0?oooomfoooo00<0003oooooool03_ooo`009oooo`030000
oooooooo0?oooomfoooo00<0003oooooool03_ooo`009oooo`030000oooooooo0?oooomfoooo00<0
003oooooool03_ooo`009oooo`030000oooooooo0?oooomfoooo00<0003oooooool03_ooo`009ooo
o`030000oooooooo0?oooomfoooo00<0003oooooool03_ooo`009oooo`030000oooooooo0?oooomf
oooo00<0003oooooool03_ooo`009oooo`80003oooooMoooo`030000oooooooo00koool002Ooool0
0`000?ooooooo`3oooooM_ooo`030000oooooooo00koool002Ooool00`000?ooooooo`3oooooMOoo
o`030000oooooooo00ooool002Ooool00`000?ooooooo`3oooooMOooo`030000oooooooo00ooool0
02Ooool00`000?ooooooo`3oooooMOooo`030000oooooooo00ooool002Ooool00`000?ooooooo`3o
ooooMOooo`030000oooooooo00ooool002Ooool00`000?ooooooo`3oooooMOooo`030000oooooooo
00ooool002Ooool00`000?ooooooo`3oooooMOooo`030000oooooooo00ooool002Ooool00`000?oo
ooooo`3oooooMOooo`030000oooooooo00ooool002Ooool00`000?ooooooo`3oooooMOooo`030000
oooooooo00ooool002Ooool00`000?ooooooo`3oooooM?ooo`030000oooooooo013oool002Ooool0
0`000?ooooooo`3oooooM?ooo`030000oooooooo013oool002Ooool00`000?ooooooo`3oooooM?oo
o`030000oooooooo013oool002Ooool20000ooooogGoool00`000?ooooooo`0@oooo000Woooo00<0
003oooooool0ooooogCoool00`000?ooooooo`0@oooo000Woooo00<0003oooooool0ooooogCoool0
0`000?ooooooo`0@oooo000Woooo00<0003oooooool0ooooogCoool00`000?ooooooo`0@oooo000W
oooo00<0003oooooool0ooooogCoool00`000?ooooooo`0@oooo000Woooo00<0003oooooool0oooo
ogCoool00`000?ooooooo`0@oooo000Woooo00<0003oooooool0ooooog?oool00`000?ooooooo`0A
oooo000Woooo00<0003oooooool0ooooog?oool00`000?ooooooo`0Aoooo000Woooo00<0003ooooo
ool0ooooog?oool00`000?ooooooo`0Aoooo000Woooo00<0003oooooool0ooooog;oool00`000?oo
ooooo`0Boooo000Woooo00<0003oooooool0ooooog;oool00`000?ooooooo`0Boooo000Woooo00<0
003oooooool0ooooog;oool00`000?ooooooo`0Boooo000Woooo0P000?oooomcoooo00<0003ooooo
ool04_ooo`009oooo`030000oooooooo0?oooomaoooo00<0003oooooool04oooo`009oooo`030000
oooooooo0?oooomaoooo00<0003oooooool04oooo`009oooo`030000oooooooo0?oooomaoooo00<0
003oooooool04oooo`009oooo`030000oooooooo0?oooom`oooo00<0003oooooool05?ooo`009ooo
o`030000oooooooo0?oooom`oooo00<0003oooooool05?ooo`009oooo`030000oooooooo0?oooom`
oooo00<0003oooooool05?ooo`009oooo`030000oooooooo0?oooom_oooo00<0003oooooool05Ooo
o`009oooo`030000oooooooo0?oooom_oooo00<0003oooooool05Oooo`002_ooo`@00004oooo0P00
00;oool700002_ooo`030000oooooooo0?oooom_oooo00<0003oooooool05Oooo`002Oooo`800002
oooo0P0000?oool200000oooo`L00009oooo00<0003oooooool0ooooofkoool00`000?ooooooo`0F
oooo0009oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000oooooooo0?oooom^oooo00<0003oooooool05_ooo`002?ooo`800004
oooo0P0000Woool00`000?ooooooo`0;oooo00<0003oooooool0ooooofkoool00`000?ooooooo`0F
oooo0008oooo0P0000Coool200002_ooo`030000oooooooo00[oool30000ooooofgoool00`000?oo
ooooo`0Goooo0008oooo0P0000Coool200002_ooo`80000;oooo00<0003oooooool0ooooofgoool0
0`000?ooooooo`0Goooo0008oooo0P0000Coool200002oooo`030000oooooooo00Woool00`000?oo
ooooo`3oooooK?ooo`030000oooooooo01Soool000Soool200001?ooo`80000;oooo0P0000[oool0
0`000?ooooooo`3oooooK?ooo`030000oooooooo01Soool000Soool200001?ooo`80000;oooo0P00
00[oool00`000?ooooooo`3oooooK?ooo`030000oooooooo01Soool000Woool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`030000oooooooo00;oool200002_ooo`030000oooooooo0?oooom[
oooo00<0003oooooool06Oooo`002Oooo`800002oooo0P0000Soool00`000?ooooooo`0300002_oo
o`030000oooooooo0?oooom[oooo00<0003oooooool06Oooo`002_ooo`@0000:oooo100000_oool0
0`000?ooooooo`3oooooJoooo`030000oooooooo01Woool002Ooool00`000?ooooooo`3oooooJ_oo
o`030000oooooooo01[oool002Ooool00`000?ooooooo`3oooooJ_ooo`030000oooooooo01[oool0
02Ooool00`000?ooooooo`3oooooJOooo`030000oooooooo01_oool002Ooool00`000?ooooooo`3o
ooooJOooo`030000oooooooo01_oool002Ooool00`000?ooooooo`3oooooJ?ooo`030000oooooooo
01coool002Ooool20000ooooofWoool00`000?ooooooo`0Loooo000Woooo00<0003oooooool0oooo
ofOoool00`000?ooooooo`0Moooo000Woooo00<0003oooooool0ooooofOoool00`000?ooooooo`0M
oooo000Woooo00<0003oooooool0ooooofKoool00`000?ooooooo`0Noooo000Woooo00<0003ooooo
ool0ooooofKoool00`000?ooooooo`0Noooo000Woooo00<0003oooooool0ooooofGoool00`000?oo
ooooo`0Ooooo000Woooo00<0003oooooool0ooooofGoool00`000?ooooooo`0Ooooo000Woooo00<0
003oooooool0ooooofCoool00`000?ooooooo`0Poooo000Woooo00<0003oooooool0ooooofCoool0
0`000?ooooooo`0Poooo000Woooo00<0003oooooool0ooooof?oool00`000?ooooooo`0Qoooo000W
oooo00<0003oooooool0ooooof?oool00`000?ooooooo`0Qoooo000Woooo00<0003oooooool0oooo
of;oool00`000?ooooooo`0Roooo000Woooo0P000?oooomSoooo00<0003oooooool08_ooo`009ooo
o`030000oooooooo0?oooomQoooo00<0003oooooool08oooo`009oooo`030000oooooooo0?oooomQ
oooo00<0003oooooool08oooo`009oooo`030000oooooooo0?oooomPoooo00<0003oooooool09?oo
o`009oooo`030000oooooooo0?oooomOoooo00<0003oooooool09Oooo`009oooo`030000oooooooo
0?oooomOoooo00<0003oooooool09Oooo`009oooo`030000oooooooo0?oooomNoooo00<0003ooooo
ool09_ooo`009oooo`030000oooooooo0?oooomMoooo00<0003oooooool09oooo`009oooo`030000
oooooooo0?oooomMoooo00<0003oooooool09oooo`009oooo`030000oooooooo0?oooomLoooo00<0
003oooooool0:?ooo`009oooo`030000oooooooo0?oooomKoooo00<0003oooooool0:Oooo`009ooo
o`030000oooooooo0?oooomJoooo00<0003oooooool0:_ooo`009oooo`030000oooooooo0?oooomJ
oooo00<0003oooooool0:_ooo`009oooo`80003oooooF_ooo`030000oooooooo02_oool002Ooool0
0`000?ooooooo`3oooooF?ooo`030000oooooooo02coool002Ooool00`000?ooooooo`3oooooF?oo
o`030000oooooooo02coool002Ooool00`000?ooooooo`3oooooEoooo`030000oooooooo02goool0
02Ooool00`000?ooooooo`3oooooE_ooo`030000oooooooo02koool002Ooool00`000?ooooooo`3o
ooooEOooo`030000oooooooo02ooool002Ooool00`000?ooooooo`3oooooEOooo`030000oooooooo
02ooool002Ooool00`000?ooooooo`3oooooE?ooo`030000oooooooo033oool002Ooool00`000?oo
ooooo`3oooooDoooo`030000oooooooo037oool000[oool400001?ooo`800007oooo0P0000[oool0
0`000?ooooooo`3oooooD_ooo`030000oooooooo03;oool000Woool200000_ooo`800003oooo0P00
00Ooool200002_ooo`030000oooooooo0?oooomAoooo00<0003oooooool0<oooo`002Oooo`030000
oooooooo00;oool00`000?ooooooo`0:oooo0P0000[oool00`000?ooooooo`3oooooDOooo`030000
oooooooo03?oool000Soool200001?ooo`800006oooo200000Woool00`000?ooooooo`3oooooD?oo
o`030000oooooooo03Coool000Soool200001?ooo`800006oooo00<0003oooooool00_ooo`80000:
oooo0`000?oooom?oooo00<0003oooooool0=Oooo`002?ooo`800004oooo0P0000Ooool010000?oo
ooooooooo`80000:oooo00<0003oooooool0ooooodkoool00`000?ooooooo`0foooo0008oooo0P00
00Coool200002?ooo`030000oooooooo0080000:oooo00<0003oooooool0ooooodkoool00`000?oo
ooooo`0foooo0008oooo0P0000Coool200002?ooo`030000oooooooo0080000:oooo00<0003ooooo
ool0ooooodgoool00`000?ooooooo`0goooo0008oooo0P0000Coool200002Oooo`040000oooo0000
00002_ooo`030000oooooooo0?oooom<oooo00<0003oooooool0>?ooo`002Oooo`030000oooooooo
00;oool00`000?ooooooo`09oooo0`0000[oool00`000?ooooooo`3oooooBoooo`030000oooooooo
03Woool000Woool200000_ooo`80000<oooo0P0000[oool00`000?ooooooo`3oooooB_ooo`030000
oooooooo03[oool000[oool400003Oooo`80000:oooo00<0003oooooool0oooood[oool00`000?oo
ooooo`0joooo000Woooo00<0003oooooool0ooooodWoool00`000?ooooooo`0koooo000Woooo00<0
003oooooool0ooooodSoool00`000?ooooooo`0loooo000Woooo00<0003oooooool0ooooodOoool0
0`000?ooooooo`0moooo000Woooo00<0003oooooool0ooooodKoool00`000?ooooooo`0noooo000W
oooo00<0003oooooool0ooooodGoool00`000?ooooooo`0ooooo000Woooo0P000?oooom5oooo00<0
003oooooool0@?ooo`009oooo`030000oooooooo0?oooom3oooo00<0003oooooool0@Oooo`009ooo
o`030000oooooooo0?oooom2oooo00<0003oooooool0@_ooo`009oooo`030000oooooooo0?oooom1
oooo00<0003oooooool0@oooo`009oooo`030000oooooooo0?oooom0oooo00<0003oooooool0A?oo
o`009oooo`030000oooooooo0?oooolooooo00<0003oooooool0AOooo`009oooo`030000oooooooo
0?oooolnoooo00<0003oooooool0A_ooo`009oooo`030000oooooooo0?oooolmoooo00<0003ooooo
ool0Aoooo`009oooo`030000oooooooo0?oooolloooo00<0003oooooool0B?ooo`009oooo`030000
oooooooo0?oooolkoooo00<0003oooooool0BOooo`009oooo`030000oooooooo0?ooooljoooo00<0
003oooooool0B_ooo`009oooo`030000oooooooo0?oooolioooo00<0003oooooool0Boooo`009ooo
o`80003ooooo>Oooo`030000oooooooo04coool002Ooool00`000?ooooooo`3ooooo=oooo`030000
oooooooo04goool002Ooool00`000?ooooooo`3ooooo=_ooo`030000oooooooo04koool002Ooool0
0`000?ooooooo`3ooooo=Oooo`030000oooooooo04ooool002Ooool00`000?ooooooo`3ooooo=?oo
o`030000oooooooo053oool002Ooool00`000?ooooooo`3ooooo<oooo`030000oooooooo057oool0
02Ooool00`000?ooooooo`3ooooo<_ooo`030000oooooooo05;oool002Ooool00`000?ooooooo`3o
oooo<Oooo`030000oooooooo05?oool002Ooool00`000?ooooooo`3ooooo;oooo`80001Foooo000W
oooo00<0003oooooool0ooooobkoool00`000?ooooooo`1Foooo000Woooo00<0003oooooool0oooo
obgoool00`000?ooooooo`1Goooo000Woooo00<0003oooooool0ooooobcoool00`000?ooooooo`1H
oooo000Woooo00<0003oooooool0ooooob_oool00`000?ooooooo`1Ioooo000Woooo0P000?ooool[
oooo00<0003oooooool0F_ooo`009oooo`030000oooooooo0?oooolYoooo00<0003oooooool0Fooo
o`009oooo`030000oooooooo0?oooolXoooo00<0003oooooool0G?ooo`009oooo`030000oooooooo
0?oooolWoooo00<0003oooooool0GOooo`009oooo`030000oooooooo0?oooolUoooo0P00063oool0
02Ooool00`000?ooooooo`3ooooo9?ooo`030000oooooooo063oool002Ooool00`000?ooooooo`3o
oooo8oooo`030000oooooooo067oool002Ooool00`000?ooooooo`3ooooo8_ooo`030000oooooooo
06;oool002Ooool00`000?ooooooo`3ooooo8?ooo`80001Uoooo000:oooo100000Coool200001?oo
o`@0000;oooo00<0003oooooool0oooooaooool00`000?ooooooo`1Uoooo0009oooo0P0000;oool2
00000oooo`800003oooo0P0000;oool200002_ooo`030000oooooooo0?oooolNoooo00<0003ooooo
ool0I_ooo`002Oooo`030000oooooooo00;oool00`000?ooooooo`05oooo0P0000Coool200002Ooo
o`030000oooooooo0?oooolMoooo00<0003oooooool0Ioooo`002?ooo`800004oooo0P0000Koool2
00001?ooo`800009oooo00<0003oooooool0oooooa_oool20000J_ooo`002?ooo`800004oooo0P00
00Koool200001?ooo`800009oooo0`000?oooolJoooo00<0003oooooool0J_ooo`002?ooo`800004
oooo0P0000Koool200001?ooo`800009oooo00<0003oooooool0oooooaWoool00`000?ooooooo`1[
oooo0008oooo0P0000Coool200001_ooo`<00002oooo0P0000[oool00`000?ooooooo`3ooooo6?oo
o`030000oooooooo06coool000Soool200001?ooo`800007oooo00<0003oool000000P0000_oool0
0`000?ooooooo`3ooooo5_ooo`80001_oooo0008oooo0P0000Coool200001oooo`80000>oooo00<0
003oooooool0oooooaGoool00`000?ooooooo`1_oooo0009oooo00<0003oooooool00_ooo`030000
oooooooo00Ooool200003Oooo`030000oooooooo0?oooolDoooo00<0003oooooool0L?ooo`002Ooo
o`800002oooo0P0000[oool300002oooo`030000oooooooo0?oooolBoooo0P0007?oool000[oool4
00003Oooo`<00009oooo00<0003oooooool0oooooa7oool00`000?ooooooo`1coooo000Woooo00<0
003oooooool0oooooa3oool00`000?ooooooo`1doooo000Woooo00<0003oooooool0ooooo`koool2
0000Moooo`009oooo`030000oooooooo0?ooool=oooo00<0003oooooool0Moooo`009oooo`030000
oooooooo0?ooool<oooo00<0003oooooool0N?ooo`009oooo`80003ooooo2oooo`80001koooo000W
oooo00<0003oooooool0ooooo`Woool00`000?ooooooo`1koooo000Woooo00<0003oooooool0oooo
o`Ooool20000O_ooo`009oooo`030000oooooooo0?ooool6oooo00<0003oooooool0O_ooo`009ooo
o`030000oooooooo0?ooool4oooo0P00087oool002Ooool00`000?ooooooo`3ooooo0oooo`030000
oooooooo087oool002Ooool00`000?ooooooo`3ooooo0Oooo`800024oooo000Woooo00<0003ooooo
ool0ooooo`030000oooooooo08Coool002Ooool00`000?ooooooo`3moooo0P0008Ooool002Ooool0
0`000?ooooooo`3loooo00<0003oooooool0Qoooo`009oooo`030000oooooooo0?[oool20000R_oo
o`009oooo`030000oooooooo0?Woool00`000?ooooooo`2:oooo000Woooo00<0003oooooool0mooo
o`80002=oooo000Woooo0P000?Koool20000Soooo`009oooo`030000oooooooo0??oool20000TOoo
o`009oooo`030000oooooooo0?;oool00`000?ooooooo`2Aoooo000Woooo00<0003oooooool0l?oo
o`80002Doooo000Woooo00<0003oooooool0k_ooo`80002Foooo000Woooo00<0003oooooool0k?oo
o`80002Hoooo000Woooo00<0003oooooool0j_ooo`80002Joooo000Woooo00<0003oooooool0jOoo
o`030000oooooooo09[oool002Ooool00`000?ooooooo`3Woooo0P0009goool002Ooool00`000?oo
ooooo`3Uoooo0P0009ooool002Ooool00`000?ooooooo`3Soooo0P000:7oool002Ooool00`000?oo
ooooo`3Roooo00<0003oooooool0XOooo`009oooo`030000oooooooo0>3oool20000Y?ooo`009ooo
o`80003Ooooo0P000:Koool002Ooool00`000?ooooooo`3Loooo0P000:Soool002Ooool00`000?oo
ooooo`3Joooo0P000:[oool002Ooool00`000?ooooooo`3Hoooo0P000:coool002Ooool00`000?oo
ooooo`3Foooo0P000:koool002Ooool00`000?ooooooo`3Doooo0P000;3oool002Ooool00`000?oo
ooooo`3Boooo0P000;;oool002Ooool00`000?ooooooo`3@oooo0P000;Coool002Ooool00`000?oo
ooooo`3>oooo0P000;Koool000[oool400001?ooo`800004oooo100000_oool00`000?ooooooo`3<
oooo0P000;Soool000Woool200000_ooo`800003oooo0P0000?oool200000oooo`030000oooooooo
00Soool00`000?ooooooo`39oooo0`000;[oool000Woool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`800004oooo0P0000Woool00`000?ooooooo`37oooo0P000;goool000Soool200001?oo
o`800006oooo0P0000Coool200002Oooo`030000oooooooo0<Goool20000_oooo`002?ooo`800004
oooo0P0000Ooool010000?ooooooooooo`80000:oooo0`000<?oool20000`Oooo`002?ooo`800004
oooo0P0000Soool400002oooo`030000oooooooo0<3oool30000`oooo`002?ooo`800004oooo0P00
00Soool300003?ooo`030000oooooooo0;koool20000a_ooo`002?ooo`800004oooo0P0000Ooool2
00000_ooo`80000:oooo00<0003oooooool0_?ooo`800038oooo0008oooo0P0000Coool200001_oo
o`800004oooo0P0000Woool00`000?ooooooo`2ioooo0`000<[oool000Woool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`800004oooo0P0000Woool00`000?ooooooo`2goooo0P000<goool0
00Woool200000_ooo`800008oooo0P0000?oool00`000?ooooooo`08oooo00<0003oooooool0]?oo
o`<0003?oooo000:oooo100000[oool400002oooo`030000oooooooo0;7oool30000d_ooo`009ooo
o`030000oooooooo0:ooool20000eOooo`009oooo`030000oooooooo0:coool30000eoooo`009ooo
o`030000oooooooo0:Soool40000f_ooo`009oooo`030000oooooooo0:Coool40000g_ooo`009ooo
o`80002Qoooo10000>;oool002Ooool00`000?ooooooo`2Loooo10000>Koool002Ooool00`000?oo
ooooo`2Hoooo10000>[oool002Ooool00`000?ooooooo`2Doooo10000>koool002Ooool00`000?oo
ooooo`2@oooo10000?;oool002Ooool00`000?ooooooo`2<oooo10000?Koool002Ooool00`000?oo
ooooo`29oooo0`000?[oool002Ooool00`000?ooooooo`25oooo10000?goool002Ooool00`000?oo
ooooo`21oooo10000?ooool2oooo000Woooo00<0003oooooool0OOooo`@0003ooooo1_ooo`009ooo
o`030000oooooooo07Ooool60000ooooo`[oool002Ooool00`000?ooooooo`1_oooo20000?ooool@
oooo000Woooo00<0003oooooool0Ioooo`P0003ooooo6?ooo`009oooo`80001Poooo20000?oooolP
oooo000Woooo00<0003oooooool0Eoooo`P0003ooooo:?ooo`009oooo`@0001>oooo20000?ooool`
oooo000Woooo00@0003ooooooooooolK00006ooooaP0003ooooo>?ooo`009oooo`030000oooooooo
01cooolK0000oooooe3oool002Ooool00`000?ooooooo`3oooooQoooo`009oooo`030000oooooooo
0?oooon7oooo000Woooo00<0003oooooool0ooooohOoool002Ooool00`000?ooooooo`3oooooQooo
o`009oooo`030000oooooooo0?oooon7oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0.895531, -0.107834, 
  0.00398525, 0.00589486}}]
}, Open  ]],

Cell["\<\
Damit ist das Grundwerkzeug zur Me\[SZ]werterfassung vorgestellt.\
\
\>", "Text"],

Cell["\<\
Als Beispiel f\[UDoubleDot]r eine gewichtete Reliefzeichnung \
gelingt folgende Interpolation, die garantiert nicht negativ wird, da nur \
doppelte Nullstellen bei quadrierten Funktionswerten vorkommen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(funktion = 
      LagrangeInterpolation[
        Transpose[{
            Range[4], {Sin[x]\^2, Log[x]\^2, Exp[\(-2\) x], Cos[x]\^2}, {2, 
              2, 2, 2}}], y]\)], "Input"],

Cell[BoxData[
    \(1\/4\ E\^\(\(-2\)\ x\)\ \((4 - y)\)\^2\ \((\(-2\) + y)\)\^2\ 
        \((\(-1\) + y)\)\^2 + 
      1\/36\ \((\(-3\) + y)\)\^2\ \((\(-2\) + y)\)\^2\ \((\(-1\) + y)\)\^2\ 
        Cos[x]\^2 + 
      1\/4\ \((3 - y)\)\^2\ \((4 - y)\)\^2\ \((\(-1\) + y)\)\^2\ Log[x]\^2 + 
      1\/36\ \((2 - y)\)\^2\ \((3 - y)\)\^2\ \((4 - y)\)\^2\ Sin[x]\^2\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[Evaluate[funktion], {x, 1\/30, 3}, {y, 1, 4}, 
      AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<f[x, y] \>"}, 
      ColorFunction \[Rule] Hue, PlotPoints \[Rule] 7]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.2234 .16912 -9.67427 -15 ]
[.2234 .16912 .32573 0 ]
[.44281 .08283 -8.97149 -15 ]
[.44281 .08283 1.02851 0 ]
[.68156 -0.01098 -8.26871 -15 ]
[.68156 -0.01098 1.73129 0 ]
[.29165 .07573 -10.2423 -15 ]
[.29165 .07573 .75771 0 ]
[.70096 -0.00478 0 -10.4368 ]
[.70096 -0.00478 10 4.56323 ]
[.80849 .15988 0 -10.1686 ]
[.80849 .15988 10 4.83137 ]
[.90119 .30183 0 -9.94535 ]
[.90119 .30183 10 5.05465 ]
[.98191 .42546 0 -9.75656 ]
[.98191 .42546 10 5.24344 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02411 .26511 -10 -4.57053 ]
[.02411 .26511 0 10.4295 ]
[.01704 .30943 -19 -4.63297 ]
[.01704 .30943 0 10.367 ]
[.00976 .35505 -10 -4.69742 ]
[.00976 .35505 0 10.3026 ]
[.00227 .40202 -19 -4.76397 ]
[.00227 .40202 0 10.236 ]
[-0.00545 .4504 -10 -4.83274 ]
[-0.00545 .4504 0 10.1673 ]
[-0.05457 .39542 -38 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.23236 .1787 m
.23684 .18349 L
s
gsave
.2234 .16912 -70.6743 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.45097 .0931 m
.45505 .09824 L
s
gsave
.44281 .08283 -69.9715 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -69.2687 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06977 .24237 m
.07261 .24509 L
s
.10946 .22683 m
.11227 .22959 L
s
.14978 .21104 m
.15255 .21384 L
s
.19074 .195 m
.19347 .19784 L
s
.27466 .16214 m
.27731 .16505 L
s
.31766 .1453 m
.32026 .14826 L
s
.36136 .12819 m
.36391 .13119 L
s
.40579 .11079 m
.40829 .11383 L
s
.49691 .07511 m
.49931 .07824 L
s
.54364 .05682 m
.54598 .05998 L
s
.59117 .0382 m
.59345 .04141 L
s
.63953 .01927 m
.64175 .02252 L
s
gsave
.29165 .07573 -71.2423 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.125000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -14.4368 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.79613 .16428 m
.78995 .16648 L
s
gsave
.80849 .15988 -61 -14.1686 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88871 .30589 m
.88247 .30793 L
s
gsave
.90119 .30183 -61 -13.9453 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -13.7566 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.71157 .03492 m
.70789 .03634 L
s
.73369 .06877 m
.73001 .07015 L
s
.75514 .10158 m
.75145 .10294 L
s
.77594 .1334 m
.77224 .13474 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.87123 .27915 m
.8675 .28039 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.95406 .40586 m
.9503 .40701 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
68.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
gsave
.02411 .26511 -71 -8.57053 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.0293 .30474 m
.03543 .3024 L
s
gsave
.01704 .30943 -80 -8.63297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02206 .35045 m
.0282 .34816 L
s
gsave
.00976 .35505 -71 -8.69742 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.0146 .39752 m
.02076 .39527 L
s
gsave
.00227 .40202 -80 -8.76397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.00691 .446 m
.0131 .4438 L
s
gsave
-0.00545 .4504 -71 -8.83274 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.03495 .26911 m
.03861 .26769 L
s
.03355 .27795 m
.03722 .27652 L
s
.03214 .28683 m
.03581 .28541 L
s
.03072 .29576 m
.0344 .29435 L
s
.02787 .31378 m
.03155 .31238 L
s
.02643 .32287 m
.03011 .32147 L
s
.02498 .33201 m
.02866 .33062 L
s
.02352 .3412 m
.02721 .33982 L
s
.02058 .35976 m
.02427 .35838 L
s
.0191 .36911 m
.02279 .36775 L
s
.01761 .37853 m
.0213 .37716 L
s
.01611 .38799 m
.0198 .38664 L
s
.01308 .4071 m
.01678 .40576 L
s
.01155 .41674 m
.01525 .4154 L
s
.01001 .42643 m
.01372 .4251 L
s
.00847 .43619 m
.01218 .43486 L
s
.00535 .45587 m
.00906 .45456 L
s
.00378 .4658 m
.00749 .4645 L
s
.00219 .4758 m
.00591 .4745 L
s
.0006 .48585 m
.00432 .48456 L
s
gsave
-0.05457 .39542 -99 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
68.125000 14.625000 moveto
(@) show
72.062500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
78.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
89.812500 14.625000 moveto
(D) show
96.750000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 1 .675 r
.34397 .73079 .40225 .68578 .4911 .63922 .44041 .56236 Metetra
.907 1 0 r
.44041 .56236 .4911 .63922 .58148 .57325 .53264 .51093 Metetra
1 .432 0 r
.53264 .51093 .58148 .57325 .6735 .52344 .62726 .47485 Metetra
1 .343 0 r
.62726 .47485 .6735 .52344 .77011 .50969 .7253 .44615 Metetra
1 .783 0 r
.7253 .44615 .77011 .50969 .87352 .51993 .82732 .42045 Metetra
.658 1 0 r
.82732 .42045 .87352 .51993 .98162 .51899 .93338 .39326 Metetra
0 1 .397 r
.29204 .58271 .34397 .73079 .44041 .56236 .38645 .50342 Metetra
1 .768 0 r
.38645 .50342 .44041 .56236 .53264 .51093 .48086 .45471 Metetra
1 .374 0 r
.48086 .45471 .53264 .51093 .62726 .47485 .57773 .41645 Metetra
1 .271 0 r
.57773 .41645 .62726 .47485 .7253 .44615 .67787 .38134 Metetra
1 .3 0 r
.67787 .38134 .7253 .44615 .82732 .42045 .78166 .34663 Metetra
1 .37 0 r
.78166 .34663 .82732 .42045 .93338 .39326 .88934 .31125 Metetra
0 1 .524 r
.21934 .66687 .29204 .58271 .38645 .50342 .32932 .43799 Metetra
1 .603 0 r
.32932 .43799 .38645 .50342 .48086 .45471 .42586 .38874 Metetra
1 .321 0 r
.42586 .38874 .48086 .45471 .57773 .41645 .52489 .35771 Metetra
1 .326 0 r
.52489 .35771 .57773 .41645 .67787 .38134 .62795 .33078 Metetra
1 .42 0 r
.62795 .33078 .67787 .38134 .78166 .34663 .73561 .30436 Metetra
1 .545 0 r
.73561 .30436 .78166 .34663 .88934 .31125 .8482 .27717 Metetra
0 .537 1 r
.1514 .61197 .21934 .66687 .32932 .43799 .26676 .39203 Metetra
1 .562 0 r
.26676 .39203 .32932 .43799 .42586 .38874 .36716 .32199 Metetra
1 .319 0 r
.36716 .32199 .42586 .38874 .52489 .35771 .46814 .30121 Metetra
1 .683 0 r
.46814 .30121 .52489 .35771 .62795 .33078 .57428 .29214 Metetra
.795 1 0 r
.57428 .29214 .62795 .33078 .73561 .30436 .68688 .28632 Metetra
.229 1 0 r
.68688 .28632 .73561 .30436 .8482 .27717 .80672 .28087 Metetra
0 .431 1 r
.07848 .55305 .1514 .61197 .26676 .39203 .20058 .32868 Metetra
1 .692 0 r
.20058 .32868 .26676 .39203 .36716 .32199 .30363 .26202 Metetra
1 .451 0 r
.30363 .26202 .36716 .32199 .46814 .30121 .40699 .23861 Metetra
.999 1 0 r
.40699 .23861 .46814 .30121 .57428 .29214 .51556 .222 Metetra
.282 1 0 r
.51556 .222 .57428 .29214 .68688 .28632 .63045 .20545 Metetra
0 1 .484 r
.63045 .20545 .68688 .28632 .80672 .28087 .75239 .18982 Metetra
0 1 .013 r
.03632 .26043 .07848 .55305 .20058 .32868 .13158 .24453 Metetra
.963 1 0 r
.13158 .24453 .20058 .32868 .30363 .26202 .23019 .24818 Metetra
.617 1 0 r
.23019 .24818 .30363 .26202 .40699 .23861 .3371 .23246 Metetra
.306 1 0 r
.3371 .23246 .40699 .23861 .51556 .222 .45153 .17285 Metetra
.378 1 0 r
.45153 .17285 .51556 .222 .63045 .20545 .5692 .08462 Metetra
.524 1 0 r
.5692 .08462 .63045 .20545 .75239 .18982 .68915 .0072 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.23236 .1787 m
.23684 .18349 L
s
gsave
.2234 .16912 -70.6743 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.45097 .0931 m
.45505 .09824 L
s
gsave
.44281 .08283 -69.9715 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -69.2687 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06977 .24237 m
.07261 .24509 L
s
.10946 .22683 m
.11227 .22959 L
s
.14978 .21104 m
.15255 .21384 L
s
.19074 .195 m
.19347 .19784 L
s
.27466 .16214 m
.27731 .16505 L
s
.31766 .1453 m
.32026 .14826 L
s
.36136 .12819 m
.36391 .13119 L
s
.40579 .11079 m
.40829 .11383 L
s
.49691 .07511 m
.49931 .07824 L
s
.54364 .05682 m
.54598 .05998 L
s
.59117 .0382 m
.59345 .04141 L
s
.63953 .01927 m
.64175 .02252 L
s
gsave
.29165 .07573 -71.2423 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.125000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GQP00`40o`000?l0003ooooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo;oooo`D0001moooo003o
oooo;oooo`800002oooo0P0007coool00?ooooldoooo0P0007_oool00?ooooldoooo0P0007_oool0
0?ooooldoooo0P0007_oool00?oooolcoooo0`0007_oool00?oooolboooo0`0007coool00?oooolc
oooo0P0007coool00?ooooldoooo0P0007_oool00?ooool_oooo00<0003oooooool00_ooo`80000=
oooo1P0006Soool00?ooool_oooo0P0000;oool300003oooo`80001Zoooo003ooooo<Oooo`@0000@
oooo0P0006[oool00?oooom5oooo0P0006[oool00?oooom5oooo0P0006[oool00?oooom5oooo0P00
06[oool00?oooom5oooo0P0006[oool00?oooom5oooo0P0006[oool00?oooom5oooo0P0006[oool0
0?oooom5oooo0P0006[oool00?oooolioooo0`0000Ooool40000J_ooo`00ooooocSoool2000000?o
ool0000000002?ooo`80001Zoooo003ooooo=Oooo`<00003oooo0P0007Coool00?oooolcoooo0P00
00Coool3000000?oool0003oool0L_ooo`00oooooc3oool300001Oooo`030000Q_l0Q_l000800000
0oooo`000?ooo`1aoooo003ooooo;Oooo`<00006oooo0P0000>6o`02000000?oool0003oool0LOoo
o`00ooooob[oool300002?ooo`030000Q_l0Q_l000>6o`0200000_ooo`030000oooooooo06ooool0
0?oooolXoooo100000Ooool200001XKo00030000Q_l0000000;oool00`000?ooooooo`1^oooo003o
oooo9_ooo`80000:oooo00<00026o`26o`001XKo00030000Q_l0000000;oool00`000?ooooooo`1^
oooo003ooooo8oooo`<0000:oooo0P0000Z6o`0200000oooo`030000oooooooo06goool00?oooolQ
oooo0P0000coool00`0008Ko08Ko000:Q_l000<00026o`0000000oooo`030000oooooooo06coool0
0:Coool3000000?oool0000000000P00077oool300003?ooo`80000=Q_l000<00026o`0000000ooo
o`030000oooooooo06coool00:Goool010000?ooooooooooo`80001_oooo0`0000koool00`0008Ko
08Ko000=Q_l000<00026o`0000000oooo`80001]oooo002Voooo00@0003oool00000000`oooo1`00
03Ooool200003oooo`80000@Q_l000@00026o`26o`000004oooo00<0003oooooool0J_ooo`00Yooo
o`80000boooo1`0003?oool3000000?oool0003oool03Oooo`030000Q_l0Q_l00126o`00100008Ko
08Ko000000Coool00`000?ooooooo`1Zoooo002Woooo0P0003?oool00`000?ooooooo`02oooo00<0
003oooooool0;oooo`80000Aoooo0P0001>6o`001@0008Ko08Ko08Ko00000004oooo00<0003ooooo
ool0JOooo`00Y_ooo`<0000doooo00<0003oooooool0<?ooo`<0000Aoooo0P0001F6o`001@0008Ko
08Ko08Ko00000004oooo00<0003oooooool0JOooo`00YOooo`800002oooo00<0003oooooool0<_oo
o`030000oooooooo02goool200004oooo`030000Q_l0Q_l001F6o`001@0008Ko08Ko08Ko00000005
oooo00<0003oooooool0J?ooo`00Y?ooo`@000001?ooo`000000000003;oool20000:oooo`<0000C
oooo0P0001R6o`000`0008Ko08Ko0002Q_l000<0003oooooool00oooo`030000oooooooo06Ooool0
0=ooool00`000?ooooooo`0Voooo0`0001Goool00`0008Ko08Ko000HQ_l000<00026o`26o`000XKo
00030000oooooooo00?oool00`000?ooooooo`1Woooo003Ooooo0P0002Goool2000000?oool0003o
ool04oooo`80000KQ_l000<00026o`26o`000XKo00030000oooooooo00Coool00`000?ooooooo`1V
oooo003Ooooo0P0002;oool300005oooo`030000Q_l0Q_l001^6o`000`0008Ko08Ko0003Q_l000<0
003oooooool01?ooo`030000oooooooo06Goool00=[oool00`000?ooooooo`02oooo0P00023oool2
00006?ooo`80000NQ_l000<00026o`26o`000hKo00030000oooooooo00Coool00`000?ooooooo`1U
oooo003Koooo00<0003oooooool00`0001goool300006Oooo`030000Q_l0Q_l001j6o`000`0008Ko
08Ko0003Q_l000<0003oooooool01Oooo`80001Uoooo003Loooo100001coool200006_ooo`80000Q
Q_l000<00026o`26o`0018Ko00030000oooooooo00?oool00`000?ooo`00001Uoooo003ioooo0`00
01_oool00`0008Ko08Ko000QQ_l000<00026o`26o`0018Ko00030000oooooooo00Goool00`000?oo
ooooo`1Soooo003foooo0`0001coool200009HKo00030000Q_l0Q_l000>6o`000`000?ooooooo`06
oooo00<0003oooooool0H_ooo`00m?ooo`800002oooo00<0003oooooool06Oooo`030000Q_l0Q_l0
02F6o`000`0008Ko08Ko0004Q_l000<0003oooooool01_ooo`030000oooooooo067oool00?7oool3
00007_ooo`80000XQ_l000<00026o`26o`0018Ko00030000oooooooo00Koool00`000?ooooooo`1Q
oooo003_oooo0P00023oool00`0008Ko08Ko000XQ_l000<00026o`26o`0018Ko00030000oooooooo
00Ooool00`000?ooooooo`1Poooo003/oooo0`00023oool2000000=Po`000026o`00:8Ko00030000
Q_l0Q_l000F6o`000`000?ooooooo`07oooo00<0003oooooool0Goooo`00j_ooo`80000Roooo00D0
001Po`1Po`1Po`000000:HKo00030000Q_l0Q_l000F6o`000`000?ooooooo`07oooo00<0003ooooo
ool0Goooo`00ioooo`<0000Soooo00<0001Po`1Po`000f3o00030000Q_l0Q_l002J6o`000`0008Ko
08Ko0005Q_l000<0003oooooool02?ooo`030000oooooooo05koool00>Coool300000_ooo`030000
oooooooo01ooool200001V3o00030000Q_l0Q_l002J6o`000`0008Ko08Ko0006Q_l000<0003ooooo
ool02?ooo`030000oooooooo05goool00>;oool200001Oooo`030000oooooooo01koool00`00063o
063o0007H?l000<00026o`26o`009HKo00030000Q_l0Q_l000J6o`000`000?ooooooo`08oooo00<0
003oooooool0GOooo`00goooo`<0000Woooo00<0001Po`1Po`00263o00030000Q_l0Q_l002F6o`00
0`0008Ko08Ko0007Q_l000<0003oooooool01oooo`80001Noooo003Moooo0P0002Soool20000363o
00030000Q_l0Q_l002B6o`000`0008Ko08Ko0007Q_l000<0003oooooool02Oooo`030000oooooooo
05_oool00=[oool30000:Oooo`030000H?l0H?l000aPo`000`0008Ko08Ko000TQ_l000<00026o`26
o`001hKo00030000oooooooo00Woool00`000?ooooooo`1Koooo003Hoooo0P0002_oool00`00063o
063o000>H?l000<00026o`26o`008hKo00030000Q_l0Q_l000R6o`000`000?ooooooo`09oooo00<0
003oooooool0F_ooo`00eOooo`<000000oooo`000?ooo`0Xoooo0P00015Po`000`0008Ko08Ko000S
Q_l000<00026o`26o`0028Ko00030000oooooooo00[oool00`000?ooooooo`1Ioooo003Boooo0`00
02goool00`00063o063o000BH?l000<00026o`26o`008XKo00030000Q_l0Q_l000R6o`000`000?oo
ooooo`0:oooo00<0003oooooool0FOooo`00d?ooo`80000^oooo0P0001EPo`000`0008Ko08Ko000R
Q_l000<00026o`26o`002HKo00030000oooooooo00[oool00`000?ooooooo`1Hoooo003=oooo0`00
02ooool00`00063o063o000FH?l000<00026o`26o`008HKo00030000Q_l0Q_l000V6o`000`000?oo
ooooo`0;oooo00<0003oooooool0Eoooo`00S_ooo`H0000goooo0P00037oool00`00063o063o000G
H?l000<00026o`26o`008XKo00030000Q_l0Q_l000R6o`000`000?ooooooo`0;oooo00<0003ooooo
ool0Eoooo`00T?ooo`80000foooo0`00037oool200006f3o00030000Q_l0Q_l00266o`000`0008Ko
08Ko0009Q_l000<0003oooooool02oooo`030000oooooooo05Koool0093oool20000=?ooo`800000
0oooo`000?ooo`0`oooo00<0001Po`1Po`006f3o00030000Q_l0Q_l00266o`000`0008Ko08Ko0009
Q_l000<0003oooooool02oooo`030000oooooooo05Koool0093oool20000<Oooo`<0000doooo00<0
001Po`1Po`007F3o00030000Q_l0Q_l00226o`000`0008Ko08Ko0009Q_l000<0003oooooool02ooo
o`80001Goooo002@oooo0P0002ooool20000=Oooo`80000PH?l000<00026o`26o`0088Ko00030000
Q_l0Q_l000Z6o`000`000?ooooooo`0<oooo00<0003oooooool02_ooo`L00013oooo002@oooo0P00
02coool30000=_ooo`030000H?l0H?l0025Po`000`0008Ko08Ko000OQ_l000<00026o`26o`002XKo
00030000oooooooo00coool00`000?ooooooo`0;oooo1`0004;oool0093oool20000:Oooo`<0000g
oooo0P0002APo`000`0008Ko08Ko000OQ_l000<00026o`26o`002XKo00030000oooooooo00goool0
0`000?ooooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo043oool0093oool200009ooo
o`80000ioooo00<0001Po`1Po`009F3o00030000Q_l0Q_l001j6o`000`0008Ko08Ko000;Q_l000<0
003oooooool03Oooo`030000oooooooo00_oool00`000?ooooooo`14oooo002@oooo0P0002Coool3
000000?oool0003oool0=oooo`030000H?l0H?l002IPo`000`0008Ko08Ko000NQ_l000<00026o`26
o`002hKo00030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool0@oooo`00T?oo
o`80000Roooo0P0003_oool20000:V3o00030000Q_l0Q_l001f6o`000`0008Ko08Ko000;Q_l000<0
003oooooool03_ooo`030000oooooooo00_oool20000A?ooo`00S_ooo`@0000Ooooo0`0003coool0
0`00063o063o000ZH?l000<00026o`26o`007HKo00030000Q_l0Q_l000b6o`000`000?ooooooo`0>
oooo00<0003oooooool02oooo`030000oooooooo04;oool0093oool200007Oooo`80000noooo00<0
001Po`1Po`00;63o00030000Q_l0Q_l001b6o`000`0008Ko08Ko000<Q_l000<0003oooooool03_oo
o`030000oooooooo00_oool20000@oooo`00[?ooo`<0000noooo0P0002mPo`000`0008Ko08Ko000L
Q_l000<00026o`26o`003HKo00030000oooooooo00koool00`000?ooooooo`0:oooo0P0004?oool0
0:Woool30000@?ooo`030000H?l0H?l0031Po`000`0008Ko08Ko000KQ_l000<00026o`26o`003HKo
00030000oooooooo00koool200001_ooo`030000oooooooo00;oool20000@oooo`00Yoooo`800002
oooo00<0003oooooool0?Oooo`030000H?l0H?l0035Po`000`0008Ko08Ko000KQ_l000<00026o`26
o`003HKo00030000oooooooo00goool00`000?ooo`000007oooo00<0003oooooool00`0004?oool0
0:Coool30000@_ooo`80000eH?l000<00026o`26o`006XKo00030000Q_l0Q_l000j6o`000`000?oo
ooooo`0?oooo00<0003oooooool01Oooo`@00014oooo002Roooo0P0004Coool00`00063o063o000e
H?l000<00026o`26o`006XKo00030000Q_l0Q_l000j6o`000`000?ooooooo`0@oooo00<0003ooooo
ool0C?ooo`00Woooo`<00014oooo0P000003C_l00000H?l003IPo`000`0008Ko08Ko000JQ_l000<0
0026o`26o`003HKo00030000oooooooo013oool00`000?ooooooo`1<oooo002Loooo0`0004Goool2
000014ko0080000eH?l000<00026o`26o`006XKo00030000Q_l0Q_l000j6o`000`000?ooooooo`0@
oooo00<0003oooooool0Boooo`00V_ooo`@00014oooo0P0000Q>o`000`00063o063o000cH?l000<0
0026o`26o`006HKo00030000Q_l0Q_l000j6o`000`000?ooooooo`0Aoooo00<0003oooooool0:?oo
o`80000Poooo002Goooo0`0000?oool00`000?ooooooo`10oooo0P0000]>o`000`00063o063o000b
H?l000<00026o`26o`006HKo00030000Q_l0Q_l000j6o`000`000?ooooooo`0Aoooo00<0003ooooo
ool0:?ooo`<0000Ooooo002Eoooo0P0004Ooool200003Tko0080000cH?l000<00026o`26o`0068Ko
00030000Q_l0Q_l000n6o`000`000?ooooooo`0Aoooo00<0003oooooool0:Oooo`030000oooooooo
01goool009;oool30000Aoooo`80000BC_l000<0001Po`1Po`00<63o00030000Q_l0Q_l001R6o`00
0`0008Ko08Ko000<Q_l0100001Coool00`000?ooooooo`0Yoooo00<0003oooooool07?ooo`00T?oo
o`800018oooo0P0001E>o`000`00063o063o000`H?l000<00026o`26o`005hKo00030000Q_l0Q_l0
00F6o`070000103oN`030000oooooooo017oool00`000?ooooooo`0Yoooo00<0003oooooool07?oo
o`00SOooo`<00018oooo0P0001Q>o`000`00063o063o000_H?l000<00026o`26o`005hKo00P0000;
0?mk00<0003oooooool04Oooo`80000Yoooo0`0001goool008_oool2000000?oool0003oool0A_oo
o`80000KC_l00P00031Po`000`0008Ko08Ko000@Q_l01`0001<0og/00`000?ooooooo`0Boooo00<0
003oooooool09_ooo`<0000Moooo0028oooo0`0004[oool00`0004ko04ko000MC_l000<0001Po`1P
o`00;F3o00030000Q_l0Q_l000V6o`0700001P3oN`0300000?mk0?mk0140og/00`000?ooooooo`0B
oooo00<0003oooooool09Oooo`800002oooo00<0003oooooool06_ooo`00QOooo`<0001;oooo0P00
025>o`000`00063o063o000]H?l000@00026o`26o`26o`0700003@3oN`0300000?mk0?mk0180og/0
0`000?ooooooo`0Boooo00<0003oooooool09?ooo`800002oooo00<0003oooooool06_ooo`00Pooo
o`80001<oooo0P0002A>o`020000:F3o00P0000D0?mk00<00000og/0og/04`3oN`030000oooooooo
01;oool00`000?ooooooo`0Roooo0P0000Coool00`000?ooooooo`0Ioooo0020oooo0`0004coool2
0000:4ko00030000H?l0H?l001iPo`0800001DSo000300000?mk0?mk01@0og/00`00003oN`3oN`0C
0?mk00<0003oooooool04_ooo`030000oooooooo02;oool200001?ooo`030000oooooooo01Woool0
07koool20000COooo`80000[C_l000<0001Po`1Po`005F3o00P0000=B?l000<00000og/0og/0503o
N`0300000?mk0?mk01@0og/00`000?ooooooo`0Boooo00<0003oooooool08?ooo`@00002oooo0`00
01[oool007_oool300000_ooo`030000oooooooo04Soool20000;Tko0080000=H?l0200001I8o`00
0`00003oN`3oN`0C0?mk00<00000og/0og/0503oN`030000oooooooo01;oool00`000?ooooooo`13
oooo001ioooo0P0004koool20000<Tko00030000H?l0H?l0009Po`0800007dSo000300000?mk0?mk
0180og/00`00003oN`3oN`0E0?mk00<0003oooooool04_ooo`030000oooooooo04;oool007Koool3
0000C_ooo`80000bC_l01`0002M8o`000`00003oN`3oN`0B0?mk00<00000og/0og/05P3oN`030000
oooooooo01;oool00`000?ooooooo`11oooo001coooo0`0004ooool20000;Tko00H00004ool000<0
0018o`18o`00:4So000300000?mk0?mk0180og/00`00003oN`3oN`0E0?mk00<0003oooooool04Ooo
o`<00012oooo001aoooo0P00053oool20000:Tko00H0000;ool000<00018o`18o`00:4So00030000
0?mk0?mk0140og/00`00003oN`3oN`0F0?mk00<0003oooooool04_ooo`030000oooooooo043oool0
06koool3000000?oool0003oool0COooo`80000UC_l01`00017oo`000`0004So04So000XB?l000<0
0000og/0og/04@3oN`0300000?mk0?mk01H0og/00`000?ooooooo`0Coooo00<0003oooooool0?ooo
o`00K?ooo`80001?oooo2P0001]>o`0600006Ooo00030000B?l0B?l002Q8o`000`00003oN`3oN`0@
0?mk00<00000og/0og/05`3oN`030000oooooooo01;oool00`000?ooooooo`0ooooo001Yoooo0`00
04Woool800002Ygo00`00009C_l01P00023oo`000`0004So04So000XB?l000<00000og/0og/03`3o
N`0300000?mk0?mk01P0og/00`000?ooooooo`0Boooo00<0003oooooool0?_ooo`00Ioooo`800015
oooo1`0001jMo`0900009ooo00030000B?l0B?l002M8o`000`00003oN`3oN`0?0?mk00<00000og/0
og/0603oN`030000oooooooo01?oool00`000?ooooooo`0moooo001Toooo0`00043oool7000099go
00@00003og<000<0003oo`3oo`00:?oo00030000B?l0B?l002M8o`000`00003oN`3oN`0>0?mk00<0
0000og/0og/06@3oN`030000oooooooo01;oool00`000?ooooooo`0moooo001Qoooo0`000003oooo
0000oooo013ooolD00005?ooo`P0000WWOl0100000SoL`000`000?oo0?oo000Wool000<00018o`18
o`00:4So000300000?mk0?mk00d0og/00`00003oN`3oN`0I0?mk00<0003oooooool04oooo`030000
oooooooo03coool005ooool200004?ooo`H000030?l300<0003fo`3fo`003_Ko01@0000ZWOl01@00
00goL`000`000?oo0?oo000Wool000<00018o`18o`009dSo000300000?mk0?mk00`0og/20000703o
N`030000oooooooo01?oool00`000?ooooooo`0koooo001Loooo0`0000goool500002P3o0`030000
m_l0m_l0023fo`0500008Ygo00@0000Cog<000<0003oo`3oo`009ooo00030000B?l0B?l002M8o`00
0`00003oN`3oN`080?mk0`000080og/00`00003oN`3oN`0I0?mk00<0003oooooool04oooo`030000
oooooooo03_oool005[oool200002_ooo`H0000?0?l300<0003fo`3fo`009OKo00H0000GWOl01@00
01SoL`000`000?oo0?oo000Wool000<00018o`18o`009dSo000300000?mk0?mk00@0og/300001@3o
N`0300000?mk0?mk01X0og/00`000?ooooooo`0Boooo0P0003coool005Soool200001oooo`D0000F
0?l300<0003fo`3fo`00:_Ko00D0000>WOl0100001koL`000`000?oo0?oo000Wool000<00018o`18
o`009dSo000300000?mk0?mk00<000090?mk00<00000og/0og/06P3oN`030000oooooooo01?oool0
0`000?ooooooo`0ioooo001Hoooo2@0001`0o`<00`000?Ko0?Ko000^m_l01@0000FMo`0400008omc
00030000ool0ool002Koo`000`0004So04So000WB?l00`0000d0og/00`00003oN`3oN`0I0?mk00<0
003oooooool04oooo`030000oooooooo03Woool005Soool300008`3o0`030000m_l0m_l003;fo`05
0000:?mc00030000ool0ool002Koo`000`0004So04So000TB?l00P000003B?l000000?mk00h0og/0
0`00003oN`3oN`0I0?mk00<0003oooooool04oooo`030000oooooooo03Soool005Soool00`00003o
0`3o0`0T0?l300<0003fo`3fo`00<OKo008000000ona00000?mc000Yog<000<0003oo`3oo`009_oo
00030000B?l0B?l00218o`03000014So000300000?mk0?mk00`0og/00`00003oN`3oN`0I0?mk00<0
003oooooool05?ooo`030000oooooooo03Ooool004[oool400002Oooo`80000W0?l300<0003fo`3f
o`00;oKo00030000ok40ok4000;o/@000`000?mc0?mc000Xog<000<0003oo`3oo`009_oo00030000
B?l0B?l001a8o`0300001dSo000300000?mk0?mk00d0og/00`00003oN`3oN`0I0?mk00<0003ooooo
ool04oooo`030000oooooooo03Ooool004Woool200000_ooo`800008oooo0P0002L0o`<00`000?Ko
0?Ko000]m_l00P0000Ko/@000`000?mc0?mc000Xog<000<0003oo`3oo`009_oo00030000B?l0B?l0
01Q8o`0300002dSo000300000?mk0?mk00d0og/00`00003oN`3oN`0I0?mk00<0003oooooool04ooo
o`030000oooooooo03Koool004Woool00`000?ooooooo`02oooo00<0003oooooool01_ooo`030000
oooo000002L0o`<00`000?Ko0?Ko000Zm_l00P0000Wo/@000`000?mc0?mc000Xog<000<0003oo`3o
o`009Ooo00030000B?l0B?l001E8o`0300003dSo000300000?mk0?mk00d0og/00`00003oN`3oN`0H
0?mk00<0003oooooool05?ooo`030000oooooooo03Goool004Soool200001?ooo`800007oooo0`00
02P0o`<00`000?Ko0?Ko000Xm_l000<0003o/@3o/@002_na00030000og<0og<002SoL`000`000?oo
0?oo000Uool000<00018o`18o`004DSo00<0000BB?l000<00000og/0og/03@3oN`0300000?mk0?mk
01T0og/00`000?ooooooo`0Coooo00<0003oooooool0=Oooo`00B?ooo`800004oooo0P0000Ooool0
0`000?ooo`00000Y0?l300<0003fo`3fo`009OKo0080000>ok4000<0003oL`3oL`00:?mc00030000
ool0ool002Goo`000`0004So04So000=B?l00`0001I8o`000`00003oN`3oN`0=0?mk00<00000og/0
og/0603oN`030000oooooooo00Goool800001oooo`030000oooooooo03Coool004Soool200001?oo
o`800007oooo00<0003oool00000:P3o0`030000m_l0m_l002?fo`000`000?na0?na000?ok4000<0
003oL`3oL`00:?mc00030000ool0ool002Goo`000`0004So04So0009B?l00`0001Y8o`000`00003o
N`3oN`0=0?mk00<00000og/0og/03P3oNa4000000c[o00000000000200000on;00030000oooooooo
00?oool00`000?ooo`00000<oooo1@0002Coool004Soool200001?ooo`800006oooo00@0003oool0
0000000[0?l300<0003fo`3fo`008?Ko0080000Cok4000<0003oL`3oL`00:?mc00030000ool0ool0
02Goo`000`0004So04So0005B?l00`0001e8o`000`00003oN`3oN`090?mk5@0000hjo`0400002?n;
00800005oooo00<0003oooooool02_ooo`800002oooo0P0002?oool004Soool200001?ooo`800006
oooo0P000003oooo00000?l302X0o`<00`000?Ko0?Ko000Om_l000<0003o/@3o/@005?na00030000
og<0og<002SoL`000`000?oo0?oo000Tool000<00018o`18o`000TSo00<0000HB?l0500000Djo`00
0`0003[o03[o000F>_l01@0000koR`000`000?ooooooo`03oooo00<0003oooooool03_ooo`80000R
oooo0018oooo0P0000Coool200001_ooo`040000oooooooo0000;03o0`030000m_l0m_l001cfo`02
00006?na00030000og<0og<002SoL`000`000?oo0?oo000Tool0100000M8o`0D00002l_o00<0000<
>_l000<0000jo`0jo`004C[o00@0000Doh/000<0003oooooool00oooo`030000oooooooo00goool2
00008_ooo`00BOooo`030000oooooooo00;oool00`000?ooooooo`05oooo0P0000;oool00`00003o
0`3o0`0Z0?l300<0003fo`3fo`006_Ko00030000ok40ok4001Wo/@020000:Omc00030000ool0ool0
01koo`0@00008/_o00<0000:>_l000<0000jo`0jo`0033[o00@0000Ioh/000<0003oooooool00_oo
o`030000oooooooo00goool200008_ooo`00BOooo`800002oooo0P0000Ooool01@000?oooooooooo
o`00000]0?l300<0003fo`3fo`005oKo0080000Nok4000<0003oL`3oL`009omc00030000ool0ool0
017oo`0<000000Co[P00000000000003ojh00P0002c;o`02000023[o00030000>_l0>_l000Ljo`05
00007_n;00800003oooo00<0003oooooool02oooo`<0000Roooo001:oooo100000Soool01@000?oo
ooooooooo`00000^0?l300<0003fo`3fo`005?Ko0080000Qok4000<0003oL`3oL`009omc00030000
ool0ool000Coo`0<00002_n^00<00008ojh000<0003;o`3;o`00:l_o00<00006>_l000<0000jo`0j
o`000S[o00@0000Uoh/000D0003oooooooooool000002oooo`<0000Soooo001Eoooo00H0003oool0
0000003oool0000_0?l300<0003fo`3fo`004_Ko00030000ok40ok4002;o/@000`000?mc0?mc000U
og<0200001?o[P0300003?n^0080000^bol00`0000@jo`040000:_n;00040000oooooooo00003?oo
o`80000Soooo001Eoooo0P0000?oool00`00003o0`3o0`0]0?l300<0003fo`3fo`004?Ko0080000V
ok4000<0003oL`3oL`007omc00D00003oe4000<0003o[P3o[P004_n^00<0000Aojh000<0003;o`3;
o`00;L_o00D000000on;00000?n;000/oh/0100000coool200008_ooo`00EOooo`030000oooooooo
00;oool00`00003o0`3o0`0^0?l300<0003fo`3fo`003_Ko00030000ok40ok4002Oo/@000`000?mc
0?mc000Iog<01@0000WoD@000`000?n^0?n^000>ojh00`0001Go[P020000:L_o00@00003of/000@0
003oR`3oR`00000_oh/00P0000Ooool00`000?ooooooo`02oooo0P0002;oool003[oool400001?oo
o`800003oooo100000[oool00`000?ooooooo`03oooo00<00000o`<0o`<0;P3o0`030000m_l0m_l0
00_fo`020000:ona00030000og<0og<001?oL`0500003omA00030000ojh0ojh000[o[P0300006_n^
00030000bol0bol002;;o`0400002?m[00040000oh/0oh/00000;_n;00<00006oooo0P0000;oool3
00008_ooo`00>Oooo`800002oooo0P0000?oool200000oooo`050000oooooooooooo000000Woool2
00001?ooo`0300000?l30?l302l0o`<00`000?Ko0?Ko0009m_l000<0003o/@3o/@00;?na00030000
og<0og<000goL`0500005OmA00030000ojh0ojh000Ko[P0300007_n^00030000bol0bol001g;o`04
00003Om[00040000oh/0oh/00000:_n;00<00002oeh00P0000Ooool400008oooo`00>Oooo`030000
oooooooo00;oool00`000?ooooooo`0;oooo00<0003oooooool01_ooo`030000oooooooo00?oool0
0`00003o0`3o0`0`0?l300<0003fo`3fo`001_Ko0080000`ok4000<0003oL`3oL`001omc00D0000K
oe4000<0003o[P3o[P000_n^00<0000Rojh00P0001W;o`0400004_m[00040000oh/0oh/000009_n;
00<00005oeh00P0002koool003Soool200001?ooo`80000<oooo00<0003oooooool01Oooo`030000
oooooooo00Coool00`00003o0`3o0`0a0?l300<0003fo`3fo`000oKo0080000cok4000@0003oL`3o
L`3oL`0500008OmA00@0000Wojh000<0003;o`3;o`004/_o00@0000Gof/000<0003oR`0000009?n;
00800009oeh00P0002goool003Soool200001?ooo`80000<oooo00<0003oooooool01Oooo`<00004
oooo00<00000o`<0o`<0<@3o0`030000m_l0m_l000;fo`000`000?na0?na000dok400`0002GoD@03
0000:_n^0080000>bol0100001coJ`000`000?n;0000000Poh/00`0000_oGP000`000?ooo`00000/
oooo000hoooo0P0000Coool200002oooo`800007oooo00<0003oooooool01?ooo`0300000?l30?l3
0380o`<010000?Ko0000000003Go/@02000000?oS`00003oD@008_mA00<00003oe4000<0003o[P3o
[P00:On^00030000bol0bol000O;o`0400008Om[00<0000Loh/00`0000ooGP020000;?ooo`00>?oo
o`800004oooo0P0000[oool300001oooo`030000oooooooo00Coool00`00003o0`3o0`0c0?l300<0
003o/@3o/@00=?na00030000ohl0ohl000;oS`000`000?mA0?mA000Moe400`0000OoD@000`000?n^
0?n^000Yojh00P0000?;o`0400009om[00030000oh/0oh/001OoR`0300004_mN00030000oooo0000
02_oool003Soool200001?ooo`800007oooo1@0000Soool200001_ooo`0300000?l30?l30340o`<0
0`00001^o`00000cok400P0000KoS`000`000?mA0?mA000Ioe400`0000_oD@000`000?n^0?n^000X
ojh01@0002coJ`000`000?n;0?n;000Coh/00`0001KoGP000`000?ooo`00000Zoooo000hoooo0P00
00Coool200002?ooo`<00009oooo00<0003oooooool01Oooo`0300000?l30?l30340o`<01000001^
o`1^o`00037o/@000`000?n?0?n?0006ohl000<0003oD@3oD@005_mA00<0000?oe4000<0003o[P3o
[P008on^00@00003oe<000<0003oJ`3oJ`00;?m[00030000oh/0oh/000ooR`0300006OmN00<0000Z
oooo000ioooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`09oooo00<0
003oooooool01Oooo`0300000?l30?l30300o`<00`00001^o`1^o`0206ko00<0003o/@3o/@00;?na
0080000:ohl000<0003oD@3oD@004_mA00<0000Coe4000<0003o[P3o[P007_n^00@00008oe<000<0
003oJ`3oJ`00;?m[00030000oh/0oh/000_oR`0300007OmN00030000oooo000002Woool003Woool2
00000_ooo`80000:oooo100000Koool00`000?ooo`000006oooo00<00000o`<0o`<0<03o0`030000
06ko06ko00<0K_l00`000?na0?na000Zok4000<0003oS`3oS`002on?00030000oe40oe4000koD@03
00005omA00030000ojh0ojh001Wo[P0400003OmC00030000of/0of/002_oJ`0200002_n;0080000Q
oeh000<0003oool00000:?ooo`00>_ooo`@0000;oooo100000Koool200001oooo`0300000?l30?l3
02l0o`<00`00001^o`1^o`0506ko00<0003o/@3o/@00:?na00030000ohl0ohl000goS`000`000?mA
0?mA000:oe400`0001_oD@000`000?n^0?n^000Dojh0100001;oD`000`000?m[0?m[000[of/00P00
00KoR`0300008omN00030000oooo000002Soool005?oool00`000?ooooooo`06oooo00<00000o`<0
o`<0;`3o0`03000006ko06ko00H0K_l00`000?na0?na000Uok400P00017oS`000`000?mA0?mA0006
oe400`0001ooD@000`000?n^0?n^000?ojh0100001OoD`000`000?m[0?m[000[of/00P0000;oR`03
00009omN00030000oooo000002Ooool005?oool300001_ooo`0300000?l30?l302h0o`<00`00001^
o`1^o`0806ko00<0003o/@3o/@008ona00030000ohl0ohl001;oS`000`000?mA0?mA0002oe400`00
02?oD@000`000?n^0?n^000:ojh0100001coD`000`000?m[0?m[000[of/00`0002[oGP0010000?oo
ooooo`0002Koool005?oool00`000?ooooooo`07oooo00<00000o`<0o`<0;@3o0`03000006ko06ko
00T0K_l00`000?na0?na000Pok400P0001KoS`0400009omA00030000ojh0ojh000Go[P0400008OmC
00030000of/0of/002OoJ`04000000?oC000003oGP00:_mN00030000oooo000002Koool005?oool0
0`000?ooooooo`07oooo00<00000o`<0o`<0;03o0`03000006ko06ko00/0K_l00`000?na0?na000N
ok4000<0003oS`3oS`005On?00<0000Zoe4000<0003o[P3o[P00100002KoD`000`000?m[0?m[000S
of/00`0000CoC0020000:omN00040000oooooooo00009Oooo`00A?ooo`H00008oooo00<0003ooooo
ool02?ooo`0300000?l30?l302`0o`<00`00001^o`1^o`0<06ko00<0003o/@3o/@006ona0080000E
ohl00`0000;oS`000`000?mA0?mA000Xoe400`0002[oD`000`000?m[0?m[000Pof/00`0000SoC002
0000:omN00040000oooooooo00009?ooo`00A_ooo`80000:oooo0`0000Soool00`00003o0`3o0`0[
0?l300<00000K_l0K_l03P1^o`80000Jok4000<0003oS`3oS`004_n?00<00006ohl000<0003oD@3o
D@009?mA00<00002oe8000<0003oD`3oD`00:OmC00030000of/0of/001coJ`0300002om<00030000
od`0000002[oGP0010000?ooo`00000002Coool004Koool200002_ooo`030000oooooooo00Soool0
0`00003o0`3o0`0[0?l300<00000K_l0K_l0401^o`030000ok40ok4001Go/@0200004_n?00<0000:
ohl000<0003oD@3oD@008?mA00<00006oe8000<0003oD`3oD`00:OmC00030000of/0of/001SoJ`03
00003om<0080000[oeh000@0003oooooool0000Soooo0016oooo0P0000[oool00`000?ooooooo`08
oooo00<00000o`<0o`<0:P3o0`03000006ko06ko0180K_l00`000?na0?na000Cok4000<0003oS`3o
S`003on?00<0000>ohl000<0003oD@3oD@007?mA00<0000:oe8000<0003oD`3oD`00:OmC00030000
of/0of/001CoJ`0300004om<0080000Zoeh000D0003oooooooooool000008_ooo`00A_ooo`80000:
oooo0P0000Woool00`00003o0`3o0`0Y0?l300<00000K_l0K_l0501^o`030000ok40ok40013o/@02
00003on?00<0000Bohl000<0003oD@3oD@006?mA00<0000>oe8000<0003oD`3oD`00:OmC00030000
of/0of/0013oJ`0300005om<00030000oeh0oeh002WoGP0010000?ooooooo`0002;oool004Koool2
00002_ooo`030000oooooooo00Woool00`00003o0`3o0`0X0?l300<00000K_l0K_l05@1^o`030000
ok40ok4000ko/@000`000?n?0?n?000<ohl00`0001KoS`000`000?mA0?mA000Doe400`0001;oDP00
0`000?mC0?mC000Yoe<000<0003oJ`3oJ`003?m[00<0000Jod`00P0002_oGP0010000?ooooooo`00
027oool004Koool200002Oooo`030000oooooooo00[oool00`00003o0`3o0`0W0?l300<00000K_l0
K_l05`1^o`030000ok40ok4000co/@000`000?n?0?n?000:ohl00`0001[oS`000`000?mA0?mA000?
oe40100001GoDP000`000?mC0?mC000Zoe<000<0003oJ`3oJ`002?m[00<0000Nod`00P0002[oGP00
1@000?ooooooooooo`00000Poooo0016oooo0P0000Woool00`000?ooo`00000:oooo00<00000o`<0
o`<09`3o0`03000006ko06ko01P0K_l00`000?na0?na0009ok400P0000[oS`0300007_n?00030000
oe40oe4000_oD@0300006_mB00030000oe<0oe<002[oD`000`000?m[0?m[0004of/00`0002;oC000
0`000?mN0?mN000Yoeh000@0003oooooool0000Poooo0016oooo0P0000Woool200002oooo`030000
0?l30?l302H0o`<00`00001^o`1^o`0J06ko00<0003o/@3o/@001ona00030000ohl0ohl000OoS`03
00008On?00030000oe40oe4000SoD@0300007_mB00030000oe<0oe<002[oD`000`000?m[0?m[0003
00009_m<00030000oeh0oeh002SoGP001@000?ooooooooooo`00000Ooooo0016oooo0P0000Woool0
0`000?ooooooo`0:oooo00<00000o`<0o`<09P3o0`03000006ko06ko01/0K_l00`000?na0?na0004
ok400P0000SoS`0200009On?00030000oe40oe4000CoD@0300008_mB00030000oe<0oe<002WoD`03
0000:Om<0080000Zoeh000<0003oool000000P0001koool002?oool200007oooo`@00009oooo0P00
00_oool00`00003o0`3o0`0U0?l300<00000K_l0K_l07@1^o`030000ok40ok4000;o/@000`000?n?
0?n?0005ohl00`0002SoS`000`000?mA0?mA000300009_mB00030000oe<0oe<002GoD`0300000_m5
00030000od`0od`002SoC0000`000?mN0?mN000Xoeh000D0003oooooooooool000007_ooo`002ooo
o`@0000;oooo00<0003oooooool01_ooo`<00006oooo100001Koool200002Oooo`030000oooooooo
00_oool00`00003o0`3o0`0T0?l300<00000K_l0K_l07P1^o`040000ok40000000001On?00<0000[
ohl00`0002[oDP000`000?mC0?mC000Qoe<00`0000KoA@000`000?m<0?m<000Xod`000<0003oGP3o
GP00:?mN00050000oooooooooooo000001goool000_oool00`000?ooooooo`0=oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Noooo00<0003oooooool03?ooo`030000
0?l30?l302<0o`<00`00001^o`1^o`0P06ko00<0003oS`3oS`000_n?00<0000/ohl00P0000;oVP00
0`000?mB0?mB000Yoe8000<0003oD`3oD`007_mC00800009odD000<0003oC03oC000:Om<00030000
oeh0oeh002OoGP001@000?ooooooooooo`00000Moooo000;oooo00<0003oooooool03_ooo`030000
oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool07_ooo`040000oooo000000002ooo
o`0300000?l30?l302<0o`<00`00001^o`1^o`0O06ko00<00000ROl000000`0002goS`0200001OnJ
00030000oe80oe8002WoDP000`000?mC0?mC000Joe<00`0000coA@000`000?m<0?m<000Xod`000<0
003oGP3oGP009_mN00<00003oooo00<0003oooooool06_ooo`001?ooo`@00003oooo00<0003ooooo
ool00_ooo`<000000oooo`000000000200000_ooo`<00009oooo00<0003oooooool01_ooo`030000
oooooooo01koool200003Oooo`0300000?l30?l30280o`<00`00001^o`1^o`0P06ko1@0002coS`02
00001onJ00030000oe80oe8002[oDP000`000?mC0?mC000Foe<00`00013oA@000`000?m<0?m<000X
od`000<0003oGP3oGP008OmN00@00002Z?l000<0003oooooool00_ooo`030000oooooooo01Woool0
00Goool200001?ooo`030000oooooooo00?oool010000?ooooooooooo`800003oooo0P0000Woool3
00001oooo`030000oooooooo01koool00`000?ooooooo`0<oooo00<00000o`<0o`<08P3o0`030000
06ko06ko01d0K_l300001@29o`030000ohl0ohl002OoS`0200002_nJ00030000oe80oe8002[oDP00
0`000?mC0?mC000Boe<00`0001CoA@000`000?m<0?m<000Xod`000<0003oGP3oGP007?mN00@00007
Z?l000D0003oooooooooool000006oooo`001Oooo`800004oooo00<0003oooooool01?ooo`040000
oooo000000003oooo`<00007oooo00<0003oooooool00_ooo`H00003oooo0P0000?oool400002_oo
o`030000oooooooo00coool00`00003o0`3o0`0Q0?l300<00000K_l0K_l06`1^o`<0000206ko00<0
0000ROl0ROl01029o`030000ohl0ohl002CoS`0200003OnJ00030000oe80oe8002WoDP000`000?mC
0?mC000?oe<00`0001OoA@000`000?m<0?m<000Xod`000<0003oGP3oGP006?mN00@0000;Z?l000<0
003oooooool00_ooo`030000oooooooo01Soool000Goool200001?ooo`030000oooooooo00Goool2
00003oooo`800002oooo00<0003oooooool01?ooo`030000oooooooo00Coool200001Oooo`800003
oooo00D0003oooooooooool000002Oooo`80000=oooo00<00000o`<0o`<0803o0`03000006ko06ko
01T0K_l30000101^o`03000008Wo08Wo00H0ROl200008_n?0080000@oiX000<0003oDP3oDP00:OmB
00030000oe<0oe<000_oD`0300006om500030000od`0od`002SoC0000`000?mN0?mN000Coeh01000
00nXo`000`000?ooooooo`02oooo0P00017oool200001_ooo`001Oooo`800004oooo00<0003ooooo
ool01Oooo`80000?oooo0P0000;oool00`000?ooooooo`04oooo00<0003oooooool01?ooo`80000?
oooo00<0003oooooool01Oooo`80000?oooo00<00000o`<0o`<07`3o0`03000006ko06ko01H0K_l3
00001`1^o`03000008Wo08Wo00P0ROl00`000?n?0?n?000Mohl00P0001?oVP000`000?mB0?mB000Y
oe8000<0003oD`3oD`002?mC0080000OodD000<0003oC03oC0009om<0080000@oeh0100001BXo`00
0`000?ooooooo`02oooo00<0003oooooool03oooo`800006oooo0005oooo0P0000Coool00`000?oo
ooooo`04oooo0`0000koool200001?ooo`030000oooooooo00?oool00`000?ooooooo`04oooo0P00
00ooool00`000?ooooooo`05oooo00<0003oooooool03_ooo`0300000?l30?l301h0o`<00`00001^
o`1^o`0D06ko0`0000T0K_l00`000029o`29o`0:08Wo00<0003oS`3oS`006_n?0080000FoiX000<0
003oDP3oDP00:OmB00030000oe<0oe<000CoD`0300008_m500030000od`0od`002OoC00200002omN
00@0000HZ?l000<0003oooooool00oooo`030000oooooooo00koool200001_ooo`001Oooo`800004
oooo00<0003oooooool00oooo`800002oooo00<0003oooooool02oooo`800004oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool200003oooo`030000oooooooo00Goool300003_ooo`030000
0?l30?l301h0o`<00`00001^o`1^o`0B06ko0P0000`0K_l00`000029o`29o`0;08Wo0P0001SoS`02
00006?nJ00030000oe80oe8002[oDP000`000?mC0?mC000300009Om500030000od`0od`002SoC000
0`000?mN0?mN0005oeh0100001fXo`000`000?ooooooo`03oooo00<0003oooooool02?ooo`P00005
oooo0004oooo1@0000;oool00`000?ooooooo`02oooo10000004oooo0000000000002_ooo`@00002
oooo0`0000Coool00`000?ooooooo`04oooo0P0000koool200001oooo`030000oooooooo00koool0
0`00003o0`3o0`0M0?l300<00000K_l0K_l0401^o`<0000=06ko00<00000ROl0ROl03P29o`030000
ohl0ohl001?oS`0200006onJ00030000oe80oe8002WoDP030000:Om500030000od`0od`002OoC002
00000_mN00@0000QZ?l000<0003oooooool00oooo`030000oooooooo00Soool00`000?ooooooo`02
oooo0P0000Koool000Goool200001?ooo`030000oooooooo027oool00`000?ooooooo`04oooo0P00
00goool300001oooo`030000oooooooo00koool00`00003o0`3o0`0M0?l300<00000K_l0K_l03@1^
o`<0000@06ko00<00000ROl0ROl03`29o`030000ohl0ohl0013oS`0200007_nJ00030000oe80oe80
02KoDP0200000_mO00030000odD0odD002SoA@000`000?m<0?m<000Vod`0100002FXo`000`000?oo
ooooo`04oooo00<0003oooooool02?ooo`040000oooooooooooo0P0000Koool000Goool200001?oo
o`030000oooooooo027oool00`000?ooooooo`04oooo0P0000[oool500002?ooo`030000oooooooo
00koool00`00003o0`3o0`0L0?l300<00000K_l0K_l02`1^o`<0000B06ko00<00000ROl0ROl04@29
o`80000>ohl00P00027oVP000`000?mB0?mB000Roe800`0000GoG`000`000?m50?m5000XodD000<0
003oC03oC0008Om<00@000001?o800000:So000002JXo`000`000?ooooooo`04oooo00<0003ooooo
ool02?ooo`030000oooooooo00800006oooo0005oooo0P0000Coool00`000?ooooooo`0Qoooo00<0
003oooooool01?ooo`80000;oooo0`0000Woool200003oooo`0300000?l30?l301`0o`<00`00001^
o`1^o`0806ko0`0001D0K_l00`000029o`29o`0C08Wo00<0003oS`3oS`002On?0080000ToiX000<0
003oDP3oDP007_mB00<00009oel000<0003oA@3oA@00:?m500030000od`0od`001coC00400001_o8
0080000VZ?l000<0003oooooool01?ooo`030000oooooooo00Soool00`000?ooooooo`0200001_oo
o`001_ooo`030000oooooooo00H0000Moooo100000Koool200002oooo`030000oooooooo00Soool0
0`000?ooooooo`0@oooo00<00000o`<0o`<06P3o0`03000006ko06ko00H0K_l300005`1^o`030000
08Wo08Wo01D0ROl00`000?n?0?n?0006ohl00P0002OoVP000`000?mB0?mB000Koe800P0000coG`00
0`000?m50?m5000XodD000<0003oC03oC0006?m<00@0000:olP000<0002Xo`0000009JSo00030000
oooooooo00Coool200002_ooo`040000oooo000000001_ooo`001oooo`<0000Zoooo100000coool4
00001_ooo`030000oooooooo013oool00`00003o0`3o0`0J0?l300<00000K_l0K_l00`1^o`<0000J
06ko00<00000ROl0ROl05P29o`800004ohl00P0002WoVP000`000?mB0?mB000Hoe800`0000ooG`00
0`000?m50?m5000XodD000<0003oC03oC0004om<00@0000?olP000<0002Xo`0000009JSo00030000
oooooooo00<000000oooo`000?ooo`0:oooo0`0000Koool003Koool200003?ooo`@00006oooo0`00
013oool00`00003o0`3o0`0I0?l300@00000K_l0K_l0K_l30000701^o`03000008Wo08Wo01T0ROl0
10000?n?0000000002coVP000`000?mB0?mB000Eoe800P0001?oG`000`000?m50?m5000XodD000<0
003oC03oC0003_m<00@0000ColP000<0002Xo`0000009JSo00<00004oooo00<0003oooooool02_oo
o`800006oooo001>oooo00<0003oooooool04?ooo`0300000?l30?l301T0o`<400007`1^o`030000
08Wo08Wo01X0ROl00`000?nJ0?nJ000]oiX000<0003oDP3oDP004OmB00<0000Foel000<0003oA@3o
A@00:?m500030000od`0od`000WoC00400006?o800030000Z?l0000002FXo`000`000?ooooooo`03
oooo00<0003oooooool02_ooo`800006oooo001>oooo00<0003oooooool04?ooo`0300000?l30?l3
01L0o`<300008@1^o`03000008Wo08Wo01/0ROl20000;onJ00030000oe80oe8000goDP0300006_mO
00030000odD0odD002OoA@000`000?m<0?m<0005od`0100001cob00010000:So0:So000002BXo`00
0`000?ooooooo`04oooo00<0003oooooool04Oooo`00C_ooo`<0000@oooo00<00000o`<0o`<05@3o
0`<0000S06ko00<00000ROl0ROl06P29o`0400000?n60?n60000;onJ00030000oe80oe8000[oDP02
00007_mO00030000odD0odD002OoA@000`000?m<0?m<000400008Oo800040000Z?l0Z?l000008jSo
00030000oooooooo00Coool00`000?ooooooo`0Aoooo001=oooo0P0001?oool00`00003o0`3o0`0A
0?l30`000080o`<00`00001^o`1^o`0P06ko00<00000ROl0ROl06`29o`0500000?n60?n60?n60000
02ooVP000`000?mB0?mB0006oe800`00023oG`000`000?m50?m5000WodD00`0002Gob00010000:So
0:So000002BXo`000`000?ooooooo`03oooo00<0003oooooool04Oooo`00COooo`030000oooooooo
01;oool00`00003o0`3o0`0>0?l30`0000@0o`<00`00001^o`1^o`0P06ko00<00000ROl0ROl06`29
o`0300000?n60?n60080ohH00`000?nJ0?nJ000]oiX000<0003oDP3oDP000omB00<0000Toel000<0
003oA@3oA@008_m500@00002oeL000<0003ob03ob0009?o800040000Z?l0Z?l000008jSo00030000
oooooooo00?oool00`000?ooooooo`0Aoooo000noooo1`0000Soool00`000?ooooooo`0Boooo00<0
0000o`<0o`<02`3o0`<000070?l300<00000K_l0K_l0801^o`03000008Wo08Wo01/0ROl00`00003o
QP3oQP030?n600<0003oVP3oVP00;OnJ00030000oe80oe800080000Xoel000<0003oA@3oA@007_m5
00<00006oeL000<0003ob03ob0009?o800050000Z?l0Z?l0Z?l0000002:Xo`000`000?ooooooo`03
oooo00<0003oooooool04Oooo`00?oooo`L00007oooo0`0001;oool00`00003o0`3o0`080?l30`00
00T0o`<00`00001^o`1^o`0P06ko00<00000ROl0ROl06`29o`0300000?n60?n600D0ohH00`000?nJ
0?nJ000]oiX00P0002_oG`000`000?m50?m5000JodD00`0000[oE`000`000?o80?o8000SolP000<0
002Xo`2Xo`000ZSo00030000Z?l0Z?l0022Xo`000`000?ooooooo`02oooo00<0003oooooool04Ooo
o`00@?ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool04_ooo`030000
0?l30?l300D0o`<30000303o0`03000006ko06ko0200K_l00`000029o`29o`0K08Wo00<00000ohH0
ohH01P3oQP030000oiX0oiX002[oVP02000000?oa000003oG`00:omO00030000odD0odD001GoA@04
00003_mG00030000olP0olP002?ob0001@000:So0:So0:So0000000RZ?l000<0003oooooool00_oo
o`030000oooooooo017oool0047oool00`000?ooooooo`09oooo00<0003oooooool04_ooo`030000
0?l30?l30080o`<300003P3o0`03000006ko06ko0200K_l00`000029o`29o`0K08Wo00<00000ohH0
ohH0203oQP030000oiX0oiX002OoVP0200001?o400030000oel0oel002[oG`000`000?m50?m5000A
odD00`0001;oE`000`000?o80?o8000SolP000<0002Xo`2Xo`000ZSo00030000Z?l0Z?l0022Xo`00
0`000?ooooooo`02oooo00<0003oooooool04?ooo`00@_ooo`030000oooooooo00Ooool00`000?oo
o`00000Coooo00<00000o`<000000P000140o`<00`00001^o`1^o`0P06ko00<00000ROl0ROl06`29
o`0300000?n60?n600T0ohH00`000?nJ0?nJ000ToiX00P0000Ooa0000`000?mO0?mO000Zoel000<0
003oA@3oA@003?m500@0000FoeL000<0003ob03ob0008oo800030000Z?l0Z?l000:Xo`000`000:So
0:So000OZ?l000<0003oooooool00_ooo`030000oooooooo013oool004;oool200002?ooo`80000C
oooo0`0001<0o`<00`00001^o`1^o`0P06ko00<00000ROl0ROl06`29o`0300000?n60?n600/0ohH0
0`000?nJ0?nJ000QoiX00P0000[oa0000`000?mO0?mO000Yoel000<0003oA@3oA@002Om500<0000K
oeL000<0003ob03ob0008_o800030000Z?l0Z?l000>Xo`000`000:So0:So000NZ?l000<0003ooooo
ool00_ooo`030000oooooooo013oool004?oool00`000?ooooooo`06oooo00<0003oooooool03ooo
o`<00002oooo00<00000o`<0o`<04@3o0`03000006ko06ko0200K_l00`000029o`29o`0K08Wo00<0
0000ohH0ohH0303oQP030000oiX0oiX001koVP0200003Oo400030000oel0oel002WoG`000`000?m5
0?m50005odD00`0001koE`000`000?o80?o8000SolP000<0002Xo`2Xo`000ZSo00030000Z?l0Z?l0
01nXo`001@000?ooooooooooo`00000Boooo0013oooo0P0000Ooool00`000?ooooooo`0<oooo0`00
00Goool00`00003o0`3o0`0@0?l300<00000K_l0K_l0801^o`03000008Wo08Wo01/0ROl00`00003o
QP3oQP0=0?n600<0003oVP3oVP007?nJ0080000@ol@000<0003oG`3oG`00:OmO00030000odD0odD0
00@0000RoeL000<0003ob03ob0008_o800030000Z?l0Z?l000>Xo`000`000:So0:So000NZ?l000D0
003oooooooooool000004_ooo`00@oooo`800007oooo0P0000_oool200002?ooo`0300000?l30?l3
0100o`<00`00001^o`1^o`0P06ko00<00000ROl0ROl06`29o`0300000?n60?n600h0ohH00`000?nJ
0?nJ000IoiX00P0001?oa0000`000?mO0?mO000Xoel00`0002OoE`000`000?o80?o8000RolP000<0
002Xo`2Xo`000jSo00030000Z?l0Z?l001fXo`001@000?ooooooooooo`00000Boooo000noooo00<0
003oooooool00_ooo`800007oooo00<0003oooooool01oooo`<0000:oooo00<00000o`<0o`<03`3o
0`03000006ko06ko0200K_l00`000029o`29o`0K08Wo00<00000ohH0ohH0403oQP030000oiX0oiX0
01KoVP0200005_o400030000oel0oel002CoG`0300000_m^00030000oeL0oeL002GoE`000`000?o8
0?o8000RolP000<0002Xo`2Xo`000jSo00030000Z?l0Z?l001jXo`0010000?ooooooo`0001;oool0
03ooool00`000?ooooooo`0300001_ooo`030000oooooooo00Goool300003Oooo`0300000?l30?l3
00h0o`<00`00001^o`1^o`0Q06ko00<00000ROl0ROl06`29o`0300000?n60?n60140ohH00`000?nJ
0?nJ000CoiX00P0001Woa0000`000?mO0?mO000Qoel00P0000KoKP000`000?mG0?mG000UoeL000<0
003ob03ob0008_o800030000Z?l0Z?l000>Xo`000`000:So0:So000MZ?l000D0003oooooooooool0
00004Oooo`00@?ooo`@00007oooo00<0003oool000000_ooo`<0000@oooo00<00000o`<0o`<03P3o
0`03000006ko06ko0200K_l00`000029o`29o`0K08Wo00<00000ohH0ohH04`3oQP030000oiX0oiX0
013oVP0200006oo400030000oel0oel001koG`0300002Om^00030000oeL0oeL002GoE`000`000?o8
0?o8000QolP000<0002Xo`2Xo`001:So00030000Z?l0Z?l001fXo`0010000?ooooooo`00017oool0
04_oool500005?ooo`0300000?l30?l300`0o`<00`00001^o`1^o`0Q06ko00<00000ROl0ROl06`29
o`0300000?n60?n601@0ohH00`000?nJ0?nJ000=oiX00P0001koa0000`000?mO0?mO000Joel00`00
00goKP000`000?mG0?mG000UoeL000<0003ob03ob0008Oo800030000Z?l0Z?l000BXo`000`000:So
0:So000LZ?l000@0003oooooool0000Aoooo001;oooo0P0001Ooool00`00003o0`3o0`0<0?l300<0
0000K_l0K_l0801^o`03000008Wo08Wo01/0ROl00`00003oQP3oQP0F0?n600<0003oVP3oVP002_nJ
0080000Qol@000<0003oG`3oG`005_mO00<0000Aofh000<0003oE`3oE`009?mG00030000olP0olP0
027ob0000`000:So0:So0004Z?l000<0002Xo`2Xo`007:So00040000oooooooo00004Oooo`00C?oo
o`030000oooooooo01Goool00`00003o0`3o0`0;0?l300<00000K_l0K_l08@1^o`03000008Wo08Wo
01/0ROl00`00003oQP3oQP0G0?n600<0003oVP3oVP001onJ0080000Tol@000<0003oG`3oG`004omO
0080000Eofh000<0003oE`3oE`009?mG00030000olP0olP0023ob0000`000:So0:So0005Z?l000<0
002Xo`2Xo`007:So00030000oooo0000017oool004goool200005Oooo`0300000?l30?l300/0o`<0
0`00001^o`1^o`0P06ko00<00000ROl0ROl06`29o`0300000?n60?n601P0ohH00`000?nJ0?nJ0005
oiX00P0002Ooa0000`000?mO0?mO000?oel00`0001SoKP000`000?mG0?mG000ToeL000<0003ob03o
b0008?o800030000Z?l0Z?l000FXo`000`000:So0:So000KZ?l000<0003oool000004Oooo`00Cooo
o`030000oooooooo01;oool00`00003o0`3o0`0:0?l300<00000K_l0K_l08@1^o`03000008Wo08Wo
01/0ROl00`00003oQP3oQP0I0?n600<0003oVP3oVP000_nJ0080000Zol@000<0003oG`3oG`002omO
00<0000Lofh000<0003oE`3oE`008omG00030000olP0olP0023ob0000`000:So0:So0006Z?l000<0
002Xo`2Xo`006ZSo00030000oooo0000017oool0053oool00`000?ooooooo`0Aoooo00<00000o`<0
o`<02P3o0`03000006ko06ko0200K_l00`000029o`29o`0K08Wo00<00000ohH0ohH06`3oQP040000
oiX000000000;Oo400030000oel0oel000OoG`0300007om^00030000oeL0oeL002CoE`000`000?o8
0?o8000PolP000<0002Xo`2Xo`001JSo00030000Z?l0Z?l001^Xo`000`000?ooo`00000@oooo001A
oooo00<0003oooooool04?ooo`0300000?l30?l300T0o`<00`00001^o`1^o`0P06ko00<00000ROl0
ROl07029o`0300000?n60?n601`0ohH00`000?o40?o4000^ol@000<0003oG`3oG`001?mO0080000S
ofh000<0003oE`3oE`009?mG00030000olP0olP001oob0000`000:So0:So0006Z?l000<0002Xo`2X
o`006ZSo00030000oooo0000013oool005;oool200004Oooo`0300000?l30?l300P0o`<00`00001^
o`1^o`0P06ko00<00000ROl0ROl06`29o`0300000?n60?n601`0ohH00`00003oI@00000`ol@000<0
003oG`3oG`000`0002KoKP000`000?mG0?mG000SoeL000<0003ob03ob0008?o800030000Z?l0Z?l0
00JXo`000`000:So0:So000JZ?l00P00013oool005Coool00`000?ooooooo`0>oooo00<00000o`<0
o`<01`3o0`03000006ko06ko0200K_l00`000029o`29o`0L08Wo00<00000ohH0ohH06`3oQP050000
0?mU0?mU0?mU0000033oa0020000:_m^00030000oeL0oeL0023oE`0800007Oo800030000Z?l0Z?l0
00JXo`000`000:So0:So000JZ?l00P00013oool005Goool00`000?ooooooo`0=oooo00<00000o`<0
o`<01`3o0`03000006ko06ko0200K_l00`000029o`29o`0K08Wo00<00000ohH0ohH06P3oQP800005
0?mU00<0003oa03oa000:oo4008000000nSo00000?m^000Zofh000<0003oE`3oE`006OmG00H00008
oooo2@0001Gob0000`000:So0:So0006Z?l000<0002Xo`2Xo`006JSo0080000@oooo001Foooo00<0
003oooooool03?ooo`0300000?l30?l300H0o`<00`00001^o`1^o`0P06ko00<00000ROl0ROl07029
o`0300000?n60?n601T0ohH00`00003oI@3oI@060?mU00<0003oa03oa000:?o400800004j?l000<0
003oKP3oKP00:Om^00030000oeL0oeL0017oE`0700005oooo`T0000<olP000<0002Xo`2Xo`001jSo
00030000Z?l0Z?l001VXo`000`000?ooooooo`0>oooo001Goooo0P0000coool00`00003o0`3o0`05
0?l300<00000K_l0K_l08@1^o`03000008Wo08Wo01`0ROl00`00003oQP3oQP0H0?n600<00000ofD0
ofD0203oI@030000ol@0ol@002Goa00200001^So00030000ofh0ofh002[oKP000`000?mG0?mG0009
oeL01`0002Ooool900001?o800030000Z?l0Z?l000NXo`000`000:So0:So0006Z?l04`00013oool0
05Woool00`000?ooooooo`09oooo00<00000o`<0o`<01@3o0`03000006ko06ko0200K_l00`000029
o`29o`0L08Wo00<00000ohH0ohH0603oQP0300000?mU0?mU00X0ofD00`000?o40?o4000Sol@000<0
003Xo`3Xo`001nSo00030000ofh0ofh002[oKP000`000?mG0?mG0002oeL01P0003OooolG00004ooo
o`030000oooooooo00goool005[oool00`000?ooooooo`09oooo00<00000o`<0o`<00`3o0`030000
06ko06ko0240K_l00`000029o`29o`0L08Wo00<00000ohH0ohH05`3oQP0300000?mU0?mU00`0ofD0
0`000?o40?o4000Pol@00P0000_Xo`000`000?m^0?m^000Zofh0100004coool00`000?ooooooo`0H
oooo00<0003oooooool03Oooo`00Foooo`030000oooooooo00Soool00`00003o0`3o0`030?l300<0
0000K_l0K_l0801^o`03000008Wo08Wo01`0ROl00`00003oQP3oQP0F0?n60P000100ofD00`000?o4
0?o4000Mol@00P0000kXo`000`000?m^0?m^000Wofh00P00057oool00`000?ooooooo`0Goooo00<0
003oooooool03Oooo`00G?ooo`800008oooo00<00000o`<0o`<00P3o0`03000006ko06ko0240K_l0
0`000029o`29o`0L08Wo00<00000ohH0ohH05@3oQP0300000?mU0?mU0140ofD00`000?o40?o4000J
ol@00P00013Xo`000`000?m^0?m^000Uofh00P0005Coool00`000?ooooooo`0Foooo00<0003ooooo
ool03Oooo`00G_ooo`030000oooooooo00Goool00`00003o0`3o0`020?l300<00000K_l0K_l0801^
o`03000008Wo08Wo01`0ROl00`00003oQP3oQP0E0?n600<00000ofD0ofD04P3oI@030000ol@0ol@0
01Soa00200004nSo00030000ofh0ofh002;oKP020000E_ooo`030000oooooooo01Koool00`000?oo
ooooo`0=oooo001Ooooo00<0003oooooool01?ooo`0500000?l30?l30?l3000002<0K_l00`000029
o`29o`0L08Wo00<00000ohH0ohH0503oQP0300000?mU0?mU01@0ofD00`000?o40?o4000Fol@000<0
003Xo`3Xo`005>So00030000ofh0ofh001ooKP020000FOooo`030000oooooooo01Goool00`000?oo
ooooo`0=oooo001Poooo00<0003oooooool00oooo`0500000?l30?l30?l300000280K_l00`000029
o`29o`0L08Wo00<00000ohH0ohH0503oQP0300000?mU0?mU01H0ofD00`000?o40?o4000Col@00P00
01SXo`000`000?m^0?m^000Lofh00P0005coool00`000?ooooooo`0Doooo00<0003oooooool03Ooo
o`00HOooo`800003oooo00@00000o`<0o`<0000S06ko00<00000ROl0ROl07029o`0300000?n60?n6
01<0ohH00`00003oI@3oI@0H0?mU00<0003oa03oa0004?o40080000Jj?l000<0003oKP3oKP006_m^
0080001Ooooo00<0003oooooool04oooo`030000oooooooo00goool006?oool01`000?oooooooooo
o`00003o0`00000R06ko00<00000ROl0ROl07029o`0300000?n60?n60180ohH20000703oI@030000
ol@0ol@000goa00200007NSo00030000ofh0ofh001OoKP020000HOooo`030000oooooooo01Coool0
0`000?ooooooo`0<oooo001Toooo00<0003oooooool00P0002<0K_l00`000029o`29o`0L08Wo00<0
0000ohH0ohH04@3oQP0300000?mU0?mU01d0ofD00`000?o40?o4000;ol@000<0003Xo`3Xo`007^So
00030000ofh0ofh001GoKP000`000?ooooooo`1Roooo00<0003oooooool04oooo`030000oooooooo
00coool006Goool010000?ooo`0000000280K_l00`000029o`29o`0L08Wo00<00000ohH0ohH04@3o
QP0300000?mU0?mU01l0ofD00`000?o40?o40008ol@00P0002;Xo`000`000?m^0?m^000Bofh00P00
06Koool00`000?ooooooo`0Boooo00<0003oooooool03?ooo`00I_ooo`80000S06ko00<00000ROl0
ROl07029o`0300000?n60?n60100ohH00`00003oI@3oI@0Q0?mU00<0003oa03oa0001Oo40080000U
j?l000<0003oKP3oKP003om^0080001Xoooo00<0003oooooool04_ooo`030000oooooooo00coool0
06Ooool200008@1^o`03000008Wo08Wo01`0ROl00`00003oQP3oQP0@0?n600<00000ofD0ofD08`3o
I@030000ol@0ol@000;oa00200009nSo00030000ofh0ofh000goKP020000Joooo`030000oooooooo
017oool00`000?ooooooo`0<oooo001Yoooo0P0001h0K_l00`000029o`29o`0M08Wo00<00000ohH0
ohH03P3oQP80000W0?mU00@0003oa0000000000Zj?l000<0003oKP3oKP002_m^0080001^oooo00<0
003oooooool04?ooo`030000oooooooo00coool006[oool200007@1^o`03000008Wo08Wo01`0ROl0
0`00003oQP3oQP0>0?n600<00000ofD0ofD0:03oI@030000j?l0j?l002_Xo`000`000?m^0?m^0007
ofh00P00077oool00`000?ooooooo`0?oooo00<0003oooooool03?ooo`00Joooo`80000K06ko00<0
0000ROl0ROl07@29o`0300000?n60?n600d0ohH00`00003oI@3oI@0X0?mU00<00000oj`00000;NSo
00030000ofh0ofh000CoKP020000Loooo`030000oooooooo013oool00`000?ooooooo`0;oooo001/
oooo0P0001X0K_l00`000029o`29o`0L08Wo00<00000ohH0ohH03@3oQP0300000?mU0?mU02T0ofD0
0`00003o[000000]j?l000<0003oKP3oKP000_m^0080001foooo00<0003oooooool03oooo`030000
oooooooo00_oool006koool200005`1^o`03000008Wo08Wo01d0ROl00`00003oQP3oQP0<0?n600<0
0000ofD0ofD0:@3oI@0500000?n/0?n/0?n/000002gXo`0010000?m^0000000007Woool00`000?oo
ooooo`0>oooo00<0003oooooool02oooo`00Koooo`80000F06ko00<00000ROl0ROl07029o`030000
0?n60?n600/0ohH20000;03oI@0300000?n/0?n/0080oj`00`000>So0>So000[j?l000<0003ooooo
ool0N_ooo`030000oooooooo00goool00`000?ooooooo`0;oooo001`oooo0P0001@0K_l00`000029
o`29o`0M08Wo00<00000ohH0ohH02P3oQP0300000?mU0?mU02/0ofD00`00003o[03o[0030?n/00<0
003Xo`3Xo`00:NSo0080001moooo00<0003oooooool03Oooo`030000oooooooo00_oool0077oool2
00004`1^o`03000008Wo08Wo01`0ROl00`00003oQP3oQP0:0?n600<00000ofD0ofD0;03oI@030000
0?n/0?n/00@0oj`00`000>So0>So000Wj?l000<0003oooooool0O_ooo`030000oooooooo00coool0
0`000?ooooooo`0;oooo001coooo0P000100K_l00`000029o`29o`0M08Wo00<00000ohH0ohH02@3o
QP0300000?mU0?mU02`0ofD00`00003o[03o[0060?n/00<0003Xo`3Xo`009NSo00030000oooooooo
083oool00`000?ooooooo`0;oooo00<0003oooooool02oooo`00M?ooo`80000?06ko00<00000ROl0
ROl07029o`0300000?n60?n600T0ohH20000;P3oI@0300000?n/0?n/00H0oj`00`000>So0>So000S
j?l00P0008?oool00`000?ooooooo`0<oooo00<0003oooooool02_ooo`00MOooo`80000=06ko00<0
0000ROl0ROl07@29o`0300000?n60?n600P0ohH010000?ooooooo`0002`0ofD00`00003o[03o[008
0?n/00<0003Xo`3Xo`008NSo00030000oooooooo08Coool00`000?ooooooo`0;oooo00<0003ooooo
ool02_ooo`00M_ooo`80000<06ko00<00000ROl0ROl07@29o`0300000?n60?n600L0ohH01@000?oo
ooooooooo`00000[0?mU00<00000oj`0oj`02P3o[0030000j?l0j?l001oXo`000`000?ooooooo`26
oooo00<0003oooooool02_ooo`030000oooooooo00[oool007Soool200002@1^o`03000008Wo08Wo
01d0ROl00`00003oQP3oQP070?n600<0003oooooool00_ooo`0300000?mU0?mU02T0ofD00`00003o
[03o[00:0?n/00<0003Xo`3Xo`007NSo0080002:oooo00<0003oooooool02Oooo`030000oooooooo
00[oool007Woool20000201^o`03000008Wo08Wo01d0ROl00`00003oQP3oQP070?n600<0003ooooo
ool00oooo`0300000?mU0?mU02L0ofD00`00003o[03o[00<0?n/00<0003Xo`3Xo`006nSo00030000
oooooooo08[oool00`000?ooooooo`09oooo00<0003oooooool02_ooo`00N_ooo`80000606ko00<0
0000ROl0ROl07@29o`0300000?n60?n600L0ohH00`000?ooooooo`04oooo00<00000ofD0ofD09`3o
I@0300000?n/0?n/00d0oj`00`000>So0>So000Ij?l000<0003oooooool0S?ooo`030000oooooooo
00Soool00`000?ooooooo`0:oooo001koooo0P0000D0K_l00`000029o`29o`0M08Wo00<00000ohH0
ohH01P3oQP030000oooooooo00Goool00`00003oI@3oI@0V0?mU00<00000oj`0oj`03P3o[0030000
j?l0j?l001OXo`020000T?ooo`030000oooooooo00Ooool00`000?ooooooo`0:oooo001moooo0P00
0080K_l00`000029o`29o`0M08Wo00<00000ohH0ohH01P3oQP030000oooooooo00Ooool00`00003o
I@3oI@0U0?mU00<00000oj`0oj`03`3o[0030000j?l0j?l001GXo`000`000?ooooooo`2Aoooo00<0
003oooooool01oooo`030000oooooooo00Woool007koool2000000<0K_l00000ROl07P29o`030000
0?n60?n600D0ohH00`000?ooooooo`08oooo00<00000ofD0ofD0903oI@0300000?n/0?n/0140oj`0
0`000>So0>So000Cj?l000<0003oooooool0T_ooo`030000oooooooo00Ooool00`000?ooooooo`09
oooo001ooooo0P0001l0ROl00`00003oQP3oQP050?n600<0003oooooool02Oooo`0300000?mU0?mU
02<0ofD00`00003o[03o[00B0?n/00<0003Xo`3Xo`004NSo0080002Foooo00<0003oooooool01_oo
o`030000oooooooo00Woool0083oool200007P29o`0300000?n60?n600@0ohH00`000?ooooooo`0;
oooo00<00000ofD0ofD08P3oI@0300000?n/0?n/01<0oj`00`000>So0>So000?j?l000<0003ooooo
ool0Uoooo`030000oooooooo00Goool00`000?ooooooo`09oooo0022oooo0P0001/0ROl00`00003o
QP3oQP040?n600<0003oooooool03?ooo`0300000?mU0?mU0240ofD00`00003o[03o[00E0?n/00<0
003Xo`3Xo`003NSo00030000oooooooo09Woool00`000?ooooooo`04oooo00<0003oooooool02Ooo
o`00Poooo`80000J08Wo00<00000ohH0ohH00`3oQP030000oooooooo00goool00`00003oI@3oI@0Q
0?mU00<00000oj`0oj`05@3o[0030000j?l0j?l000_Xo`020000W?ooo`030000oooooooo00Coool0
0`000?ooooooo`09oooo0024oooo0P0001P0ROl00`00003oQP3oQP030?n600<0003oooooool03ooo
o`0300000?mU0?mU01l0ofD00`00003o[03o[00G0?n/00<0003Xo`3Xo`002NSo00030000oooooooo
09goool00`000?ooooooo`03oooo00<0003oooooool02Oooo`00QOooo`80000G08Wo00<00000ohH0
ohH00`3oQP030000oooooooo00ooool00`00003oI@3oI@0O0?mU00<00000oj`0oj`0603o[0030000
j?l0j?l000OXo`000`000?ooooooo`2Ooooo00<0003oooooool00oooo`030000oooooooo00Soool0
08Ooool00`000029o`29o`0C08Wo00<00000ohH0ohH00`3oQP030000oooooooo017oool00`00003o
I@3oI@0M0?mU00<00000oj`0oj`06@3o[0030000j?l0j?l000GXo`020000X_ooo`030000oooooooo
00?oool00`000?ooooooo`08oooo0028oooo0P0001<0ROl00`00003oQP3oQP020?n600<0003ooooo
ool04_ooo`0300000?mU0?mU01d0ofD00`00003o[03o[00J0?n/00<0003Xo`3Xo`000nSo00030000
oooooooo0:?oool00`000?ooooooo`02oooo00<0003oooooool02?ooo`00ROooo`80000A08Wo00<0
0000ohH0ohH00P3oQP030000oooooooo01?oool00`00003oI@3oI@0L0?mU00<00000oj`0oj`0703o
[0050000j?l0j?l0j?l000000:Ooool01@000?ooooooooooo`00000:oooo002:oooo0P000100ROl0
1@00003oQP3oQP3oQP00000Goooo00<00000ofD0ofD06P3oI@0300000?n/0?n/01d0oj`010000>So
000000000:Woool010000?ooooooo`0000[oool008coool00`000029o`29o`0<08Wo00D00000ohH0
ohH0ohH000006?ooo`0300000?mU0?mU01X0ofD00`00003o[03o[00N0?n/00<0003oooooool0ZOoo
o`040000oooooooo00002_ooo`00SOooo`03000008Wo08Wo00/0ROl01000003oQP3oQP0001Woool0
0`00003oI@3oI@0I0?mU00<00000oj`0oj`07@3o[080002]oooo00<0003oool000002_ooo`00S_oo
o`80000:08Wo00@00000ohH0ohH0000Koooo00<00000ofD0ofD0603oI@0300000?n/0?n/01/0oj`2
0000/?ooo`030000oooo000000Woool008ooool200002@29o`0300000?n6000001coool00`00003o
I@3oI@0G0?mU00<00000oj`0oj`06P3o[080002coooo0P0000Woool0093oool200001`29o`030000
0?n6000001goool00`00003oI@3oI@0G0?mU00<00000oj`0oj`0603o[080002eoooo0P0000Woool0
09;oool00`000029o`29o`0408Wo00<00000ohH000007_ooo`0300000?mU0?mU01D0ofD00`00003o
[03o[00G0?n/0P000;Ooool200002Oooo`00Toooo`03000008Wo08Wo0080ROl00`00003oQP00000O
oooo00<00000ofD0ofD05@3oI@0300000?n/0?n/01D0oj`20000]Oooo`@0000;oooo002Doooo0P00
0080ROl200008?ooo`0300000?mU0?mU01@0ofD00`00003o[03o[00D0?n/0P000;?oool400003ooo
o`00UOooo`@0000Roooo00<00000ofD0ofD04P3oI@0300000?n/0?n/01<0oj`20000/Oooo`@0000C
oooo002Goooo00<0003oooooool08Oooo`0300000?mU0?mU0180ofD00`00003o[03o[00A0?n/0P00
0:ooool400005oooo`00V?ooo`030000oooooooo023oool00`00003oI@3oI@0A0?mU00<00000oj`0
oj`0403o[080002]oooo100001_oool009Woool00`000?ooooooo`0Poooo00<00000ofD0ofD0403o
I@0300000?n/0?n/00h0oj`20000Zoooo`@0000Ooooo002Joooo0P00023oool00`00003oI@3oI@0?
0?mU00<00000oj`0oj`03@3o[080002Yoooo100002?oool009coool00`000?ooooooo`0Moooo00<0
0000ofD0ofD03`3oI@0300000?n/0?n/00/0oj`20000Z?ooo`<0000Woooo002Moooo00<0003ooooo
ool07Oooo`0300000?mU0?mU00d0ofD00`00003o[03o[00:0?n/0P000:Koool40000:_ooo`00W_oo
o`030000oooooooo01coool00`00003oI@3oI@0=0?mU00<00000oj`0oj`0203o[080002Toooo1000
02koool009ooool200007?ooo`0300000?mU0?mU00`0ofD00`00003o[03o[0080?n/00<0003ooooo
ool0X?ooo`@0000boooo002Qoooo00<0003oooooool06_ooo`0300000?mU0?mU00X0ofD00`00003o
[03o[0080?n/0P0009koool40000=_ooo`00X_ooo`030000oooooooo01Woool00`00003oI@3oI@0:
0?mU00<00000oj`0oj`01P3o[08000000oooo`000?ooo`2Ioooo100003[oool00:?oool00`000?oo
ooooo`0Hoooo00<00000ofD0ofD02@3oI@0300000?n/0?n/00H0oj`01@000?ooooooooooo`00002F
oooo100003koool00:Coool200006Oooo`0300000?mU0?mU00P0ofD00`00003o[03o[0050?n/00<0
003oooooool00_ooo`030000oooooooo097oool30000@_ooo`00Y_ooo`030000oooooooo01Koool0
0`00003oI@3oI@070?mU00<00000oj`0oj`01@3o[0030000oooooooo00?oool00`000?ooooooo`2=
oooo100004Goool00:Ooool00`000?ooooooo`0Foooo00<00000ofD0ofD01P3oI@0300000?n/0?n/
00<0oj`200001_ooo`030000oooooooo08Woool40000BOooo`00Z?ooo`030000oooooooo01Goool0
0`00003oI@3oI@050?mU00<00000oj`0oj`00`3o[0030000oooooooo00Goool00`000?ooooooo`26
oooo100004goool00:Woool200005Oooo`0300000?mU0?mU00@0ofD00`00003o[03o[0030?n/00<0
003oooooool01_ooo`030000oooooooo08;oool40000DOooo`00Zoooo`030000oooooooo01?oool0
0`00003oI@3oI@030?mU00<00000oj`0oj`00P3o[0030000oooooooo00Ooool00`000?ooooooo`1n
oooo100005Goool00:coool00`000?ooooooo`0Boooo00<00000ofD0ofD00P3oI@0400000?n/0?n/
0?n/0P0000[oool00`000?ooooooo`1joooo100005Woool00:goool00`000?ooooooo`0Aoooo00<0
0000ofD0ofD00P3oI@0400000?n/0?n/00003?ooo`030000oooooooo07Koool40000GOooo`00[_oo
o`80000Boooo00@00000ofD0ofD000020?n/00<0003oooooool02oooo`030000oooooooo07?oool3
0000HOooo`00/?ooo`030000oooooooo00ooool01P00003oI@3oI@00003o[00000koool00`000?oo
ooooo`1_oooo100006Coool00;7oool00`000?ooooooo`0>oooo00<00000ofD000000P0000ooool0
0`000?ooooooo`1[oooo100006Soool00;;oool00`000?ooooooo`0>oooo0P00017oool00`000?oo
ooooo`1Woooo100006coool00;?oool200003_ooo`030000oooooooo013oool00`000?ooooooo`1S
oooo1000073oool00;Goool00`000?ooooooo`0Noooo00<0003oooooool0Goooo`@0001doooo002f
oooo00<0003oooooool07Oooo`030000oooooooo05_oool40000N?ooo`00]oooo`030000oooooooo
01coool00`000?ooooooo`1Goooo100007coool00;Soool200007?ooo`030000oooooooo05Coool3
0000P?ooo`00^_ooo`030000oooooooo01Woool00`000?ooooooo`1@oooo100008?oool00;_oool0
0`000?ooooooo`0Hoooo00<0003oooooool0C?ooo`@00027oooo002loooo00<0003oooooool05ooo
o`030000oooooooo04Soool40000Roooo`00_Oooo`030000oooooooo01Koool00`000?ooooooo`14
oooo100008ooool00;koool200005_ooo`030000oooooooo043oool40000Toooo`00`?ooo`030000
oooooooo01?oool00`000?ooooooo`0loooo100009Ooool00<7oool00`000?ooooooo`0Boooo00<0
003oooooool0>?ooo`@0002Koooo0032oooo00<0003oooooool04Oooo`030000oooooooo03Goool3
0000Woooo`00`oooo`80000Aoooo00<0003oooooool0<Oooo`@0002Roooo0035oooo00<0003ooooo
ool03_ooo`030000oooooooo02goool40000Y_ooo`00a_ooo`030000oooooooo00coool00`000?oo
ooooo`0Zoooo10000:[oool00<Ooool00`000?ooooooo`0;oooo00<0003oooooool09_ooo`@0002^
oooo0038oooo0P0000_oool00`000?ooooooo`0Roooo10000;;oool00<[oool00`000?ooooooo`08
oooo00<0003oooooool07_ooo`@0002foooo003;oooo00<0003oooooool01oooo`030000oooooooo
01_oool30000^_ooo`00c?ooo`030000oooooooo00Koool00`000?ooooooo`0Goooo10000;goool0
0<goool200001_ooo`030000oooooooo01?oool40000`Oooo`00coooo`030000oooooooo00?oool0
0`000?ooooooo`0?oooo10000<Goool00=3oool00`000?ooooooo`02oooo00<0003oooooool02ooo
o`@00039oooo003Aoooo00D0003oooooooooool000002Oooo`@0003=oooo003Boooo0P000003oooo
0000oooo00Coool40000dOooo`00e?ooo`8000000oooo`00000000020000eOooo`00eOooo`80003I
oooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooona
oooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooona
oooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooona
oooo003ooooo/Oooo`00oooook7oool00?oooonaoooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {349.313, 0}} -> {-0.208754, -0.0654451, 
  0.00412542, 0.00412542}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Interpolation bei \[ADoubleDot]quidistanten St\[UDoubleDot]tzstellen"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Motivation"
}], "Subsubsection"],

Cell["\<\
Wird ein Experiment systematisch aufgebaut, so ist es von \
entscheidendem Vorteil, wenn die Intervalle der Messung (etwa die \
Zeitschritte) jeweils gleich gro\[SZ] (\[ADoubleDot]quidistant) sind.\
\>", 
  "Text"],

Cell[TextData[{
  "In diesem Fall kann n\[ADoubleDot]mlich eine besondere Eigenschaft des ",
  StyleBox["Pascalschen Dreiecks",
    FontSlant->"Italic"],
  " ausgenutzt werden (",
  ButtonBox["[BrS1987]",
    ButtonData:>"[BrS1987]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 2.2.1.2., Additionssatz, Seite 105):"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(n + 1\)},
              {\(k + 1\)}
              }], ")"}], "-", 
        RowBox[{"(", GridBox[{
              {"n"},
              {\(k + 1\)}
              }], ")"}]}], "\[Equal]", 
      RowBox[{"(", GridBox[{
            {"n"},
            {"k"}
            }], ")"}]}]], "NumberedEquation",
  CellTags->"Binomische Differenzengleichung"],

Cell[TextData[{
  "F\[UDoubleDot]r ganzzahlige ",
  Cell[BoxData[
      \(k\)]],
  " stellen diese ",
  StyleBox["Binomial-Koeffizienten",
    FontSlant->"Italic"],
  " Polynome ",
  Cell[BoxData[
      \(k\)]],
  "-ten Grades in ",
  Cell[BoxData[
      \(n\)]],
  " bzw. ",
  Cell[BoxData[
      \(n + 1\)]],
  " dar. Die Eigenschaft (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomische Differenzengleichung"],
  ") ist grundlegend f\[UDoubleDot]r alle ",
  StyleBox["arithmetischen Folgen ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(k\)]],
  "-ter Ordnung."
}], "Text"],

Cell[TextData[{
  "Die Binomial-Koeffizienten lassen sich mit Hilfe der \
Fakult\[ADoubleDot]t-Formel berechnen (",
  ButtonBox["[BrS1987]",
    ButtonData:>"[BrS1987]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 2.2.1.2., Formel (2.1), Seite 104):"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", GridBox[{
            {"n"},
            {"k"}
            }], ")"}], "\[Equal]", \(\(n!\)\/\(\(k!\)\ \(\((n - k)\)!\)\)\), 
      "\[Equal]", 
      RowBox[{"(", GridBox[{
            {"n"},
            {\(n - k\)}
            }], ")"}]}]], "NumberedEquation",
  CellTags->"Berechnung der Binomial-Koeffizienten"],

Cell[TextData[{
  "Der Zusammenhang (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomische Differenzengleichung"],
  ") l\[ADoubleDot]\[SZ]t sich mit Hilfe der Formel (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Berechnung der Binomial-Koeffizienten"],
  ") auch durch direktes Einsetzen  allgemein best\[ADoubleDot]tigen."
}], "Text"],

Cell["\<\
Wird ein Polynom in Termen der Binomial-Koeffizienten angegeben, so \
ist vor allem die Summenbildung \[UDoubleDot]ber derartige Terme extrem \
einfach:\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Einfaches Beispiel"
}], "Subsubsection"],

Cell[TextData[{
  "Die Zahlenfolge ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {"n"},
            {"1"}
            }], ")"}]]],
  " lautet f\[UDoubleDot]r die ersten zehn ",
  Cell[BoxData[
      \(n\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zahlenfolge = Range[10]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10}\)], "Output"]
}, Open  ]],

Cell["Die Summe \[UDoubleDot]ber diese Zahlen ergibt:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zahlensumme = 
      \(Table[Plus@@Take[#, z\[ADoubleDot]hler], {z\[ADoubleDot]hler, 
              Length[#]}]&\)@zahlenfolge\)], "Input"],

Cell[BoxData[
    \({1, 3, 6, 10, 15, 21, 28, 36, 45, 55}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Dies sind nach dem Zusammenhang (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomische Differenzengleichung"],
  ") die Binomial-Koeffizienten ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(n + 1\)},
            {"2"}
            }], ")"}]]],
  "."
}], "Text"],

Cell[TextData[{
  "Allgemein ergibt eine Summe einen Zuwachs ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", GridBox[{
              {"n"},
              {"k"}
              }], ")"}], "\[Rule]", 
        RowBox[{"(", GridBox[{
              {\(n + 1\)},
              {\(k + 1\)}
              }], ")"}]}]]],
  ". Es ist deshalb immer wieder zweckm\[ADoubleDot]\[SZ]ig, Polynome als \
Binomial-Folgen darzustellen."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Weiteres Beispiel"
}], "Subsubsection"],

Cell["Die Quadratzahlen ergeben folgende Werteliste:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(quadratzahlen = \(#\^2&\)/@Range[10]\)], "Input"],

Cell[BoxData[
    \({1, 4, 9, 16, 25, 36, 49, 64, 81, 100}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Darstellung der Quadratzahlen in Binomial-Koeffizienten geschieht \
\[UDoubleDot]ber ",
  StyleBox["Differenzenbildung",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[TextData[{
  "Die erste \"Differenzensumme\" ergibt die ungeraden Zahlen ab ",
  Cell[BoxData[
      \(3\)]],
  ", die n\[ADoubleDot]chste Differenzensumme ist stets ",
  Cell[BoxData[
      \(2\)]],
  ". Dadurch ergibt sich folgende alternative Darstellung der Quadratzahlen:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1\ Binomial[x - 1, 0] + 3\ Binomial[x - 1, 1] + 
        2\ Binomial[x - 1, 2] // Expand\)], "Input"],

Cell[BoxData[
    \(x\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Summe \[UDoubleDot]ber die Quadratzahlen ergibt (vgl. ",
  ButtonBox["[BrS1987]",
    ButtonData:>"[BrS1987]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 2.3.3.(5), Seite 114):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1  Binomial[x, 1] + 3  Binomial[x, 2] + 2  Binomial[x, 3] // ExpandAll
      \)], "Input"],

Cell[BoxData[
    \(x\/6 + x\^2\/2 + x\^3\/3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Koeffizienten ",
  Cell[BoxData[
      \(1\)]],
  ", ",
  Cell[BoxData[
      \(3\)]],
  " und ",
  Cell[BoxData[
      \(2\)]],
  " des hier vorgestellten Beispiels \[ADoubleDot]ndern sich durch Summen- \
oder Differenzenbildung nicht."
}], "Text"],

Cell["\<\
Dadurch ist die Entwicklung von bilanzierenden Summen ebenfalls \
interpoliert:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
          Plus@@Take[#, z\[ADoubleDot]hler], {z\[ADoubleDot]hler, Length[#]}]&
        \)@quadratzahlen\)], "Input"],

Cell[BoxData[
    \({1, 5, 14, 30, 55, 91, 140, 204, 285, 385}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InterpolatingPolynomial[{1, 5, 14, 30, 55}, x] // ExpandAll\)], "Input"],

Cell[BoxData[
    \(x\/6 + x\^2\/2 + x\^3\/3\)], "Output"]
}, Open  ]],

Cell["Das Ergebnis ist unabh\[ADoubleDot]ngig vom Rechenweg.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Beispiel von Faulhaber (1617) und Remmelin (1619)"
}], "Subsubsection"],

Cell["\<\
Die Summenfolge \[UDoubleDot]ber die f\[UDoubleDot]nften Potenzen \
ist zu interpolieren:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(potenzfolge = \((\(#\^5&\)/@Range[10])\)\)], "Input"],

Cell[BoxData[
    \({1, 32, 243, 1024, 3125, 7776, 16807, 32768, 59049, 100000}\)], "Output"]
}, Open  ]],

Cell["Die Differenzensummen ergeben folgende Koeffizienten:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(differenzenfolgen = 
      NestList[\(Last[#] - First[#]&\)/@Partition[#, 2, 1]&, potenzfolge, 7]; 
    differenzenfolgen // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"1", "32", "243", "1024", "3125", "7776", "16807", "32768", 
            "59049", "100000"},
          {"31", "211", "781", "2101", "4651", "9031", "15961", "26281", 
            "40951", \(""\)},
          {"180", "570", "1320", "2550", "4380", "6930", "10320", "14670", 
            \(""\), \(""\)},
          {"390", "750", "1230", "1830", "2550", "3390", "4350", \(""\), 
            \(""\), \(""\)},
          {"360", "480", "600", "720", "840", "960", \(""\), \(""\), \(""\), 
            \(""\)},
          {"120", "120", "120", "120", "120", \(""\), \(""\), \(""\), \(""\), 
            \(""\)},
          {"0", "0", "0", "0", \(""\), \(""\), \(""\), \(""\), \(""\), 
            \(""\)},
          {"0", "0", "0", \(""\), \(""\), \(""\), \(""\), \(""\), \(""\), 
            \(""\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {{1, 32, 243, 1024, 3125, 7776, 16807, 32768, 59049, 100000}, {31, 211,
         781, 2101, 4651, 9031, 15961, 26281, 40951}, {180, 570, 1320, 2550, 
        4380, 6930, 10320, 14670}, {390, 750, 1230, 1830, 2550, 3390, 4350}, {
        360, 480, 600, 720, 840, 960}, {120, 120, 120, 120, 120}, {0, 0, 0, 
        0}, {0, 0, 0}}]]], "Output"]
}, Open  ]],

Cell["Die gesuchten Koeffizienzen lauten:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(koeffizienten = DeleteCases[First/@differenzenfolgen, 0]\)], "Input"],

Cell[BoxData[
    \({1, 31, 180, 390, 360, 120}\)], "Output"]
}, Open  ]],

Cell["Damit ergibt sich (zur Probe) die f\[UDoubleDot]nfte Potenz:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(koeffizienten.\((\(Binomial[x - 1, #]&\)/@Range[0, 5])\) // Expand\)], 
  "Input"],

Cell[BoxData[
    \(x\^5\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Summenfolge dar\[UDoubleDot]ber ergibt in \
\[CapitalUDoubleDot]bereinstimmung mit Faulhaber und Remmelin (",
  ButtonBox["[Haw1995]",
    ButtonData:>"[Haw1995]",
    ButtonStyle->"Hyperlink"],
  ", Seite 158 und 214):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(koeffizienten.\((\(Binomial[x, # + 1]&\)/@Range[0, 5])\) // Expand\)], 
  "Input"],

Cell[BoxData[
    \(\(-\(x\^2\/12\)\) + \(5\ x\^4\)\/12 + x\^5\/2 + x\^6\/6\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Anmerkung des Historikers lautet \[UDoubleDot]ber Faulhabers Werk ",
  StyleBox["Newer Arithmetischer Wegweyser",
    FontSlant->"Italic"],
  " aus dem Jahre 1617 (",
  ButtonBox["[Haw1995]",
    ButtonData:>"[Haw1995]",
    ButtonStyle->"Hyperlink"],
  ", Seite 159): \"Auf S. 86 weist Faulhaber darauf hin, da\[SZ] Peter Roth \
auf die Aufgabe 149 des ",
  StyleBox["Cubiccosischen Lustgartens",
    FontSlant->"Italic"],
  " nicht eingegangen ist. Zu deren L\[ODoubleDot]sung ben\[ODoubleDot]tigt \
man die Summe der Potenzen 5. Grades.\""
}], "Text"],

Cell["Der unabh\[ADoubleDot]ngige Rechenweg best\[ADoubleDot]tigt das \
Ergebnis:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InterpolatingPolynomial[
        \(Table[Plus@@Take[#, z\[ADoubleDot]hler], {z\[ADoubleDot]hler, 
                Length[#]}]&\)@potenzfolge, x] // Expand\)], "Input"],

Cell[BoxData[
    \(\(-\(x\^2\/12\)\) + \(5\ x\^4\)\/12 + x\^5\/2 + x\^6\/6\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In der Literatur (etwa bei ",
  ButtonBox["[Spie1982]",
    ButtonData:>"[Spie1982]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitt Faktoriellenpolynome, Seite 6-7) werden ",
  StyleBox["Stirlingsche Zahlen",
    FontSlant->"Italic"],
  " eingef\[UDoubleDot]hrt, die mit schlecht skalierten \
Binomial-Koeffizienten \[ADoubleDot]hnliche Ergebnisse erzielen. Die Idee der \
iterierten Differenzenbildung findet sich auch schon bei Newton, die \
Ergebnisse bereits bei Faulhaber (1604 und 1617) und Remmelin (1619) (",
  ButtonBox["[Haw1995]",
    ButtonData:>"[Haw1995]",
    ButtonStyle->"Hyperlink"],
  ", Seite 214). Der hier vorgestellte L\[ODoubleDot]sungsweg ist erfrischend \
kurz und eventuell auch verst\[ADoubleDot]ndlich."
}], "Text"],

Cell["\<\
F\[UDoubleDot]r \[ADoubleDot]quidistante St\[UDoubleDot]tzstellen \
sind Binomial-Darstellungen von Polynomen immer wieder vorteilhafte \
Interpolationen:\
\>", "Text"],

Cell["\<\
Es kommt auf eine m\[ODoubleDot]glichst geschickte Darstellungsform \
an,
damit weitere Zusammenh\[ADoubleDot]nge erkannt und vermittelt werden k\
\[ODoubleDot]nnen.
Das Bestehen der Proberechnung allein ist zu wenig f\[UDoubleDot]r ein gutes \
Ergebnis.\
\>", "Text",
  TextAlignment->Center,
  FontSlant->"Italic"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Grenzen der Interpolation"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". L\[ODoubleDot]sung algebraischer Gleichungen"
}], "Subsubsection"],

Cell[TextData[{
  "Sind auch bei g\[UDoubleDot]nstiger Wahl des Koordinatensystems mindestens \
",
  Cell[BoxData[
      \(n\)]],
  " verschiedene Ordinaten f\[UDoubleDot]r mindestens eine Abszisse \
vorhanden, so ist als Ergebnis der Interpolation eine ",
  Cell[BoxData[
      \(n\)]],
  "-te Wurzel aus einem zugeh\[ODoubleDot]rigen Interpolationspolynom zu \
erwarten. Der Rechenweg, der zu diesem Polynom und anschlie\[SZ]end zur ",
  Cell[BoxData[
      \(n\)]],
  "-ten Wurzel aus demselben f\[UDoubleDot]hrt, kann schnell ungenie\[SZ]bar \
werden \[Dash] besonders, wenn entsprechende L\[ODoubleDot]sungsans\
\[ADoubleDot]tze fehlen."
}], "Text"],

Cell[TextData[{
  "Eine algebraische Gleichung ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-ten Grades besitzt ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " Nullstellen und eine eindeutige Produktdarstellung darin. Diesen ",
  StyleBox["Fundamentalsatz der Algebra",
    FontSlant->"Italic"],
  " hat Carl Friedrich Gau\[SZ] (1777-1855) im Jahre 1799 im Rahmen seiner \
Doktorarbeit bewiesen."
}], "Text"],

Cell[TextData[{
  "Johann Faulhaber (1580-1635) konnte Gleichungen dritten Grades allgemein l\
\[ODoubleDot]sen. Ein anspruchsvolles Beispiel f\[UDoubleDot]r das Rechnen \
von Hand findet sich in seinem ersten Lehrwerk ",
  StyleBox["Arithmetisch Cubiccosischer Lustgarten",
    FontSlant->"Italic"],
  " aus dem Jahre 1604 (",
  ButtonBox["[Haw1995]",
    ButtonData:>"[Haw1995]",
    ButtonStyle->"Hyperlink"],
  ", Seite 150-153):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Solve[\(18  n\^3 + 3  n\^2 - 15  n\)\/6 \[Equal] 312456, n] // First
        \) // Union\)], "Input"],

Cell[BoxData[
    \({n \[Rule] 47}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "F\[UDoubleDot]r die Gleichungen vierten Grades existiert eine allgemeine \
Formel (vgl. ",
  ButtonBox["[GKHK1974]",
    ButtonData:>"[GKHK1974]",
    ButtonStyle->"Hyperlink"],
  ", Kapitel V, Seite 112) von Geronimo Cardano (1501-1576), die aufwendig zu \
handhaben ist. Ab den Gleichungen f\[UDoubleDot]nften und h\[ODoubleDot]heren \
Grades wird eine analytische L\[ODoubleDot]sung schwierig, obwohl sich \
andeutet, da\[SZ] derjenige, der die L\[ODoubleDot]sung der Gleichungen \
vierten Grades beherrscht, auch die Gleichungen f\[UDoubleDot]nften Grades \
knacken kann. Bereits die dritten Wurzeln k\[ODoubleDot]nnen bislang nicht \
gen\[UDoubleDot]gend allgemein gezogen werden, obwohl dort eine einfachere L\
\[ODoubleDot]sung vorhanden ist."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Statistisches Rauschen"
}], "Subsubsection"],

Cell[TextData[{
  "Ein Interpolationspolynom verbindet alle Punkte durch ein Polynom, das \
seinerseits eine arithmetische Folge und nicht eine Potenzreihe (unendliche \
Summe) darstellt. Potenzreihen ergeben sich bei ",
  StyleBox["transzendenten Funktionen",
    FontSlant->"Italic"],
  ", von denen die Funktionen ",
  Cell[BoxData[
      \(TraditionalForm\`Exp[x]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Sin[x]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Cos[x]\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`Log[x]\)]],
  " die bekanntesten sind."
}], "Text"],

Cell[TextData[{
  "Um bei einem vermuteten transzendenten Zusammenhang eine \
gegl\[UDoubleDot]ckte Interpolation vornehmen zu k\[ODoubleDot]nnen, ist eine \
",
  StyleBox["Datenspiegelung",
    FontSlant->"Italic"],
  " an den Randbereichen zu empfehlen, wodurch im Interpolationsbereich aus ",
  
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " Datenpunkten ",
  Cell[BoxData[
      \(TraditionalForm\`2  n\)]],
  " oder mehr Koeffizienten werden. Dieser Rechentrick ist umstritten, so da\
\[SZ] immer, wenn er ben\[ODoubleDot]tigt wird, von ",
  StyleBox["verrauschten Daten",
    FontSlant->"Italic"],
  " die Rede ist."
}], "Text"],

Cell[TextData[{
  "Die Ergebnisse von ",
  StyleBox["Zufallszahlen-Generatoren",
    FontSlant->"Italic"],
  " werden durch iterierte L\[ODoubleDot]sung von ",
  StyleBox["Differenzengleichungen",
    FontSlant->"Italic"],
  " erhalten, deren analytische ",
  StyleBox["L\[ODoubleDot]sung garantiert transzendent",
    FontSlant->"Italic"],
  " sein mu\[SZ]."
}], "Text"],

Cell[TextData[{
  "Ein Beispiel soll dies beleuchten, wobei aus didaktischen \
Gr\[UDoubleDot]nden ",
  StyleBox["Wertepaare",
    FontSlant->"Italic"],
  " und nicht einzelne Me\[SZ]werte angegeben werden:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SeedRandom[\ ]\), 
    \(daten[3] = {Range[20], Table[Random[Integer, {1, 100}], {20}]} // 
        Transpose\)}], "Input"],

Cell[BoxData[
    \({{1, 65}, {2, 82}, {3, 81}, {4, 95}, {5, 44}, {6, 56}, {7, 1}, {8, 
        57}, {9, 97}, {10, 2}, {11, 5}, {12, 65}, {13, 49}, {14, 14}, {15, 
        26}, {16, 49}, {17, 84}, {18, 39}, {19, 19}, {20, 35}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(punkte[3] = 
      ListPlot[daten[3], PlotStyle \[Rule] {PointSize[0.02], Hue[1]}, 
        DisplayFunction \[Rule] Identity]; \)\)], "Input"],

Cell["\<\
Die Interpolation ohne Datenspiegelung ergibt ein Verlassen des \
Wertebereichs:\
\>", "Text"],

Cell[BoxData[
    \(\(kurve[3] = 
      Plot[Evaluate[InterpolatingPolynomial[daten[3], x]], {x, 1, 20}, 
        PlotRange \[Rule] {\(-50\), 150}, DisplayFunction \[Rule] Identity]; 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[kurve[3], punkte[3], DisplayFunction \[Rule] $DisplayFunction]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.154508 0.00309017 [
[.2619 .14201 -5 -15 ]
[.2619 .14201 5 0 ]
[.5 .14201 -8 -15 ]
[.5 .14201 8 0 ]
[.7381 .14201 -8 -15 ]
[.7381 .14201 8 0 ]
[.97619 .14201 -8 -15 ]
[.97619 .14201 8 0 ]
[.01131 0 -25 -7.5 ]
[.01131 0 0 7.5 ]
[.01131 .07725 -25 -7.5 ]
[.01131 .07725 0 7.5 ]
[.01131 .23176 -16 -7.5 ]
[.01131 .23176 0 7.5 ]
[.01131 .30902 -16 -7.5 ]
[.01131 .30902 0 7.5 ]
[.01131 .38627 -16 -7.5 ]
[.01131 .38627 0 7.5 ]
[.01131 .46353 -22 -7.5 ]
[.01131 .46353 0 7.5 ]
[.01131 .54078 -22 -7.5 ]
[.01131 .54078 0 7.5 ]
[.01131 .61803 -22 -7.5 ]
[.01131 .61803 0 7.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .15451 m
.2619 .16076 L
s
gsave
.2619 .14201 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .15451 m
.5 .16076 L
s
gsave
.5 .14201 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 .15451 m
.7381 .16076 L
s
gsave
.7381 .14201 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 .15451 m
.97619 .16076 L
s
gsave
.97619 .14201 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 .15451 m
.07143 .15826 L
s
.11905 .15451 m
.11905 .15826 L
s
.16667 .15451 m
.16667 .15826 L
s
.21429 .15451 m
.21429 .15826 L
s
.30952 .15451 m
.30952 .15826 L
s
.35714 .15451 m
.35714 .15826 L
s
.40476 .15451 m
.40476 .15826 L
s
.45238 .15451 m
.45238 .15826 L
s
.54762 .15451 m
.54762 .15826 L
s
.59524 .15451 m
.59524 .15826 L
s
.64286 .15451 m
.64286 .15826 L
s
.69048 .15451 m
.69048 .15826 L
s
.78571 .15451 m
.78571 .15826 L
s
.83333 .15451 m
.83333 .15826 L
s
.88095 .15451 m
.88095 .15826 L
s
.92857 .15451 m
.92857 .15826 L
s
.25 Mabswid
0 .15451 m
1 .15451 L
s
.02381 0 m
.03006 0 L
s
gsave
.01131 0 -86 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02381 .07725 m
.03006 .07725 L
s
gsave
.01131 .07725 -86 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02381 .23176 m
.03006 .23176 L
s
gsave
.01131 .23176 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .30902 m
.03006 .30902 L
s
gsave
.01131 .30902 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .38627 m
.03006 .38627 L
s
gsave
.01131 .38627 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(75) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .46353 m
.03006 .46353 L
s
gsave
.01131 .46353 -83 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .54078 m
.03006 .54078 L
s
gsave
.01131 .54078 -83 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(125) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61803 m
.03006 .61803 L
s
gsave
.01131 .61803 -83 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.07143 .35496 m
0 0 rlineto s
.07143 .35496 m
.07146 0 L
s
.1184 0 m
.11947 .61803 L
s
.16392 .61803 m
.16704 .3806 L
.16942 .24546 L
.17202 .13252 L
.17316 .09344 L
.17438 .05854 L
.17551 .0318 L
.17656 .01205 L
s
.17656 .01205 m
.17741 0 L
s
.18601 0 m
.18703 .01041 L
.19632 .17058 L
.20119 .26525 L
.20631 .35335 L
.21082 .41411 L
.21337 .44025 L
.21575 .45895 L
.21687 .46597 L
.21794 .4715 L
.2189 .47563 L
.21993 .47909 L
.22104 .48183 L
.22207 .48343 L
.22317 .4842 L
.22439 .48397 L
.22554 .48276 L
.22679 .48042 L
.22797 .4773 L
.22907 .47367 L
.23334 .45392 L
.24295 .39089 L
.2513 .33616 L
.25599 .31176 L
.2603 .29514 L
.26242 .28915 L
.26474 .28427 L
.26592 .28245 L
.26717 .28097 L
.26835 .28001 L
.26943 .27949 L
.27053 .27929 L
.27154 .27938 L
.27266 .27979 L
.27384 .28053 L
.27486 .28143 L
.27582 .28247 L
.27801 .28546 L
.28293 .29461 L
.28743 .30451 L
.29234 .31508 L
.29504 .32014 L
.29757 .32411 L
.29993 .32694 L
.30126 .32812 L
.30248 .32892 L
.30351 .32936 L
.30465 .32961 L
.30583 .32958 L
.30693 .32928 L
Mistroke
.30806 .32871 L
.30913 .32792 L
.31009 .32699 L
.31113 .32575 L
.31346 .32211 L
.31562 .31769 L
.32016 .30529 L
.32517 .28732 L
.33531 .24204 L
.34428 .20054 L
.34916 .18086 L
.35371 .16601 L
.3561 .15988 L
.35865 .15478 L
.3601 .15258 L
.36082 .1517 L
.36148 .151 L
.36271 .15001 L
.36336 .14965 L
.36405 .1494 L
.36517 .14925 L
.36638 .14949 L
.36752 .15009 L
.36856 .15095 L
.36978 .15235 L
.37111 .15434 L
.37352 .15923 L
.37596 .16577 L
.37859 .1746 L
.38336 .19492 L
.39227 .24524 L
.40178 .30976 L
.41221 .3809 L
.41696 .40975 L
.42204 .43625 L
.42683 .45603 L
.42895 .46294 L
.4312 .46894 L
.43242 .47161 L
.43377 .47407 L
.435 .47587 L
.43613 .47713 L
.43682 .4777 L
.43747 .47812 L
.43815 .47843 L
.4389 .47862 L
.43955 .47864 L
.44025 .47852 L
.44149 .47796 L
.44215 .47748 L
Mistroke
.44276 .47693 L
.44412 .47529 L
.44533 .4734 L
.4466 .47096 L
.45123 .45829 L
.45364 .44945 L
.45593 .43977 L
.46023 .41849 L
.46988 .35903 L
.48729 .23635 L
.49645 .1793 L
.50148 .15363 L
.50619 .13408 L
.5102 .12132 L
.51245 .11576 L
.51451 .11171 L
.51665 .10859 L
.51786 .10729 L
.51898 .1064 L
.52017 .10578 L
.52126 .1055 L
.52251 .10552 L
.52369 .10587 L
.52479 .10647 L
.52596 .1074 L
.52707 .10857 L
.52809 .10986 L
.53057 .11392 L
.53292 .11889 L
.5376 .13174 L
.5427 .14965 L
.56022 .22935 L
.57067 .27846 L
.5805 .31772 L
.5848 .3316 L
.58933 .34372 L
.5917 .34897 L
.5943 .35385 L
.59649 .35723 L
.59887 .36016 L
.60017 .36143 L
.60137 .36241 L
.6025 .36314 L
.60374 .36377 L
.60485 .36415 L
.60589 .36437 L
.60699 .36445 L
.60817 .36437 L
.60938 .36411 L
.61007 .36389 L
Mistroke
.6107 .36363 L
.61199 .36296 L
.61337 .36205 L
.61586 .35987 L
.61813 .35734 L
.62256 .351 L
.62737 .34235 L
.63608 .32304 L
.65462 .27456 L
.66445 .24908 L
.675 .22457 L
.68019 .21413 L
.68512 .20551 L
.68992 .19849 L
.69436 .19336 L
.69653 .19139 L
.69856 .18988 L
.70068 .18865 L
.70181 .18816 L
.70303 .18775 L
.70417 .18748 L
.70542 .18733 L
.70606 .1873 L
.70673 .18732 L
.70795 .18745 L
.70917 .18772 L
.71031 .18811 L
.71135 .18856 L
.71247 .18918 L
.7147 .19076 L
.7171 .19301 L
.72144 .19852 L
.7266 .20738 L
.73132 .21752 L
.7513 .27286 L
.76003 .29529 L
.76254 .30053 L
.76491 .30479 L
.76706 .30802 L
.76934 .31071 L
.77056 .31183 L
.77189 .3128 L
.77311 .31342 L
.77424 .31379 L
.77493 .31391 L
.77558 .31395 L
.7768 .31384 L
.77749 .31367 L
.77812 .31345 L
.77881 .31313 L
Mistroke
.77955 .3127 L
.78187 .3108 L
.78405 .30828 L
.78903 .30026 L
.79837 .28073 L
.80064 .27626 L
.80307 .27215 L
.80446 .27022 L
.80573 .26881 L
.80634 .26827 L
.807 .26778 L
.80821 .26721 L
.8093 .26706 L
.81032 .26728 L
.81144 .26795 L
.81265 .26921 L
.81325 .27006 L
.81391 .27117 L
.81511 .2737 L
.81735 .2803 L
.81947 .28898 L
.82173 .30103 L
.82579 .3306 L
.83089 .38307 L
.83559 .44595 L
Mfstroke
.83559 .44595 m
.84579 .61803 L
s
.87444 .61803 m
.8752 .59052 L
.87757 .47898 L
.88007 .33316 L
s
.88007 .33316 m
.88453 0 L
s
.92811 0 m
.92848 .16573 L
s
.92848 .16573 m
.92927 .61803 L
s
.97614 .61803 m
.97619 .26299 L
s
1 0 0 r
.02 w
.07143 .35537 Mdot
.11905 .4079 Mdot
.16667 .40481 Mdot
.21429 .44807 Mdot
.2619 .29048 Mdot
.30952 .32756 Mdot
.35714 .1576 Mdot
.40476 .33065 Mdot
.45238 .45425 Mdot
.5 .16069 Mdot
.54762 .16996 Mdot
.59524 .35537 Mdot
.64286 .30593 Mdot
.69048 .19777 Mdot
.7381 .23485 Mdot
.78571 .30593 Mdot
.83333 .41408 Mdot
.88095 .27503 Mdot
.92857 .21322 Mdot
.97619 .26266 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012QP00`40o`000?l0003ooooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
017oool400001_ooo`@0003oooooT_ooo`004Oooo`050000oooooooooooo000000Coool200000_oo
o`80003oooooTOooo`005_ooo`050000oooooooooooo000000Coool00`000?ooooooo`3oooooSooo
o`005_ooo`030000oooooooo00800004oooo0P000?oooon@oooo0004oooo2@0000Woool00`000?oo
ooooo`0200001?ooo`80000:oooo0`0000ooool00`000?ooooooo`0@oooo00<0003oooooool05?oo
o`050000oooooooooooo00000?oooolCoooo00<0003oooooool03_ooo`030000oooooooo01koool0
01Goool200000_ooo`800004oooo0P0000[oool00`000?ooooooo`0?oooo00<0003oooooool04?oo
o`030000oooooooo01Coool01@000?ooooooooooo`00003ooooo4oooo`030000oooooooo00koool0
0`000?ooooooo`0Noooo000Doooo0`0000;oool200001?ooo`80000:oooo00<0003oooooool03ooo
o`030000oooooooo013oool00`000?ooooooo`0Doooo00D0003oooooooooool00000oooooa?oool0
0`000?ooooooo`0>oooo00<0003oooooool07_ooo`004Oooo`D00003oooo0P0000Coool200002_oo
o`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool05?ooo`050000oooooooo
oooo00000?oooolCoooo00<0003oooooool03_ooo`030000oooooooo01koool001;oool300001?oo
o`800004oooo0P0000[oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo
01Coool01@000?ooooooooooo`00003ooooo4oooo`030000oooooooo00koool00`000?ooooooo`0N
oooo000Boooo00<0003oooooool01Oooo`030000oooooooo00;oool00`000?ooooooo`09oooo00<0
003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Doooo00D0003oooooooooool0
0000oooooa?oool00`000?ooooooo`0>oooo00<0003oooooool07_ooo`004oooo`@00003oooo0P00
00;oool200002oooo`80000@oooo00<0003oooooool04?ooo`030000oooooooo01Coool01@000?oo
ooooooooo`00003ooooo4oooo`030000oooooooo00koool00`000?ooooooo`0Noooo000Coooo1000
00Coool400003?ooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool05?oo
o`050000oooooooooooo00000?oooolCoooo00<0003oooooool03_ooo`030000oooooooo01koool0
02_oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo01Coool01@000?oo
ooooooooo`00003ooooo4oooo`030000oooooooo00koool00`000?ooooooo`0Noooo000[oooo00<0
003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Coooo00<0003oooooool00_oo
o`030000oooooooo0?oooolAoooo00<0003oooooool03_ooo`030000oooooooo01koool002_oool0
0`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo01?oool00`000?ooooooo`02
oooo00<0003oooooool0oooooa7oool00`000?ooooooo`0>oooo00<0003oooooool07_ooo`00:ooo
o`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04oooo`030000oooooooo
00;oool00`000?ooooooo`3ooooo4Oooo`030000oooooooo00koool00`000?ooooooo`0Noooo000[
oooo0P00013oool00`000?ooooooo`0@oooo00<0003oooooool04oooo`030000oooooooo00?oool0
0`000?ooooooo`3ooooo4?ooo`030000oooooooo00koool00`000?ooooooo`0Noooo000[oooo00<0
003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Coooo00<0003oooooool00ooo
o`030000oooooooo0?ooool@oooo00<0003oooooool03_ooo`030000oooooooo01koool002_oool0
0`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo01?oool00`000?ooooooo`03
oooo00<0003oooooool0oooooa3oool00`000?ooooooo`0>oooo00<0003oooooool07_ooo`00:ooo
o`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04oooo`030000oooooooo
00?oool00`000?ooooooo`3ooooo4?ooo`030000oooooooo00koool00`000?ooooooo`0Noooo000[
oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Coooo00<0003ooooo
ool00oooo`030000oooooooo0?ooool@oooo00<0003oooooool03_ooo`030000oooooooo01koool0
02_oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo01?oool00`000?oo
ooooo`03oooo00<0003oooooool0oooooa3oool00`000?ooooooo`0>oooo00<0003oooooool07_oo
o`00:oooo`80000@oooo00<0003oooooool04?ooo`030000oooooooo01?oool00`000?ooooooo`03
oooo00<0003oooooool0oooooa3oool00`000?ooooooo`0>oooo00<0003oooooool07_ooo`00:ooo
o`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04oooo`030000oooooooo
00?oool00`000?ooooooo`3ooooo4?ooo`030000oooooooo00koool00`000?ooooooo`0Noooo000[
oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Coooo00<0003ooooo
ool00oooo`030000oooooooo0?ooool@oooo00<0003oooooool03_ooo`030000oooooooo01koool0
02_oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo01?oool00`000?oo
ooooo`03oooo00<0003oooooool0oooooa3oool00`000?ooooooo`0>oooo00<0003oooooool07_oo
o`00:oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04oooo`030000
oooooooo00?oool00`000?ooooooo`3ooooo4?ooo`030000oooooooo00koool00`000?ooooooo`0N
oooo000[oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Coooo00<0
003oooooool00oooo`030000oooooooo0?ooool@oooo00<0003oooooool03_ooo`030000oooooooo
01koool002_oool200004?ooo`030000oooooooo013oool00`000?ooooooo`0Coooo00<0003ooooo
ool00oooo`030000oooooooo0?ooool@oooo00<0003oooooool03_ooo`030000oooooooo01koool0
02_oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo01?oool00`000?oo
ooooo`03oooo00<0003oooooool0oooooa3oool00`000?ooooooo`0>oooo00<0003oooooool07_oo
o`00:oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04oooo`030000
oooooooo00?oool00`000?ooooooo`3ooooo4?ooo`030000oooooooo00koool00`000?ooooooo`0N
oooo000@oooo1`0000?oool400003Oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0
003oooooool04oooo`030000oooooooo00?oool00`000?ooooooo`3ooooo4?ooo`030000oooooooo
00koool00`000?ooooooo`0Noooo000Aoooo1`0000;oool01@000?ooooooooooo`00000<oooo00<0
003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Coooo00<0003oooooool01?oo
o`030000oooooooo0?ooool?oooo00<0003oooooool03_ooo`030000oooooooo01koool001;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00Woool00`000?ooooooo`0?
oooo00<0003oooooool04?ooo`030000oooooooo01?oool00`000?ooooooo`04oooo00<0003ooooo
ool0ooooo`ooool00`000?ooooooo`0>oooo00<0003oooooool07_ooo`004oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo0`0000ooool00`000?ooooooo`0@oooo00<0003oooooool04ooo
o`030000oooooooo00Coool00`000?ooooooo`3ooooo3oooo`030000oooooooo00koool00`000?oo
ooooo`0Noooo0004oooo2@0000Ooool00`000?ooooooo`08oooo00<0003oooooool02Oooo`030000
oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04oooo`030000oooooooo00Coool0
0`000?ooooooo`3ooooo3oooo`030000oooooooo00koool00`000?ooooooo`0Noooo000Doooo0P00
00Soool200002oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04ooo
o`030000oooooooo00Coool00`000?ooooooo`3ooooo3oooo`030000oooooooo00koool00`000?oo
ooooo`0Noooo000Eoooo00<0003oooooool01Oooo`<0000;oooo00<0003oooooool03oooo`030000
oooooooo013oool00`000?ooooooo`0Coooo00<0003oooooool01?ooo`030000oooooooo0?ooool>
oooo00<0003oooooool03oooo`030000oooooooo01koool001Goool200000oooo`D0000<oooo00<0
003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Coooo00<0003oooooool01?oo
o`030000oooooooo0?ooool>oooo00<0003oooooool03oooo`030000oooooooo01koool001Goool2
00001?ooo`<0000=oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0C
oooo00<0003oooooool01?ooo`030000oooooooo0?ooool>oooo00<0003oooooool03oooo`030000
oooooooo01koool0013oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P00
013oool00`000?ooooooo`0@oooo00<0003oooooool04oooo`030000oooooooo00Coool00`000?oo
ooooo`3ooooo3_ooo`030000oooooooo00ooool00`000?ooooooo`0Noooo000Aoooo00<0003ooooo
ool00`0000Goool400002oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003ooooo
ool04oooo`030000oooooooo00Coool00`000?ooooooo`3ooooo3_ooo`030000oooooooo00ooool0
0`000?ooooooo`0Noooo000Boooo100000Koool400002oooo`030000oooooooo00ooool00`000?oo
ooooo`0@oooo00<0003oooooool04oooo`030000oooooooo00Coool00`000?ooooooo`3ooooo3_oo
o`030000oooooooo00ooool00`000?ooooooo`0Noooo000[oooo00<0003oooooool03oooo`030000
oooooooo013oool00`000?ooooooo`0Coooo00<0003oooooool01?ooo`030000oooooooo0?ooool>
oooo00<0003oooooool03oooo`030000oooooooo01koool002_oool00`000?ooooooo`0?oooo00<0
003oooooool04?ooo`030000oooooooo01?oool00`000?ooooooo`04oooo00<0003oooooool0oooo
o`koool00`000?ooooooo`0?oooo00<0003oooooool07_ooo`00:oooo`030000oooooooo00ooool0
0`000?ooooooo`0@oooo00<0003oooooool04oooo`030000oooooooo00Coool00`000?ooooooo`0E
oooo100005Goool600001?ooo`@00003oooo00<0003oooooool0B_ooo`H00003oooo100003Coool0
0`000?ooooooo`0?oooo00<0003oooooool01oooo`L00004oooo100000Soool002_oool200004?oo
o`030000oooooooo013oool00`000?ooooooo`0Coooo00<0003oooooool01?ooo`030000oooooooo
01Goool01@000?ooooooooooo`00001Foooo0P0000Goool200000_ooo`@000000oooo`000?ooo`1<
oooo0P0000Goool01@000?ooooooooooo`00000coooo00<0003oooooool03oooo`030000oooooooo
00Soool700000_ooo`800002oooo0P0000Ooool002_oool00`000?ooooooo`0?oooo00<0003ooooo
ool04?ooo`030000oooooooo01?oool00`000?ooooooo`04oooo00<0003oooooool06_ooo`030000
oooooooo05?oool200001Oooo`030000oooooooo00;oool200000oooo`030000oooooooo04[oool2
00002_ooo`030000oooooooo033oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000
oooooooo00;oool010000?ooooooo`0000Coool00`000?ooooooo`05oooo000[oooo00<0003ooooo
ool03oooo`030000oooooooo013oool00`000?ooooooo`0Coooo00<0003oooooool01Oooo`030000
oooooooo01Woool00`000?ooooooo`1Coooo0P0000Coool200001?ooo`800004oooo00<0003ooooo
ool0BOooo`80000:oooo00<0003oooooool0<?ooo`030000oooooooo00ooool00`000?ooooooo`0:
oooo00<0003oooooool00oooo`800004oooo0P0000Koool002_oool00`000?ooooooo`0?oooo00<0
003oooooool04?ooo`030000oooooooo01;oool00`000?ooooooo`06oooo00<0003oooooool06Ooo
o`030000oooooooo05?oool200001?ooo`800003oooo0`0000Coool00`000?ooooooo`19oooo0P00
00[oool00`000?ooooooo`0`oooo00<0003oooooool03oooo`030000oooooooo00_oool00`000?oo
ooooo`02oooo0P0000Coool200001_ooo`00:oooo`030000oooooooo00ooool00`000?ooooooo`0@
oooo00<0003oooooool04_ooo`030000oooooooo00Koool00`000?ooooooo`0Hoooo0P0005Goool2
00001?ooo`800003oooo0`0000Goool00`000?ooooooo`18oooo0P0000Woool20000<_ooo`030000
oooooooo00ooool00`000?ooooooo`0;oooo0P0000?oool200001?ooo`800006oooo000[oooo00<0
003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Boooo00<0003oooooool01_oo
o`030000oooooooo01Ooool30000EOooo`800004oooo0P0000;oool010000?ooo`00000000Goool0
0`000?ooooooo`18oooo0P0000Soool30000<_ooo`030000oooooooo00ooool00`000?ooooooo`0<
oooo00@0003oooooooooool200001?ooo`800006oooo000[oooo00<0003oooooool03oooo`030000
oooooooo013oool00`000?ooooooo`0Boooo00<0003oooooool01_ooo`030000oooooooo01Coool5
0000E_ooo`800004oooo0P0000;oool010000?ooo`00000000Goool00`000?ooooooo`18oooo0P00
00Goool50000<oooo`030000oooooooo00ooool00`000?ooooooo`0<oooo0P0000;oool200001?oo
o`800006oooo000[oooo0P00013oool00`000?ooooooo`0@oooo00<0003oooooool04_ooo`030000
oooooooo00Koool00`000?ooooooo`0Eoooo0`0005Ooool200001?ooo`800002oooo00@0003oool0
00000006oooo00<0003oooooool0Aoooo`800006oooo0`0003Coool00`000?ooooooo`0?oooo00<0
003oooooool03?ooo`800002oooo0P0000Coool200001_ooo`00:oooo`030000oooooooo00ooool0
0`000?ooooooo`0@oooo00<0003oooooool04_ooo`030000oooooooo00Koool00`000?ooooooo`0E
oooo00<0003oooooool0Eoooo`800005oooo00H0003oooooool0003oool00007oooo00<0003ooooo
ool0Aoooo`800006oooo00<0003oooooool0=?ooo`030000oooooooo00ooool00`000?ooooooo`07
oooo00<0003oooooool00_ooo`800003oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
02_oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo01;oool00`000?oo
ooooo`06oooo00<0003oooooool05_ooo`@0001Coooo100000Goool3000000?oool0000000002?oo
o`030000oooooooo04Coool400001oooo`@0000boooo00<0003oooooool03oooo`030000oooooooo
00Soool00`000?ooooooo`0300000oooo`800002oooo0P0000Ooool002_oool00`000?ooooooo`0?
oooo00<0003oooooool04?ooo`030000oooooooo01;oool00`000?ooooooo`06oooo00<0003ooooo
ool05_ooo`@0001Eoooo0P0000Koool400002Oooo`030000oooooooo04Koool200001oooo`@0000b
oooo00<0003oooooool03oooo`030000oooooooo00Woool400001Oooo`@00008oooo000[oooo00<0
003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Boooo00<0003oooooool01_oo
o`030000oooooooo07Soool00`000?ooooooo`09oooo00<0003oooooool0QOooo`030000oooooooo
00ooool00`000?ooooooo`0Noooo000[oooo00<0003oooooool03oooo`030000oooooooo013oool0
0`000?ooooooo`0Boooo00<0003oooooool01_ooo`030000oooooooo07Soool00`000?ooooooo`0:
oooo00<0003oooooool0Q?ooo`030000oooooooo00ooool00`000?ooooooo`0Noooo000[oooo0P00
013oool00`000?ooooooo`0@oooo00<0003oooooool04_ooo`030000oooooooo00Koool00`000?oo
ooooo`1goooo00<0003oooooool02oooo`030000oooooooo08Coool00`000?ooooooo`0?oooo00<0
003oooooool07_ooo`00:oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003ooooo
ool04_ooo`030000oooooooo00Koool00`000?ooooooo`1goooo00<0003oooooool02oooo`030000
oooooooo08Coool00`000?ooooooo`0?oooo00<0003oooooool07_ooo`00:oooo`030000oooooooo
00ooool00`000?ooooooo`0@oooo00<0003oooooool04_ooo`030000oooooooo00Koool00`000?oo
ooooo`1goooo00<0003oooooool02oooo`030000oooooooo08Coool00`000?ooooooo`0?oooo00<0
003oooooool07_ooo`00:oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003ooooo
ool04_ooo`030000oooooooo00Koool00`000?ooooooo`1goooo00<0003oooooool03?ooo`030000
oooooooo08?oool00`000?ooooooo`0?oooo00<0003oooooool07_ooo`00:oooo`030000oooooooo
00ooool00`000?ooooooo`0@oooo00<0003oooooool04_ooo`030000oooooooo00Koool00`000?oo
ooooo`0ooooo0`0003Coool00`000?ooooooo`0=oooo00<0003oooooool0Poooo`030000oooooooo
00ooool00`000?ooooooo`0Noooo000[oooo00<0003oooooool03oooo`030000oooooooo013oool0
0`000?ooooooo`0Boooo00<0003oooooool01oooo`030000oooooooo03[oool4o`000oooo`030000
oooooooo037oool00`000?ooooooo`0=oooo00<0003oooooool0Poooo`030000oooooooo00ooool0
0`000?ooooooo`0Noooo000QooooRP0000Ko003k00001?ooo`00:oooo`030000oooooooo00ooool0
0`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooo000000Woool00`000?ooooooo`04
oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0=oooo1_l000?oool0
0`000?ooooooo`0:oooo00<0003oooooool03oooo`030000oooooooo00koool4o`004?ooo`80000B
oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003ooooo
ool04?ooo`030000oooooooo00ooool00`000?ooooooo`0@oooo0P00017oool00`000?ooooooo`0@
oooo00<0003oooooool02oooo`00:oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0
003oooooool04_ooo`030000oooooooo00Ooool00`000?ooooooo`0Foooo00<0003oooooool08?oo
o`Ko0003oooo00<0003oooooool0;?ooo`Ko000?oooo00<0003oooooool0BOooo`030000oooooooo
03Koool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool0
0`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo01;oool00`000?ooooooo`07
oooo00<0003oooooool0>_ooo`Co0005oooo00<0003oooooool0:oooo`Ko000?oooo00<0003ooooo
ool0P_ooo`030000oooooooo00ooool00`000?ooooooo`0Noooo000[oooo00<0003oooooool03ooo
o`030000oooooooo013oool00`000?ooooooo`0Boooo00<0003oooooool01oooo`030000oooooooo
03_oool2o`001_ooo`030000oooooooo02_oool6o`003_ooo`Co0022oooo00<0003oooooool03ooo
o`030000oooooooo01koool002_oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000
oooooooo01;oool00`000?ooooooo`07oooo00<0003oooooool0>oooo`030000oooooooo00Goool0
0`000?ooooooo`0/oooo1?l000koool6o`00POooo`030000oooooooo00ooool00`000?ooooooo`0N
oooo000[oooo0P00013oool00`000?ooooooo`0@oooo00<0003oooooool04_ooo`030000oooooooo
00Ooool00`000?ooooooo`0joooo00<0003oooooool01oooo`030000oooooooo02coool2o`003ooo
o`Ko0021oooo00<0003oooooool03oooo`030000oooooooo01koool002_oool00`000?ooooooo`0?
oooo00<0003oooooool04?ooo`030000oooooooo01;oool00`000?ooooooo`07oooo00<0003ooooo
ool0>_ooo`030000oooooooo00Ooool00`000?ooooooo`0/oooo00<0003oooooool03_ooo`Ko0021
oooo00<0003oooooool03oooo`030000oooooooo01koool002_oool00`000?ooooooo`0?oooo00<0
003oooooool04?ooo`030000oooooooo01;oool00`000?ooooooo`07oooo00<0003oooooool0>_oo
o`030000oooooooo00Ooool00`000?ooooooo`0/oooo00<0003oooooool03oooo`Co0022oooo00<0
003oooooool03oooo`030000oooooooo01koool002_oool00`000?ooooooo`0?oooo00<0003ooooo
ool04?ooo`030000oooooooo01;oool00`000?ooooooo`07oooo00<0003oooooool0>Oooo`030000
oooooooo00Soool00`000?ooooooo`0/oooo00<0003oooooool04?ooo`;o0023oooo00<0003ooooo
ool03oooo`030000oooooooo01koool002_oool00`000?ooooooo`0?oooo00<0003oooooool04?oo
o`030000oooooooo01;oool00`000?ooooooo`07oooo00<0003oooooool0>Oooo`030000oooooooo
00Woool00`000?ooooooo`0[oooo00<0003oooooool04_ooo`030000oooooooo083oool00`000?oo
ooooo`0?oooo00<0003oooooool07_ooo`00:oooo`030000oooooooo00ooool00`000?ooooooo`0@
oooo00<0003oooooool04_ooo`030000oooooooo00Ooool00`000?ooooooo`0ioooo00<0003ooooo
ool02Oooo`030000oooooooo02_oool00`000?ooooooo`0Boooo00<0003oooooool0P?ooo`030000
oooooooo00ooool00`000?ooooooo`0Noooo000[oooo0P00013oool00`000?ooooooo`0@oooo00<0
003oooooool04_ooo`030000oooooooo00Ooool00`000?ooooooo`0ioooo00<0003oooooool02Ooo
o`030000oooooooo02[oool00`000?ooooooo`0Coooo00<0003oooooool0P?ooo`030000oooooooo
00ooool00`000?ooooooo`0Noooo000[oooo00<0003oooooool03oooo`030000oooooooo013oool0
0`000?ooooooo`0Boooo00<0003oooooool01oooo`030000oooooooo03Soool00`000?ooooooo`0:
oooo00<0003oooooool0:_ooo`030000oooooooo01?oool00`000?ooooooo`0hoooo1P0004;oool0
0`000?ooooooo`0?oooo00<0003oooooool07_ooo`00:oooo`030000oooooooo00ooool00`000?oo
ooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo00Soool00`000?ooooooo`0hoooo00<0
003oooooool02oooo`030000oooooooo02Woool00`000?ooooooo`0Doooo00<0003oooooool0=_oo
o`030000oooooooo00Coool00`000?ooooooo`0ooooo00<0003oooooool03oooo`030000oooooooo
01koool002_oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo017oool0
0`000?ooooooo`08oooo00<0003oooooool0>?ooo`030000oooooooo00_oool00`000?ooooooo`0Y
oooo00<0003oooooool05?ooo`030000oooooooo037oool4o`0000<0003oooooool01_ooo`030000
oooooooo03koool00`000?ooooooo`0?oooo00<0003oooooool07_ooo`00:oooo`030000oooooooo
00ooool00`000?ooooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo00Woool00`000?oo
ooooo`0goooo00<0003oooooool02oooo`030000oooooooo02Woool00`000?ooooooo`0Doooo00<0
003oooooool0<?ooo`Ko0009oooo00<0003oooooool0?Oooo`030000oooooooo00ooool00`000?oo
ooooo`0Noooo000[oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0A
oooo00<0003oooooool02Oooo`030000oooooooo03Koool00`000?ooooooo`0<oooo00<0003ooooo
ool0:Oooo`030000oooooooo01Coool00`000?ooooooo`0`oooo1_l000Woool00`000?ooooooo`0m
oooo00<0003oooooool03oooo`030000oooooooo01koool002_oool200004?ooo`030000oooooooo
013oool00`000?ooooooo`0Aoooo00<0003oooooool02Oooo`030000oooooooo03Koool00`000?oo
ooooo`0<oooo00<0003oooooool0:?ooo`030000oooooooo01Koool00`000?ooooooo`0_oooo1_l0
00[oool00`000?ooooooo`0loooo00<0003oooooool03oooo`030000oooooooo01koool002_oool0
0`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`09
oooo00<0003oooooool0=_ooo`030000oooooooo00goool00`000?ooooooo`0Woooo00<0003ooooo
ool05_ooo`030000oooooooo033oool4o`002oooo`030000oooooooo03coool00`000?ooooooo`0?
oooo00<0003oooooool07_ooo`00:oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0
003oooooool04Oooo`030000oooooooo00Woool00`000?ooooooo`0foooo00<0003oooooool03Ooo
o`030000oooooooo02Ooool00`000?ooooooo`0Foooo00<0003oooooool0<?ooo`030000o`00o`00
00goool00`000?ooooooo`0koooo00<0003oooooool03oooo`030000oooooooo01koool002_oool0
0`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`09
oooo00<0003oooooool0=Oooo`030000oooooooo00koool00`000?ooooooo`0Woooo00<0003ooooo
ool05_ooo`030000oooooooo02ooool00`000?ooooooo`0>oooo00<0003oooooool0>oooo`030000
oooooooo00goool4o`007oooo`00:oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0
003oooooool04Oooo`030000oooooooo00Woool00`000?ooooooo`0eoooo00<0003oooooool03_oo
o`030000oooooooo02Ooool00`000?ooooooo`0Foooo00<0003oooooool0;oooo`030000oooooooo
00ooool00`000?ooooooo`0joooo00<0003oooooool03?ooo`Ko000Noooo000[oooo00<0003ooooo
ool03oooo`030000oooooooo013oool00`000?ooooooo`0Aoooo00<0003oooooool02Oooo`030000
oooooooo03Goool00`000?ooooooo`0>oooo00<0003oooooool09oooo`030000oooooooo01Ooool0
0`000?ooooooo`0]oooo00<0003oooooool04?ooo`030000oooooooo03[oool00`000?ooooooo`0<
oooo1_l001koool002_oool200004?ooo`030000oooooooo013oool00`000?ooooooo`0Aoooo00<0
003oooooool02Oooo`030000oooooooo03Goool00`000?ooooooo`0?oooo00<0003oooooool09Ooo
o`030000oooooooo01Soool00`000?ooooooo`0]oooo00<0003oooooool04Oooo`030000oooooooo
03Woool00`000?ooooooo`0<oooo1_l001koool002_oool00`000?ooooooo`0?oooo00<0003ooooo
ool04?ooo`030000oooooooo017oool00`000?ooooooo`09oooo00<0003oooooool0=?ooo`030000
oooooooo013oool00`000?ooooooo`0Uoooo00<0003oooooool06?ooo`030000oooooooo02coool0
0`000?ooooooo`0Boooo00<0003oooooool0>Oooo`030000oooooooo00goool4o`007oooo`004Ooo
o`L00003oooo100000coool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo
017oool00`000?ooooooo`09oooo00<0003oooooool0=?ooo`030000oooooooo013oool00`000?oo
ooooo`0Uoooo00<0003oooooool06?ooo`030000oooooooo02coool00`000?ooooooo`0Boooo00<0
003oooooool0>Oooo`030000oooooooo00koool2o`008?ooo`004_ooo`L00002oooo00D0003ooooo
ooooool000002oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04Ooo
o`030000oooooooo00Woool00`000?ooooooo`0doooo00<0003oooooool04?ooo`030000oooooooo
02Goool00`000?ooooooo`0Ioooo00<0003oooooool0:_ooo`030000oooooooo01Coool00`000?oo
ooooo`0hoooo00<0003oooooool03oooo`030000oooooooo01koool001?oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`030000oooooooo00Soool00`000?ooooooo`0?oooo00<0003ooooo
ool04?ooo`030000oooooooo017oool00`000?ooooooo`09oooo00<0003oooooool0=?ooo`030000
oooooooo017oool00`000?ooooooo`0Toooo00<0003oooooool06Oooo`030000oooooooo02[oool0
0`000?ooooooo`0Doooo00<0003oooooool0>?ooo`030000oooooooo00ooool00`000?ooooooo`0N
oooo000Doooo00<0003oooooool02Oooo`030000oooooooo00Soool00`000?ooooooo`0?oooo00<0
003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`09oooo00<0003oooooool0<ooo
o`030000oooooooo01;oool00`000?ooooooo`0Toooo00<0003oooooool06Oooo`030000oooooooo
02Woool00`000?ooooooo`0Foooo00<0003oooooool0=oooo`030000oooooooo00ooool00`000?oo
ooooo`0Noooo000Eoooo00<0003oooooool02?ooo`030000oooooooo00Soool300003oooo`030000
oooooooo013oool00`000?ooooooo`0Aoooo00<0003oooooool02Oooo`030000oooooooo03?oool0
0`000?ooooooo`0Boooo00<0003oooooool08oooo`030000oooooooo01[oool00`000?ooooooo`0Y
oooo00<0003oooooool05Oooo`Co000goooo00<0003oooooool03oooo`030000oooooooo01koool0
01Goool200002?ooo`80000:oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?oo
ooooo`0Aoooo00<0003oooooool02Oooo`030000oooooooo03?oool00`000?ooooooo`0Boooo00<0
003oooooool08oooo`030000oooooooo01[oool00`000?ooooooo`0Xoooo00<0003oooooool05Ooo
o`Ko000foooo00<0003oooooool03oooo`030000oooooooo01koool001Koool00`000?ooooooo`05
oooo0`0000[oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo017oool0
0`000?ooooooo`09oooo00<0003oooooool0<oooo`030000oooooooo01;oool00`000?ooooooo`0S
oooo00<0003oooooool06oooo`030000oooooooo02Ooool00`000?ooooooo`0Eoooo1_l003Koool0
0`000?ooooooo`0?oooo00<0003oooooool07_ooo`005_ooo`800003oooo1@0000_oool00`000?oo
ooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`09oooo00<0
003oooooool0<_ooo`030000oooooooo01Coool00`000?ooooooo`0Roooo00<0003oooooool06ooo
o`030000oooooooo02Ooool00`000?ooooooo`0Eoooo1_l003Koool00`000?ooooooo`0?oooo00<0
003oooooool07_ooo`005_ooo`800004oooo0`0000coool00`000?ooooooo`0?oooo00<0003ooooo
ool04?ooo`030000oooooooo017oool00`000?ooooooo`0:oooo00<0003oooooool0<Oooo`030000
oooooooo01Coool00`000?ooooooo`0Roooo00<0003oooooool06oooo`030000oooooooo02Koool0
0`000?ooooooo`0Goooo1?l003Ooool00`000?ooooooo`0?oooo00<0003oooooool07_ooo`004Ooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00coool00`000?ooooooo`0?oooo00<0
003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`0:oooo00<0003oooooool0<Ooo
o`030000oooooooo01Coool00`000?ooooooo`0Roooo00<0003oooooool06oooo`030000oooooooo
02Koool00`000?ooooooo`0Hoooo0_l000030000oooooooo03Goool00`000?ooooooo`0?oooo00<0
003oooooool07_ooo`004_ooo`030000oooooooo00<00005oooo100000[oool200004?ooo`030000
oooooooo013oool00`000?ooooooo`0Aoooo00<0003oooooool02_ooo`030000oooooooo037oool0
0`000?ooooooo`0Doooo00<0003oooooool08Oooo`030000oooooooo01coool00`000?ooooooo`0U
oooo00<0003oooooool06oooo`030000oooooooo03Goool00`000?ooooooo`0?oooo00<0003ooooo
ool07_ooo`004oooo`@00006oooo100000[oool00`000?ooooooo`0?oooo00<0003oooooool04?oo
o`030000oooooooo017oool00`000?ooooooo`0:oooo00<0003oooooool0<?ooo`030000oooooooo
01Goool00`000?ooooooo`0Qoooo00<0003oooooool07Oooo`030000oooooooo02Coool00`000?oo
ooooo`0Loooo00<0003oooooool0=?ooo`030000oooooooo00ooool00`000?ooooooo`0Noooo000[
oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0Aoooo00<0003ooooo
ool02_ooo`030000oooooooo033oool00`000?ooooooo`0Eoooo00<0003oooooool08Oooo`030000
oooooooo01goool00`000?ooooooo`0Toooo00<0003oooooool07?ooo`030000oooooooo03?oool0
0`000?ooooooo`0@oooo00<0003oooooool07_ooo`00:oooo`030000oooooooo00ooool00`000?oo
ooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo00[oool00`000?ooooooo`0`oooo00<0
003oooooool05_ooo`030000oooooooo023oool00`000?ooooooo`0Moooo00<0003oooooool08ooo
o`030000oooooooo01goool00`000?ooooooo`0coooo00<0003oooooool04?ooo`030000oooooooo
01koool002_oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo017oool0
0`000?ooooooo`0:oooo00<0003oooooool0<?ooo`030000oooooooo01Koool00`000?ooooooo`0P
oooo00<0003oooooool07Oooo`030000oooooooo02?oool00`000?ooooooo`0Noooo00<0003ooooo
ool0<_ooo`030000oooooooo013oool00`000?ooooooo`0Noooo000[oooo00<0003oooooool03ooo
o`030000oooooooo013oool00`000?ooooooo`0Aoooo00<0003oooooool02_ooo`030000oooooooo
02ooool00`000?ooooooo`0Goooo00<0003oooooool08?ooo`030000oooooooo01goool00`000?oo
ooooo`0Roooo00<0003oooooool07oooo`030000oooooooo03;oool00`000?ooooooo`0@oooo00<0
003oooooool03Oooo`Co000=oooo000[oooo0P00013oool00`000?ooooooo`0@oooo00<0003ooooo
ool04Oooo`030000oooooooo00[oool00`000?ooooooo`0_oooo00<0003oooooool05oooo`030000
oooooooo023oool00`000?ooooooo`0Noooo00<0003oooooool08Oooo`030000oooooooo01ooool0
0`000?ooooooo`0boooo00<0003oooooool04?ooo`030000oooooooo00coool6o`003?ooo`00:ooo
o`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo
00[oool00`000?ooooooo`0_oooo00<0003oooooool05oooo`030000oooooooo01ooool00`000?oo
ooooo`0Ooooo00<0003oooooool08Oooo`030000oooooooo023oool00`000?ooooooo`0aoooo00<0
003oooooool04?ooo`030000oooooooo00coool6o`003?ooo`00:oooo`030000oooooooo00ooool0
0`000?ooooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo00[oool00`000?ooooooo`0_
oooo00<0003oooooool05oooo`030000oooooooo01ooool00`000?ooooooo`0Ooooo00<0003ooooo
ool08?ooo`030000oooooooo027oool00`000?ooooooo`0Doooo0`0001[oool00`000?ooooooo`0@
oooo00<0003oooooool03?ooo`Ko000<oooo000[oooo00<0003oooooool03oooo`030000oooooooo
013oool00`000?ooooooo`0Aoooo00<0003oooooool02_ooo`030000oooooooo02ooool00`000?oo
ooooo`0Hoooo00<0003oooooool07_ooo`030000oooooooo01ooool00`000?ooooooo`0Poooo00<0
003oooooool08_ooo`030000oooooooo01;oool2000000?oool0000000006Oooo`030000oooooooo
013oool00`000?ooooooo`0=oooo1?l000goool002_oool00`000?ooooooo`0?oooo00<0003ooooo
ool04?ooo`030000oooooooo017oool00`000?ooooooo`0:oooo00<0003oooooool0;_ooo`030000
oooooooo01Woool00`000?ooooooo`0Noooo00<0003oooooool07oooo`030000oooooooo01ooool0
0`000?ooooooo`0Soooo00<0003oooooool04_ooo`050000oooooooooooo000001Ooool4o`004Ooo
o`030000oooooooo00koool2o`0000<0003oooooool02oooo`00:oooo`030000oooooooo00ooool0
0`000?ooooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo00[oool00`000?ooooooo`0^
oooo00<0003oooooool06Oooo`030000oooooooo01koool00`000?ooooooo`0Poooo00<0003ooooo
ool07_ooo`030000oooooooo02?oool00`000?ooooooo`0Boooo00D0003oooooooooool000005_oo
o`Ko000@oooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool200004?ooo`030000
oooooooo013oool00`000?ooooooo`0Aoooo00<0003oooooool02_ooo`030000oooooooo02koool0
0`000?ooooooo`0Ioooo00<0003oooooool07_ooo`030000oooooooo023oool00`000?ooooooo`0N
oooo00<0003oooooool09?ooo`030000oooooooo013oool00`000?ooooooo`03oooo00<0003ooooo
ool04oooo`Ko000@oooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?oo
ooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`0:oooo00<0
003oooooool05oooo`<0000Doooo00<0003oooooool06Oooo`030000oooooooo01koool00`000?oo
ooooo`0Poooo00<0003oooooool07Oooo`030000oooooooo02Goool00`000?ooooooo`0?oooo00<0
003oooooool01?ooo`030000oooooooo01?oool6o`004?ooo`030000oooooooo013oool00`000?oo
ooooo`0;oooo000[oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0A
oooo00<0003oooooool02_ooo`030000oooooooo01Koool200000_ooo`030000oooooooo013oool0
0`000?ooooooo`0Joooo00<0003oooooool07Oooo`030000oooooooo027oool00`000?ooooooo`0M
oooo00<0003oooooool09_ooo`030000oooooooo00koool00`000?ooooooo`04oooo00<0003ooooo
ool05?ooo`Co000Aoooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?oo
ooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`0:oooo00<0
003oooooool05_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool06_oo
o`030000oooooooo01goool00`000?ooooooo`0Roooo00<0003oooooool07?ooo`030000oooooooo
02Koool00`000?ooooooo`0=oooo00<0003oooooool01_ooo`030000oooooooo01Coool2o`004_oo
o`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool03oooo`030000
oooooooo013oool00`000?ooooooo`0Aoooo00<0003oooooool02oooo`030000oooooooo017oool4
o`0000<0003oooooool00oooo`030000oooooooo00koool00`000?ooooooo`0Koooo00<0003ooooo
ool07?ooo`030000oooooooo02;oool00`000?ooooooo`0Koooo00<0003oooooool0:?ooo`030000
oooooooo00coool00`000?ooooooo`06oooo00<0003oooooool05Oooo`030000oooooooo013oool0
0`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo00ooool00`000?oo
ooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo00_oool00`000?ooooooo`0@oooo1_l0
00Goool00`000?ooooooo`0>oooo00<0003oooooool06oooo`030000oooooooo01coool00`000?oo
ooooo`0Roooo00<0003oooooool06oooo`030000oooooooo02Soool00`000?ooooooo`0;oooo00<0
003oooooool01oooo`030000oooooooo01Goool00`000?ooooooo`0@oooo00<0003oooooool04?oo
o`030000oooooooo00_oool002_oool200004?ooo`030000oooooooo013oool00`000?ooooooo`0A
oooo00<0003oooooool02oooo`030000oooooooo013oool6o`001_ooo`030000oooooooo00coool0
0`000?ooooooo`0Loooo00<0003oooooool07?ooo`030000oooooooo02;oool00`000?ooooooo`0J
oooo00<0003oooooool0:_ooo`030000oooooooo00[oool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`00:ooo
o`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo
00_oool00`000?ooooooo`0@oooo1_l000Koool00`000?ooooooo`0<oooo00<0003oooooool07?oo
o`030000oooooooo01coool00`000?ooooooo`0Soooo00<0003oooooool06Oooo`030000oooooooo
02[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Coool00`000?oo
ooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0?
oooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`0;oooo00<0003ooooo
ool04Oooo`Co0008oooo00<0003oooooool02oooo`030000oooooooo01coool00`000?ooooooo`0L
oooo00<0003oooooool08oooo`030000oooooooo01Woool00`000?ooooooo`0[oooo00<0003ooooo
ool02?ooo`030000oooooooo00Woool00`000?ooooooo`0Doooo00<0003oooooool04?ooo`030000
oooooooo013oool00`000?ooooooo`0;oooo000Boooo100000Koool400002oooo`030000oooooooo
00ooool00`000?ooooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo00_oool00`000?oo
ooooo`0Boooo0_l000Woool00`000?ooooooo`0;oooo00<0003oooooool07?ooo`030000oooooooo
01_oool00`000?ooooooo`0Toooo00<0003oooooool06?ooo`030000oooooooo02coool00`000?oo
ooooo`07oooo00<0003oooooool02_ooo`030000oooooooo01Coool00`000?ooooooo`0@oooo00<0
003oooooool04?ooo`030000oooooooo00_oool001;oool01@000?ooooooooooo`000004oooo0P00
00;oool200002_ooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04Ooo
o`030000oooooooo00_oool00`000?ooooooo`0Boooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0Noooo00<0003oooooool06_ooo`030000oooooooo02Coool00`000?oo
ooooo`0Eoooo1?l002ooool00`000?ooooooo`02oooo1?l000goool00`000?ooooooo`0Doooo00<0
003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000Goooo00D0003ooooo
ooooool000001?ooo`030000oooooooo00Soool00`000?ooooooo`0?oooo00<0003oooooool04?oo
o`030000oooooooo017oool00`000?ooooooo`0;oooo00<0003oooooool04_ooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool07_ooo`030000oooooooo01[oool00`000?oo
ooooo`0Uoooo00<0003oooooool04oooo`Ko000^oooo00@0003oooooooooool6o`003?ooo`030000
oooooooo01Coool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00_oool0
01Ooool00`000?ooooooo`0200001?ooo`800009oooo00<0003oooooool03oooo`030000oooooooo
013oool00`000?ooooooo`0Aoooo00<0003oooooool02oooo`030000oooooooo01;oool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01koool00`000?ooooooo`0Joooo00<0
003oooooool09Oooo`030000oooooooo01?oool6o`00;_ooo`040000oooooooooooo1_l000coool0
0`000?ooooooo`0Doooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0;
oooo000Goooo00<0003oooooool00P0000Coool200002Oooo`<0000?oooo00<0003oooooool04?oo
o`030000oooooooo017oool00`000?ooooooo`0;oooo00<0003oooooool04Oooo`030000oooooooo
00_oool00`000?ooooooo`08oooo00<0003oooooool07_ooo`030000oooooooo01[oool00`000?oo
ooooo`0Uoooo00<0003oooooool04oooo`Ko000_oooo00<0003oooooool01_l000goool00`000?oo
ooooo`0Coooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000F
oooo0P0000;oool200001?ooo`800009oooo00<0003oooooool03oooo`030000oooooooo013oool0
0`000?ooooooo`0Aoooo00<0003oooooool02oooo`030000oooooooo017oool00`000?ooooooo`0;
oooo00<0003oooooool01oooo`030000oooooooo01ooool00`000?ooooooo`0Joooo00<0003ooooo
ool09Oooo`030000oooooooo01Coool4o`00<Oooo`<00004o`003_ooo`030000oooooooo01?oool0
0`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00_oool001Goool300000_oo
o`800004oooo0P0000Woool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo
013oool00`000?ooooooo`0<oooo00<0003oooooool04Oooo`030000oooooooo00_oool00`000?oo
ooooo`07oooo00<0003oooooool07oooo`030000oooooooo01Woool00`000?ooooooo`0Woooo00<0
003oooooool05?ooo`;o000doooo00@0003ooooo003o000?oooo00<0003oooooool04oooo`030000
oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`004_ooo`D00003oooo0P00
00Coool200002Oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04?oo
o`030000oooooooo00coool00`000?ooooooo`0Aoooo00<0003oooooool03?ooo`030000oooooooo
00Koool00`000?ooooooo`0Ooooo00<0003oooooool06Oooo`030000oooooooo02Ooool00`000?oo
ooooo`0Doooo00<0003oooooool0A_ooo`030000oooooooo01?oool00`000?ooooooo`0@oooo00<0
003oooooool04?ooo`030000oooooooo00_oool001?oool300001?ooo`800004oooo0P0000Woool0
0`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0<
oooo00<0003oooooool04?ooo`030000oooooooo00koool00`000?ooooooo`05oooo00<0003ooooo
ool08?ooo`030000oooooooo01Soool00`000?ooooooo`0Woooo00<0003oooooool04oooo`030000
oooooooo04Ooool00`000?ooooooo`0Coooo00<0003oooooool04?ooo`030000oooooooo013oool0
0`000?ooooooo`0;oooo000Coooo00<0003oooooool01Oooo`030000oooooooo00;oool00`000?oo
ooooo`08oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0@oooo00<0
003oooooool03?ooo`030000oooooooo013oool00`000?ooooooo`0>oooo00<0003oooooool01?l0
00030000oooooooo027oool00`000?ooooooo`0Hoooo00<0003oooooool0:?ooo`030000oooooooo
01;oool00`000?ooooooo`17oooo00<0003oooooool04oooo`030000oooooooo013oool00`000?oo
ooooo`0@oooo00<0003oooooool02oooo`005?ooo`@00003oooo0P0000;oool200002_ooo`80000@
oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0<oooo00<0003ooooo
ool04?ooo`030000oooooooo00koool00`000?ooool00005o`008oooo`030000oooooooo01Soool0
0`000?ooooooo`0Xoooo00<0003oooooool04_ooo`030000oooooooo04Soool00`000?ooooooo`0B
oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000Doooo1000
00Coool400002oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04?oo
o`030000oooooooo00coool00`000?ooooooo`0@oooo00<0003oooooool03oooo`030000o`00o`00
00Co000Poooo1?l001[oool00`000?ooooooo`0Yoooo00<0003oooooool04?ooo`030000oooooooo
04Woool00`000?ooooooo`0Boooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?oo
ooooo`0;oooo000[oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0@
oooo00<0003oooooool03?ooo`030000oooooooo00ooool00`000?ooooooo`0Aoooo1_l001ooool6
o`006Oooo`030000oooooooo02Woool00`000?ooooooo`0@oooo00<0003oooooool0BOooo`030000
oooooooo01;oool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00_oool0
02_oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?oo
ooooo`0=oooo00<0003oooooool03_ooo`030000oooooooo01;oool4o`008?ooo`Ko000Hoooo00<0
003oooooool0:_ooo`030000oooooooo00ooool00`000?ooooooo`1:oooo00<0003oooooool04_oo
o`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000
oooooooo00ooool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00goool0
0`000?ooooooo`0>oooo00<0003oooooool04oooo`;o000Qoooo1_l001Soool00`000?ooooooo`0Z
oooo00<0003oooooool03oooo`030000oooooooo04[oool00`000?ooooooo`0Boooo00<0003ooooo
ool04?ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool03ooo
o`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool03Oooo`030000oooooooo
00koool00`000?ooooooo`0goooo1?l000030000oooooooo01Koool00`000?ooooooo`0[oooo00<0
003oooooool03Oooo`030000oooooooo04_oool00`000?ooooooo`0Boooo00<0003oooooool04?oo
o`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo0P00013oool00`000?ooooooo`0@
oooo00<0003oooooool04?ooo`030000oooooooo00goool00`000?ooooooo`0>oooo00<0003ooooo
ool0>?ooo`;o00000oooo`000?ooo`0Goooo00<0003oooooool0:oooo`030000oooooooo00goool0
0`000?ooooooo`1;oooo00<0003oooooool04_ooo`030000oooooooo013oool00`000?ooooooo`0@
oooo00<0003oooooool02oooo`00:oooo`030000oooooooo00ooool00`000?ooooooo`0@oooo00<0
003oooooool04?ooo`030000oooooooo00goool00`000?ooooooo`0>oooo00<0003oooooool0>ooo
o`030000oooooooo01Koool00`000?ooooooo`0[oooo00<0003oooooool03?ooo`030000oooooooo
04coool00`000?ooooooo`0Boooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?oo
ooooo`0;oooo000[oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0@
oooo00<0003oooooool03Oooo`030000oooooooo00goool00`000?ooooooo`0loooo00<0003ooooo
ool05_ooo`030000oooooooo02coool00`000?ooooooo`0:oooo00<0003oooooool0C_ooo`030000
oooooooo017oool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00_oool0
02_oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?oo
ooooo`0=oooo00<0003oooooool03Oooo`030000oooooooo03coool00`000?ooooooo`0Foooo00<0
003oooooool0;?ooo`030000oooooooo00[oool00`000?ooooooo`1>oooo00<0003oooooool04Ooo
o`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000
oooooooo00goool4o`004Oooo`030000oooooooo013oool00`000?ooooooo`0=oooo00<0003ooooo
ool03Oooo`030000oooooooo03coool00`000?ooooooo`0Eoooo00<0003oooooool0;?ooo`Co0009
oooo00<0003oooooool0Coooo`030000oooooooo017oool00`000?ooooooo`0@oooo00<0003ooooo
ool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0<oooo1_l0013oool00`000?oo
ooooo`0@oooo00<0003oooooool03Oooo`030000oooooooo00goool00`000?ooooooo`0loooo00<0
003oooooool05Oooo`030000oooooooo02_oool6o`002?ooo`030000oooooooo04ooool00`000?oo
ooooo`0Aoooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[
oooo0P0000goool6o`004?ooo`030000oooooooo013oool00`000?ooooooo`0=oooo00<0003ooooo
ool03Oooo`030000oooooooo03goool00`000?ooooooo`0Doooo00<0003oooooool0:oooo`Ko0007
oooo00<0003oooooool0D?ooo`030000oooooooo017oool00`000?ooooooo`0@oooo00<0003ooooo
ool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0<oooo1_l0013oool00`000?oo
ooooo`0@oooo00<0003oooooool03Oooo`030000oooooooo00goool00`000?ooooooo`0moooo00<0
003oooooool05?ooo`030000oooooooo02_oool6o`001oooo`030000oooooooo053oool00`000?oo
ooooo`0Aoooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[
oooo00<0003oooooool03Oooo`Co000Aoooo00<0003oooooool04?ooo`030000oooooooo00goool0
0`000?ooooooo`0=oooo00<0003oooooool0?Oooo`030000oooooooo01Coool00`000?ooooooo`0/
oooo1?l000800004oooo0P0005?oool00`000?ooooooo`0Aoooo00<0003oooooool04?ooo`030000
oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool03_ooo`;o000Boooo00<0
003oooooool04?ooo`030000oooooooo00goool00`000?ooooooo`0=oooo00<0003oooooool0?Ooo
o`030000oooooooo01Coool00`000?ooooooo`0]oooo0_l000;oool50000EOooo`030000oooooooo
017oool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool0
0`000?ooooooo`0Roooo00<0003oooooool04?ooo`030000oooooooo00goool00`000?ooooooo`0<
oooo00<0003oooooool0?_ooo`030000oooooooo01Coool00`000?ooooooo`2;oooo00<0003ooooo
ool04Oooo`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`00:ooo
o`030000oooooooo02;oool00`000?ooooooo`0@oooo00<0003oooooool03Oooo`030000oooooooo
00coool00`000?ooooooo`0noooo00<0003oooooool05?ooo`030000oooooooo08_oool00`000?oo
ooooo`0Aoooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[
oooo0P0002?oool00`000?ooooooo`0@oooo00<0003oooooool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0noooo00<0003oooooool04oooo`030000oooooooo08goool00`000?ooooooo`0@
oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0
003oooooool08_ooo`030000oooooooo013oool00`000?ooooooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo03ooool00`000?ooooooo`0Boooo00<0003oooooool0SOooo`030000oooooooo
013oool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00_oool001Coool0
0`000?ooooooo`04oooo100000coool00`000?ooooooo`0Roooo00<0003oooooool04?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool0?oooo`030000oooooooo01;oool0
0`000?ooooooo`2=oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0@
oooo00<0003oooooool02oooo`005Oooo`030000oooooooo00?oool01@000?ooooooooooo`00000;
oooo00<0003oooooool08_ooo`030000oooooooo013oool00`000?ooooooo`0=oooo00<0003ooooo
ool03?ooo`030000oooooooo03ooool00`000?ooooooo`0Boooo00<0003oooooool0SOooo`030000
oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00_oool0
01Goool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo02;oool00`000?oo
ooooo`0@oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0ooooo00<0
003oooooool04_ooo`030000oooooooo08goool00`000?ooooooo`0@oooo00<0003oooooool04?oo
o`030000oooooooo013oool00`000?ooooooo`0;oooo000Eoooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`0Roooo00<0003oooooool04?ooo`030000oooooooo00goool0
0`000?ooooooo`0;oooo00<0003oooooool0@?ooo`030000oooooooo01;oool00`000?ooooooo`2=
oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003ooooo
ool02oooo`005_ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo0`0002;oool00`000?oo
ooooo`0@oooo00<0003oooooool03_ooo`030000oooooooo00[oool00`000?ooooooo`10oooo00<0
003oooooool04_ooo`030000oooooooo08goool00`000?ooooooo`0@oooo00<0003oooooool04?oo
o`030000oooooooo013oool00`000?ooooooo`0;oooo000Foooo00<0003oooooool01_ooo`80000:
oooo00<0003oooooool08_ooo`030000oooooooo013oool00`000?ooooooo`0>oooo00<0003ooooo
ool02_ooo`030000oooooooo047oool00`000?ooooooo`0Aoooo00<0003oooooool0SOooo`030000
oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00_oool0
01Ooool00`000?ooooooo`04oooo0`0000[oool00`000?ooooooo`0Roooo00<0003oooooool04?oo
o`030000oooooooo00koool00`000?ooooooo`0:oooo00<0003oooooool0@Oooo`030000oooooooo
013oool00`000?ooooooo`2>oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?oo
ooooo`0@oooo00<0003oooooool02oooo`005oooo`040000oooooooooooo1@0000_oool00`000?oo
ooooo`0Roooo00<0003oooooool04?ooo`030000oooooooo00koool00`000?ooooooo`0:oooo00<0
003oooooool0@Oooo`030000oooooooo013oool00`000?ooooooo`2>oooo00<0003oooooool04?oo
o`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`005oooo`030000
oooooooo00;oool300003?ooo`030000oooooooo02;oool00`000?ooooooo`0@oooo00<0003ooooo
ool03_ooo`030000oooooooo00[oool00`000?ooooooo`11oooo00<0003oooooool04?ooo`030000
oooooooo08koool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo013oool0
0`000?ooooooo`0;oooo000Aoooo00<0003oooooool01?ooo`050000oooooooooooo000000koool0
0`000?ooooooo`0Roooo00<0003oooooool04?ooo`030000oooooooo00koool00`000?ooooooo`0:
oooo00<0003oooooool0@Oooo`030000oooooooo013oool00`000?ooooooo`2>oooo00<0003ooooo
ool04?ooo`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`004_oo
o`L00004oooo100000[oool200008oooo`030000oooooooo00koool4o`003oooo`030000oooooooo
00Woool00`000?ooooooo`12oooo00<0003oooooool04?ooo`030000oooooooo08koool00`000?oo
ooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000B
oooo200000?oool400002_ooo`030000oooooooo023oool4o`003_ooo`Ko000>oooo00<0003ooooo
ool02Oooo`030000oooooooo04?oool00`000?ooooooo`0?oooo00<0003oooooool0S_ooo`030000
oooooooo013oool00`000?ooooooo`0@oooo00<0003oooooool04?ooo`030000oooooooo00_oool0
02_oool00`000?ooooooo`0Ooooo1_l000goool6o`003_ooo`030000oooooooo00Woool00`000?oo
ooooo`13oooo00<0003oooooool03oooo`030000oooooooo08koool00`000?ooooooo`0?oooo00<0
003oooooool04Oooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003ooooo
ool07oooo`Ko000=oooo1_l000koool00`000?ooooooo`09oooo00<0003oooooool0@oooo`030000
oooooooo00ooool00`000?ooooooo`2<oooo1?l0013oool00`000?ooooooo`0Aoooo00<0003ooooo
ool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Ooooo1_l000koool4o`003ooo
o`030000oooooooo00Woool00`000?ooooooo`13oooo00<0003oooooool03_ooo`030000oooooooo
08coool6o`003oooo`030000oooooooo017oool00`000?ooooooo`0@oooo00<0003oooooool02ooo
o`00:oooo`030000oooooooo023oool4o`004?ooo`;o000@oooo00<0003oooooool02Oooo`030000
oooooooo04?oool00`000?ooooooo`0>oooo00<0003oooooool0S?ooo`Ko000?oooo00<0003ooooo
ool04Oooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo0P0002;oool2o`004_oo
o`030000oooooooo00koool00`000?ooooooo`08oooo00<0003oooooool0AOooo`030000oooooooo
00goool00`000?ooooooo`2<oooo1_l000ooool00`000?ooooooo`0Aoooo00<0003oooooool04?oo
o`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003oooooool04?ooo`030000
oooooooo00koool00`000?ooooooo`08oooo00<0003oooooool0AOooo`030000oooooooo00goool0
0`000?ooooooo`2=oooo1?l0013oool00`000?ooooooo`0Aoooo00<0003oooooool04?ooo`030000
oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003oooooool04?ooo`030000oooooooo
00koool00`000?ooooooo`08oooo00<0003oooooool0AOooo`030000oooooooo00goool00`000?oo
ooooo`2>oooo0_l000030000oooooooo00koool00`000?ooooooo`0Aoooo00<0003oooooool04?oo
o`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003oooooool04?ooo`030000
oooooooo00koool00`000?ooooooo`08oooo00<0003oooooool0AOooo`030000oooooooo00goool0
0`000?ooooooo`2@oooo00<0003oooooool03_ooo`030000oooooooo017oool00`000?ooooooo`0@
oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool00`000?ooooooo`0@oooo00<0
003oooooool03_ooo`030000oooooooo00Soool00`000?ooooooo`15oooo00<0003oooooool03?oo
o`030000oooooooo097oool00`000?ooooooo`0>oooo00<0003oooooool04Oooo`030000oooooooo
013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_ooo`030000oooooooo013oool0
0`000?ooooooo`0?oooo00<0003oooooool01oooo`030000oooooooo04Goool00`000?ooooooo`0<
oooo00<0003oooooool0TOooo`030000oooooooo00koool00`000?ooooooo`0Aoooo00<0003ooooo
ool04?ooo`030000oooooooo00_oool002_oool200008oooo`030000oooooooo013oool00`000?oo
ooooo`0?oooo00<0003oooooool01_ooo`030000oooooooo04Ooool00`000?ooooooo`0;oooo00<0
003oooooool0TOooo`030000oooooooo00koool00`000?ooooooo`0Aoooo00<0003oooooool04?oo
o`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003oooooool04?ooo`030000
oooooooo00ooool00`000?ooooooo`06oooo00<0003oooooool0Aoooo`030000oooooooo00_oool0
0`000?ooooooo`2Aoooo00<0003oooooool03_ooo`030000oooooooo017oool00`000?ooooooo`0@
oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool00`000?ooooooo`0@oooo00<0
003oooooool03oooo`030000oooooooo00Koool00`000?ooooooo`17oooo00<0003oooooool02_oo
o`030000oooooooo09;oool00`000?ooooooo`0>oooo00<0003oooooool04Oooo`030000oooooooo
013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_ooo`030000oooooooo013oool0
0`000?ooooooo`0?oooo00<0003oooooool01_ooo`030000oooooooo04Ooool00`000?ooooooo`0:
oooo00<0003oooooool0T_ooo`030000oooooooo00koool00`000?ooooooo`0Aoooo00<0003ooooo
ool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003oooooool04?oo
o`030000oooooooo00ooool00`000?ooooooo`06oooo00<0003oooooool0Aoooo`030000oooooooo
00[oool00`000?ooooooo`2Boooo00<0003oooooool03_ooo`030000oooooooo017oool00`000?oo
ooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool00`000?ooooooo`0@
oooo00<0003oooooool03Oooo`Co0007oooo00<0003oooooool0Aoooo`030000oooooooo00[oool0
0`000?ooooooo`2Boooo00<0003oooooool03_ooo`030000oooooooo017oool00`000?ooooooo`0@
oooo00<0003oooooool02oooo`00:oooo`80000Soooo00<0003oooooool04?ooo`030000oooooooo
00coool6o`001Oooo`030000oooooooo04Woool00`000?ooooooo`08oooo00<0003oooooool0Tooo
o`030000oooooooo00koool00`000?ooooooo`0Aoooo00<0003oooooool04?ooo`030000oooooooo
00_oool002_oool00`000?ooooooo`0Roooo00<0003oooooool04?ooo`030000oooooooo00coool6
o`001Oooo`030000oooooooo04Woool00`000?ooooooo`05oooo1?l009Goool00`000?ooooooo`0>
oooo00<0003oooooool04Oooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0
003oooooool08_ooo`030000oooooooo013oool00`000?ooooooo`0<oooo1_l000Goool00`000?oo
ooooo`19oooo00<0003oooooool01?ooo`Ko002Doooo00<0003oooooool03_ooo`030000oooooooo
017oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`002Oooo`H00004oooo100000Goool4
00002oooo`030000oooooooo02;oool00`000?ooooooo`0@oooo00<0003oooooool03Oooo`Co0006
oooo00<0003oooooool0BOooo`030000oooooooo00Coool6o`00U?ooo`030000oooooooo00koool0
0`000?ooooooo`0Aoooo00<0003oooooool04?ooo`030000oooooooo00_oool000_oool200001Ooo
o`800002oooo0P0000?oool200000_ooo`80000:oooo00<0003oooooool08_ooo`030000oooooooo
013oool00`000?ooooooo`0>oooo0_l000030000oooooooo00Coool00`000?ooooooo`19oooo00<0
003oooooool01?ooo`Ko002Doooo00<0003oooooool03_ooo`030000oooooooo017oool00`000?oo
ooooo`0@oooo00<0003oooooool02oooo`002oooo`800005oooo00<0003oooooool00_ooo`050000
oooooooooooo000000Coool00`000?ooooooo`08oooo00<0003oooooool08_ooo`030000oooooooo
013oool00`000?ooooooo`0@oooo00<0003oooooool01?ooo`030000oooooooo04[oool00`000?oo
ooooo`04oooo1?l009Goool00`000?ooooooo`0>oooo00<0003oooooool04Oooo`030000oooooooo
013oool00`000?ooooooo`0;oooo000;oooo0P0000Coool200001?ooo`8000000oooo`0000000004
oooo0P0000Woool300008_ooo`030000oooooooo013oool00`000?ooooooo`0Aoooo00<0003ooooo
ool00oooo`030000oooooooo04[oool00`000?ooooooo`05oooo0_l009Koool00`000?ooooooo`0>
oooo00<0003oooooool04Oooo`030000oooooooo013oool00`000?ooooooo`0;oooo000;oooo0P00
00Coool200001?ooo`8000000oooo`0000000004oooo0P0000Woool00`000?ooooooo`0Roooo00<0
003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`02oooo00<0003oooooool0Booo
o`030000oooooooo00Goool00`000?ooooooo`2Eoooo00<0003oooooool03_ooo`030000oooooooo
017oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`002oooo`800004oooo0P0000Coool2
000000?oool0000000001?ooo`800009oooo00<0003oooooool08_ooo`030000oooooooo013oool0
0`000?ooooooo`0Aoooo00<0003oooooool00_ooo`030000oooooooo04coool00`000?ooooooo`03
oooo00<0003oooooool0Uoooo`030000oooooooo00goool00`000?ooooooo`0Aoooo00<0003ooooo
ool04?ooo`030000oooooooo00_oool000_oool200001?ooo`800004oooo0P000003oooo00000000
00Coool200002Oooo`030000oooooooo02;oool00`000?ooooooo`0@oooo00<0003oooooool04Ooo
o`030000oooooooo00;oool00`000?ooooooo`1<oooo00<0003oooooool00oooo`030000oooooooo
09Ooool00`000?ooooooo`0=oooo00<0003oooooool04Oooo`030000oooooooo013oool00`000?oo
ooooo`0;oooo000;oooo0P0000Coool200001?ooo`8000000oooo`0000000004oooo0P0000Woool0
0`000?ooooooo`0Roooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`02
oooo00<0003oooooool0COooo`030000oooooooo00;oool00`000?ooooooo`2Goooo00<0003ooooo
ool03Oooo`030000oooooooo017oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`002ooo
o`800004oooo0P0000Coool2000000?oool0000000001?ooo`800009oooo00<0003oooooool08_oo
o`030000oooooooo013oool00`000?ooooooo`0Boooo00D0003oooooooooool00000Coooo`800002
oooo00<0003oooooool0V?ooo`030000oooooooo00goool00`000?ooooooo`0Aoooo00<0003ooooo
ool04?ooo`030000oooooooo00_oool000_oool200001Oooo`030000oooooooo00;oool01@000?oo
ooooooooo`000004oooo00<0003oooooool02?ooo`80000Soooo00<0003oooooool04?ooo`030000
oooooooo01;oool010000?ooooooo`00057oool40000V_ooo`030000oooooooo00goool00`000?oo
ooooo`0Aoooo00<0003oooooool04?ooo`030000oooooooo00_oool000Woool400001Oooo`800002
oooo0P0000?oool200000_ooo`80000:oooo00<0003oooooool08_ooo`030000oooooooo013oool0
0`000?ooooooo`0Boooo00@0003oooooool0003_oooo00<0003oooooool03Oooo`030000oooooooo
017oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`002oooo`800006oooo100000Goool4
00002oooo`030000oooooooo02;oool00`000?ooooooo`0@oooo00<0003oooooool04_ooo`<0003`
oooo00<0003oooooool03Oooo`030000oooooooo017oool00`000?ooooooo`0@oooo00<0003ooooo
ool02oooo`00:oooo`030000oooooooo02;oool00`000?ooooooo`0@oooo00<0003oooooool04ooo
o`030000oooooooo0>ooool00`000?ooooooo`0=oooo00<0003oooooool04Oooo`030000oooooooo
013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_ooo`030000oooooooo013oool0
0`000?ooooooo`3ooooo1_ooo`030000oooooooo00goool00`000?ooooooo`0Aoooo00<0003ooooo
ool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003oooooool04?oo
o`030000oooooooo0?ooool6oooo00<0003oooooool03Oooo`030000oooooooo017oool00`000?oo
ooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool00`000?ooooooo`0@
oooo00<0003oooooool0ooooo`Koool00`000?ooooooo`0=oooo00<0003oooooool04Oooo`030000
oooooooo013oool00`000?ooooooo`0;oooo000[oooo0P0002?oool00`000?ooooooo`0@oooo00<0
003oooooool0ooooo`Koool00`000?ooooooo`0=oooo00<0003oooooool04Oooo`030000oooooooo
013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_ooo`030000oooooooo013oool0
0`000?ooooooo`3ooooo1_ooo`030000oooooooo00goool00`000?ooooooo`0Aoooo00<0003ooooo
ool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003oooooool03ooo
o`030000oooooooo0?ooool7oooo00<0003oooooool03Oooo`030000oooooooo017oool00`000?oo
ooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool00`000?ooooooo`0?
oooo00<0003oooooool0ooooo`Ooool00`000?ooooooo`0=oooo00<0003oooooool04Oooo`030000
oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_ooo`030000oooooooo
00ooool00`000?ooooooo`3ooooo1oooo`030000oooooooo00goool00`000?ooooooo`0Aoooo00<0
003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003ooooo
ool03oooo`030000oooooooo0?ooool7oooo00<0003oooooool03Oooo`030000oooooooo017oool0
0`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`80000Soooo00<0003oooooool03ooo
o`030000oooooooo0?ooool8oooo00<0003oooooool03?ooo`030000oooooooo017oool00`000?oo
ooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool00`000?ooooooo`0?
oooo00<0003oooooool0ooooo`Soool00`000?ooooooo`0<oooo00<0003oooooool04Oooo`030000
oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_ooo`030000oooooooo
00ooool00`000?ooooooo`3ooooo2?ooo`030000oooooooo00coool00`000?ooooooo`0Aoooo00<0
003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003ooooo
ool03oooo`030000oooooooo0?ooool8oooo00<0003oooooool03?ooo`030000oooooooo017oool0
0`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool00`000?oo
ooooo`0?oooo00<0003oooooool0ooooo`Soool00`000?ooooooo`0<oooo00<0003oooooool04Ooo
o`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_ooo`030000
oooooooo00ooool00`000?ooooooo`3ooooo2?ooo`030000oooooooo00coool00`000?ooooooo`0A
oooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool200008oooo`030000oooooooo
00ooool00`000?ooooooo`3ooooo2?ooo`030000oooooooo00coool00`000?ooooooo`0Aoooo00<0
003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003ooooo
ool03oooo`030000oooooooo0?ooool8oooo00<0003oooooool03?ooo`030000oooooooo017oool0
0`000?ooooooo`0@oooo00<0003oooooool02oooo`002Oooo`H00002oooo1`0000?oool400003?oo
o`030000oooooooo02;oool00`000?ooooooo`0?oooo00<0003oooooool0ooooo`Soool00`000?oo
ooooo`0<oooo00<0003oooooool04Oooo`030000oooooooo013oool00`000?ooooooo`0;oooo000;
oooo0P0000Goool700000_ooo`050000oooooooooooo000000_oool00`000?ooooooo`0Roooo00<0
003oooooool03oooo`030000oooooooo0?ooool8oooo00<0003oooooool03?ooo`030000oooooooo
017oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`002oooo`800006oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool00`000?ooooooo`08oooo00<0003oooooool08_ooo`030000
oooooooo00ooool00`000?ooooooo`3ooooo2?ooo`030000oooooooo00_oool00`000?ooooooo`0B
oooo00<0003oooooool04?ooo`030000oooooooo00_oool000_oool200001oooo`030000oooooooo
00Woool00`000?ooooooo`08oooo00<0003oooooool08_ooo`030000oooooooo00ooool00`000?oo
ooooo`3ooooo2?ooo`030000oooooooo00_oool00`000?ooooooo`0Boooo00<0003oooooool04?oo
o`030000oooooooo00_oool000_oool200002?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo0`0002;oool00`000?ooooooo`0?oooo00<0003oooooool0ooooo`Soool00`000?ooooooo`0;
oooo00<0003oooooool04_ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000;oooo0P00
00Soool200002?ooo`80000:oooo00<0003oooooool08_ooo`030000oooooooo00ooool00`000?oo
ooooo`3ooooo2?ooo`030000oooooooo00_oool00`000?ooooooo`0Boooo00<0003oooooool04?oo
o`030000oooooooo00_oool000_oool200002Oooo`030000oooooooo00Goool300002_ooo`030000
oooooooo02;oool00`000?ooooooo`0?oooo00<0003oooooool0ooooo`Soool00`000?ooooooo`0;
oooo00<0003oooooool04_ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000;oooo0P00
00Woool200000oooo`D0000;oooo00<0003oooooool08_ooo`030000oooooooo00ooool00`000?oo
ooooo`3ooooo2?ooo`030000oooooooo00_oool00`000?ooooooo`0Boooo00<0003oooooool04?oo
o`030000oooooooo00_oool000_oool200002Oooo`800004oooo0`0000coool00`000?ooooooo`0R
oooo00<0003oooooool03oooo`030000oooooooo0?ooool8oooo00<0003oooooool02oooo`030000
oooooooo01;oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`002oooo`800004oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`030000oooooooo02;oool00`000?oo
ooooo`0?oooo00<0003oooooool0ooooo`Woool00`000?ooooooo`0:oooo00<0003oooooool04_oo
o`030000oooooooo013oool00`000?ooooooo`0;oooo0009oooo100000Goool00`000?ooooooo`03
00001Oooo`@0000:oooo0P0002?oool00`000?ooooooo`0?oooo00<0003oooooool0ooooo`Woool0
0`000?ooooooo`0:oooo00<0003oooooool04_ooo`030000oooooooo013oool00`000?ooooooo`0;
oooo000;oooo0P0000Koool400001_ooo`@0000:oooo00<0003oooooool08_ooo`030000oooooooo
00ooool00`000?ooooooo`3ooooo2Oooo`030000oooooooo00[oool00`000?ooooooo`0Boooo00<0
003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0003ooooo
ool03oooo`030000oooooooo0?ooool9oooo00<0003oooooool02_ooo`030000oooooooo01;oool0
0`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool00`000?oo
ooooo`0?oooo00<0003oooooool0ooooo`Woool00`000?ooooooo`0:oooo00<0003oooooool04_oo
o`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_ooo`030000
oooooooo00ooool00`000?ooooooo`3ooooo2Oooo`030000oooooooo00[oool00`000?ooooooo`0B
oooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0
003oooooool03oooo`030000oooooooo0?ooool9oooo00<0003oooooool02_ooo`030000oooooooo
01;oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`80000Soooo00<0003ooooo
ool03oooo`030000oooooooo0?ooool9oooo00<0003oooooool02_ooo`030000oooooooo01;oool0
0`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool00`000?oo
ooooo`0?oooo00<0003oooooool0ooooo`Woool00`000?ooooooo`0:oooo00<0003oooooool04_oo
o`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_ooo`030000
oooooooo00ooool00`000?ooooooo`3ooooo2Oooo`030000oooooooo00[oool00`000?ooooooo`0B
oooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0
003oooooool03oooo`030000oooooooo0?ooool9oooo00<0003oooooool02_ooo`030000oooooooo
01;oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool0
0`000?ooooooo`0?oooo00<0003oooooool0ooooo`Woool00`000?ooooooo`0:oooo00<0003ooooo
ool04_ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_oo
o`030000oooooooo00ooool00`000?ooooooo`3ooooo2Oooo`030000oooooooo00[oool00`000?oo
ooooo`0Boooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool200008oooo`030000
oooooooo00ooool00`000?ooooooo`3ooooo2Oooo`030000oooooooo00[oool00`000?ooooooo`0B
oooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0Roooo00<0
003oooooool03oooo`030000oooooooo0?ooool9oooo00<0003oooooool02_ooo`030000oooooooo
01;oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo02;oool0
0`000?ooooooo`0?oooo00<0003oooooool0ooooo`Woool00`000?ooooooo`0:oooo00<0003ooooo
ool04_ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_oo
o`030000oooooooo00ooool00`000?ooooooo`3ooooo2Oooo`030000oooooooo00[oool00`000?oo
ooooo`0Boooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0R
oooo00<0003oooooool03oooo`030000oooooooo0?ooool:oooo00<0003oooooool02Oooo`030000
oooooooo01;oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`00:oooo`030000oooooooo
02;oool00`000?ooooooo`0?oooo00<0003oooooool0ooooo`[oool00`000?ooooooo`09oooo00<0
003oooooool04_ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo0P0002?oool0
0`000?ooooooo`0?oooo00<0003oooooool0ooooo`[oool00`000?ooooooo`09oooo00<0003ooooo
ool04_ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000[oooo00<0003oooooool08_oo
o`030000oooooooo00ooool00`000?ooooooo`3ooooo2_ooo`030000oooooooo00Woool00`000?oo
ooooo`0Boooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool00`000?ooooooo`0R
oooo00<0003oooooool03oooo`030000oooooooo0?ooool:oooo00<0003oooooool02Oooo`030000
oooooooo01;oool00`000?ooooooo`0@oooo00<0003oooooool02oooo`002Oooo`H00003oooo1000
00Koool400002oooo`030000oooooooo02;oool00`000?ooooooo`0?oooo00<0003oooooool0oooo
o`[oool00`000?ooooooo`09oooo00<0003oooooool04_ooo`030000oooooooo013oool00`000?oo
ooooo`0;oooo000;oooo0P0000Goool01@000?ooooooooooo`000004oooo0P0000;oool200002_oo
o`030000oooooooo02;oool00`000?ooooooo`0?oooo00<0003oooooool0ooooo`[oool00`000?oo
ooooo`09oooo00<0003oooooool04_ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000;
oooo0P0000[oool01@000?ooooooooooo`000004oooo00<0003oooooool02?ooo`030000oooooooo
02;oool00`000?ooooooo`0?oooo00<0003oooooool0ooooo`[oool00`000?ooooooo`09oooo00<0
003oooooool04_ooo`030000oooooooo013oool00`000?ooooooo`0;oooo000;oooo0P0000[oool0
0`000?ooooooo`0200001?ooo`800009oooo0`0002;oool00`000?ooooooo`0?oooo00<0003ooooo
ool0ooooo`[oool00`000?ooooooo`09oooo00<0003oooooool04_ooo`030000oooooooo013oool0
0`000?ooooooo`0;oooo000;oooo0P0000[oool00`000?ooooooo`0200001?ooo`80003oooooSooo
o`002oooo`800009oooo0P0000;oool200001?ooo`80003oooooSoooo`002oooo`800008oooo0`00
00;oool200001?ooo`80003oooooSoooo`002oooo`800005oooo1@0000?oool200001?ooo`80003o
ooooSoooo`002oooo`800006oooo0`0000Coool200001?ooo`80003oooooSoooo`002oooo`800006
oooo00<0003oooooool01Oooo`030000oooooooo00;oool00`000?ooooooo`3oooooS_ooo`002Ooo
o`@00007oooo100000?oool200000_ooo`80003oooooT?ooo`002oooo`800007oooo100000Coool4
0000oooooi7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.30342, -59.2459, 
  0.0799924, 1.23267}}]
}, Open  ]],

Cell["\<\
Die Interpolation mit Datenspiegelung ergibt eine weniger \
durchschwingende Interpolation des Wertebereichs:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(spiegeldaten[3]
         = {Range[1 - Length[daten[3]], 2  Length[daten[3]]], 
          \(Join[Reverse[#], #, Reverse[#]]&\)[Last/@daten[3]]} // Transpose
        \)], "Input"],

Cell[BoxData[
    \({{\(-19\), 35}, {\(-18\), 19}, {\(-17\), 39}, {\(-16\), 84}, {\(-15\), 
        49}, {\(-14\), 26}, {\(-13\), 14}, {\(-12\), 49}, {\(-11\), 65}, {
        \(-10\), 5}, {\(-9\), 2}, {\(-8\), 97}, {\(-7\), 57}, {\(-6\), 1}, {
        \(-5\), 56}, {\(-4\), 44}, {\(-3\), 95}, {\(-2\), 81}, {\(-1\), 82}, {
        0, 65}, {1, 65}, {2, 82}, {3, 81}, {4, 95}, {5, 44}, {6, 56}, {7, 
        1}, {8, 57}, {9, 97}, {10, 2}, {11, 5}, {12, 65}, {13, 49}, {14, 
        14}, {15, 26}, {16, 49}, {17, 84}, {18, 39}, {19, 19}, {20, 35}, {21, 
        35}, {22, 19}, {23, 39}, {24, 84}, {25, 49}, {26, 26}, {27, 14}, {28, 
        49}, {29, 65}, {30, 5}, {31, 2}, {32, 97}, {33, 57}, {34, 1}, {35, 
        56}, {36, 44}, {37, 95}, {38, 81}, {39, 82}, {40, 65}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(kurve[3, 2] = 
      Plot[Evaluate[InterpolatingPolynomial[spiegeldaten[3], x]], {x, 1, 20}, 
        PlotRange \[Rule] {\(-50\), 150}, DisplayFunction \[Rule] Identity]; 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[kurve[3, 2], punkte[3], 
      DisplayFunction \[Rule] $DisplayFunction]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.154508 0.00309017 [
[.2619 .14201 -5 -15 ]
[.2619 .14201 5 0 ]
[.5 .14201 -8 -15 ]
[.5 .14201 8 0 ]
[.7381 .14201 -8 -15 ]
[.7381 .14201 8 0 ]
[.97619 .14201 -8 -15 ]
[.97619 .14201 8 0 ]
[.01131 0 -25 -7.5 ]
[.01131 0 0 7.5 ]
[.01131 .07725 -25 -7.5 ]
[.01131 .07725 0 7.5 ]
[.01131 .23176 -16 -7.5 ]
[.01131 .23176 0 7.5 ]
[.01131 .30902 -16 -7.5 ]
[.01131 .30902 0 7.5 ]
[.01131 .38627 -16 -7.5 ]
[.01131 .38627 0 7.5 ]
[.01131 .46353 -22 -7.5 ]
[.01131 .46353 0 7.5 ]
[.01131 .54078 -22 -7.5 ]
[.01131 .54078 0 7.5 ]
[.01131 .61803 -22 -7.5 ]
[.01131 .61803 0 7.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .15451 m
.2619 .16076 L
s
gsave
.2619 .14201 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .15451 m
.5 .16076 L
s
gsave
.5 .14201 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 .15451 m
.7381 .16076 L
s
gsave
.7381 .14201 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 .15451 m
.97619 .16076 L
s
gsave
.97619 .14201 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 .15451 m
.07143 .15826 L
s
.11905 .15451 m
.11905 .15826 L
s
.16667 .15451 m
.16667 .15826 L
s
.21429 .15451 m
.21429 .15826 L
s
.30952 .15451 m
.30952 .15826 L
s
.35714 .15451 m
.35714 .15826 L
s
.40476 .15451 m
.40476 .15826 L
s
.45238 .15451 m
.45238 .15826 L
s
.54762 .15451 m
.54762 .15826 L
s
.59524 .15451 m
.59524 .15826 L
s
.64286 .15451 m
.64286 .15826 L
s
.69048 .15451 m
.69048 .15826 L
s
.78571 .15451 m
.78571 .15826 L
s
.83333 .15451 m
.83333 .15826 L
s
.88095 .15451 m
.88095 .15826 L
s
.92857 .15451 m
.92857 .15826 L
s
.25 Mabswid
0 .15451 m
1 .15451 L
s
.02381 0 m
.03006 0 L
s
gsave
.01131 0 -86 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02381 .07725 m
.03006 .07725 L
s
gsave
.01131 .07725 -86 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02381 .23176 m
.03006 .23176 L
s
gsave
.01131 .23176 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .30902 m
.03006 .30902 L
s
gsave
.01131 .30902 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .38627 m
.03006 .38627 L
s
gsave
.01131 .38627 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(75) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .46353 m
.03006 .46353 L
s
gsave
.01131 .46353 -83 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .54078 m
.03006 .54078 L
s
gsave
.01131 .54078 -83 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(125) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61803 m
.03006 .61803 L
s
gsave
.01131 .61803 -83 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.07143 .35537 m
.07584 .3815 L
.07996 .40371 L
.08485 .42578 L
.0893 .44059 L
.09154 .44592 L
.09272 .44813 L
.09397 .45002 L
.09507 .45128 L
.09627 .45226 L
.09737 .45278 L
.0984 .45296 L
.09965 .45277 L
.10085 .45218 L
.10192 .45134 L
.10309 .45007 L
.1057 .44606 L
.10813 .44101 L
.11894 .40827 L
.12425 .39019 L
.12913 .37511 L
.13357 .36402 L
.13581 .35973 L
.13827 .35615 L
.13956 .35478 L
.14074 .35384 L
.14139 .35346 L
.1421 .35315 L
.14277 .35297 L
.14338 .35288 L
.14449 .35295 L
.1457 .35335 L
.14631 .35368 L
.14697 .35412 L
.14816 .35518 L
.14929 .35647 L
.1505 .35816 L
.15267 .36196 L
.15761 .37395 L
.16755 .40819 L
.1768 .44335 L
.18087 .45703 L
.18533 .46946 L
.18778 .47478 L
.19006 .47869 L
.1913 .48034 L
.19247 .4816 L
.19312 .48215 L
.19383 .48266 L
.19506 .48325 L
Mistroke
.19578 .48344 L
.19646 .4835 L
.19706 .48346 L
.19771 .48332 L
.19843 .48306 L
.19919 .48265 L
.19983 .48219 L
.20054 .48157 L
.20181 .48017 L
.20316 .47826 L
.20561 .47377 L
.20808 .46792 L
.21076 .46019 L
.21563 .44293 L
.22476 .40299 L
.23447 .35781 L
.24358 .32188 L
.24815 .30835 L
.25051 .30281 L
.25308 .29793 L
.25574 .29417 L
.25719 .29268 L
.25789 .29211 L
.25854 .29165 L
.25915 .29129 L
.25981 .29097 L
.26097 .29061 L
.26162 .2905 L
.26231 .29047 L
.26355 .2906 L
.2647 .29095 L
.26536 .29123 L
.26596 .29155 L
.26825 .29322 L
.27033 .29532 L
.27254 .29806 L
.28218 .31374 L
.2866 .32122 L
.29126 .32797 L
.29318 .33018 L
.29524 .33209 L
.29642 .33294 L
.29749 .33355 L
.29857 .33399 L
.29959 .33424 L
.30067 .33434 L
.30181 .33423 L
.30278 .33397 L
.30385 .33349 L
.305 .33275 L
Mistroke
.30624 .3317 L
.30848 .32909 L
.31105 .32497 L
.31349 .31996 L
.31807 .30776 L
.32637 .27771 L
.33542 .2377 L
.34506 .19531 L
.34978 .17762 L
.35413 .1645 L
.35657 .15876 L
.35915 .15413 L
.36049 .15235 L
.36174 .15108 L
.36246 .15054 L
.36311 .15016 L
.36387 .14985 L
.36458 .14971 L
.36573 .14975 L
.36694 .15018 L
.36798 .15087 L
.36912 .15196 L
.37035 .15354 L
.37167 .15569 L
.37406 .16079 L
.37634 .16709 L
.37877 .17532 L
.38316 .1938 L
.39311 .25027 L
.41316 .38754 L
.41789 .41595 L
.4229 .44145 L
.42551 .45252 L
.42839 .46267 L
.43101 .46996 L
.43345 .47501 L
.43464 .47682 L
.43526 .47761 L
.43593 .47833 L
.43715 .47929 L
.43828 .47978 L
.43947 .47987 L
.44059 .47958 L
.4416 .47899 L
.44268 .47801 L
.44389 .47652 L
.4452 .47441 L
.44785 .46862 L
.45031 .4615 L
.4526 .45342 L
Mistroke
.46256 .40417 L
.47199 .34253 L
.48963 .21932 L
.49884 .16636 L
.50348 .1453 L
.50615 .13519 L
.5086 .12731 L
.51068 .12165 L
.51295 .11659 L
.5142 .11431 L
.51536 .11252 L
.51653 .111 L
.51764 .10988 L
.51867 .10907 L
.51979 .10848 L
.52081 .10815 L
.52174 .10808 L
.52275 .10821 L
.52387 .10862 L
.52503 .10931 L
.52611 .11022 L
.52858 .11316 L
.53086 .11695 L
.53604 .129 L
.54059 .14312 L
.54544 .16104 L
.56306 .24024 L
.57217 .28142 L
.58176 .31901 L
.58995 .34374 L
.5946 .35401 L
.59892 .36111 L
.60131 .36387 L
.60248 .365 L
.60357 .36586 L
.60455 .36643 L
.6056 .36699 L
.60664 .36731 L
.6078 .36768 L
.60903 .36766 L
.61016 .36759 L
.61078 .36738 L
.61146 .36724 L
.6127 .36668 L
.61385 .36596 L
.61508 .3651 L
.61729 .36304 L
.61986 .35997 L
.62264 .35563 L
.62768 .34593 L
Mistroke
.6371 .32224 L
.65569 .26609 L
.66554 .23835 L
.67096 .22474 L
.67609 .21434 L
.68096 .20614 L
.6823 .20484 L
.68297 .20414 L
.68371 .20234 L
.68434 .20221 L
.68503 .20093 L
.68626 .20006 L
.6884 .19776 L
.68957 .19814 L
.69068 .19578 L
.69131 .19539 L
.692 .19558 L
.69319 .19626 L
.6944 .19517 L
.69552 .19482 L
.69659 .19463 L
.69776 .19465 L
.699 .19504 L
.70013 .19472 L
.70134 .19526 L
.702 .19516 L
.70263 .19543 L
.70498 .19671 L
.70602 .19754 L
.70712 .19734 L
.70833 .19841 L
.70944 .1986 L
.71048 .20004 L
.71145 .20054 L
.71364 .20185 L
.71472 .20227 L
.71574 .20301 L
.71692 .20537 L
.71799 .20621 L
.7191 .20719 L
.72029 .20849 L
.72091 .21112 L
.72159 .21132 L
.72279 .212 L
.72344 .21438 L
.72405 .21211 L
.72521 .21611 L
.72646 .21796 L
.72717 .21827 L
.72781 .21989 L
Mistroke
.729 .22004 L
.72964 .22025 L
.73025 .22206 L
.73134 .22175 L
.73252 .22276 L
.73354 .22689 L
.73463 .22458 L
.73583 .2284 L
.73695 .22944 L
.74163 .23411 L
.74271 .23457 L
.74388 .23332 L
.74499 .23968 L
.74601 .23903 L
.74693 .24177 L
.74795 .24195 L
.74901 .24282 L
.75001 .2474 L
.75113 .24599 L
.75232 .24748 L
.75345 .24707 L
.75447 .24641 L
.75568 .25238 L
.75636 .25485 L
.75698 .25522 L
.75813 .25429 L
.75935 .25479 L
.76052 .25814 L
.76177 .25408 L
.76296 .26421 L
.76404 .26259 L
.76469 .25588 L
.7653 .25684 L
.76597 .26564 L
.76668 .26316 L
.76736 .26213 L
.768 .26405 L
.76919 .26647 L
.78677 .29523 L
.80427 .33269 L
.80545 .34412 L
.80612 .34317 L
.80673 .35138 L
.80786 .34046 L
.80906 .3352 L
.80972 .34062 L
.81034 .34319 L
.81102 .3468 L
.81175 .35382 L
.81241 .33854 L
Mistroke
.81303 .34673 L
.8142 .35843 L
.81531 .37018 L
.81649 .35381 L
.81761 .38163 L
.81862 .36155 L
.81981 .34763 L
.82049 .38286 L
.82111 .36848 L
.82225 .36615 L
.82345 .35475 L
.82463 .37055 L
.82571 .36416 L
.82695 .3467 L
.82813 .33858 L
.82921 .36584 L
.83022 .3887 L
.83132 .35237 L
.8325 .38994 L
.83367 .3662 L
.83433 .37728 L
.83493 .39986 L
.83605 .37017 L
.83722 .38746 L
.83784 .38643 L
.83851 .37085 L
.83971 .35541 L
.84044 .37426 L
.84114 .38163 L
.84176 .3727 L
.84243 .3665 L
.84308 .34562 L
.84369 .34028 L
.8444 .36034 L
.84505 .35677 L
.84622 .35739 L
.84688 .35305 L
.84749 .33542 L
.84873 .37966 L
.84942 .31781 L
.85004 .3708 L
.85074 .35403 L
.85149 .35278 L
.8522 .3289 L
.85285 .26412 L
.854 .2884 L
.85508 .3149 L
.85626 .29414 L
.85692 .27601 L
.85752 .33699 L
Mistroke
.85874 .33239 L
.85943 .20352 L
.86006 .22808 L
.86122 .23967 L
.86246 .26377 L
.86354 .26643 L
.86473 .25506 L
.86596 .23528 L
.86711 .29742 L
.86819 .23489 L
.86917 .20383 L
.87031 .17597 L
.87137 .07632 L
.87254 .2058 L
.87377 .22799 L
.87483 .18764 L
.87598 .11339 L
.87723 .08647 L
.87791 .20821 L
.87856 .05432 L
.87917 .12644 L
.87983 .25553 L
.88098 .09865 L
.88216 .10942 L
.88327 .01903 L
.88427 .06897 L
.88535 .11435 L
.88653 .06015 L
.88777 .07078 L
.88883 .18111 L
.88999 .00704 L
.89109 .07952 L
.89208 .01534 L
.89323 .05279 L
.89432 .05562 L
.89532 .04847 L
.89625 .01048 L
.89727 .1488 L
.89835 .07777 L
.89949 .07338 L
Mfstroke
.89949 .07338 m
.90005 0 L
s
.9016 0 m
.90192 .03438 L
.90302 .04144 L
s
.90302 .04144 m
.90324 0 L
s
.90605 0 m
.90622 .02663 L
s
.90622 .02663 m
.90634 0 L
s
.91003 0 m
.91075 .13224 L
.91191 .21688 L
.91315 .03883 L
s
.91315 .03883 m
.91329 0 L
s
.91567 0 m
.91575 .01365 L
s
.91575 .01365 m
.91584 0 L
s
.91864 0 m
.91898 .1696 L
s
.91898 .1696 m
.91976 0 L
s
.9247 0 m
.92477 .02262 L
s
.92477 .02262 m
.92488 0 L
s
.92862 0 m
.92918 .10931 L
s
.92918 .10931 m
.92964 0 L
s
.93207 0 m
.93219 .01139 L
s
.93219 .01139 m
.93223 0 L
s
.95904 0 m
.95914 .06429 L
s
.95914 .06429 m
.95924 0 L
s
.96899 0 m
.9691 .06934 L
s
.9691 .06934 m
.96924 0 L
s
1 0 0 r
.02 w
.07143 .35537 Mdot
.11905 .4079 Mdot
.16667 .40481 Mdot
.21429 .44807 Mdot
.2619 .29048 Mdot
.30952 .32756 Mdot
.35714 .1576 Mdot
.40476 .33065 Mdot
.45238 .45425 Mdot
.5 .16069 Mdot
.54762 .16996 Mdot
.59524 .35537 Mdot
.64286 .30593 Mdot
.69048 .19777 Mdot
.7381 .23485 Mdot
.78571 .30593 Mdot
.83333 .41408 Mdot
.88095 .27503 Mdot
.92857 .21322 Mdot
.97619 .26266 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012QP00`40o`000?l0003ooooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
017oool400001_ooo`@0003oooooT_ooo`004Oooo`050000oooooooooooo000000Coool200000_oo
o`80003oooooTOooo`005_ooo`050000oooooooooooo000000Coool00`000?ooooooo`3oooooSooo
o`005_ooo`030000oooooooo00800004oooo0P000?oooon@oooo0004oooo2@0000Woool00`000?oo
ooooo`0200001?ooo`80000:oooo0`000?oooomGoooo0`000003oooo0000000000L0000:oooo00D0
003oooooooooool000004?ooo`005Oooo`800002oooo0P0000Coool200002_ooo`030000oooooooo
0?oooomGoooo0`000003oooo0000000000L0000:oooo00D0003oooooooooool000004?ooo`005?oo
o`<00002oooo0P0000Coool200002_ooo`030000oooooooo0?oooomGoooo0`000003oooo00000000
00L0000:oooo00D0003oooooooooool000004?ooo`004Oooo`D00003oooo0P0000Coool200002_oo
o`030000oooooooo0?oooomCoooo00@0003oooooooooool3000000?oool0000000001`0000[oool0
1@000?ooooooooooo`00000@oooo000Boooo0`0000Coool200001?ooo`80000:oooo00<0003ooooo
ool0oooooe?oool010000?ooo`000?ooo`<000000oooo`000000000700002_ooo`050000oooooooo
oooo0000013oool001;oool00`000?ooooooo`05oooo00<0003oooooool00_ooo`030000oooooooo
00Woool00`000?ooooooo`3oooooDoooo`040000oooo0000oooo0`000003oooo0000000000@00000
0oooo`000?ooo`0:oooo00D0003oooooooooool000004?ooo`004oooo`@00003oooo0P0000;oool2
00002oooo`80003oooooE?ooo`<000001Oooo`00000000000?ooo`02000000Koool000000000003o
ool0000;oooo00D0003oooooooooool000004?ooo`004oooo`@00004oooo100000coool00`000?oo
ooooo`3oooooD?ooo`030000oooooooo00<000001Oooo`00000000000?ooo`02000000Koool00000
0000003oool0000;oooo00D0003oooooooooool000004?ooo`00:oooo`030000oooooooo0?oooom@
oooo00<0003oooooool00`000005oooo000000000000oooo008000001_ooo`00000000000?ooo`00
00_oool01@000?ooooooooooo`00000@oooo000[oooo00<0003oooooool0oooooe3oool00`000?oo
ooooo`03000000Goool000000000003oool00P000006oooo000000000000oooo00002oooo`050000
oooooooooooo0000013oool002_oool00`000?ooooooo`3oooooD?ooo`030000oooooooo00<00000
1Oooo`00000000000?ooo`02000000?oool0000000000_ooo`030000oooooooo00Woool01@000?oo
ooooooooo`00000@oooo000[oooo00<0003oooooool0oooooe3oool00`000?ooooooo`03000000?o
ool0000000000_ooo`8000000oooo`0000000002oooo00<0003oooooool02Oooo`050000oooooooo
oooo0000013oool002_oool20000oooooe7oool00`000?ooooooo`03000000?oool0000000000_oo
o`8000000oooo`0000000002oooo00<0003oooooool02Oooo`050000oooooooooooo0000013oool0
02_oool00`000?ooooooo`3oooooD?ooo`030000oooooooo00<000000oooo`0000000002oooo0P00
0003oooo0000000000;oool00`000?ooooooo`09oooo00D0003oooooooooool000004?ooo`00:ooo
o`030000oooooooo0?oooom@oooo00<0003oooooool00`000003oooo0000000000;oool2000000?o
ool0000000000_ooo`030000oooooooo00Woool01@000?ooooooooooo`00000@oooo000[oooo00<0
003oooooool0oooooe3oool00`000?ooooooo`03000000?oool0000000000_ooo`8000000oooo`00
00000002oooo00<0003oooooool02Oooo`050000oooooooooooo0000013oool002_oool00`000?oo
ooooo`3oooooD?ooo`030000oooooooo00<000000oooo`0000000002oooo0P000003oooo00000000
00;oool00`000?ooooooo`09oooo00D0003oooooooooool000004?ooo`00:oooo`030000oooooooo
0?oooom@oooo00<0003oooooool00`000003oooo0000oooo00;oool2000000?oool0000000000_oo
o`030000oooooooo00Woool01@000?ooooooooooo`00000@oooo000[oooo0P000?oooomAoooo0P00
0006oooo000000000000oooo00000oooo`8000000oooo`0000000002oooo00<0003oooooool02Ooo
o`050000oooooooooooo0000013oool002_oool00`000?ooooooo`3oooooD?ooo`8000001_ooo`00
000000000?ooo`0000?oool2000000?oool0000000000_ooo`030000oooooooo00Woool01@000?oo
ooooooooo`00000@oooo000[oooo00<0003oooooool0oooooe3oool2000000Koool000000000003o
ool00003oooo0P000003oooo0000000000;oool00`000?ooooooo`09oooo00D0003oooooooooool0
00004?ooo`00:oooo`030000oooooooo0?oooom>oooo00D0003oool00000003oool00`000003oooo
0000oooo00;oool2000000?oool0000000000_ooo`030000oooooooo00Woool01@000?oooooooooo
o`00000@oooo000[oooo00<0003oooooool0ooooodkoool01@000?ooo`0000000?ooo`03000000?o
ool0003oool00_ooo`8000000oooo`0000000002oooo00<0003oooooool02Oooo`050000oooooooo
oooo0000013oool002_oool00`000?ooooooo`3oooooC_ooo`0:0000oooo00000000oooo0000oooo
0000oooo00000oooo`8000000oooo`0000000002oooo00<0003oooooool02Oooo`050000oooooooo
oooo0000013oool002_oool20000ooooodooool02P000?ooo`0000000?ooo`000?ooo`000?ooo`00
00?oool2000000?oool0000000000_ooo`030000oooooooo00Woool01@000?ooooooooooo`00000@
oooo000[oooo00<0003oooooool0ooooodkoool02P000?ooo`0000000?ooo`000?ooo`000?ooo`00
00?oool2000000?oool0000000000_ooo`030000oooooooo00Woool01@000?ooooooooooo`00000@
oooo000[oooo00<0003oooooool0ooooodkoool00`000?ooo`000003000000Coool0003oool00003
oooo0P000003oooo0000000000;oool00`000?ooooooo`0=oooo00<0003oooooool03_ooo`004?oo
o`L00003oooo100000goool00`000?ooooooo`3oooooC_ooo`030000oooo000000<000001?ooo`00
0?ooo`0000?oool2000000?oool0000000000_ooo`030000oooooooo00goool00`000?ooooooo`0>
oooo000Aoooo1`0000;oool01@000?ooooooooooo`00000<oooo00<0003oooooool0ooooodkoool0
0`000?ooo`000003000000Coool0003oool00003oooo0P000003oooo0000000000;oool00`000?oo
ooooo`0Noooo000Boooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`09
oooo00<0003oooooool0ooooodkoool00`000?ooo`000003000000Coool0003oool00003oooo0P00
0003oooo0000000000;oool00`000?ooooooo`0Noooo000Coooo00<0003oooooool02Oooo`030000
oooooooo00Woool30000oooood_oool01@000?ooooooo`000?ooo`04000000?oool0000000001?oo
o`8000000oooo`0000000002oooo00<0003oooooool07_ooo`001?ooo`T00007oooo00<0003ooooo
ool02?ooo`030000oooooooo00Woool00`000?ooooooo`3oooooBoooo`050000oooooooo0000oooo
00@000000oooo`0000000004oooo0P000003oooo0000000000;oool00`000?ooooooo`0Noooo000D
oooo0P0000Soool200002oooo`030000oooooooo0?oooom;oooo00D0003oooooool0003oool01000
00;oool00`000?ooooooo`02oooo0P000003oooo0000000000;oool00`000?ooooooo`0Noooo000E
oooo00<0003oooooool01Oooo`<0000;oooo00<0003oooooool0oooood_oool01@000?ooooooo`00
0?ooo`0400000_ooo`030000oooooooo00;oool2000000?oool0000000000_ooo`030000oooooooo
01koool001Goool200000oooo`D0000<oooo00<0003oooooool0oooood_oool01@000?ooooooo`00
0?ooo`0400000_ooo`030000oooooooo00;oool2000000?oool0003oool00_ooo`030000oooooooo
01koool001Goool200001?ooo`<0000=oooo00<0003oooooool0oooood_oool01@000?ooooooo`00
0?ooo`0400000_ooo`030000oooooooo00;oool2000000?oool0003oool00_ooo`030000oooooooo
01koool0013oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P000?oooom<
oooo00<0003oooooool01P0000;oool00`000?ooooooo`02oooo0P000003oooo0000oooo00;oool0
0`000?ooooooo`0Noooo000Aoooo00<0003oooooool00`0000Goool400002oooo`030000oooooooo
0?oooom;oooo00<0003oooooool01P0000;oool00`000?ooooooo`02oooo0P000003oooo0000oooo
00;oool00`000?ooooooo`0Noooo000Boooo100000Koool400002oooo`030000oooooooo0?oooom;
oooo00<0003oooooool01@0000?oool00`000?ooooooo`02oooo0P000003oooo0000oooo00;oool0
0`000?ooooooo`0Noooo000[oooo00<0003oooooool0oooood_oool00`000?ooooooo`0500000ooo
o`030000oooooooo00;oool2000000?oool0003oool00_ooo`030000oooooooo01koool002_oool0
0`000?ooooooo`3oooooBoooo`030000oooo000000D00003oooo00<0003oooooool00_ooo`800000
0oooo`000?ooo`02oooo00<0003oooooool07_ooo`00:oooo`030000oooooooo05Ooool40000EOoo
o`H00004oooo1000053oool600000oooo`@0000_oooo00<0003oool000001@0000?oool00`000?oo
ooooo`02oooo0P000003oooo0000oooo00;oool00`000?ooooooo`07oooo1`0000Coool400002?oo
o`00:oooo`80001Hoooo00D0003oooooooooool00000E_ooo`800005oooo0P0000;oool2000000?o
ool000000000C_ooo`800005oooo00D0003oooooooooool00000;_ooo`030000oooo000000D00003
oooo00<0003oooooool00_ooo`8000000oooo`000?ooo`02oooo00<0003oooooool02?ooo`L00002
oooo0P0000;oool200001oooo`00:oooo`030000oooooooo05coool00`000?ooooooo`1Coooo0P00
00Goool00`000?ooooooo`02oooo0`000003oooo0000oooo04coool200002_ooo`030000oooooooo
02_oool00`000?ooo`00000500000oooo`030000oooooooo00;oool2000000?oool0003oool00_oo
o`030000oooooooo00Woool00`000?ooooooo`02oooo00@0003oooooool00004oooo00<0003ooooo
ool01Oooo`00:oooo`030000oooooooo05coool00`000?ooooooo`1Coooo0P0000Coool200001?oo
o`800003oooo00<0003oooooool0B_ooo`80000:oooo00<0003oooooool0:oooo`030000oooo0000
008000000oooo`0000000003oooo00<0003oooooool00_ooo`8000000oooo`000?ooo`0?oooo00<0
003oooooool00oooo`800004oooo0P0000Koool002_oool00`000?ooooooo`1Loooo00<0003ooooo
ool0Doooo`800004oooo0P0000Coool200001?ooo`030000oooooooo04Woool200002_ooo`030000
oooooooo02_oool00`000?ooo`000002000000?oool0000000000oooo`030000oooooooo00;oool2
000000?oool0003oool04?ooo`030000oooooooo00;oool200001?ooo`800006oooo000[oooo00<0
003oooooool0Foooo`80001Eoooo0P0000Coool200000oooo`<00004oooo00<0003oooooool0BOoo
o`800009oooo0P0002goool00`000?ooo`00000200000_ooo`050000oooooooooooo000000Coool2
000000?oool0003oool04?ooo`800003oooo0P0000Coool200001_ooo`00:oooo`030000oooooooo
05[oool30000EOooo`800004oooo0P0000?oool300001?ooo`030000oooooooo04Woool200002?oo
o`<0000]oooo00<0003oool000000P0000;oool01@000?ooooooooooo`000004oooo0P000003oooo
0000oooo017oool010000?ooooooooooo`800004oooo0P0000Koool002_oool00`000?ooooooo`1G
oooo1@0005Koool200001?ooo`800002oooo00@0003oool000000005oooo00<0003oooooool0B?oo
o`800005oooo1@0002koool00`000?ooo`00000200000_ooo`050000oooooooooooo000000Coool2
000000?oool0003oool04Oooo`800002oooo0P0000Coool200001_ooo`00:oooo`80001Ioooo0`00
05Ooool200001?ooo`800002oooo00@0003oool000000005oooo00<0003oooooool0B?ooo`800006
oooo0`0002ooool00`000?ooo`00000200000_ooo`050000oooooooooooo000000Coool2000000?o
ool0003oool04Oooo`800002oooo0P0000Coool200001_ooo`00:oooo`030000oooooooo05Soool0
0`000?ooooooo`1Goooo0P0000Goool01P000?ooooooo`000?ooo`0000Ooool00`000?ooooooo`17
oooo0P0000Koool00`000?ooooooo`0_oooo00<0003oool000000P0000;oool01@000?oooooooooo
o`000004oooo0P000003oooo0000oooo00coool00`000?ooooooo`02oooo0P0000?oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`00:oooo`030000oooooooo05Woool40000Doooo`@00005
oooo0P000004oooo0000000000001oooo`030000oooooooo04Goool400001oooo`@0000]oooo00<0
003oool000000P0000;oool01@000?ooooooooooo`000004oooo00@0003oooooool0000>oooo00<0
003oooooool00`0000?oool200000_ooo`800007oooo000[oooo00<0003oooooool0FOooo`@0001E
oooo0P0000Koool400002?ooo`030000oooooooo04Ooool200001oooo`@0000]oooo00<0003oool0
00000P0000;oool01@000?ooooooooooo`000004oooo00@0003oooooool0000?oooo100000Goool4
00002?ooo`00:oooo`030000oooooooo0;_oool00`000?ooooooo`09oooo00<0003oooooool0P?oo
o`030000oooo000000800002oooo00D0003oooooooooool000001?ooo`040000oooooooo00009?oo
o`00:oooo`030000oooooooo0;_oool00`000?ooooooo`09oooo00<0003oooooool0P?ooo`030000
oooo000000800002oooo00D0003oooooooooool000001?ooo`040000oooooooo00009?ooo`00:ooo
o`80002loooo00<0003oooooool02_ooo`030000oooooooo07ooool00`000?ooo`00000200000_oo
o`050000oooooooooooo000000Coool010000?ooooooo`0002Coool002_oool00`000?ooooooo`2j
oooo00<0003oooooool02oooo`030000oooooooo07ooool500000_ooo`050000oooooooooooo0000
00Coool010000?ooooooo`0002Coool002_oool00`000?ooooooo`2joooo00<0003oooooool02ooo
o`030000oooooooo07ooool500000_ooo`050000oooooooooooo000000Coool010000?ooooooo`00
02Coool002_oool00`000?ooooooo`2joooo00<0003oooooool03?ooo`030000oooooooo07koool5
00000_ooo`050000oooooooooooo000000Coool010000?ooooooo`0002Coool002_oool00`000?oo
ooooo`22oooo0`0003Goool00`000?ooooooo`0<oooo00<0003oooooool0O_ooo`D00002oooo00<0
003oooooool01_ooo`040000oooooooo00009?ooo`00:oooo`030000oooooooo07koool4o`000ooo
o`030000oooooooo037oool00`000?ooooooo`0=oooo00<0003oooooool0O_ooo`D00002oooo00<0
003oooooool01_ooo`040000oooooooo00009?ooo`008OooohX00006o`00n`0000Coool002_oool0
0`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`0@
oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0=oooo1_l000Coool0
0`000?ooooooo`09oooo00<0003oooooool03oooo`030000oooooooo00koool4o`004?ooo`80000B
oooo00<0003oooooool03oooo`030000oooooooo013oool00`000?ooooooo`0@oooo00<0003ooooo
ool04?ooo`030000oooooooo00ooool00`000?ooooooo`0<oooo1@0000;oool00`000?ooooooo`06
oooo00@0003oooooool00003oooo00<0003oooooool04?ooo`030000oooooooo00_oool002_oool0
0`000?ooooooo`1Joooo00<0003oooooool08?ooo`Ko0004oooo00<0003oooooool0:oooo`Ko000?
oooo00<0003oooooool0BOooo`030000oooooooo037oool500000_ooo`030000oooooooo00Koool0
10000?ooooooo`0001Koool00`000?ooooooo`0;oooo000[oooo00<0003oooooool0O_ooo`Co0005
oooo00<0003oooooool0:oooo`Ko000?oooo00<0003oooooool0OOooo`D00002oooo00<0003ooooo
ool01_ooo`040000oooooooo00009?ooo`00:oooo`030000oooooooo07ooool2o`001oooo`030000
oooooooo02[oool6o`003_ooo`Co001moooo1@0000;oool00`000?ooooooo`06oooo00@0003ooooo
ool0000Toooo000[oooo00<0003oooooool0Ooooo`030000oooooooo00Koool00`000?ooooooo`0[
oooo1?l000koool6o`00O?ooo`D00002oooo00<0003oooooool01_ooo`040000oooooooo00009?oo
o`00:oooo`80001ooooo00<0003oooooool01oooo`030000oooooooo02coool2o`003oooo`Ko001l
oooo1@0000;oool00`000?ooooooo`06oooo00@0003oooooool0000Toooo000[oooo00<0003ooooo
ool0O_ooo`030000oooooooo00Ooool00`000?ooooooo`0/oooo00<0003oooooool03_ooo`Ko001l
oooo1@0000;oool00`000?ooooooo`06oooo00<0003oooooool09Oooo`00:oooo`030000oooooooo
07goool00`000?ooooooo`08oooo00<0003oooooool0;?ooo`030000oooooooo00ooool4o`00OOoo
o`D00002oooo00<0003oooooool01_ooo`030000oooooooo02Goool002_oool00`000?ooooooo`1m
oooo00<0003oooooool02?ooo`030000oooooooo02coool00`000?ooooooo`0@oooo0_l000030000
oooooooo07_oool500000_ooo`030000oooooooo00Koool00`000?ooooooo`0Uoooo000[oooo00<0
003oooooool0OOooo`030000oooooooo00Woool00`000?ooooooo`0[oooo00<0003oooooool04_oo
o`030000oooooooo07_oool500000_ooo`030000oooooooo00Koool00`000?ooooooo`0Uoooo000[
oooo00<0003oooooool0O?ooo`030000oooooooo00[oool00`000?ooooooo`0[oooo00<0003ooooo
ool04_ooo`030000oooooooo07_oool500002oooo`030000oooooooo02Goool002_oool20000OOoo
o`030000oooooooo00[oool00`000?ooooooo`0Zoooo00<0003oooooool04oooo`030000oooooooo
07_oool500002oooo`030000oooooooo02Goool002_oool00`000?ooooooo`1loooo00<0003ooooo
ool02_ooo`030000oooooooo02[oool00`000?ooooooo`0Coooo00<0003oooooool0Noooo`D0000;
oooo00<0003oooooool09Oooo`00:oooo`030000oooooooo07coool00`000?ooooooo`0;oooo00<0
003oooooool0:Oooo`030000oooooooo01Coool00`000?ooooooo`1joooo1@0000_oool00`000?oo
ooooo`0Uoooo000[oooo00<0003oooooool0Noooo`030000oooooooo00coool00`000?ooooooo`0Y
oooo00<0003oooooool05?ooo`030000oooooooo037oool4o`00AOooo`D0000;oooo00<0003ooooo
ool09Oooo`00:oooo`030000oooooooo07_oool00`000?ooooooo`0<oooo00<0003oooooool0:Ooo
o`030000oooooooo01Coool00`000?ooooooo`0`oooo1_l000@00010oooo1@0000_oool00`000?oo
ooooo`0Uoooo000[oooo00<0003oooooool0Noooo`030000oooooooo00coool00`000?ooooooo`0Y
oooo00<0003oooooool05?ooo`030000oooooooo033oool6o`000oooo`<0000noooo1@0000_oool0
0`000?ooooooo`0Uoooo000[oooo0P0007coool00`000?ooooooo`0=oooo00<0003oooooool09ooo
o`030000oooooooo01Koool00`000?ooooooo`0_oooo1_l000Goool20000?Oooo`D0000;oooo00<0
003oooooool09Oooo`00:oooo`030000oooooooo07[oool00`000?ooooooo`0>oooo00<0003ooooo
ool09oooo`030000oooooooo01Koool00`000?ooooooo`0_oooo00<0003o003o00000_l000Soool0
0`000?ooooooo`0foooo00@0003oooooooooool500002oooo`030000oooooooo02Goool002_oool0
0`000?ooooooo`1joooo00<0003oooooool03_ooo`030000oooooooo02Ooool00`000?ooooooo`0F
oooo00<0003oooooool0;_ooo`8000000oooool00?l0000:oooo00<0003oooooool0=Oooo`040000
oooooooooooo1@0000_oool00`000?ooooooo`0Uoooo000[oooo00<0003oooooool0N_ooo`030000
oooooooo00koool00`000?ooooooo`0Woooo00<0003oooooool05_ooo`030000oooooooo02koool0
0`000?ooooooo`0=oooo00<0003oooooool0=?ooo`040000oooooooooooo1@0000_oool00`000?oo
ooooo`02oooo1?l001ooool002_oool00`000?ooooooo`1joooo00<0003oooooool03_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Goooo00<0003oooooool0;?ooo`030000oooooooo00koool2
0000=Oooo`040000oooooooooooo0P0000;oool00`000?ooooooo`09oooo00@0003oooooooooool6
o`007_ooo`00:oooo`030000oooooooo07Woool00`000?ooooooo`0?oooo00<0003oooooool09_oo
o`030000oooooooo01Soool00`000?ooooooo`0/oooo00<0003oooooool03oooo`80000doooo00@0
003oooooooooool200000_ooo`030000oooooooo00Woool010000?ooooooooooo`Ko000Noooo000[
oooo0P0007[oool00`000?ooooooo`0@oooo00<0003oooooool09Oooo`030000oooooooo01Soool0
0`000?ooooooo`0/oooo00<0003oooooool04?ooo`030000oooooooo03;oool010000?oooooooooo
o`800002oooo00<0003oooooool02Oooo`040000oooooooooooo1_l001koool002_oool00`000?oo
ooooo`1ioooo00<0003oooooool04?ooo`030000oooooooo02Goool00`000?ooooooo`0Hoooo00<0
003oooooool0:oooo`030000oooooooo017oool20000<oooo`040000oooooooooooo0P0000;oool0
0`000?ooooooo`0>oooo1?l001ooool0017oool700000oooo`@0000<oooo00<0003oooooool0NOoo
o`030000oooooooo013oool00`000?ooooooo`0Uoooo00<0003oooooool06?ooo`030000oooooooo
02_oool00`000?ooooooo`0Boooo0P0003;oool01P000?ooooooo`000?ooo`0000;oool00`000?oo
ooooo`0?oooo0_l0023oool001;oool700000_ooo`050000oooooooooooo000000_oool00`000?oo
ooooo`1hoooo00<0003oooooool04Oooo`030000oooooooo02Goool00`000?ooooooo`0Ioooo00<0
003oooooool0:Oooo`030000oooooooo01Goool20000<?ooo`060000oooooooo0000oooo00000_oo
o`030000oooooooo037oool001?oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000
oooooooo00Soool00`000?ooooooo`1hoooo00<0003oooooool04Oooo`030000oooooooo02Goool0
0`000?ooooooo`0Ioooo00<0003oooooool0:Oooo`030000oooooooo01Goool20000<?ooo`060000
oooooooo0000oooo00000_ooo`030000oooooooo037oool001Coool00`000?ooooooo`09oooo00<0
003oooooool02?ooo`030000oooooooo07Soool00`000?ooooooo`0Boooo00<0003oooooool08ooo
o`030000oooooooo01[oool00`000?ooooooo`0Xoooo00<0003oooooool05oooo`80000_oooo00H0
003oooooool0003oool00002oooo00<0003oooooool0<Oooo`005Oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo0`0007Soool00`000?ooooooo`0Boooo00<0003oooooool08oooo`030000
oooooooo01[oool00`000?ooooooo`0Xoooo00<0003oooooool05_ooo`Co000^oooo00@0003ooooo
ool00004oooo00<0003oooooool0<Oooo`005Oooo`800008oooo0P0000[oool00`000?ooooooo`1g
oooo00<0003oooooool04oooo`030000oooooooo02?oool00`000?ooooooo`0Koooo00<0003ooooo
ool09_ooo`030000oooooooo01Koool6o`00;Oooo`040000oooooooo00001?ooo`030000oooooooo
037oool001Koool00`000?ooooooo`05oooo0`0000[oool00`000?ooooooo`1goooo00<0003ooooo
ool04oooo`030000oooooooo02?oool00`000?ooooooo`0Koooo00<0003oooooool09_ooo`030000
oooooooo01Koool6o`0000<0003oooooool0:_ooo`040000oooo000000001?ooo`030000oooooooo
037oool001Koool200000oooo`D0000;oooo00<0003oooooool0Moooo`030000oooooooo01?oool0
0`000?ooooooo`0Soooo00<0003oooooool06oooo`030000oooooooo02Goool00`000?ooooooo`0G
oooo1_l000030000oooooooo02[oool010000?ooo`00000000Coool00`000?ooooooo`0aoooo000F
oooo0P0000Coool300003?ooo`030000oooooooo07Ooool00`000?ooooooo`0Coooo00<0003ooooo
ool08oooo`030000oooooooo01_oool00`000?ooooooo`0Uoooo00<0003oooooool06?ooo`Co0000
0oooo`000000000[oooo00@0003oool000000004oooo00<0003oooooool0<Oooo`004Oooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00coool00`000?ooooooo`1foooo00<0003ooooo
ool05Oooo`030000oooooooo02;oool00`000?ooooooo`0Koooo00<0003oooooool09?ooo`030000
oooooooo01[oool2o`001?ooo`030000oooooooo02Soool010000?ooo`00000000Coool00`000?oo
ooooo`0aoooo000Boooo00<0003oooooool00`0000Goool400002_ooo`80001goooo00<0003ooooo
ool05Oooo`030000oooooooo027oool00`000?ooooooo`0Moooo00<0003oooooool08oooo`030000
oooooooo023oool20000:Oooo`040000oooo000000001?ooo`030000oooooooo037oool001?oool4
00001_ooo`@0000:oooo00<0003oooooool0M_ooo`030000oooooooo01Goool00`000?ooooooo`0Q
oooo00<0003oooooool07Oooo`030000oooooooo02?oool00`000?ooooooo`0Roooo00<0003ooooo
ool09_ooo`040000oooo000000001?ooo`030000oooooooo037oool002_oool00`000?ooooooo`1f
oooo00<0003oooooool05Oooo`030000oooooooo027oool00`000?ooooooo`0Moooo00<0003ooooo
ool08oooo`030000oooooooo02;oool00`000?ooooooo`0Voooo00@0003oool000000004oooo00<0
003oooooool0<Oooo`00:oooo`030000oooooooo07Koool00`000?ooooooo`0Eoooo00<0003ooooo
ool08Oooo`030000oooooooo01goool00`000?ooooooo`0Roooo00<0003oooooool08oooo`<0000V
oooo100000Coool00`000?ooooooo`0aoooo000[oooo00<0003oooooool0M_ooo`030000oooooooo
01Goool00`000?ooooooo`0Qoooo00<0003oooooool07_ooo`030000oooooooo027oool00`000?oo
ooooo`0Uoooo0`0002Coool40000>?ooo`00:oooo`030000oooooooo07Goool00`000?ooooooo`0G
oooo00<0003oooooool08?ooo`030000oooooooo01koool00`000?ooooooo`0Qoooo00<0003ooooo
ool09Oooo`<0000Toooo100002Ooool4o`003Oooo`00:oooo`80001foooo00<0003oooooool05ooo
o`030000oooooooo023oool00`000?ooooooo`0Noooo00<0003oooooool08Oooo`030000oooooooo
02Koool200009?ooo`@0000Voooo1_l000coool002_oool00`000?ooooooo`1eoooo00<0003ooooo
ool05oooo`030000oooooooo01ooool00`000?ooooooo`0Ooooo00<0003oooooool08?ooo`030000
oooooooo02Ooool300008?ooo`030000oooooooo00@0000Voooo1_l000coool002_oool00`000?oo
ooooo`1eoooo00<0003oooooool05oooo`030000oooooooo01ooool00`000?ooooooo`0Poooo00<0
003oooooool07oooo`030000oooooooo02Woool00`000?ooooooo`0Noooo00<0003oooooool01000
02Koool6o`003?ooo`00:oooo`030000oooooooo07Goool00`000?ooooooo`0Goooo00<0003ooooo
ool07oooo`030000oooooooo023oool00`000?ooooooo`0Ooooo00<0003oooooool0:_ooo`030000
oooooooo01goool00`000?ooo`000003oooo00<0003oooooool09Oooo`Co000=oooo000[oooo00<0
003oooooool0M?ooo`030000oooooooo01Soool00`000?ooooooo`0Ooooo00<0003oooooool08?oo
o`030000oooooooo01koool00`000?ooooooo`0[oooo00<0003oooooool07Oooo`030000oooo0000
00?oool00`000?ooooooo`04o`008_ooo`;o000>oooo000[oooo00<0003oooooool0M?ooo`030000
oooooooo01Soool00`000?ooooooo`0Ooooo00<0003oooooool08?ooo`030000oooooooo01koool0
0`000?ooooooo`0/oooo00<0003oooooool07?ooo`030000oooo000000?oool00`000?ooool00005
o`00<Oooo`00:oooo`80001eoooo00<0003oooooool06Oooo`030000oooooooo01koool00`000?oo
ooooo`0Qoooo00<0003oooooool07Oooo`030000oooooooo02goool00`000?ooooooo`0Koooo0`00
00?oool00`000?ooool00005o`00<Oooo`00:oooo`030000oooooooo07Coool00`000?ooooooo`0I
oooo00<0003oooooool07_ooo`030000oooooooo027oool00`000?ooooooo`0Loooo00<0003ooooo
ool0;_ooo`030000oooooooo01_oool300000oooo`030000ooooo`0000Go000aoooo000[oooo00<0
003oooooool0M?ooo`030000oooooooo01Woool00`000?ooooooo`0Moooo00<0003oooooool08_oo
o`030000oooooooo01coool00`000?ooooooo`0_oooo00<0003oooooool06_ooo`<00003oooo00<0
003oooooool01?l003;oool002_oool00`000?ooooooo`1coooo00<0003oooooool06_ooo`030000
oooooooo01goool00`000?ooooooo`0Roooo00<0003oooooool06oooo`030000oooooooo033oool0
0`000?ooooooo`0Joooo0`0000?oool010000?ooooooooooo`;o000coooo000[oooo00<0003ooooo
ool0F?ooo`Co000Goooo00<0003oooooool06_ooo`030000oooooooo01goool00`000?ooooooo`0R
oooo00<0003oooooool06oooo`030000oooooooo037oool00`000?ooooooo`0Ioooo0`0000?oool0
0`000?ooooooo`0foooo000[oooo00<0003oooooool0Eoooo`Ko000Foooo00<0003oooooool06_oo
o`030000oooooooo01goool00`000?ooooooo`0Soooo00<0003oooooool06_ooo`030000oooooooo
03;oool00`000?ooooooo`0Hoooo0`0000?oool00`000?ooooooo`0foooo000[oooo0P0005Soool6
o`0000<0003oooooool04oooo`030000oooooooo01_oool00`000?ooooooo`0Loooo00<0003ooooo
ool08oooo`030000oooooooo01Woool00`000?ooooooo`0coooo00<0003oooooool06?ooo`<00003
oooo00<0003oooooool0=_ooo`00:oooo`030000oooooooo05Ooool6o`0000?oool0003oool04_oo
o`030000oooooooo01coool00`000?ooooooo`0Loooo00<0003oooooool08oooo`030000oooooooo
01Woool00`000?ooooooo`0doooo00<0003oooooool05oooo`<00003oooo00<0003oooooool0=_oo
o`00:oooo`030000oooooooo05Ooool00`000?l00?l00002o`000oooo`030000oooooooo013oool0
0`000?ooooooo`0Loooo00<0003oooooool07?ooo`030000oooooooo02?oool00`000?ooooooo`0I
oooo00<0003oooooool0=?ooo`030000oooooooo01Ooool300000oooo`030000oooooooo03Koool0
01;oool400001_ooo`@0000;oooo00<0003oooooool0Eoooo`040000ooooo`00o`001Oooo`030000
oooooooo00ooool00`000?ooooooo`0Loooo00<0003oooooool06oooo`030000oooooooo02Coool0
0`000?ooooooo`0Hoooo00<0003oooooool0=_ooo`030000oooooooo01Koool30000??ooo`004_oo
o`050000oooooooooooo000000Coool200000_ooo`80000:oooo00<0003oooooool0E_ooo`030000
oooooooo00Ooool00`000?ooooooo`0?oooo00<0003oooooool07?ooo`030000oooooooo01_oool0
0`000?ooooooo`0Uoooo00<0003oooooool05?ooo`Co000doooo1?l000030000oooooooo01Koool3
0000??ooo`005oooo`050000oooooooooooo000000Coool00`000?ooooooo`08oooo00<0003ooooo
ool0E_ooo`030000oooooooo00Soool00`000?ooooooo`0=oooo00<0003oooooool07Oooo`030000
oooooooo01_oool00`000?ooooooo`0Uoooo00<0003oooooool04oooo`Ko000boooo1_l000030000
oooooooo01Goool30000??ooo`005oooo`030000oooooooo00800004oooo0P0000Woool00`000?oo
ooooo`1Eoooo00<0003oooooool02Oooo`030000oooooooo00goool00`000?ooooooo`0Moooo00<0
003oooooool06oooo`030000oooooooo02Goool00`000?ooooooo`0Coooo1_l003;oool6o`0000<0
003oooooool05Oooo`<0000loooo000Goooo00<0003oooooool00P0000Coool200002Oooo`<0001E
oooo00<0003oooooool02_ooo`030000oooooooo00coool00`000?ooooooo`0Noooo00<0003ooooo
ool06_ooo`030000oooooooo02Goool00`000?ooooooo`0Coooo1_l003;oool6o`0000?oool0003o
ool05Oooo`<0000loooo000Foooo0P0000;oool200001?ooo`800009oooo00<0003oooooool0E?oo
o`030000oooooooo00_oool00`000?ooooooo`0;oooo00<0003oooooool07oooo`030000oooooooo
01[oool00`000?ooooooo`0Voooo00<0003oooooool04oooo`Co000doooo1?l000;oool00`000?oo
ooooo`0Doooo0`0003coool001Goool300000_ooo`800004oooo0P0000Woool00`000?ooooooo`1D
oooo00<0003oooooool03?ooo`030000oooooooo00[oool00`000?ooooooo`0Ooooo00<0003ooooo
ool06_ooo`030000oooooooo02Koool00`000?ooooooo`0Doooo0_l003Koool2o`001?ooo`030000
oooooooo01?oool30000??ooo`004_ooo`D00003oooo0P0000Coool200002Oooo`030000oooooooo
05Coool00`000?ooooooo`0<oooo00<0003oooooool02Oooo`030000oooooooo023oool00`000?oo
ooooo`0Ioooo00<0003oooooool09oooo`030000oooooooo01Coool00`000?ooooooo`0koooo00<0
003oooooool04_ooo`8000000oooo`000?ooo`0koooo000Coooo0`0000Coool200001?ooo`800009
oooo00<0003oooooool0Doooo`030000oooooooo00koool00`000?ooooooo`08oooo00<0003ooooo
ool08?ooo`030000oooooooo01Woool00`000?ooooooo`0Woooo00<0003oooooool04oooo`030000
oooooooo03goool00`000?ooooooo`0Aoooo0P000003oooo0000oooo03_oool001?oool00`000?oo
ooooo`05oooo00<0003oooooool00_ooo`030000oooooooo00Soool00`000?ooooooo`1Coooo00<0
003oooooool03oooo`030000oooooooo00?oool4o`0000<0003oooooool08?ooo`030000oooooooo
01Woool00`000?ooooooo`0Xoooo00<0003oooooool04_ooo`030000oooooooo03goool00`000?oo
ooooo`0Aoooo0P000003oooo0000oooo03_oool001Coool400000oooo`800002oooo0P0000[oool2
0000E?ooo`030000oooooooo00ooool00`000?ooooooo`02oooo1_l002;oool00`000?ooooooo`0I
oooo00<0003oooooool0:?ooo`030000oooooooo01;oool00`000?ooooooo`0noooo00<0003ooooo
ool04?ooo`8000000oooo`000?ooo`0koooo000Doooo100000Coool400002oooo`030000oooooooo
05?oool00`000?ooooooo`0@oooo00@0003oooooooooool6o`008?ooo`Co000Joooo00<0003ooooo
ool0:Oooo`030000oooooooo013oool00`000?ooooooo`0ooooo00<0003oooooool04?ooo`800000
0oooo`000?ooo`0koooo000[oooo00<0003oooooool0D_ooo`030000oooooooo01;oool00`000?oo
ooooo`06o`007oooo`Ko000Ioooo00<0003oooooool0:Oooo`030000oooooooo013oool00`000?oo
ooooo`10oooo00<0003oooooool03oooo`8000000oooo`000?ooo`0koooo000[oooo00<0003ooooo
ool0D_ooo`030000oooooooo01?oool300001?l0023oool6o`006Oooo`030000oooooooo02Woool0
0`000?ooooooo`0?oooo00<0003oooooool0@Oooo`030000oooooooo00ooool2000000?oool0003o
ool0>oooo`00:oooo`030000oooooooo05;oool00`000?ooooooo`0Eoooo00@0003ooooo003o000Q
oooo1_l001Soool00`000?ooooooo`0[oooo00<0003oooooool03_ooo`030000oooooooo047oool0
0`000?ooo`00000>oooo0`000003oooo0000oooo03_oool002_oool00`000?ooooooo`1Boooo00<0
003oooooool0>oooo`Co000Ioooo00<0003oooooool0:oooo`030000oooooooo00goool00`000?oo
ooooo`12oooo00@0003oool000000005oooo00<0003oooooool01Oooo`<000000oooo`000?ooo`0k
oooo000[oooo0P0005?oool00`000?ooooooo`0loooo0_l000030000oooooooo01Ooool00`000?oo
ooooo`0/oooo00<0003oooooool03?ooo`030000oooooooo04;oool400001Oooo`030000oooooooo
00Coool40000?_ooo`00:oooo`030000oooooooo057oool00`000?ooooooo`0ooooo00<0003ooooo
ool05oooo`030000oooooooo02coool00`000?ooooooo`0;oooo00<0003oooooool0@oooo`@00005
oooo00<0003oooooool01?ooo`@0000noooo000[oooo00<0003oooooool0DOooo`030000oooooooo
043oool00`000?ooooooo`0Foooo00<0003oooooool0;?ooo`030000oooooooo00_oool00`000?oo
ooooo`14oooo00<0003oool000001Oooo`030000oooooooo00?oool50000?_ooo`00:oooo`030000
oooooooo057oool00`000?ooooooo`10oooo00<0003oooooool05_ooo`030000oooooooo02goool0
0`000?ooooooo`0:oooo00<0003oooooool0A?ooo`030000oooo000000;oool010000?ooooooo`00
00Goool50000?_ooo`00:oooo`030000oooooooo00goool4o`00@?ooo`030000oooooooo043oool0
0`000?ooooooo`0Foooo00<0003oooooool0:oooo`Co000;oooo00<0003oooooool0A?ooo`030000
oooo000000;oool010000?ooooooo`0000Goool50000?_ooo`00:oooo`030000oooooooo00coool6
o`006Oooo`<0000Roooo00<0003oooooool0@Oooo`030000oooooooo01Goool00`000?ooooooo`0[
oooo1_l000Woool00`000?ooooooo`17oooo100000;oool300000oooo`D0000noooo000[oooo0P00
00goool6o`006?ooo`050000oooooooooooo0000027oool00`000?ooooooo`11oooo00<0003ooooo
ool05Oooo`030000oooooooo02_oool6o`002Oooo`030000oooooooo04Soool3000000?oool0003o
ool00P0000;oool50000?oooo`00:oooo`030000oooooooo00coool6o`006?ooo`030000oooooooo
00;oool00`000?ooooooo`0Noooo00<0003oooooool0@Oooo`030000oooooooo01Goool00`000?oo
ooooo`0[oooo1_l000Soool00`000?ooooooo`19oooo0`000003oooo0000oooo00800002oooo1@00
03ooool002_oool00`000?ooooooo`0=oooo1?l001Soool00`000?ooooooo`03oooo00<0003ooooo
ool07_ooo`030000oooooooo04;oool00`000?ooooooo`0Doooo00<0003oooooool0;?ooo`Co0000
0`000?ooooooo`05oooo00<0003oooooool0B_ooo`<000000oooo`000?ooo`0200000_ooo`<00000
0oooo`000?ooo`0noooo000[oooo00<0003oooooool03_ooo`;o00000`000?ooooooo`0Eoooo00<0
003oooooool01?ooo`030000oooooooo01koool00`000?ooooooo`12oooo00<0003oooooool05?oo
o`030000oooooooo02goool2o`000_ooo`030000oooooooo00?oool00`000?ooooooo`1;oooo1@00
0003oooo0000000000;oool200000_ooo`030000oooooooo03goool002_oool00`000?ooooooo`0@
oooo00<0003oooooool05Oooo`030000oooooooo00Goool00`000?ooooooo`0Loooo00<0003ooooo
ool0@oooo`030000oooooooo01Coool00`000?ooooooo`0boooo0P000004oooo000000000000COoo
o`D000001Oooo`00000000000?ooo`0200000_ooo`030000oooooooo03goool002_oool00`000?oo
ooooo`0@oooo00<0003oooooool05?ooo`030000oooooooo00Koool00`000?ooooooo`0Loooo00<0
003oooooool0@oooo`030000oooooooo01?oool00`000?ooooooo`0doooo0`0004ooool5000000Go
ool000000000003oool00P0000;oool00`000?ooooooo`0moooo000[oooo0P00017oool00`000?oo
ooooo`0Doooo00<0003oooooool01oooo`030000oooooooo01_oool00`000?ooooooo`13oooo00<0
003oooooool04oooo`030000oooooooo08Koool5000000?oool000000000100000;oool00`000?oo
ooooo`0moooo000[oooo00<0003oooooool04?ooo`030000oooooooo01?oool00`000?ooooooo`08
oooo00<0003oooooool06oooo`030000oooooooo04?oool00`000?ooooooo`0Coooo00<0003ooooo
ool0Qoooo`<00002oooo1P0000;oool00`000?ooooooo`0moooo000Doooo00<0003oooooool01?oo
o`@0000<oooo00<0003oooooool04Oooo`030000oooooooo01;oool00`000?ooooooo`08oooo00<0
003oooooool06_ooo`030000oooooooo04Coool00`000?ooooooo`0Coooo00<0003oooooool0Qooo
o`<00002oooo1P0000;oool00`000?ooooooo`0moooo000Eoooo00<0003oooooool00oooo`050000
oooooooooooo000000_oool00`000?ooooooo`0Aoooo00<0003oooooool04_ooo`030000oooooooo
00Woool00`000?ooooooo`0Ioooo00<0003oooooool0AOooo`030000oooooooo01;oool00`000?oo
ooooo`27oooo0P0000?oool600000_ooo`030000oooooooo03goool001Goool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003ooooo
ool02_ooo`030000oooooooo01Woool00`000?ooooooo`15oooo00<0003oooooool04_ooo`030000
oooooooo08Ooool200000oooo`@000000oooo`000?ooo`11oooo000Eoooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo
00[oool00`000?ooooooo`0Ioooo00<0003oooooool0AOooo`030000oooooooo017oool00`000?oo
ooooo`29oooo00@0003oooooooooool40000A?ooo`005_ooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo0`00017oool00`000?ooooooo`0Aoooo00<0003oooooool02_ooo`030000oooooooo
01Woool00`000?ooooooo`15oooo00<0003oooooool04Oooo`030000oooooooo08goool40000A?oo
o`005_ooo`030000oooooooo00Koool200002_ooo`030000oooooooo01;oool00`000?ooooooo`0?
oooo00<0003oooooool03?ooo`030000oooooooo01Ooool00`000?ooooooo`16oooo00<0003ooooo
ool04Oooo`030000oooooooo08goool30000AOooo`005oooo`030000oooooooo00Coool300002_oo
o`030000oooooooo01;oool00`000?ooooooo`0?oooo00<0003oooooool03?ooo`030000oooooooo
01Ooool00`000?ooooooo`16oooo00<0003oooooool04Oooo`030000oooooooo08ooool00`000?oo
ooooo`13oooo000Goooo00@0003oooooooooool500002oooo`030000oooooooo01;oool00`000?oo
ooooo`0?oooo00<0003oooooool03?ooo`030000oooooooo01Ooool00`000?ooooooo`16oooo00<0
003oooooool04Oooo`030000oooooooo08ooool00`000?ooooooo`13oooo000Goooo00<0003ooooo
ool00_ooo`<0000<oooo00<0003oooooool04_ooo`030000oooooooo00koool00`000?ooooooo`0>
oooo00<0003oooooool05_ooo`030000oooooooo04Ooool00`000?ooooooo`0@oooo00<0003ooooo
ool0Soooo`030000oooooooo04?oool0017oool00`000?ooooooo`04oooo00D0003oooooooooool0
00003_ooo`030000oooooooo01?oool00`000?ooooooo`0=oooo00<0003oooooool03_ooo`030000
oooooooo01Goool00`000?ooooooo`18oooo00<0003oooooool03oooo`030000oooooooo093oool0
0`000?ooooooo`13oooo000Boooo1`0000Coool400002_ooo`80000Doooo00<0003oooooool03Ooo
o`030000oooooooo00goool4o`005Oooo`030000oooooooo04Soool00`000?ooooooo`0?oooo00<0
003oooooool0e_ooo`004_ooo`P00003oooo100000[oool00`000?ooooooo`0Coooo00<0003ooooo
ool02_ooo`Co000>oooo1_l001Coool00`000?ooooooo`18oooo00<0003oooooool03oooo`030000
oooooooo0=Koool002_oool00`000?ooooooo`0Coooo00<0003oooooool02Oooo`Ko000=oooo1_l0
01Coool00`000?ooooooo`18oooo00<0003oooooool03oooo`030000oooooooo0=Koool002_oool0
0`000?ooooooo`0Coooo00<0003oooooool02Oooo`Ko000=oooo1_l001?oool00`000?ooooooo`19
oooo00<0003oooooool03oooo`030000oooooooo08goool4o`00AOooo`00:oooo`030000oooooooo
01Coool00`000?ooooooo`08oooo1_l000koool4o`005?ooo`030000oooooooo04[oool00`000?oo
ooooo`0>oooo00<0003oooooool0S?ooo`Ko0014oooo000[oooo00<0003oooooool05?ooo`030000
oooooooo00Woool4o`004?ooo`;o00000`000?ooooooo`0Boooo00<0003oooooool0B_ooo`030000
oooooooo00goool00`000?ooooooo`2=oooo1_l004Coool002_oool200005Oooo`030000oooooooo
00[oool2o`004oooo`030000oooooooo01;oool00`000?ooooooo`1:oooo00<0003oooooool03Ooo
o`030000oooooooo08goool6o`00A?ooo`00:oooo`030000oooooooo01Coool00`000?ooooooo`0:
oooo00<0003oooooool04_ooo`030000oooooooo017oool00`000?ooooooo`1;oooo00<0003ooooo
ool03Oooo`030000oooooooo08koool4o`00AOooo`00:oooo`030000oooooooo01Goool00`000?oo
ooooo`08oooo00<0003oooooool05?ooo`030000oooooooo013oool00`000?ooooooo`1;oooo00<0
003oooooool03Oooo`030000oooooooo08ooool2o`00A_ooo`00:oooo`030000oooooooo01Goool0
0`000?ooooooo`08oooo00<0003oooooool05?ooo`030000oooooooo013oool00`000?ooooooo`1<
oooo00<0003oooooool03?ooo`030000oooooooo0=Ooool002_oool00`000?ooooooo`0Eoooo00<0
003oooooool02?ooo`030000oooooooo01Coool00`000?ooooooo`0@oooo00<0003oooooool0C?oo
o`030000oooooooo00coool00`000?ooooooo`3Goooo000[oooo00<0003oooooool05Oooo`030000
oooooooo00Soool00`000?ooooooo`0Doooo00<0003oooooool03oooo`030000oooooooo04goool0
0`000?ooooooo`0;oooo00<0003oooooool0f?ooo`00:oooo`80000Foooo00<0003oooooool01ooo
o`030000oooooooo01Koool00`000?ooooooo`0>oooo00<0003oooooool0COooo`030000oooooooo
00_oool00`000?ooooooo`3Hoooo000[oooo00<0003oooooool05_ooo`030000oooooooo00Koool0
0`000?ooooooo`0Foooo00<0003oooooool03_ooo`030000oooooooo04goool00`000?ooooooo`0;
oooo00<0003oooooool0f?ooo`00:oooo`030000oooooooo01Koool00`000?ooooooo`06oooo00<0
003oooooool05_ooo`030000oooooooo00koool00`000?ooooooo`1>oooo00<0003oooooool02_oo
o`030000oooooooo0=Soool002_oool00`000?ooooooo`0Foooo00<0003oooooool01Oooo`030000
oooooooo01Soool00`000?ooooooo`0<oooo00<0003oooooool0Coooo`030000oooooooo00[oool0
0`000?ooooooo`3Hoooo000[oooo00<0003oooooool05oooo`030000oooooooo00Coool00`000?oo
ooooo`0Hoooo00<0003oooooool03?ooo`030000oooooooo04ooool00`000?ooooooo`0:oooo00<0
003oooooool0f?ooo`00:oooo`030000oooooooo01Ooool00`000?ooooooo`04oooo00<0003ooooo
ool06?ooo`030000oooooooo00Woool4o`00DOooo`030000oooooooo00Woool00`000?ooooooo`3I
oooo000[oooo0P0001Woool00`000?ooooooo`02oooo00<0003oooooool06_ooo`030000oooooooo
00Ooool6o`00DOooo`030000oooooooo00Soool00`000?ooooooo`3Ioooo000[oooo00<0003ooooo
ool06?ooo`050000oooooooooooo000001goool00`000?ooooooo`07oooo1_l0057oool00`000?oo
ooooo`05oooo1?l00=_oool002_oool00`000?ooooooo`0Ioooo0`0001koool00`000?ooooooo`07
oooo1_l0057oool00`000?ooooooo`04oooo1_l00=[oool000Woool600001?ooo`@00005oooo1000
00_oool00`000?ooooooo`0koooo00<0003oooooool01oooo`Co001Boooo00<0003oooooool01?oo
o`Ko003Joooo000;oooo0P0000Goool200000_ooo`800003oooo0P0000;oool200002_ooo`030000
oooooooo03_oool00`000?ooooooo`08oooo0_l005Coool00`000?ooooooo`03oooo1_l00=[oool0
00_oool200001Oooo`030000oooooooo00;oool01@000?ooooooooooo`000004oooo00<0003ooooo
ool02?ooo`030000oooooooo03_oool00`000?ooooooo`08oooo00<0003oooooool0Doooo`030000
oooooooo00Coool4o`00foooo`002oooo`800004oooo0P0000Coool2000000?oool0000000001?oo
o`800009oooo0`0003_oool00`000?ooooooo`08oooo00<0003oooooool0Doooo`030000oooooooo
00Goool2o`00g?ooo`002oooo`800004oooo0P0000Coool2000000?oool0000000001?ooo`800009
oooo00<0003oooooool0??ooo`030000oooooooo00Koool00`000?ooooooo`1Doooo00<0003ooooo
ool01_ooo`030000oooooooo0=[oool000_oool200001?ooo`800004oooo0P000003oooo00000000
00Coool200002Oooo`030000oooooooo03coool00`000?ooooooo`06oooo00<0003oooooool0EOoo
o`030000oooooooo00Coool00`000?ooooooo`3Koooo000;oooo0P0000Coool200001?ooo`800000
0oooo`0000000004oooo0P0000Woool00`000?ooooooo`0loooo00<0003oooooool01_ooo`030000
oooooooo05Goool00`000?ooooooo`04oooo00<0003oooooool0foooo`002oooo`800004oooo0P00
00Coool2000000?oool0000000001?ooo`800009oooo00<0003oooooool0?Oooo`030000oooooooo
00Coool00`000?ooooooo`1Goooo00<0003oooooool00_ooo`030000oooooooo0=coool000_oool2
00001?ooo`800004oooo0P000003oooo0000000000Coool200002Oooo`030000oooooooo03goool0
0`000?ooooooo`04oooo00<0003oooooool0Eoooo`030000oooooooo00;oool00`000?ooooooo`3L
oooo000;oooo0P0000Goool00`000?ooooooo`02oooo00D0003oooooooooool000001?ooo`030000
oooooooo00Soool20000?oooo`030000oooooooo00;oool00`000?ooooooo`1Hoooo0P000003oooo
000000000=ooool000Woool400001Oooo`800002oooo0P0000?oool200000_ooo`80000:oooo00<0
003oooooool0?oooo`050000oooooooooooo000005_oool30000h?ooo`002oooo`800006oooo1000
00Goool400002oooo`030000oooooooo03ooool40000oooood3oool002_oool00`000?ooooooo`3o
ooooPoooo`00:oooo`030000oooooooo0?oooon3oooo000[oooo00<0003oooooool0oooooh?oool0
02_oool00`000?ooooooo`3oooooPoooo`00:oooo`80003oooooQ?ooo`00:oooo`030000oooooooo
0?oooon3oooo000[oooo00<0003oooooool0oooooh?oool002_oool00`000?ooooooo`3oooooPooo
o`00:oooo`030000oooooooo0?oooon3oooo000[oooo00<0003oooooool0oooooh?oool002_oool2
0000ooooohCoool002_oool00`000?ooooooo`3oooooPoooo`00:oooo`030000oooooooo0?oooon3
oooo000[oooo00<0003oooooool0oooooh?oool002_oool00`000?ooooooo`3oooooPoooo`00:ooo
o`030000oooooooo0?oooon3oooo000[oooo0P000?oooon4oooo000[oooo00<0003oooooool0oooo
oh?oool000Woool600000_ooo`L00003oooo100000coool00`000?ooooooo`3oooooPoooo`002ooo
o`800005oooo1`0000;oool01@000?ooooooooooo`00000;oooo00<0003oooooool0oooooh?oool0
00_oool200001_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02?oo
o`030000oooooooo0?oooon3oooo000;oooo0P0000Ooool00`000?ooooooo`09oooo00<0003ooooo
ool02?ooo`030000oooooooo0?oooon3oooo000;oooo0P0000Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`<0003oooooPoooo`002oooo`800008oooo0P0000Soool200002_ooo`030000
oooooooo0?oooon3oooo000;oooo0P0000Woool00`000?ooooooo`05oooo0`0000[oool00`000?oo
ooooo`3oooooPoooo`002oooo`800009oooo0P0000?oool500002oooo`030000oooooooo0?oooon3
oooo000;oooo0P0000Woool200001?ooo`<0000<oooo00<0003oooooool0oooooh?oool000_oool2
00001?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool00`000?ooooooo`3o
ooooPoooo`002Oooo`@00005oooo00<0003oooooool00`0000Goool400002_ooo`80003oooooQ?oo
o`002oooo`800006oooo100000Koool400002_ooo`030000oooooooo0?oooon3oooo000[oooo00<0
003oooooool0oooooh?oool002_oool00`000?ooooooo`3oooooPoooo`00:oooo`030000oooooooo
0?oooon3oooo000[oooo00<0003oooooool0oooooh?oool002_oool20000ooooohCoool002_oool0
0`000?ooooooo`3oooooPoooo`00:oooo`030000oooooooo0?oooon3oooo000[oooo00<0003ooooo
ool0oooooh?oool002_oool00`000?ooooooo`3oooooPoooo`00:oooo`030000oooooooo0?oooon3
oooo000[oooo0P000?oooon4oooo000[oooo00<0003oooooool0oooooh?oool002_oool00`000?oo
ooooo`3oooooPoooo`00:oooo`030000oooooooo0?oooon3oooo000[oooo00<0003oooooool0oooo
oh?oool002_oool00`000?ooooooo`3oooooPoooo`00:oooo`80003oooooQ?ooo`00:oooo`030000
oooooooo0?oooon3oooo000[oooo00<0003oooooool0oooooh?oool000Woool600000oooo`@00006
oooo100000_oool00`000?ooooooo`3oooooPoooo`002oooo`800005oooo00D0003oooooooooool0
00001?ooo`800002oooo0P0000[oool00`000?ooooooo`3oooooPoooo`002oooo`80000:oooo00D0
003oooooooooool000001?ooo`030000oooooooo00Soool00`000?ooooooo`3oooooPoooo`002ooo
o`80000:oooo00<0003oooooool00P0000Coool200002Oooo`<0003oooooPoooo`002oooo`80000:
oooo00<0003oooooool00P0000Coool20000ooooohooool000_oool200002Oooo`800002oooo0P00
00Coool20000ooooohooool000_oool200002?ooo`<00002oooo0P0000Coool20000ooooohooool0
00_oool200001Oooo`D00003oooo0P0000Coool20000ooooohooool000_oool200001_ooo`<00004
oooo0P0000Coool20000ooooohooool000_oool200001_ooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo00<0003oooooool0ooooohkoool000Woool400001oooo`@00003oooo0P0000;oool2
0000oooooi3oool000_oool200001oooo`@00004oooo10000?oooonAoooo003ooooo/Oooo`00oooo
ok7oool00?oooonaoooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.30342, -59.2459, 
  0.0799924, 1.23267}}]
}, Open  ]],

Cell[TextData[{
  "Die Verbesserung der Interpolation ist vorgestellt, ebenso die Grenze \
einer Numerik mit ",
  Cell[BoxData[
      \(TraditionalForm\`16\)]],
  "-stelliger interner Additionsgenauigkeit bei Verwendung eines Polynoms ",
  Cell[BoxData[
      \(59\)]],
  "-ten Grades."
}], "Text"],

Cell[TextData[{
  "Die Gl\[ADoubleDot]ttung von verrauschten Me\[SZ]werten ist notwendig, um \
die relevante Information der Me\[SZ]reihe im Sinne des ",
  StyleBox["Abtasttheorems",
    FontSlant->"Italic"],
  " mit einer ",
  StyleBox["Hauptl\[ODoubleDot]sung einer Differenzengleichung",
    FontSlant->"Italic"],
  " (vgl. ",
  ButtonBox["[N",
    ButtonData:>"[Noer1924]",
    ButtonStyle->"Hyperlink"],
  ButtonBox["\[OSlash]",
    ButtonData:>"[Noer1924]",
    ButtonStyle->"Hyperlink"],
  ButtonBox["r1924]",
    ButtonData:>"[Noer1924]",
    ButtonStyle->"Hyperlink"],
  ") vergleichen zu k\[ODoubleDot]nnen."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Fehlerrechnung"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Arithmetisches Mittel"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Motivation"
}], "Subsubsection"],

Cell[TextData[{
  "Nachdem nun einige Verfahren der Me\[SZ]wert-Interpolation vorgestellt \
wurden, erscheint es sinnvoll, dazu passend die ",
  StyleBox["Fehlerrechnung",
    FontSlant->"Italic"],
  " anzuschlie\[SZ]en."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Definition"
}], "Subsubsection"],

Cell[TextData[{
  "Ein ",
  StyleBox["Fehler",
    FontSlant->"Italic"],
  " gibt an, um wieviel der entsprechenden Einheit ein errechneter Wert von \
einem gemessenen Wert abweicht. Grundlage der Fehlerbehandlung ist die \
Messung und nicht die Theorie, da ja mehrere Auswertetheorien zu einer \
Me\[SZ]reihe vorhanden sein k\[ODoubleDot]nnen."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Durchschnitt"
}], "Subsubsection"],

Cell[TextData[{
  "Me\[SZ]reihen unterliegen immer wieder ",
  StyleBox["Schwankungen",
    FontSlant->"Italic"],
  ", obwohl nur der Durchschnitt interessant ist. Bei der \
Pr\[ADoubleDot]sentation von Me\[SZ]reihen kommt es darauf an, das \
Wesentliche kurz und genau zu formulieren."
}], "Text"],

Cell["\<\
Eine Betrachtung des Benzinverbrauchs ergab folgende \
Me\[SZ]reihe:\
\>", "Text"],

Cell[BoxData[GridBox[{
        {\(km - Differenz\), "420", "516", "506", "516", "506", "482", "434", 
          "446", "420"},
        {\(\ Tankf\[UDoubleDot]llung\/\([\ Liter\ ]\)\), "31.6", "40.2", 
          "42.4", "42.2", "38.9", "40.8", "36.0", "42.5", "30.5"}
        },
      GridFrame->True,
      RowLines->True,
      ColumnLines->True]], "NumberedTable"],

Cell["\<\
F\[UDoubleDot]r die Pr\[ADoubleDot]sentation interessiert der \
durchschnittliche Benzinverbrauch und die zugeh\[ODoubleDot]rige \
Schwankung.\
\>", "Text"],

Cell[TextData[{
  "Es liegen ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " Wertepaare ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_\[Mu], y\_\[Mu]}\)]],
  " vor, so da\[SZ] sich der Durchschnitt als das arithmetische Mittel \
ergibt:"
}], "Text"],

Cell[BoxData[
    \(\(f[x, y]\)\&_ := 
      \(1\/N\) \(\[Sum]\+\(\[Mu]\  = \ 1\)\%N f[x\_\[Mu], y\_\[Mu]]\)\)], 
  "NumberedEquation",
  CellTags->"Arithmetisches Mittel"],

Cell["\<\
F\[UDoubleDot]r das konkrete Beispiel ergibt sich also ein \
durchschnittlicher Benzinverbrauch von:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(wertepaare[2] = 
      \({First[#] "\<km\>", Last[#] "\<l\>"}&
          \)/@{{420, 31.6}, {516, 40.2}, {506, 42.4}, {516, 42.2}, {506, 
            38.9}, {482, 40.8}, {434, 36.0}, {446, 42.5}, {420, 30.5}}; \n
    benzinverbrauch[2] = 
      \(\(Last[#]\/\(First[#] HoldForm[100]\)\) 100&\)/@wertepaare[2]\), 
    \(durchschnitt[2] = 
      Plus@@benzinverbrauch[2]\/Length[benzinverbrauch[2]]\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        FractionBox[\(7.52380952380952461`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(7.79069767441860516`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(8.37944664031620511`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(8.17829457364341116`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(7.687747035573123`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(8.46473029045642988`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(8.29493087557603736`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(9.52914798206277957`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(7.26190476190476275`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]]}], "}"}]], "Output"],

Cell[BoxData[
    FractionBox[\(8.12341215086231827`\ "l"\), 
      RowBox[{\("km"\), " ", 
        TagBox["100",
          HoldForm]}]]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Mittlerer Fehler ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Schwankung"
}], "Subsubsection"],

Cell["\<\
Zu dem errechneten Durchschnitt kann jeweils die Schwankung des Me\
\[SZ]werts bestimmt werden:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(schwankung[2] = \(# - durchschnitt[2]&\)/@benzinverbrauch[2]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"-", 
          FractionBox[\(0.599602627052793657`\ "l"\), 
            RowBox[{\("km"\), " ", 
              TagBox["100",
                HoldForm]}]]}], ",", 
        RowBox[{"-", 
          FractionBox[\(0.332714476443713103`\ "l"\), 
            RowBox[{\("km"\), " ", 
              TagBox["100",
                HoldForm]}]]}], ",", 
        FractionBox[\(0.256034489453886848`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(0.0548824227810928988`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        RowBox[{"-", 
          FractionBox[\(0.43566511528919527`\ "l"\), 
            RowBox[{\("km"\), " ", 
              TagBox["100",
                HoldForm]}]]}], ",", 
        FractionBox[\(0.341318139594111613`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(0.171518724713719095`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        FractionBox[\(1.4057358312004613`\ "l"\), 
          RowBox[{\("km"\), " ", 
            TagBox["100",
              HoldForm]}]], ",", 
        RowBox[{"-", 
          FractionBox[\(0.861507388957555519`\ "l"\), 
            RowBox[{\("km"\), " ", 
              TagBox["100",
                HoldForm]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Die Summe aller Schwankungen ist bei Verwendung des arithmetischen \
Mittelwerts immer Null:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Plus@@schwankung[2]\), 
    \(% // Chop\)}], "Input"],

Cell[BoxData[
    FractionBox[\(1.42108547152020037`*^-14\ "l"\), 
      RowBox[{\("km"\), " ", 
        TagBox["100",
          HoldForm]}]]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Schwankungsbetrag"
}], "Subsubsection"],

Cell["\<\
Werden jeweils die Betr\[ADoubleDot]ge der Schwankungen addiert, so \
ergibt sich ein durchschnittlicher Schwankungsbetrag von:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(schwankungsbetrag[2]\), "=", 
      RowBox[{
      \(Plus@@\((Abs/@schwankung[2])\)\/Length[schwankung[2]]\), "/.", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"Abs", "[", 
              FractionBox[\("\<l\>"\), 
                RowBox[{\("\<km\>"\), " ", 
                  TagBox["100",
                    HoldForm]}]], "]"}], "\[Rule]", 
            FractionBox[\("\<l\>"\), 
              RowBox[{\("\<km\>"\), " ", 
                TagBox["100",
                  HoldForm]}]]}], "}"}]}]}]], "Input"],

Cell[BoxData[
    FractionBox[\(0.495442135054058852`\ "l"\), 
      RowBox[{\("km"\), " ", 
        TagBox["100",
          HoldForm]}]]], "Output"]
}, Open  ]],

Cell["\<\
Damit ist die erste M\[ODoubleDot]glichkeit zur Formulierung des \
Ergebnisses gefunden:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(durchschnitt[2] \[PlusMinus] schwankungsbetrag[2]\)], "Input"],

Cell[BoxData[
    RowBox[{
      FractionBox[\(8.12341215086231827`\ "l"\), 
        RowBox[{\("km"\), " ", 
          TagBox["100",
            HoldForm]}]], "\[PlusMinus]", 
      FractionBox[\(0.495442135054058852`\ "l"\), 
        RowBox[{\("km"\), " ", 
          TagBox["100",
            HoldForm]}]]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Schwankungsquadrate"
}], "Subsubsection"],

Cell["\<\
Die Betragsfunktion ist mathematisch komplizierter als das Quadrat, \
da f\[UDoubleDot]r reelle Zahlen gilt:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Abs[x] \[Equal] \@x\^2 /. {x \[Rule] #}&\)/@Range[\(-4\), 4]\)], 
  "Input"],

Cell[BoxData[
    \({True, True, True, True, True, True, True, True, True}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In der Theorie der Statistik wird also das Schwankungsquadrat oder \
Fehlerquadrat ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " minimiert, woraus das arithmetische Mittel sogar folgt:"
}], "Text"],

Cell[BoxData[
    \(\[Delta] \((\[Sum]\+\(\[Mu]\  = \ 1\)\%N\((x\_\[Mu] - x\&_)\)\^2)\) 
      \[Equal] 0\ \ \[DoubleLongLeftRightArrow]\ \ x\&_ \[Equal] 
      \(1\/N\) \(\[Sum]\+\(\[Mu]\  = \ 1\)\%N x\_\[Mu]\)\)], 
  "NumberedEquation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(schwankungsquadrat[2] = 
      Plus@@\((\(#\^2&\)/@schwankung[2])\)\/Length[schwankung[2]]\)], "Input"],

Cell[BoxData[
    FractionBox[\(0.399199668855192371`\ "l"\^2\), 
      RowBox[{\("km"\^2\), " ", 
        SuperscriptBox[
          TagBox["100",
            HoldForm], "2"]}]]], "Output"]
}, Open  ]],

Cell["\<\
Um nun dieselbe Einheit wie beim arithmetischen Mittel zu bekommen, \
mu\[SZ] noch die (positive) Wurzel gezogen werden, damit folgender Mittelwert \
resultiert:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(durchschnitt[2] \[PlusMinus] \@schwankungsquadrat[2] // PowerExpand\)], 
  "Input"],

Cell[BoxData[
    RowBox[{
      FractionBox[\(8.12341215086231827`\ "l"\), 
        RowBox[{\("km"\), " ", 
          TagBox["100",
            HoldForm]}]], "\[PlusMinus]", 
      FractionBox[\(0.631822497902055069`\ "l"\), 
        RowBox[{\("km"\), " ", 
          TagBox["100",
            HoldForm]}]]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Der mittlere Fehler ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " errechnet sich wie folgt:"
}], "Text"],

Cell[BoxData[
    \(\[Chi] \[Equal] \@\[Chi]\^2 := 
      \@\(\(1\/N\) 
          \(\[Sum]\+\(\[Mu]\  = \ 1\)\%N\((x\_\[Mu] - x\&_)\)\^2\)\)\)], 
  "NumberedEquation",
  CellTags->"mittlerer Fehler"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Ein Wort zur Rundung"
}], "Subsubsection"],

Cell[TextData[{
  "Der mittlere Fehler ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] \[Equal] \@\[Chi]\^2\)]],
  " wird in aller Regel auf eine oder zwei Stellen Genauigkeit angegeben. Der \
zugeh\[ODoubleDot]rige Me\[SZ]wert wird nicht genauer angegeben als es der \
mittlere Fehler ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " zul\[ADoubleDot]\[SZ]t."
}], "Text"],

Cell[TextData[{
  "Je nach Schulrichtung wird die ",
  StyleBox["Ingenieurform",
    FontSlant->"Italic"],
  " oder die ",
  StyleBox["wissenschaftliche Form",
    FontSlant->"Italic"],
  " zur Pr\[ADoubleDot]sentation eines Me\[SZ]werts verwendet. Die \
Ingenieurform achtet auf die richtige Gr\[ODoubleDot]\[SZ]enordnung und \
verwendet die Vors\[ADoubleDot]tze Tera-, milli-, nano-, usw. Die \
wissenschaftliche Form gibt auch die Zahl ",
  Cell[BoxData[
      \(TraditionalForm\`100\)]],
  " mit ",
  Cell[BoxData[
      \(TraditionalForm\`1.00*10\^2\)]],
  " an."
}], "Text"],

Cell[TextData[{
  "Um mit den verschiedenen Schulmeinungen zurecht zu kommen, ist es ratsam, \
den errechneten mittleren Fehler mit einer ",
  Cell[BoxData[
      \(TraditionalForm\`\[PlusMinus]\)]],
  "-Toleranz anzugeben. Es gibt auch F\[ADoubleDot]lle, bei denen eine ",
  Cell[BoxData[
      \(TraditionalForm\`\[PlusMinus]\)]],
  "-Toleranz nicht angebracht ist. In diesen F\[ADoubleDot]llen werden zum \
Beispiel Wertebereiche angegeben, etwa in der ",
  StyleBox["Historik",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Fehlerhafte Fehlerrechnung"
}], "Subsubsection"],

Cell[TextData[{
  "In verschiedenen Lehrwerken kursieren noch weitere Formeln zur Berechnung \
von Toleranzen. So gibt es oft genug den Begriff Varianz ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  " statt ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " und ferner eine alternative \"Varianz\", auch ",
  StyleBox["Standardabweichung des Me\[SZ]werts",
    FontSlant->"Italic"],
  " (vgl. ",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", Formel (1-7), Seite 11) genannt, die sich wie folgt errechnet (auch auf \
Taschenrechnern verf\[UDoubleDot]gbar):"
}], "Text"],

Cell[BoxData[
    \(s \[Equal] \[Sigma]\_\(N - 1\) := 
      \@\(\(1\/\(N - 1\)\) 
          \(\[Sum]\+\(\[Mu]\  = \ 1\)\%N\((x\_\[Mu] - x\&_)\)\^2\)\)\)], 
  "NumberedEquation",
  CellTags->"falsche Standardabweichung"],

Cell[TextData[{
  "Eine Motivation zu derart ge\[ADoubleDot]nderten Formeln findet sich z.B. \
bei Baule (",
  ButtonBox["[Baul1956]",
    ButtonData:>"[Baul1956]",
    ButtonStyle->"Hyperlink"],
  ", \[Section] 2., Seite 5-7). Diese Varianten sind einleuchtend motiviert \
und letztlich doch unsachlich. Bei nur einer Messung (",
  Cell[BoxData[
      \(TraditionalForm\`N \[Rule] 1\)]],
  ") ergibt sich bei Formel (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "falsche Standardabweichung"],
  ") ein unbestimmter Ausdruck der Art ",
  Cell[BoxData[
      \(TraditionalForm\`0\/0\)]],
  ", da Mittelwert ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_\)]],
  " und Me\[SZ]wert ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  " identisch sind, w\[ADoubleDot]hrend nach Formel (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "mittlerer Fehler"],
  ") der ",
  StyleBox["mittlere Fehler",
    FontSlant->"Italic"],
  " Null ergibt, was besagt, da\[SZ] eine Einzelmessung \
tats\[ADoubleDot]chlich beliebig genau interpretiert werden kann. Als \
Toleranz der Messung wird bei Einzelmessungen die Ablesegenauigkeit des Me\
\[SZ]ger\[ADoubleDot]ts verwendet. Die Toleranz Null kommt also auch mit \
Formel (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "mittlerer Fehler"],
  ") bei keiner Messung vor."
}], "Text"],

Cell[TextData[{
  "Eine weitere Stilbl\[UDoubleDot]te ist der ",
  StyleBox["mittlere Fehler des Mittelwerts",
    FontSlant->"Italic"],
  ", auch als ",
  StyleBox["Standardabweichung des arithmetischen Mittelwerts",
    FontSlant->"Italic"],
  " (vgl. ",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", Formel (1-8), Seite 11; mit Herleitung: ",
  ButtonBox["[GKHK1974]",
    ButtonData:>"[GKHK1974]",
    ButtonStyle->"Hyperlink"],
  ", Seite 631-633) bezeichnet:"
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta]  x\&_ \[Equal] 
      \@\(\(1\/\(N \((N - 1)\)\)\) 
          \(\[Sum]\+\(\[Mu]\  = \ 1\)\%N\((x\_\[Mu] - x\&_)\)\^2\)\)\)], 
  "NumberedEquation"],

Cell["\<\
Durch diese Formel wird suggeriert, da\[SZ] die \
H\[ADoubleDot]ufigkeit des Me\[SZ]vorgangs die Me\[SZ]genauigkeit steigern k\
\[ODoubleDot]nne. Diese Vorstellung ist jedenfalls noch unterwegs.\
\>", 
  "Text"],

Cell[TextData[{
  "Sie m\[UDoubleDot]ssen um diese Formeln wissen und sollten sich fr\
\[UDoubleDot]h genug darauf einstellen, da\[SZ] es zu Auseinandersetzungen \
kommt, wenn ein Kunde einen korrekten mittleren Fehler ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " genannt bekommt. Je nach Firma bedeutet eine angegebene Toleranz etwas \
anderes. Die Frage nach dem ",
  StyleBox["mittleren Fehler",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " f\[UDoubleDot]hrt meistens noch zu vergleichbaren Toleranzen \
unterschiedlicher Angebote."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Statistische Fehlabsch\[ADoubleDot]tzung"
}], "Subsubsection"],

Cell[TextData[{
  "In der Theorie der Statistik taucht mit v\[ODoubleDot]llig anderem \
Hintergrund die sogenannte ",
  StyleBox["Standardnormalverteilung",
    FontSlant->"Italic"],
  " auf, die angeblich die Streuung von Me\[SZ]werten beliebig gut und genau \
beschreibt. Diese Funktion hat in der Statistik ihre Bedeutung, allerdings \
nicht generell. Sie lautet (",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", Formel (1-3), Seite 10):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[x] = 
      Exp[\(-\(\((x - \[Mu])\)\^2\/\(2  \[Sigma]\^2\)\)\)]
          \/\@\(2  \[Pi]\ \[Sigma]\^2\)\)], "Input"],

Cell[BoxData[
    \(E\^\(-\(\((x - \[Mu])\)\^2\/\(2\ \[Sigma]\^2\)\)\)\/\(\@\(2\ \[Pi]\)\ 
        \@\[Sigma]\^2\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Das Integral \[UDoubleDot]ber dieser Funktion f\[UDoubleDot]hrt auf die ",
  StyleBox["unvollst\[ADoubleDot]ndige Gamma-Funktion",
    FontSlant->"Italic"],
  ", die ihrerseits eine ",
  StyleBox["hypergeometrische Funktion",
    FontSlant->"Italic"],
  " darstellt:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\(Exp[\(-\((x - \[Mu])\)\^k\)\/\(2  \[Sigma]\^2\)]
                  \/\@\(2  \[Pi]\ \[Sigma]\^2\)\) \[DifferentialD]x /. {
          k \[Rule] 2} // PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(-\(Gamma[1\/2, \((x - \[Mu])\)\^2\/\(2\ \[Sigma]\^2\)]\/\(2\ 
            \@\[Pi]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(x\^a\) Hypergeometric1F1[a, a + 1, \(-x\)]\)], "Input"],

Cell[BoxData[
    \(Gamma[1 + a] - a\ Gamma[a, x]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die sogenannte ",
  StyleBox["error function",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`Erf[\ ]\)]],
  " geh\[ODoubleDot]rt in den Zoo der \[UDoubleDot]berfl\[UDoubleDot]ssigen \
Funktionen der Mathematik:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]f[x] \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(\(\[Sigma]\ Erf[\(x - \[Mu]\)\/\(\@2\ \[Sigma]\)]\)\/\(2\ 
        \@\[Sigma]\^2\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Folgende bestimmte Integrale ergeben sogenannte ",
  StyleBox["Vertrauensbereiche",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Integral]\_\(\(-k\)\ \[Sigma]\)\%\(k\ \[Sigma]\)f[x] 
            \[DifferentialD]x /. {\[Mu] \[Rule] 0} // PowerExpand\), 
    \(\(% /. {k \[Rule] #}&\)/@Range[6] // N\)}], "Input"],

Cell[BoxData[
    \(Erf[k\/\@2]\)], "Output"],

Cell[BoxData[
    \({0.682689492137085807`, 0.954499736103641538`, 0.997300203936739748`, 
      0.99993665751633376`, 0.999999426696856197`, 0.999999998026824776`}\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "Mit einem ",
  Cell[BoxData[
      \(TraditionalForm\`95  %\)]],
  "-Vertrauensbereich ist also ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Sigma]\)]],
  " gemeint. Die ",
  StyleBox["Normalverteilung",
    FontSlant->"Italic"],
  " stellt inhaltlich ein verbreitetes Trugschlu\[SZ]-Verfahren dar, wenn \
alle Me\[SZ]wertschwankungen damit gedeutet werden sollen. Eine ausf\
\[UDoubleDot]hrlichere Abhandlung dazu findet im Rahmen der \
Statistik-Vorlesung statt."
}], "Text"],

Cell[TextData[{
  "Unter dem Stichwort ",
  Cell[BoxData[
      \(TraditionalForm\`6  \[Sigma]\)]],
  " kursieren einige B\[UDoubleDot]cher f\[UDoubleDot]r Manager, wo eine \
vollst\[ADoubleDot]ndige Qualit\[ADoubleDot]tspr\[UDoubleDot]fung und Qualit\
\[ADoubleDot]tssicherung f\[UDoubleDot]r ein Produkt gefordert wird, so da\
\[SZ] ausschlie\[SZ]lich Qualit\[ADoubleDot]t die Firma verlassen soll. Der \
Aufwand zur Erreichung dieses Ziels ist sehr gro\[SZ], da ja auch noch \
Transportsch\[ADoubleDot]den vorkommen k\[ODoubleDot]nnen."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Zusammengesetzte Ergebnisse"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Motivation"
}], "Subsubsection"],

Cell["\<\
Wird ein Ergebnis aus mehreren Me\[SZ]werten errechnet, so kann die \
Toleranz jeder einzelnen Me\[SZ]gr\[ODoubleDot]\[SZ]e gesondert ber\
\[UDoubleDot]cksichtigt werden, wenn das totale Differential der Ergebnisgr\
\[ODoubleDot]\[SZ]e betrachtet wird.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Fehlerfortpflanzung"
}], "Subsubsection"],

Cell[TextData[{
  "Damit ergibt sich folgende Standardabweichung (vgl. ",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", Formel (1-12), Seite 13; mit Herleitung: ",
  ButtonBox["[GKHK1974]",
    ButtonData:>"[GKHK1974]",
    ButtonStyle->"Hyperlink"],
  ", Seite 632):"
}], "Text"],

Cell[BoxData[
    \(s\_f \[Equal] 
      \@\(\[Sum]\+\(\[Mu]\  = \ 1\)\%N
            \(\((\[PartialD]f\/\[PartialD]x\_\[Mu])\)\^2\) s\_x\%2\)\)], 
  "NumberedEquation",
  CellTags->"Fehlerfortpflanzung"],

Cell[TextData[{
  "Je nachdem, ob Formel (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "mittlerer Fehler"],
  ") oder (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "falsche Standardabweichung"],
  ") in die Formel (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fehlerfortpflanzung"],
  ") eingesetzt wird, fallen die Ergebnisse verschieden aus."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Gr\[ODoubleDot]\[SZ]tfehlerformel"
}], "Subsubsection"],

Cell[TextData[{
  "Beim physikalischen Praktikum wird meist nur der ",
  StyleBox["Gr\[ODoubleDot]\[SZ]tfehler",
    FontSlant->"Italic"],
  " abgesch\[ADoubleDot]tzt, damit die Me\[SZ]toleranz gen\[UDoubleDot]gend \
gro\[SZ] ist, um bei der Fehlerdiskussion nicht zu ausf\[UDoubleDot]hrlich zu \
werden."
}], "Text"],

Cell["\<\
Der Gr\[ODoubleDot]\[SZ]tfehler berechnet sich nach Gau\[SZ] tats\
\[ADoubleDot]chlich aus der Summe der Betr\[ADoubleDot]ge, und zwar wie \
folgt:\
\>", "Text"],

Cell[BoxData[
    \(\[CapitalDelta]f := 
      \[Sum]\+\(\[Mu]\  = \ 1\)\%N|\((\[PartialD]f\/\[PartialD]x\_\[Mu])\) | 
        \[CapitalDelta]x\_\[Mu]\)], "NumberedEquation",
  CellTags->"Groesstfehler"],

Cell["\<\
Liegt im Praktikum ein Literaturwert au\[SZ]erhalb der Gr\
\[ODoubleDot]\[SZ]tfehlerschranke, so liegt entweder ein Me\[SZ]fehler oder \
wahrscheinlicher ein Auswertefehler vor. Es lohnt sich dann, der \
Angelegenheit genauer nachzugehen.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Beispiel"
}], "Subsubsection"],

Cell[TextData[{
  "Im vorgestellten Beispiel wird der Benzinverbrauch als Quotient zweier Me\
\[SZ]gr\[ODoubleDot]\[SZ]en bestimmt. Der zugeh\[ODoubleDot]rige Gr\
\[ODoubleDot]\[SZ]tfehler ergibt sich aus der Genauigkeit von Kilometerz\
\[ADoubleDot]hler ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]s\)]],
  " und Tankuhr ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]V\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta]f \[Equal] 
      f \((\[CapitalDelta]s\/s + \[CapitalDelta]V\/V)\)\)], "NumberedEquation"],

Cell["\<\
Besteht ein Ergebnis nur aus Faktoren, so addieren sich die \
relativen Gr\[ODoubleDot]\[SZ]tfehler zum gesamten \
Gr\[ODoubleDot]\[SZ]tfehler. Im gew\[ADoubleDot]hlten Beispiel ergibt sich:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalDelta]s\/s + \[CapitalDelta]V\/V /. {
        \[CapitalDelta]s \[Rule] 1 "\<km\>", 
        s \[Rule] Plus@@\((First/@wertepaare[2])\)\/Length[wertepaare[2]], 
        \[CapitalDelta]V \[Rule] "\<l\>"\/10, 
        V \[Rule] Plus@@\((Last/@wertepaare[2])\)\/Length[wertepaare[2]]}\)], 
  "Input"],

Cell[BoxData[
    \(0.00472758174363025762`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Der Gr\[ODoubleDot]\[SZ]tfehler ist also deutlich geringer als der \
errechnete ",
  StyleBox["mittlere Fehler",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\@schwankungsquadrat[2]\/durchschnitt[2] // PowerExpand\)], "Input"],

Cell[BoxData[
    \(0.0777779689332869317`\)], "Output"]
}, Open  ]],

Cell["\<\
Diese Situation zeigt, da\[SZ] der Benzinverbrauch je nach Fahrstil \
und Gel\[ADoubleDot]nde schwankt und deshalb \[UDoubleDot]ber dem sehr \
geringen Gr\[ODoubleDot]\[SZ]tfehler liegt. Es stellt sich die Frage, ob der \
Benzinverbrauch nicht besser f\[UDoubleDot]r jedes Volltanken als Schaubild \
dargestellt werden sollte.\
\>", "Text"],

Cell["Mit der M\[ODoubleDot]glichkeit der Interpolation ergibt sich:", "Text"],

Cell[BoxData[
    \(\(benzinkurve[4] = 
      LagrangeInterpolation[
        MapIndexed[{Sequence@@#2, #1}&, benzinverbrauch[2]], d]; \)\)], 
  "Input"],

Cell[BoxData[
    \(\(punkte[4] = 
      ListPlot[Evaluate[
          benzinverbrauch[2]\/\("\<l\>"\/\(HoldForm[100] "\<km\>"\)\)], 
        PlotStyle \[Rule] {PointSize[0.02], Hue[0]}, 
        DisplayFunction \[Rule] Identity]; \)\)], "Input"],

Cell[BoxData[
    \(\(kurve[4] = 
      Plot[Evaluate[
          benzinkurve[4]\/\("\<l\>"\/\(HoldForm[100] "\<km\>"\)\)], {d, 1, 
          Length[wertepaare[2]]}, AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] All, DisplayFunction \[Rule] Identity, 
        AxesLabel 
          \[Rule] {\*"\"\<\!\(Tankz\[ADoubleDot]hler\/\([\\\ ]\)\)\>\"", 
            \*"\"\<\!\(Verbrauch\/\([l\/\(100  km\)]\)\)\>\""}]; \)\)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[kurve[4], punkte[4], DisplayFunction \[Rule] $DisplayFunction]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .51931 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
-0.0952381 0.119048 -0.852148 0.119048 [
[.38095 .08773 -5 -15 ]
[.38095 .08773 5 0 ]
[.61905 .08773 -5 -15 ]
[.61905 .08773 5 0 ]
[.85714 .08773 -5 -15 ]
[.85714 .08773 5 0 ]
[1.025 .10023 0 -15 ]
[1.025 .10023 64 15 ]
[.13036 .21928 -10 -7.5 ]
[.13036 .21928 0 7.5 ]
[.13036 .33833 -16 -7.5 ]
[.13036 .33833 0 7.5 ]
[.13036 .45738 -16 -7.5 ]
[.13036 .45738 0 7.5 ]
[.14286 .54431 -30.5 0 ]
[.14286 .54431 30.5 34 ]
[ 0 0 0 0 ]
[ 1 .51931 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.38095 .10023 m
.38095 .10648 L
s
gsave
.38095 .08773 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.61905 .10023 m
.61905 .10648 L
s
gsave
.61905 .08773 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.85714 .10023 m
.85714 .10648 L
s
gsave
.85714 .08773 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.20238 .10023 m
.20238 .10398 L
s
.2619 .10023 m
.2619 .10398 L
s
.32143 .10023 m
.32143 .10398 L
s
.44048 .10023 m
.44048 .10398 L
s
.5 .10023 m
.5 .10398 L
s
.55952 .10023 m
.55952 .10398 L
s
.67857 .10023 m
.67857 .10398 L
s
.7381 .10023 m
.7381 .10398 L
s
.79762 .10023 m
.79762 .10398 L
s
.08333 .10023 m
.08333 .10398 L
s
.02381 .10023 m
.02381 .10398 L
s
.91667 .10023 m
.91667 .10398 L
s
.97619 .10023 m
.97619 .10398 L
s
.25 Mabswid
0 .10023 m
1 .10023 L
s
gsave
1.025 .10023 -61 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 38 translate 1 -1 scale
63.000000 21.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
66.062500 13.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Tankz\\344hler) show
0.687500 setlinewidth
0.000000 0.000000 0.000000 setrgbcolor
64.312500 18.187500 moveto
55.687500 0.000000 rlineto
stroke
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
89.000000 30.312500 moveto
(@) show
92.937500 30.312500 moveto
(D) show
122.875000 21.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.14286 .21928 m
.14911 .21928 L
s
gsave
.13036 .21928 -71 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.14286 .33833 m
.14911 .33833 L
s
gsave
.13036 .33833 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.14286 .45738 m
.14911 .45738 L
s
gsave
.13036 .45738 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(11) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.14286 .12404 m
.14661 .12404 L
s
.14286 .14785 m
.14661 .14785 L
s
.14286 .17166 m
.14661 .17166 L
s
.14286 .19547 m
.14661 .19547 L
s
.14286 .24309 m
.14661 .24309 L
s
.14286 .2669 m
.14661 .2669 L
s
.14286 .29071 m
.14661 .29071 L
s
.14286 .31452 m
.14661 .31452 L
s
.14286 .36214 m
.14661 .36214 L
s
.14286 .38595 m
.14661 .38595 L
s
.14286 .40976 m
.14661 .40976 L
s
.14286 .43357 m
.14661 .43357 L
s
.14286 .07642 m
.14661 .07642 L
s
.14286 .05261 m
.14661 .05261 L
s
.14286 .0288 m
.14661 .0288 L
s
.14286 .00499 m
.14661 .00499 L
s
.14286 .48119 m
.14661 .48119 L
s
.14286 .50499 m
.14661 .50499 L
s
.25 Mabswid
.14286 0 m
.14286 .51931 L
s
gsave
.14286 .54431 -91.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
63.000000 21.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
66.062500 13.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Verbrauch) show
0.687500 setlinewidth
0.000000 0.000000 0.000000 setrgbcolor
64.312500 18.187500 moveto
52.250000 0.000000 rlineto
stroke
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.875000 32.312500 moveto
(@) show
89.937500 27.187500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.500000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
0.687500 setlinewidth
0.000000 0.000000 0.000000 setrgbcolor
76.312500 28.875000 moveto
28.562500 0.000000 rlineto
stroke
77.875000 36.687500 moveto
(100) show
91.562500 36.687500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
( ) show
93.187500 36.687500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.500000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(km) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
107.562500 32.312500 moveto
(D) show
119.437500 21.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Math2
%%+ font Times-Roman
grestore
.5 Mabswid
.02381 .04354 m
.02846 .08037 L
.03279 .10815 L
.03754 .13222 L
.04262 .15149 L
.04518 .15895 L
.04795 .16552 L
.05058 .17038 L
.053 .17381 L
.05518 .1761 L
.05642 .17709 L
.05758 .17781 L
.05881 .17838 L
.05993 .17874 L
.06122 .17895 L
.06244 .17898 L
.0631 .17892 L
.06381 .17881 L
.0651 .17848 L
.06635 .17799 L
.0675 .17742 L
.07012 .17568 L
.07289 .17326 L
.07752 .16809 L
.08259 .16115 L
.10458 .12426 L
.11544 .10651 L
.12572 .0921 L
.13496 .08183 L
.13973 .07764 L
.145 .07392 L
.14744 .07253 L
.15006 .07126 L
.15232 .07035 L
.1548 .06957 L
.15745 .06895 L
.15889 .06872 L
.15958 .06863 L
.16023 .06856 L
.1615 .06846 L
.16264 .06842 L
.16388 .06842 L
.16457 .06844 L
.16521 .06847 L
.16629 .06856 L
.16745 .06868 L
.16854 .06884 L
.16954 .06902 L
.17198 .06957 L
.1743 .07025 L
Mistroke
.1789 .07202 L
.18391 .07456 L
.19426 .0815 L
.20362 .08938 L
.22461 .11014 L
.24552 .13123 L
.25468 .13953 L
.26473 .14751 L
.2738 .15347 L
.28351 .15835 L
.28888 .16034 L
.29377 .16169 L
.29612 .16219 L
.29868 .1626 L
.29986 .16276 L
.3011 .16289 L
.30216 .16298 L
.30333 .16305 L
.30455 .16311 L
.30569 .16313 L
.30694 .16313 L
.30763 .16311 L
.30826 .16309 L
.30955 .16303 L
.31027 .16298 L
.31093 .16293 L
.31345 .16265 L
.3156 .16233 L
.31796 .16188 L
.32272 .16067 L
.32792 .15891 L
.33351 .15654 L
.34359 .1511 L
.3648 .13563 L
.38492 .11782 L
.42321 .08403 L
.44296 .07073 L
.45294 .06582 L
.45862 .06365 L
.46396 .06205 L
.46865 .06101 L
.47131 .06058 L
.47378 .06027 L
.47512 .06015 L
.4764 .06005 L
.47754 .05999 L
.47878 .05995 L
.47942 .05994 L
.48013 .05994 L
.48086 .05994 L
Mistroke
.48156 .05995 L
.48279 .05999 L
.48349 .06002 L
.48412 .06006 L
.48526 .06014 L
.48647 .06025 L
.48866 .06051 L
.49125 .06091 L
.49361 .06137 L
.49825 .06253 L
.50262 .06393 L
.51239 .06808 L
.52271 .0739 L
.54119 .08741 L
.57918 .12226 L
.60034 .14143 L
.61962 .15593 L
.6292 .16153 L
.63426 .16397 L
.63962 .16614 L
.6443 .16767 L
.64678 .16834 L
.64946 .16894 L
.65191 .1694 L
.65415 .16973 L
.6563 .16997 L
.65737 .17006 L
.65855 .17014 L
.65988 .1702 L
.66109 .17023 L
.66173 .17023 L
.66243 .17023 L
.66316 .17022 L
.66384 .1702 L
.6651 .17015 L
.66625 .17008 L
.66758 .16997 L
.66884 .16984 L
.67116 .16954 L
.67331 .16918 L
.67818 .1681 L
.68351 .16651 L
.68833 .16473 L
.69913 .15968 L
.72006 .14698 L
.73927 .13464 L
.749 .12935 L
.75375 .12724 L
.75807 .12566 L
.76026 .125 L
Mistroke
.76264 .1244 L
.76395 .12413 L
.76515 .12392 L
.7663 .12375 L
.76753 .12361 L
.76877 .1235 L
.76992 .12344 L
.77063 .12343 L
.7713 .12342 L
.77256 .12345 L
.77388 .12353 L
.77511 .12366 L
.77646 .12385 L
.7779 .12412 L
.7805 .12479 L
.78325 .12575 L
.78817 .12818 L
.79348 .13187 L
.7993 .13731 L
.80973 .15098 L
.81947 .16862 L
.82991 .19303 L
.83981 .22139 L
.85836 .28702 L
.87657 .36232 L
.88694 .40611 L
.89668 .44458 L
.9017 .46234 L
.90699 .47876 L
.91189 .49128 L
.91644 .50004 L
.91878 .50327 L
.92008 .50466 L
.92127 .50566 L
.92257 .50643 L
.92331 .50672 L
.92399 .50689 L
.92523 .50695 L
.92655 .50663 L
.92784 .50594 L
.92857 .50537 L
.92923 .50475 L
.93052 .50321 L
.93174 .50135 L
.93447 .49572 L
.93745 .48707 L
.93989 .4779 L
.94252 .46569 L
.94729 .43694 L
.95194 .39983 L
Mistroke
.95621 .35681 L
.96593 .22189 L
.97082 .13149 L
.97619 .01237 L
Mfstroke
1 0 0 r
.02 w
.02381 .04354 Mdot
.14286 .07532 Mdot
.2619 .14541 Mdot
.38095 .12146 Mdot
.5 .06306 Mdot
.61905 .15556 Mdot
.7381 .13534 Mdot
.85714 .28227 Mdot
.97619 .01236 Mdot
0 0 m
1 0 L
1 .51931 L
0 .51931 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 149.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000h1P00`40o`000?l0003o<_ooo`030000
oooooooo0?oooomloooo000boooo00<0003oooooool0ooooogcoool003;oool20000oooooggoool0
03;oool00`000?ooooooo`3ooooo0oooo`Go001doooo000boooo00<0003oooooool0ooooo`?oool5
o`00M?ooo`00<_ooo`030000oooooooo0?ooool3oooo1Ol007Coool003;oool00`000?ooooooo`3o
oooo0oooo`Go001doooo000boooo00<0003oooooool0ooooo`Coool3o`00MOooo`00<_ooo`030000
oooooooo0?ooool6oooo00<0003oooooool0Loooo`00<_ooo`80003ooooo1oooo`030000oooooooo
07?oool003;oool00`000?ooooooo`3ooooo1_ooo`030000oooooooo07?oool003;oool00`000?oo
ooooo`3ooooo1_ooo`030000oooooooo07?oool003;oool00`000?ooooooo`3ooooo1_ooo`030000
oooooooo07?oool000[oool5o`008oooo`030000oooooooo04Woool20000A_ooo`@00018oooo1000
02Coool00`000?ooooooo`0goooo100000;oool40000<_ooo`002_ooo`Go000Soooo00<0003ooooo
ool0BOooo`800015oooo0P0000;oool20000A_ooo`800003oooo00<0003oooooool08?ooo`030000
oooooooo03Soool00`000?ooooooo`06oooo00<0003oooooool0<?ooo`002_ooo`Go000Soooo00<0
003oooooool0BOooo`800014oooo0P0000Coool20000A?ooo`800004oooo0P00027oool00`000?oo
ooooo`0hoooo00<0003oooooool01_ooo`030000oooooooo033oool000[oool5o`008oooo`030000
oooooooo04Coool80000@oooo`800004oooo0P0004Coool200001?ooo`80000Qoooo00<0003ooooo
ool0>?ooo`030000oooooooo00Koool00`000?ooooooo`0`oooo000;oooo0ol002Coool20000AOoo
o`030000oooooooo00;oool20000A?ooo`800004oooo0P0004Goool010000?ooooooooooo`80000R
oooo00<0003oooooool0>?ooo`030000oooooooo00Koool00`000?ooooooo`0`oooo000=oooo00<0
003oooooool08_ooo`030000oooooooo04Goool010000?ooooooooooo`800014oooo0P0000Coool2
0000A_ooo`@0000Soooo00<0003oooooool0>?ooo`030000oooooooo00Koool00`000?ooooooo`0`
oooo000=oooo00<0003oooooool08_ooo`030000oooooooo04Koool00`000?ooooooo`0200006_oo
o`L00005o`007_ooo`<00002oooo0P0004Ooool300009?ooo`030000oooooooo03Soool00`000?oo
ooooo`06oooo00<0003oooooool0<?ooo`003Oooo`030000oooooooo02;oool00`000?ooooooo`16
oooo00<0003oooooool00P0001Goool500001oooo`Go000Ooooo00<0003oool000000P0004Ooool2
00000_ooo`80000Roooo00<0003oooooool0>?ooo`030000oooooooo00Koool00`000?ooooooo`0`
oooo000>oooo00<0003oooooool08Oooo`030000oooooooo04Ooool010000?ooo`00000001Coool0
0`000?ooooooo`0:oooo1Ol000030000oooooooo01coool20000BOooo`800004oooo0P00027oool0
0`000?ooooooo`0hoooo00<0003oooooool01_ooo`030000oooooooo033oool000koool00`000?oo
ooooo`0Qoooo00@0003oooooooooool80000?oooo`<0000Boooo0P0000goool5o`0000?oool00000
00007Oooo`800018oooo0P0000Coool200008Oooo`030000oooooooo03Soool00`000?ooooooo`06
oooo00<0003oooooool0<?ooo`003_ooo`030000oooooooo01ooool5o`0000<0003oooooool01_oo
o`030000oooooooo03goool200004Oooo`030000oooooooo00koool3o`001?ooo`80000Loooo0`00
04Ooool200000oooo`030000oooooooo023oool00`000?ooooooo`0hoooo00<0003oooooool01_oo
o`030000oooooooo033oool000koool00`000?ooooooo`0Ooooo1Ol000[oool20000?Oooo`80000?
oooo0P0001[oool00`000?ooooooo`0Koooo0`0004Koool400008oooo`030000oooooooo03Soool0
0`000?ooooooo`06oooo00<0003oooooool0<?ooo`003_ooo`030000oooooooo01ooool5o`003?oo
o`80001;oooo00<0003oooooool06oooo`030000oooooooo08[oool00`000?ooooooo`0hoooo00<0
003oooooool01_ooo`030000oooooooo033oool000koool00`000?ooooooo`0Ooooo1Ol000koool0
0`000?ooooooo`16oooo0P0001ooool20000R_ooo`030000oooooooo03Soool00`000?ooooooo`06
oooo00<0003oooooool0<?ooo`003_ooo`030000oooooooo01koool00`000?ooool00002o`004?oo
o`030000oooooooo04Coool00`000?ooooooo`0Qoooo00<0003oooooool0Qoooo`030000oooooooo
03Soool400000_ooo`@0000boooo000>oooo00<0003oooooool07Oooo`050000oooooooooooo0000
01;oool00`000?ooooooo`12oooo00<0003oooooool08oooo`030000oooooooo08Koool00`000?oo
ooooo`1doooo000>oooo00<0003oooooool07?ooo`030000oooooooo00;oool00`000?ooooooo`0A
oooo00<0003oooooool0@?ooo`030000oooooooo02Goool00`000?ooooooo`25oooo00<0003ooooo
ool0M?ooo`003oooo`030000oooooooo01[oool00`000?ooooooo`03oooo00<0003oooooool04_oo
o`030000oooooooo03koool00`000?ooooooo`0Woooo00<0003oooooool0Q?ooo`030000oooooooo
07Coool000ooool00`000?ooooooo`0Joooo00<0003oooooool00oooo`030000oooooooo01?oool0
0`000?ooooooo`0loooo00<0003oooooool0:Oooo`030000oooooooo08?oool00`000?ooooooo`1d
oooo0005ooooo`0003l0001]oooo000=oooo00<0003oool000003oooo`030000oooooooo00Woool0
0`000?ooooooo`04oooo00<0003oooooool04?ooo`030000oooooooo00;oool00`000?ooooooo`0;
oooo00<0003oooooool04?ooo`030000oooooooo013oool00`000?ooooooo`03oooo0P0000[oool0
0`000?ooooooo`0@oooo00<0003oooooool03oooo`80000Boooo00<0003oooooool04?ooo`030000
oooooooo013oool00`000?ooooooo`0?oooo00<0003oooooool04?ooo`030000oooooooo013oool0
0`000?ooooooo`0>oooo00<0003oool000004ooooeD0000=oooo000?oooo00<0003oooooool06?oo
o`030000oooooooo00Goool00`000?ooooooo`0Foooo00<0003oooooool0<?ooo`030000oooooooo
00;oool00`000?ooooooo`0aoooo00<0003oooooool03oooo`030000oooooooo04Soool00`000?oo
ooooo`0Qoooo00<0003oooooool0MOooo`003oooo`030000oooooooo01Ooool00`000?ooooooo`06
oooo00<0003oooooool05oooo`030000oooooooo03?oool00`000?ooooooo`0coooo00<0003ooooo
ool0OOooo`030000oooooooo07Goool0013oool00`000?ooooooo`0Foooo00<0003oooooool01_oo
o`030000oooooooo01Soool00`000?ooooooo`0aoooo00<0003oooooool0=Oooo`030000oooooooo
07coool00`000?ooooooo`1eoooo000@oooo00<0003oooooool05Oooo`030000oooooooo00Ooool0
0`000?ooooooo`0Ioooo00<0003oooooool0:_ooo`Go00000`000?ooooooo`0goooo00<0003ooooo
ool0Noooo`030000oooooooo07Goool0013oool00`000?ooooooo`0Doooo00<0003oooooool02?oo
o`030000oooooooo01[oool00`000?ooooooo`0Yoooo1Ol003_oool00`000?ooooooo`1joooo00<0
003oooooool0MOooo`004?ooo`030000oooooooo01Coool00`000?ooooooo`08oooo00<0003ooooo
ool06oooo`030000oooooooo02Soool5o`00??ooo`030000oooooooo03Soool50000??ooo`030000
oooooooo07Goool0017oool00`000?ooooooo`0Boooo00<0003oooooool02Oooo`80000Moooo00<0
003oooooool09oooo`Go000moooo00<0003oooooool0=Oooo`<00003oooo100003Woool00`000?oo
ooooo`1eoooo000Aoooo00<0003oooooool04Oooo`030000oooooooo00[oool00`000?ooooooo`0M
oooo00<0003oooooool09_ooo`040000o`00o`00o`00?oooo`030000oooooooo037oool300002_oo
o`030000oooooooo03Koool00`000?ooooooo`0Ioooo1P0000Coool;000000?oool0000000001P00
0003oooo0000000000X000000oooo`0000000009000000?oool0000000001P0000?oool300000_oo
o`@0000@oooo000Aoooo00<0003oooooool04Oooo`030000oooooooo00[oool00`000?ooooooo`0N
oooo00<0003oooooool09?ooo`030000oooooooo04;oool20000:oooo`Go00000`000?ooooooo`0<
oooo00<0003oooooool0=Oooo`030000oooooooo01_oool200001_ooo`800002oooo0P0000;oool2
00000oooo`800002oooo0P0000?oool200000_ooo`800004oooo00@0003oool000000002oooo0P00
00;oool200000oooo`800002oooo0P0000?oool500000_ooo`80000Aoooo000Aoooo00<0003ooooo
ool04?ooo`030000oooooooo00_oool00`000?ooooooo`0Ooooo0P0002?oool00`000?ooooooo`15
oooo00<0003oooooool0:?ooo`Go000@oooo00<0003oooooool0=?ooo`030000oooooooo01_oool2
00001_ooo`800002oooo0P0000;oool200000oooo`800002oooo0P0000;oool200001?ooo`800005
oooo0P0000;oool200000_ooo`800003oooo0P0000;oool200000_ooo`<00002oooo00<0003ooooo
ool00P00017oool001;oool00`000?ooooooo`0>oooo00<0003oooooool03?ooo`030000oooooooo
027oool00`000?ooooooo`0Noooo0P0004Woool00`000?ooooooo`0Woooo1Ol0017oool00`000?oo
ooooo`0coooo00<0003oooooool06oooo`800007oooo0P000003oooo0000000000;oool200000ooo
o`800002oooo1@0000Koool200001Oooo`8000000oooo`0000000002oooo0P0000?oool200000_oo
o`800002oooo0P0000Koool200004Oooo`004_ooo`030000oooooooo00koool00`000?ooooooo`0<
oooo00<0003oooooool08?ooo`Go000Loooo00<0003oooooool0B_ooo`030000oooooooo02Koool5
o`004_ooo`030000oooooooo03;oool00`000?ooooooo`0Koooo0P0000Woool300000_ooo`800003
oooo0P0000;oool2000000?oool0003oool01_ooo`800007oooo0`0000;oool200000oooo`800002
oooo0P0000;oool200001_ooo`80000Aoooo000Boooo00<0003oooooool03Oooo`030000oooooooo
00goool00`000?ooooooo`0Poooo1Ol001_oool00`000?ooooooo`1<oooo00<0003oooooool08ooo
o`8000001?ooool00?l00?l001Coool00`000?ooooooo`0aoooo00<0003oooooool06oooo`800006
oooo0P0000;oool200000_ooo`800003oooo0P0000;oool200000_ooo`030000oooooooo00Goool2
00000oooo`800002oooo0P0000;oool200000oooo`800002oooo0P0000;oool600000_ooo`80000A
oooo000Coooo00<0003oooooool03?ooo`030000oooooooo00goool200008Oooo`Go000Ioooo0P00
053oool200008_ooo`030000oooooooo01Soool00`000?ooooooo`0aoooo00<0003oooooool06ooo
o`800006oooo0P0000;oool2000000?oool0000000000P0000;oool200000_ooo`800003oooo00D0
003oooooooooool000000oooo`800002oooo0P0000;oool200000_ooo`<00002oooo0P0000;oool2
00000oooo`030000oooooooo008000000oooo`0000000002000000?oool0003oool03Oooo`004ooo
o`030000oooooooo00_oool00`000?ooooooo`0>oooo00<0003oooooool08?ooo`Go000200005_oo
o`030000oooooooo057oool5o`007?ooo`80000Loooo00<0003oooooool0<?ooo`030000oooooooo
01_oool200001oooo`@00003oooo0P000004oooo0000000000000oooo`800002oooo0`0000;oool7
00000_ooo`@00003oooo0P000004oooo0000000000000oooo`800004oooo0`0000?oool2000000?o
ool0000000003_ooo`004oooo`030000oooooooo00[oool00`000?ooooooo`0?oooo00<0003ooooo
ool08Oooo`?o0003oooo0P0001;oool20000E?ooo`Go000Joooo0P0001ooool00`000?ooooooo`0_
oooo00<0003oooooool06oooo`80000Goooo0P0001Ooool200001oooo`80000Moooo000Coooo00<0
003oooooool02_ooo`030000oooooooo00ooool00`000?ooooooo`0Yoooo0`0000goool20000E_oo
o`Go000Hoooo0P00027oool00`000?ooooooo`0_oooo00<0003oooooool05oooo`040000oooooooo
oooo0P0000?oool00`000?ooooooo`0Aoooo0P00013oool2000000?oool0000000000_ooo`800007
oooo0P0001goool001?oool00`000?ooooooo`09oooo00<0003oooooool04?ooo`030000oooooooo
02coool200001oooo`@0001Hoooo1Ol000<0000Coooo0P0002Coool00`000?ooooooo`0^oooo00<0
003oooooool05oooo`040000oooooooooooo0P0000?oool00`000?ooooooo`0Aoooo0P00013oool2
000000?oool0000000000_ooo`800007oooo0P0001goool001Coool00`000?ooooooo`08oooo00<0
003oooooool04?ooo`030000oooooooo02koool70000GOooo`?o0004oooo0P0000koool300009_oo
o`030000oooooooo02koool00`000?ooooooo`0Goooo2P0001;oool300005_ooo`<00006oooo0`00
01goool001Coool00`000?ooooooo`07oooo00<0003oooooool04Oooo`030000oooooooo09_oool2
00002Oooo`<0000Zoooo00<0003oooooool0;Oooo`030000oooooooo03Coool200005oooo`800007
oooo0P0001goool001Goool00`000?ooooooo`05oooo00<0003oooooool04_ooo`030000oooooooo
09goool90000;Oooo`030000oooooooo02goool00`000?ooooooo`1eoooo000Foooo00<0003ooooo
ool00oooo`030000oooooooo01?oool20000eOooo`030000oooooooo02coool00`000?ooooooo`1e
oooo000Goooo00<0003oooooool00P0001Koool00`000?ooooooo`3Doooo00<0003oooooool0;?oo
o`030000oooooooo07Goool001Ooool400005oooo`030000oooooooo0=Goool00`000?ooooooo`0Z
oooo00<0003oooooool0M_ooo`00<_ooo`030000oooooooo0=Goool00`000?ooooooo`0Zoooo00<0
003oooooool0M_ooo`00<_ooo`030000oooooooo0=Koool00`000?ooooooo`0Yoooo00<0003ooooo
ool0M_ooo`00<_ooo`030000oooooooo0=Koool00`000?ooooooo`0Yoooo00<0003oooooool0M_oo
o`00<_ooo`030000oooooooo0=Ooool00`000?ooooooo`0Xoooo00<0003oooooool0M_ooo`00<_oo
o`80003Hoooo00<0003oooooool0:?ooo`030000oooooooo07Koool003;oool00`000?ooooooo`3H
oooo00<0003oooooool09oooo`030000oooooooo07Koool003;oool00`000?ooooooo`3Hoooo00<0
003oooooool09oooo`030000oooooooo07Koool003;oool00`000?ooooooo`3Hoooo00<0003ooooo
ool09oooo`030000oooooooo07Koool002;oool300003Oooo`030000oooooooo0=Woool00`000?oo
ooooo`0Voooo00<0003oooooool0M_ooo`009Oooo`80000;oooo00<0003oooooool0fOooo`030000
oooooooo02Koool00`000?ooooooo`1foooo000Voooo0P0000[oool00`000?ooooooo`3Ioooo00<0
003oooooool09_ooo`030000oooooooo07Koool002Ooool200002Oooo`030000oooooooo0=[oool0
0`000?ooooooo`0Uoooo00<0003oooooool0M_ooo`009?ooo`D00009oooo0`000=[oool00`000?oo
ooooo`0Uoooo00<0003oooooool0M_ooo`008oooo`800003oooo0P0000Soool00`000?ooooooo`3J
oooo00<0003oooooool09Oooo`030000oooooooo07Koool002;oool200001?ooo`800008oooo00<0
003oooooool0foooo`030000oooooooo02Coool00`000?ooooooo`1foooo000Roooo0P0000Coool2
00002?ooo`030000oooooooo0=_oool00`000?ooooooo`0Toooo00<0003oooooool0M_ooo`008_oo
o`800004oooo0P0000Soool00`000?ooooooo`3Koooo00<0003oooooool09?ooo`030000oooooooo
07Koool002;oool200001?ooo`800008oooo00<0003oooooool0foooo`030000oooooooo02Coool0
0`000?ooooooo`1foooo000Soooo0P0000;oool200002Oooo`030000oooooooo0=coool00`000?oo
ooooo`0Soooo00<0003oooooool0M_ooo`009?ooo`@0000:oooo0P000=goool00`000?ooooooo`0S
oooo00<0003oooooool0M_ooo`00<_ooo`030000oooooooo0=coool00`000?ooooooo`0Roooo00<0
003oooooool0Moooo`00<_ooo`030000oooooooo0=goool00`000?ooooooo`0Qoooo00<0003ooooo
ool0Moooo`00<_ooo`030000oooooooo0=goool00`000?ooooooo`0Qoooo00<0003oooooool0Mooo
o`00<_ooo`030000oooooooo0=goool00`000?ooooooo`0Qoooo00<0003oooooool0Moooo`00<_oo
o`030000oooooooo0=goool00`000?ooooooo`0Qoooo00<0003oooooool0Moooo`00<_ooo`030000
oooooooo0=koool00`000?ooooooo`0Poooo00<0003oooooool0Moooo`00<_ooo`030000oooooooo
0=koool00`000?ooooooo`0Poooo00<0003oooooool0Moooo`00<_ooo`80003Ooooo00<0003ooooo
ool08?ooo`030000oooooooo07Ooool003;oool00`000?ooooooo`3Ooooo00<0003oooooool07ooo
o`030000oooooooo07Ooool003;oool00`000?ooooooo`3Ooooo00<0003oooooool07oooo`030000
oooooooo07Ooool003;oool00`000?ooooooo`3Moooo1Ol001ooool00`000?ooooooo`1goooo000b
oooo00<0003oooooool0gOooo`Go000Ooooo00<0003oooooool0Moooo`00<_ooo`030000oooooooo
0=goool5o`007oooo`030000oooooooo07Ooool003;oool00`000?ooooooo`3Moooo1Ol001ooool0
0`000?ooooooo`1goooo000boooo0P000=ooool3o`007oooo`030000oooooooo07Soool003;oool0
0`000?ooooooo`3Poooo00<0003oooooool07Oooo`030000oooooooo07Soool003;oool00`000?oo
ooooo`3Qoooo00<0003oooooool07?ooo`030000oooooooo07Soool003;oool00`000?ooooooo`3Q
oooo00<0003oooooool07?ooo`030000oooooooo07Soool003;oool00`000?ooooooo`3Qoooo00<0
003oooooool07?ooo`030000oooooooo07Soool003;oool00`000?ooooooo`3Qoooo00<0003ooooo
ool07?ooo`030000oooooooo07Soool003;oool00`000?ooooooo`3Qoooo00<0003oooooool07?oo
o`030000oooooooo07Soool003;oool00`000?ooooooo`3Roooo00<0003oooooool06oooo`030000
oooooooo07Soool003;oool20000hoooo`030000oooooooo01_oool00`000?ooooooo`1hoooo000b
oooo00<0003oooooool0h_ooo`030000oooooooo01_oool00`000?ooooooo`1hoooo000boooo00<0
003oooooool0h_ooo`030000oooooooo01_oool00`000?ooooooo`1hoooo000boooo00<0003ooooo
ool0h_ooo`030000oooooooo01_oool00`000?ooooooo`1hoooo000Joooo1P0000Coool400002_oo
o`030000oooooooo0>?oool00`000?ooooooo`0Joooo00<0003oooooool0N?ooo`007?ooo`800005
oooo0P0000;oool200002Oooo`030000oooooooo0>?oool00`000?ooooooo`0Joooo00<0003ooooo
ool0N?ooo`007?ooo`800005oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?oo
ooooo`3Soooo00<0003oooooool06Oooo`030000oooooooo07Woool001coool200001?ooo`800004
oooo0P0000Soool30000hoooo`030000oooooooo01Woool00`000?ooooooo`1ioooo000Loooo0P00
00Coool200001?ooo`800008oooo00<0003oooooool0i?ooo`030000oooooooo01Soool00`000?oo
ooooo`1ioooo000Loooo0P0000Coool200001?ooo`800008oooo00<0003oooooool0i?ooo`030000
oooooooo01Soool00`000?ooooooo`1ioooo000Loooo0P0000Coool200001?ooo`800008oooo00<0
003oooooool0i?ooo`030000oooooooo01Soool00`000?ooooooo`1ioooo000Loooo0P0000Coool2
00001?ooo`800008oooo00<0003oooooool0i?ooo`030000oooooooo01Soool00`000?ooooooo`1i
oooo000Loooo0P0000Coool200001?ooo`800008oooo00<0003oooooool0i?ooo`030000oooooooo
01Soool00`000?ooooooo`1ioooo000Loooo0P0000Goool00`000?ooooooo`02oooo00<0003ooooo
ool01oooo`030000oooooooo0>Goool00`000?ooooooo`0Goooo00<0003oooooool0NOooo`006_oo
o`@00005oooo0P0000;oool200002Oooo`030000oooooooo0>Goool00`000?ooooooo`0Goooo00<0
003oooooool0NOooo`007?ooo`800006oooo100000[oool20000i_ooo`030000oooooooo01Ooool0
0`000?ooooooo`1ioooo000boooo00<0003oooooool0iOooo`030000oooooooo01Ooool00`000?oo
ooooo`1ioooo000boooo00<0003oooooool0i_ooo`030000oooooooo01Goool00`000?ooooooo`1j
oooo000boooo00<0003oooooool0i_ooo`030000oooooooo01Goool00`000?ooooooo`1joooo000b
oooo00<0003oooooool0i_ooo`030000oooooooo01Goool00`000?ooooooo`1joooo000boooo00<0
003oooooool0i_ooo`030000oooooooo01Goool00`000?ooooooo`1joooo000boooo00<0003ooooo
ool0ioooo`030000oooooooo01Coool00`000?ooooooo`1joooo000boooo0P000>Soool00`000?oo
ooooo`0Doooo00<0003oooooool0N_ooo`00<_ooo`030000oooooooo0>Ooool00`000?ooooooo`0D
oooo00<0003oooooool0N_ooo`00<_ooo`030000oooooooo0>Soool00`000?ooooooo`0Boooo00<0
003oooooool0Noooo`00<_ooo`030000oooooooo0>Soool00`000?ooooooo`0Boooo00<0003ooooo
ool0Noooo`00<_ooo`030000oooooooo0>Soool00`000?ooooooo`0Boooo00<0003oooooool0Nooo
o`00<_ooo`030000oooooooo0>Soool00`000?ooooooo`0Boooo00<0003oooooool0Noooo`00<_oo
o`030000oooooooo0>Woool00`000?ooooooo`0Aoooo00<0003oooooool0Noooo`00<_ooo`030000
oooooooo0>Woool00`000?ooooooo`0Aoooo00<0003oooooool0Noooo`00<_ooo`80003Zoooo00<0
003oooooool04Oooo`030000oooooooo07_oool003;oool00`000?ooooooo`3Zoooo00<0003ooooo
ool04?ooo`030000oooooooo07_oool003;oool00`000?ooooooo`3Zoooo00<0003oooooool04?oo
o`030000oooooooo07_oool003;oool00`000?ooooooo`3Zoooo00<0003oooooool04?ooo`030000
oooooooo07_oool003;oool00`000?ooooooo`3Zoooo00<0003oooooool03oooo`030000oooooooo
07coool003;oool00`000?ooooooo`3[oooo00<0003oooooool03_ooo`030000oooooooo07coool0
03;oool00`000?ooooooo`3[oooo00<0003oooooool03_ooo`030000oooooooo07coool003;oool2
0000k?ooo`030000oooooooo00koool00`000?ooooooo`1loooo000boooo00<0003oooooool0jooo
o`030000oooooooo00koool00`000?ooooooo`1loooo000boooo00<0003oooooool0k?ooo`030000
oooooooo00goool00`000?ooooooo`1loooo000boooo00<0003oooooool0k?ooo`030000oooooooo
00goool00`000?ooooooo`1loooo000Joooo1P0000?oool600002Oooo`030000oooooooo0>coool0
0`000?ooooooo`0=oooo00<0003oooooool0O?ooo`007?ooo`800007oooo0P0000_oool00`000?oo
ooooo`3/oooo00<0003oooooool03?ooo`030000oooooooo07goool001coool200001oooo`80000;
oooo00<0003oooooool0k?ooo`030000oooooooo00coool00`000?ooooooo`1moooo000Loooo0P00
00Ooool200002oooo`030000oooooooo0>coool00`000?ooooooo`0<oooo00<0003oooooool0OOoo
o`007?ooo`800007oooo0P0000_oool30000kOooo`030000oooooooo00_oool00`000?ooooooo`1m
oooo000Loooo0P0000Ooool200002oooo`030000oooooooo0>goool00`000?ooooooo`0:oooo00<0
003oooooool0O_ooo`007?ooo`800007oooo0P0000_oool00`000?ooooooo`3]oooo00<0003ooooo
ool02_ooo`030000oooooooo07koool001coool200001oooo`80000;oooo00<0003oooooool0kOoo
o`030000oooooooo00[oool00`000?ooooooo`1noooo000Loooo0P0000Ooool200002oooo`030000
oooooooo0>koool00`000?ooooooo`09oooo00<0003oooooool0O_ooo`007?ooo`800007oooo0P00
00_oool00`000?ooooooo`3^oooo00<0003oooooool02Oooo`030000oooooooo07koool001[oool4
00001Oooo`@0000;oooo00<0003oooooool0koooo`030000oooooooo00Soool00`000?ooooooo`1n
oooo000Loooo0P0000Ooool200002oooo`030000oooooooo0>ooool00`000?ooooooo`08oooo00<0
003oooooool0O_ooo`00<_ooo`80003aoooo00<0003oooooool01_ooo`030000oooooooo07ooool0
03;oool00`000?ooooooo`3`oooo00<0003oooooool01_ooo`030000oooooooo07ooool003;oool0
0`000?ooooooo`3aoooo00<0003oooooool01Oooo`030000oooooooo07ooool003;oool00`000?oo
ooooo`3aoooo00<0003oooooool01?ooo`030000oooooooo083oool003;oool00`000?ooooooo`3b
oooo00<0003oooooool00oooo`030000oooooooo083oool003;oool00`000?ooooooo`3boooo00<0
003oooooool00oooo`030000oooooooo083oool003;oool00`000?ooooooo`3coooo00D0003ooooo
ooooool00000Poooo`00<_ooo`80003doooo0P000003oooo0000oooo08?oool003;oool00`000?oo
ooooo`3doooo0P0008Goool003;oool00`000?ooooooo`3oooooO?ooo`00<_ooo`030000oooooooo
0?oooomloooo000boooo00<0003oooooool0ooooogcoool003;oool00`000?ooooooo`3oooooO?oo
o`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Ooo
o`00oooook7oool00?oooonaoooo003ooooo/Oooo`007oooo`<00003oooo0`0000?oool300001ooo
o`<000000oooo`0000000003000000Coool00000003oool20000ooooofgoool0023oool01@000?oo
ooooooooo`000003oooo00<0003oool000000oooo`030000oooooooo00Goool010000?ooooooo`00
00;oool010000?ooooooo`0000;oool00`000?ooooooo`3oooooK?ooo`008?ooo`050000oooooooo
oooo000000?oool00`000?ooo`000003oooo00<0003oooooool01Oooo`030000oooo000000?oool0
10000?ooooooo`0000;oool00`000?ooooooo`3oooooK?ooo`008?ooo`050000oooooooooooo0000
00?oool00`000?ooo`000003oooo00<0003oooooool01Oooo`800004oooo00@0003oooooool00002
oooo00<0003oooooool0ooooofcoool001Coool400002?ooo`050000oooooooooooo000000?oool0
0`000?ooo`000003oooo00<0003oooooool01Oooo`030000oooo000000?oool2000000Goool00000
003oool000002?ooo`@0003oooooH_ooo`005?ooo`030000oooooooo00Woool01@000?oooooooooo
o`000003oooo00<0003oool000000oooo`030000oooooooo00Goool01@000?ooo`0000000?ooo`02
000000Goool0003oooooool000003?ooo`030000oooooooo0?oooomPoooo000Doooo00<0003ooooo
ool02Oooo`050000oooooooooooo000000?oool00`000?ooo`000003oooo00<0003oooooool01Ooo
o`030000oooooooo01Goool00`000?ooooooo`3oooooH?ooo`005?ooo`030000oooooooo00Soool2
00000oooo`070000oooooooooooo0000oooo000000?oool00`000?ooooooo`05oooo00<0003ooooo
ool05Oooo`030000oooooooo0?oooomPoooo000Doooo00<0003oooooool02Oooo`030000oooooooo
00;oool300000oooo`<00007oooo0P0001Ooool00`000?ooooooo`3oooooH?ooo`005?ooo`030000
oooooooo03Ooool00`000?ooooooo`3oooooH?ooo`005?ooo`030000oooooooo03Ooool00`000?oo
ooooo`3oooooH?ooo`005?ooo`030000oooooooo00Goool[00001oooo`030000oooooooo0?oooomP
oooo000Doooo00<0003oooooool0=oooo`030000oooooooo0?oooomPoooo000Doooo00<0003ooooo
ool0=oooo`030000oooooooo0?oooomPoooo000Doooo00<0003oooooool0=oooo`030000oooooooo
0?oooomPoooo000Doooo00<0003oooooool06Oooo`<0000Koooo00<0003oooooool0ooooof3oool0
01Coool00`000?ooooooo`0Joooo00<0003oooooool06_ooo`030000oooooooo0?oooomPoooo000D
oooo00<0003oooooool06_ooo`030000oooooooo01[oool00`000?ooooooo`3oooooH?ooo`005?oo
o`@0000Ioooo00<0003oooooool05oooo`@0003oooooH_ooo`00<Oooo`030000oooooooo0?oooomm
oooo000aoooo00<0003oooooool0oooooggoool0037oool00`000?ooooooo`3oooooOOooo`00<Ooo
o`030000oooooooo0?oooommoooo000`oooo0P000?oooomooooo003ooooo/Oooo`00oooook7oool0
0?oooonaoooo000:ooooC`000?oooomHoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003o
oooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`004_ooo`030000oooooooo00Koool3
00000_ooo`@00004oooo100000?oool400000oooo`L00002oooo0`000003oooo0000000000Coool3
00000_ooo`@000000oooo`00000000020000oooooe[oool0017oool200001oooo`D00002oooo0P00
00Coool200000_ooo`800003oooo0P0000Coool200000_ooo`800002oooo0P0000;oool400000_oo
o`D00002oooo0P0000?oool20000oooooe_oool0017oool300001Oooo`<00002oooo00<0003ooooo
ool00P0000Coool200000oooo`800002oooo0P0000Coool200000_ooo`800002oooo0P0000?oool2
00000_ooo`<00002oooo00<0003oooooool00P0000?oool20000oooooe_oool0013oool2000000?o
ool0003oool01?ooo`800006oooo0P0000Coool200000oooo`800002oooo0P0000Goool2000000?o
ool0000000000_ooo`800003oooo0P0000;oool200001_ooo`800003oooo0P000?oooomKoooo000@
oooo0P000003oooo0000oooo00Coool200001_ooo`800004oooo0P0000?oool200000_ooo`800007
oooo0`0000;oool200000oooo`800002oooo0P0000Koool200000oooo`80003oooooFoooo`004?oo
o`050000oooooooooooo000000Coool600000_ooo`800004oooo0P0000?oool200000_ooo`800004
oooo0P0000;oool200000_ooo`800003oooo0P0000;oool200000_ooo`800002oooo0P0000?oool2
0000oooooe_oool000ooool200000oooo`030000oooooooo00?oool00`000?ooooooo`02000000?o
ool0000000000P000003oooo0000oooo00<000001Oooo`00000000000?ooo`04000000?oool0003o
ool00P0000;oool200000_ooo`800003oooo0P0000?oool00`000?ooooooo`0200000_ooo`<00002
oooo0P000?oooomKoooo000?oooo0P0000?oool00`000?ooooooo`04oooo0`0000?oool2000000Co
ool00000003oool2000000Coool0000000000003oooo0P000003oooo0000000000;oool400000_oo
o`<00002oooo0`0000Coool300000oooo`8000001?ooo`00000000000?oooomLoooo000>oooo0P00
00Goool00`000?ooooooo`0?oooo0P0002Koool20000ooooof3oool000koool200001Oooo`030000
oooooooo00ooool200009_ooo`80003oooooH?ooo`003Oooo`800006oooo0P00013oool200009_oo
o`80003oooooH?ooo`003?ooo`@00004oooo100000koool300009Oooo`<0003oooooH?ooo`009ooo
o`80000Voooo0P000?oooomPoooo003ooooo/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {223.25, 0}} -> {0.651645, 7.158, 0.0398163, 
  0.0398163}}]
}, Open  ]],

Cell["\<\
Zu diesem Schaubild ist der Durchschnitt samt mittlerem Fehler \
inhaltlich aussagekr\[ADoubleDot]ftig:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(durchschnitt[2] \[PlusMinus] \@schwankungsquadrat[2] // PowerExpand\)], 
  "Input"],

Cell[BoxData[
    RowBox[{
      FractionBox[\(8.12341215086231827`\ "l"\), 
        RowBox[{\("km"\), " ", 
          TagBox["100",
            HoldForm]}]], "\[PlusMinus]", 
      FractionBox[\(0.631822497902055069`\ "l"\), 
        RowBox[{\("km"\), " ", 
          TagBox["100",
            HoldForm]}]]}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Ausgleichsrechnung"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Vorbereitung"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Anliegen"
}], "Subsubsection"],

Cell["\<\
Das Anliegen der Ausgleichsrechnung besteht generell in der \
Minimierung von Fehlern im Ergebnis.\
\>", "Text"],

Cell["\<\
Dazu ist eine Ausgleichskurve zu gemessenen Daten zu ermitteln, und \
zwar so, da\[SZ] die sich ergebende mittlere Summe der Fehlerquadrate minimal \
wird.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Methode"
}], "Subsubsection"],

Cell[TextData[{
  "Die Methode der Ausgleichsrechnung ist die ",
  StyleBox["Variationsrechnung",
    FontSlant->"Italic"],
  ", die im Rahmen der Ausgleichsrechnung eine denkbar einfache Anwendung \
findet."
}], "Text"],

Cell[TextData[{
  "Bei der Variationsrechnung werden Terme in noch unbekannten Funktionen \
ermittelt, die auf systematischem Wege zu den ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " mathematischen Bestimmungsgleichungen f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " zugeh\[ODoubleDot]rige Unbekannte f\[UDoubleDot]hren."
}], "Text"],

Cell[TextData[{
  "Allgemein ergeben sich bei Verwendung der Variationsrechnung die \
sogenannten Euler-Ostrogradskischen Gleichungen, bei denen Funktionen in \
mehreren Koordinaten und auch gemischten partiellen Ableitungen korrekt ber\
\[UDoubleDot]cksichtigt sind (vgl. ",
  ButtonBox["[Smi1988]",
    ButtonData:>"[Smi1988]",
    ButtonStyle->"Hyperlink"],
  ", Gleichung (36) und (37), Seite 183):"
}], "Text"],

Cell[BoxData[
    \(\(\[Delta]\ F\)\/\(\[Delta]\ q\_i\) = 
      \[Sum]\+\(n\_1 = 0
            \)\%\[Infinity]\(\[Sum]\+\(n\_2 = 0
              \)\%\[Infinity]\(\[Sum]\+\(n\_3 = 0
                \)\%\[Infinity]\(\[Sum]\+\(n\_4 = 0
                  \)\%\[Infinity]\(\((
                      \(-\[DifferentialD]\)\/\[DifferentialD]x)\)\^n\_1\) 
                \(\((\(-\[DifferentialD]\)\/\[DifferentialD]y)\)\^n\_2\) 
                \(\((\(-\[DifferentialD]\)\/\[DifferentialD]z)\)\^n\_3\) 
                \(\((\(-\[DifferentialD]\)\/\[DifferentialD]t)\)\^n\_4\) 
                \[PartialD]F
                    \/\[PartialD]q\_i\%\((n\_1, n\_2, n\_3, n\_4)\)[x, y, z, 
                      t]\)\)\)\)], "NumberedEquation",
  CellTags->"Euler-Ostrogradskische Gleichungen"],

Cell[TextData[{
  "Das hier angegebene ",
  StyleBox["Funktional",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " h\[ADoubleDot]ngt von entsprechenden Feldvariablen ",
  Cell[BoxData[
      \(TraditionalForm\`q\_i[x, y, z, t]\)]],
  " mit ",
  Cell[BoxData[
      \(TraditionalForm\`i \[Element] {1, 2, ..., N}\)]],
  " ab, wobei die vier Koordinaten ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " f\[UDoubleDot]r die nicht-statistische Feldphysik ausreichen."
}], "Text"],

Cell["\<\
In der Praxis brechen die unendlichen Summen ab, da Terme unendlich \
hoher Differentiationsordnung in der Technischen Physik keine Rolle \
spielen.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". ",
  "Ausgleichspolynom"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Ansatz"
}], "Subsubsection"],

Cell[TextData[{
  "Die mittlere Fehlerquadratsumme ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " ergibt:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ansatz = 
      \(1\/N\) \(\[Sum]\+\(j\  = \ 1\)\%N
            \((\[Sum]\+\(\[Mu]\  = \ 0\)\%n\( a\_\[Mu]\) x\_j\%\[Mu] - y\_j)
              \)\^2\)\)], "Input"],

Cell[BoxData[
    \(\(\[Sum]\+\(j = 1\)\%N
          \((\[Sum]\+\(\[Mu] = 0\)\%n a\_\[Mu]\ x\_j\%\[Mu] - y\_j)\)\^2\)\/N
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Dieser Term soll durch geeignete Wahl der ",
  Cell[BoxData[
      \(TraditionalForm\`\((n + 1)\)\)]],
  " Koeffizienten minimal werden. "
}], "Text"],

Cell[TextData[{
  "Es sind also Variationsableitungen nach den ",
  Cell[BoxData[
      \(TraditionalForm\`\((n + 1)\)\)]],
  " unabh\[ADoubleDot]ngigen Koeffizienten des (noch unbekannten) \
Ausgleichspolynoms zu bestimmen."
}], "Text"],

Cell[TextData[{
  "Im hier f\[UDoubleDot]r die Ausgleichsrechnung ben\[ODoubleDot]tigten Fall \
sind die Variabtionsableitungen (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Euler-Ostrogradskische Gleichungen"],
  ") identisch mit den partiellen Ableitungen:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(bestimmungsgleichungen = \[PartialD]\_\(a\_\[Mu]\)ansatz == 0\)], 
  "Input"],

Cell[BoxData[
    \(\(\[Sum]\+\(j = 1\)\%N
            \[PartialD]\_\(a\_\[Mu]\)\((
                \[Sum]\+\(\[Mu] = 0\)\%n a\_\[Mu]\ x\_j\%\[Mu] - y\_j)\)\^2
              \)\/N == 0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Nun taucht das Problem auf, da\[SZ] der Z\[ADoubleDot]hlindex ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  " bei ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[Mu]\)]],
  " anders benannt werden mu\[SZ], da die Zuordnung beispielsweise zu ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0\)]],
  " geh\[ODoubleDot]rt und das Polynom mit allen ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[Mu]\)]],
  " jeweils vorkommen mu\[SZ]."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Bestimmungsgleichungen"
}], "Subsubsection"],

Cell[TextData[{
  "Eine M\[ODoubleDot]glichkeit, diese Rechnung korrekter zu formulieren, \
besteht in der Wahl eines Index ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)]],
  ", der auch au\[SZ]erhalb der Polynomsumme existiert und \[UDoubleDot]ber \
das sogenannte ",
  StyleBox["KroneckerDelta",
    FontSlant->"Italic"],
  " auf folgendes Ergebnis f\[UDoubleDot]hrt:"
}], "Text"],

Cell[BoxData[
    \(\(1\/N\) 
        \(\[Sum]\+\(j = 1\)\%N
            \[PartialD]\_\(a\_\[Nu]\)\((
                \[Sum]\+\(\[Mu] = 0\)\%n a\_\[Mu]\ x\_j\%\[Mu] - y\_j)\)\^2
              \) = \(\(2\/N\) 
          \(\[Sum]\+\(j = 1\)\%N
              \((\[Sum]\+\(\[Mu] = 0\)\%n a\_\[Mu]\ x\_j\%\[Mu] - y\_j)\) 
              \[PartialD]\_\(a\_\[Nu]\)\((
                  \[Sum]\+\(\[Mu] = 0\)\%n a\_\[Mu]\ x\_j\%\[Mu])\)\) = 
        \(\(2\/N\) 
            \(\[Sum]\+\(j = 1\)\%N
                \((\[Sum]\+\(\[Mu] = 0\)\%n a\_\[Mu]\ x\_j\%\[Mu] - y\_j)\) 
                \((\[Sum]\+\(\[Mu] = 0\)\%n\( x\_j\%\[Mu]\) 
                      \[Delta]\_\(\[Mu], \[Nu]\))\)\) = 
          \(2\/N\) 
              \(\[Sum]\+\(j = 1\)\%N
                  \((\[Sum]\+\(\[Mu] = 0\)\%n a\_\[Mu]\ x\_j\%\[Mu] - y\_j)\) 
                  x\_j\%\[Nu]\)\( \[Equal] \&! \)0\)\)\)], "NumberedEquation"],

Cell["Eine Umsummierung ergibt:", "Text"],

Cell[BoxData[
    \(\[Sum]\+\(\[Mu] = 0\)\%n a\_\[Mu]\ 
          \(\[Sum]\+\(j = 1\)\%N x\_j\%\(\[Mu] + \[Nu]\)\) == 
      \[Sum]\+\(j = 1\)\%N\( y\_j\) x\_j\%\[Nu]\)], "NumberedEquation"],

Cell[TextData[{
  "Es hat sich also ein lineares Gleichungssystem in den noch unbekannten ",
  Cell[BoxData[
      \(TraditionalForm\`\((n + 1)\)\)]],
  " Koeffizienten ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[Mu]\)]],
  "des Ausgleichspolynoms ergeben."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Gau\[SZ]sche Schreibweise"
}], "Subsubsection"],

Cell["\<\
Nun hat Gau\[SZ] folgende abk\[UDoubleDot]rzende Schreibweise \
eingef\[UDoubleDot]hrt, um zum einen dem Setzer die Arbeit zu erleichtern und \
zum anderen \[CapitalUDoubleDot]bersicht der Terme zu erzeugen:\
\>", "Text"],

Cell[BoxData[
    \(\[Sum]\+\(j = 1\)\%N\( y\_j\) 
        x\_j\%\[Nu]\ \ \ \ \ \ \ \ \ \ \ 
          \[DoubleLongLeftRightArrow]\ \ \ \ \ \ \ \ \ \([y\ x\^\[Nu]]\)\)], 
  "NumberedEquation"],

Cell["\<\
In dieser Schreibweise sieht das sich ergebende lineare \
Gleichungssystem wie folgt aus:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {"N", \([x]\), \(\([x\^2]\)\ ...\), \([x\^n]\)},
              {\([x]\), \([x\^2]\), \(\([x\^3]\)\ ...\), \([x\^\(n + 1\)]\)},
              {":", ":", ":", ":"},
             
               {\([x\^n]\), \([x\^\(n + 1\)]\), \(\([x\^\(n + 2\)]\)\ ...\), 
                \([x\^\(2  n\)]\)}
              }], ")"}], 
        RowBox[{"(", GridBox[{
              {\(a\_0\)},
              {\(a\_1\)},
              {":"},
              {\(a\_n\)}
              }], ")"}]}], "\[Equal]", 
      RowBox[{"(", GridBox[{
            {\([y]\)},
            {\([y\ x]\)},
            {":"},
            {\([y\ x\^n]\)}
            }], ")"}]}]], "NumberedEquation"],

Cell[TextData[{
  "Hierbei wurde bereits ber\[UDoubleDot]cksichtigt, da\[SZ] ",
  Cell[BoxData[
      \(TraditionalForm\`\([x\^0]\) \[Equal] \([1]\) = N\)]],
  " gilt."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Konkretes Beispiel"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Lineare Regression"
}], "Subsubsection"],

Cell[TextData[{
  "F\[UDoubleDot]r ein konkretes Beispiel eignet sich ein Polynom ersten \
Grades, eine sogenannte Ausgleichsgerade, die auch unter dem Stichwort ",
  StyleBox["lineare Regression",
    FontSlant->"Italic"],
  " diskutiert wird:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(linearansatz = 
      \(1\/N\) \(\[Sum]\+\(j\  = \ 1\)\%N\((a + b\ x\_j - y\_j)\)\^2\)\)], 
  "Input"],

Cell[BoxData[
    \(\(\[Sum]\+\(j = 1\)\%N\((a + b\ x\_j - y\_j)\)\^2\)\/N\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Variationsableitungen nach ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " ergeben zur Minimalisierung der Fehlerquadratsumme ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gl[a] = 
      \((\[PartialD]\_a linearansatz  N\/2 == 0 /. Sum \[Rule] Dummy)\) /. 
        Dummy \[Rule] Sum\)], "Input"],

Cell[BoxData[
    \(1\/2\ \(\[Sum]\+\(j = 1\)\%N 2\ \((a + b\ x\_j - y\_j)\)\) == 0\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gl[b] = 
      \((\[PartialD]\_b linearansatz  N\/2 == 0 /. Sum \[Rule] Dummy)\) /. 
        Dummy \[Rule] Sum\)], "Input"],

Cell[BoxData[
    \(1\/2\ \(\[Sum]\+\(j = 1\)\%N 2\ x\_j\ \((a + b\ x\_j - y\_j)\)\) == 0
      \)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Matrix-Darstellung des Gleichungssystems"
}], "Subsubsection"],

Cell["Die Vereinfachung dieser Terme ergibt:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gln = 
      MatrixForm[{{\[Sum]\+\(j = 1\)\%N x\_j\%0, \[Sum]\+\(j = 1\)\%N x\_j}, {
                \[Sum]\+\(j = 1\)\%N x\_j, 
                \[Sum]\+\(j = 1\)\%N x\_j\%2}}].MatrixForm[{a, b}] == 
        MatrixForm[{\[Sum]\+\(j = 1\)\%N\( y\_j\) x\_j\%0, 
            \[Sum]\+\(j = 1\)\%N\( y\_j\) x\_j}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {"N", \(\[Sum]\+\(j = 1\)\%N x\_j\)},
               
                 {\(\[Sum]\+\(j = 1\)\%N x\_j\), 
                  \(\[Sum]\+\(j = 1\)\%N x\_j\%2\)}
                }], ")"}],
          (MatrixForm[ #]&)], ".", 
        InterpretationBox[
          RowBox[{"(", GridBox[{
                {"a"},
                {"b"}
                }], ")"}],
          MatrixForm[ {a, b}]]}], "==", 
      InterpretationBox[
        RowBox[{"(", GridBox[{
              {\(\[Sum]\+\(j = 1\)\%N y\_j\ x\_j\%0\)},
              {\(\[Sum]\+\(j = 1\)\%N y\_j\ x\_j\)}
              }], ")"}],
        MatrixForm[ {
          Sum[ 
            Times[ 
              Subscript[ y, j], 
              Power[ 
                Subscript[ x, j], 0]], {j, 1, N}], 
          Sum[ 
            Times[ 
              Subscript[ y, j], 
              Subscript[ x, j]], {j, 1, N}]}]]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Spezialf\[ADoubleDot]lle der L\[ODoubleDot]sung"
}], "Subsubsection"],

Cell[TextData[{
  "F\[UDoubleDot]r den Fall ",
  Cell[BoxData[
      \(TraditionalForm\`b = 0\)]],
  " ist nur die erste Gleichung relevant. Dadurch ergibt sich das ",
  StyleBox["arithmetische Mittel",
    FontSlant->"Italic"],
  " als ",
  StyleBox["Approximation nullter Ordnung",
    FontSlant->"Italic"],
  " ganz allgemein:"
}], "Text"],

Cell[BoxData[
    \(N\ a == 
        \([y]\)\ \ \ \ \ \ \ \ \ \ \ \ 
          \[DoubleLongLeftRightArrow]\ \ \ \ \ \ \ \ \ a = \([y]\)\/N\)], 
  "NumberedEquation"],

Cell[TextData[{
  "F\[UDoubleDot]r den Fall ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)]],
  " ist nur die zweite Gleichung relevant. Dadurch ergibt sich eine \
Ausgleichsgerade durch den Ursprung (",
  StyleBox["approximative Ursprungsgerade",
    FontSlant->"Italic"],
  "), die bei sehr vielen Me\[SZ]reihen Sinn hat, da oft genug von einem \
definierten Start aus ein dynamischer Sachverhalt gemessen wird:"
}], "Text"],

Cell[BoxData[
    \(\([x\ x]\) b == 
        \([x\ y]\)\ \ \ \ \ \ \ \ \ \ \ \ 
          \[DoubleLongLeftRightArrow]\ \ \ \ \ \ \ b = 
      \([x\ y]\)\/\([x\ x]\)\)], "NumberedEquation"],

Cell[TextData[{
  "Die Kalibrierung von Me\[SZ]ger\[ADoubleDot]ten auf den Startzustand ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 0)\)\)]],
  " besitzt also nicht nur \[ADoubleDot]sthetische Gesichtspunkte, sondern \
erleichtert in entscheidender Weise die Ausgleichsrechnung. Das Ergebnis ",
  Cell[BoxData[
      \(TraditionalForm\`\([x\ y]\)/\([x\ x]\)\)]],
  " ist sehr einfach und unter dem Stichwort Geradensteigung einsichtig."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Wann wird die allgemeine L\[ODoubleDot]sung wichtig?"
}], "Subsubsection"],

Cell[TextData[{
  "Wird ein allgemeines Potenzgesetz ab Me\[SZ]start ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 0)\)\)]],
  " gesucht, so ergibt sich folgender Ansatz f\[UDoubleDot]r die \
Ausgleichskurve in zwei Parametern:"
}], "Text"],

Cell[BoxData[
    \(y = 
      \(A\ x\^\[Alpha]\ \ \ \ \ \ \ \ \ \ \ \ \ 
            \[DoubleLongLeftRightArrow]\ \ \ \ \ \ \ \ \ Log[y] = 
        Log[A] + \[Alpha]\ Log[x]\)\)], "NumberedEquation"],

Cell[TextData[{
  "Durch Logarithmieren kann also bei kalibrierten Me\[SZ]reihen (und nur \
dort) eine allgemeine Regressionsgerade zur simultanen Auffindung der beiden \
Parameter ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " dienen. Es ist also sinnvoll und notwendig, auch die allgemeine lineare \
Regression zu beherrschen:"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". L\[ODoubleDot]sungsverfahren des Gleichungssystems"
}], "Subsubsection"],

Cell[TextData[{
  "Als sicheres L\[ODoubleDot]sungsverfahren f\[UDoubleDot]r ein lineares \
(Matrix-)Gleichungssystem eignet sich der sogenannte ",
  StyleBox["Gau\[SZ]-Algorithmus",
    FontSlant->"Italic"],
  ", bei dem ein Minimum an Rechenoperationen zur L\[ODoubleDot]sungsfindung \
auch dann m\[ODoubleDot]glich ist, wenn die sogenannte ",
  StyleBox["Determinante",
    FontSlant->"Italic"],
  " der Matrix Null werden sollte. Der Gau\[SZ]-Algorithmus dient der ",
  StyleBox["Diagonalisierung",
    FontSlant->"Italic"],
  " eines Matrix-Gleichungssystems und ist \[UDoubleDot]bersichtlich sowie \
schnell."
}], "Text"],

Cell["\<\
Anschaulich wird beim Gau\[SZ]-Algorithmus zuerst das Dreieck unter \
der Hauptdiagonale genullt, danach das Dreieck \[UDoubleDot]ber der \
Hauptdiagonale. Bei richtiger Rechenweise ist nur der Speicherplatz der \
Matrix-Koeffizienten notwendig, was besonders bei C-Programmen bedeutsam ist.\
\
\>", "Text"],

Cell[TextData[{
  "Zuerst wird die erste Gleichung durch ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " geteilt, damit der erste Term der Hauptdiagonalen Eins ist:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {"1", \(\([x]\)\/N\)},
              {\([x]\), \([x\^2]\)}
              }], ")"}], 
        RowBox[{"(", GridBox[{
              {"a"},
              {"b"}
              }], ")"}]}], "\[Equal]", 
      RowBox[{"(", GridBox[{
            {\(\([y]\)\/N\)},
            {\([y\ x]\)}
            }], ")"}]}]], "NumberedEquation"],

Cell[TextData[{
  "Dann wird von der zweiten Gleichung die mit ",
  Cell[BoxData[
      \(TraditionalForm\`\([x]\)\)]],
  " multiplizierte erste Gleichung abgezogen:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {"1", \(\([x]\)\/N\)},
              {"0", \(\([x\^2]\) - \([x]\)\^2\/N\)}
              }], ")"}], 
        RowBox[{"(", GridBox[{
              {"a"},
              {"b"}
              }], ")"}]}], "\[Equal]", 
      RowBox[{"(", GridBox[{
            {\(\([y]\)\/N\)},
            {\(\([y\ x]\) - \([x]\)[y]\/N\)}
            }], ")"}]}]], "NumberedEquation"],

Cell["Der zweite Term der Hauptdiagonale wird zu Eins gemacht:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {"1", \(\([x]\)\/N\)},
              {"0", "1"}
              }], ")"}], 
        RowBox[{"(", GridBox[{
              {"a"},
              {"b"}
              }], ")"}]}], "\[Equal]", 
      RowBox[{"(", GridBox[{
            {\(\([y]\)\/N\)},
            {\(\(N[y\ x] - \([x]\)[y]\)\/\(N[x\^2] - \([x]\)\^2\)\)}
            }], ")"}]}]], "NumberedEquation"],

Cell[TextData[{
  "Von der ersten Gleichung wird das ",
  Cell[BoxData[
      \(TraditionalForm\`\([x]\)/N\)]],
  "-fache der zweiten Gleichung abgezogen:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {"1", "0"},
              {"0", "1"}
              }], ")"}], 
        RowBox[{"(", GridBox[{
              {"a"},
              {"b"}
              }], ")"}]}], "\[Equal]", 
      RowBox[{"(", GridBox[{
           
             {\(\([y]\)\/N - 
                \(\([x]\)\/N\) 
                  \(N[y\ x] - \([x]\)[y]\)\/\(N[x\^2] - \([x]\)\^2\)\)},
            {\(\(N[y\ x] - \([x]\)[y]\)\/\(N[x\^2] - \([x]\)\^2\)\)}
            }], ")"}]}]], "NumberedEquation"],

Cell[TextData[{
  "Als Lehrbuch \[UDoubleDot]ber Matrizenrechnung ist das Werk von Zurm\
\[UDoubleDot]hl und Falk ",
  ButtonBox["[ZF1984]",
    ButtonData:>"[ZF1984]",
    ButtonStyle->"Hyperlink"],
  " zu empfehlen, das weitaus mehr abhandelt als zur Ausgleichsrechnung \
notwendig ist. Das gefundene Ergebnis findet sich auch in der Literatur (z.B. \
",
  ButtonBox["[GKHK1974]",
    ButtonData:>"[GKHK1974]",
    ButtonStyle->"Hyperlink"],
  ", Seite 637)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". L\[ODoubleDot]sung des Gleichungssystems"
}], "Subsubsection"],

Cell["\<\
Die abk\[UDoubleDot]rzende Schreibweise nach Gau\[SZ] erlaubt \
folgende Darstellung:\
\>", "Text"],

Cell[BoxData[{
    \(b = \(N\ [x\ y] - \([x]\)[y]\)\/\(N\ [x\^2] - \([x]\)\^2\)\), 
    \(a = \([y]\)\/N - \(\([x]\)\/N\) b\)}], "NumberedEquation"],

Cell[TextData[{
  "Die L\[ODoubleDot]sung des linearen Gleichungssystems ergibt mit ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(l\[ODoubleDot]sung[linear] = 
      LinearSolve[\(\(gln // First\) // First\) // First, 
          \(gln // Last\) // First] // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
           
             {\(\(\[Sum]\+\(j = 1\)\%N y\_j\ x\_j\%0\)\/N - 
                \(\((\[Sum]\+\(j = 1\)\%N x\_j)\)\ 
                    \((\(-\(\[Sum]\+\(j = 1\)\%N y\_j\ x\_j\%0\)\)\ 
                          \(\[Sum]\+\(j = 1\)\%N x\_j\) + 
                        N\ \(\[Sum]\+\(j = 1\)\%N y\_j\ x\_j\))\)\)\/\(N\ 
                    \((\(-\((\[Sum]\+\(j = 1\)\%N x\_j)\)\^2\) + 
                        N\ \(\[Sum]\+\(j = 1\)\%N x\_j\%2\))\)\)\)},
           
             {\(\(\(-\(\[Sum]\+\(j = 1\)\%N y\_j\ x\_j\%0\)\)\ 
                      \(\[Sum]\+\(j = 1\)\%N x\_j\) + 
                    N\ \(\[Sum]\+\(j = 1\)\%N y\_j\ x\_j\)\)\/\(\(-
                      \((\[Sum]\+\(j = 1\)\%N x\_j)\)\^2\) + 
                    N\ \(\[Sum]\+\(j = 1\)\%N x\_j\%2\)\)\)}
            }], ")"}],
      MatrixForm[ {
        Plus[ 
          Times[ 
            Power[ N, -1], 
            Sum[ 
              Times[ 
                Subscript[ y, j], 
                Power[ 
                  Subscript[ x, j], 0]], {j, 1, N}]], 
          Times[ -1, 
            Power[ N, -1], 
            Sum[ 
              Subscript[ x, j], {j, 1, N}], 
            Plus[ 
              Times[ -1, 
                Sum[ 
                  Times[ 
                    Subscript[ y, j], 
                    Power[ 
                      Subscript[ x, j], 0]], {j, 1, N}], 
                Sum[ 
                  Subscript[ x, j], {j, 1, N}]], 
              Times[ N, 
                Sum[ 
                  Times[ 
                    Subscript[ y, j], 
                    Subscript[ x, j]], {j, 1, N}]]], 
            Power[ 
              Plus[ 
                Times[ -1, 
                  Power[ 
                    Sum[ 
                      Subscript[ x, j], {j, 1, N}], 2]], 
                Times[ N, 
                  Sum[ 
                    Power[ 
                      Subscript[ x, j], 2], {j, 1, N}]]], -1]]], 
        Times[ 
          Plus[ 
            Times[ -1, 
              Sum[ 
                Times[ 
                  Subscript[ y, j], 
                  Power[ 
                    Subscript[ x, j], 0]], {j, 1, N}], 
              Sum[ 
                Subscript[ x, j], {j, 1, N}]], 
            Times[ N, 
              Sum[ 
                Times[ 
                  Subscript[ y, j], 
                  Subscript[ x, j]], {j, 1, N}]]], 
          Power[ 
            Plus[ 
              Times[ -1, 
                Power[ 
                  Sum[ 
                    Subscript[ x, j], {j, 1, N}], 2]], 
              Times[ N, 
                Sum[ 
                  Power[ 
                    Subscript[ x, j], 2], {j, 1, N}]]], -1]]}]]], "Output"]
}, Open  ]],

Cell["\<\
Durch die Computertechnik sind gen\[UDoubleDot]gend Programme \
vorhanden, die Ausgleichspolynome der gew\[UDoubleDot]nschten Ordnung schnell \
und sicher zu entsprechenden Datenreihen erzeugen. Deshalb ist der hier \
dargestellte L\[ODoubleDot]sungsweg vor allem zum Kennenlernen der Programme \
sinnvoll, w\[ADoubleDot]hrend in der Praxis die vorhandenen Programme genutzt \
und mit Hilfe der Fehlerquadratsummen gepr\[UDoubleDot]ft und verglichen \
werden k\[ODoubleDot]nnen.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Einfaches Beispiel"
}], "Subsubsection"],

Cell["\<\
Werden die Zahlenwerte einer Urspungsgeraden bearbeitet, so ergeben \
die einzelnen Summenterme:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(gerade = \({#, 1 - #}&\)/@Range[10]\), 
    \(summenregel
       = {RuleDelayed@@{summe[\(x\^m_.\) y\^n_.], 
            Plus@@\((\(\(First[#]\^m\) Last[#]\^n&\)/@gerade)\)}, 
        RuleDelayed@@{summe[x\^m_.], Plus@@\((\(First[#]\^m&\)/@gerade)\)}, 
        RuleDelayed@@{summe[y\^n_.], Plus@@\((\(Last[#]\^n&\)/@gerade)\)}, 
        RuleDelayed@@{summe[1], Length[gerade]}}\)}], "Input"],

Cell[BoxData[
    \({{1, 0}, {2, \(-1\)}, {3, \(-2\)}, {4, \(-3\)}, {5, \(-4\)}, {6, 
        \(-5\)}, {7, \(-6\)}, {8, \(-7\)}, {9, \(-8\)}, {10, \(-9\)}}\)], 
  "Output"],

Cell[BoxData[
    \({summe[x\^m_.\ y\^n_.] \[RuleDelayed] 
        0\^n + \((\(-1\))\)\^n\ 2\^m + \((\(-2\))\)\^n\ 3\^m + 
          \((\(-3\))\)\^n\ 4\^m + \((\(-4\))\)\^n\ 5\^m + 
          \((\(-5\))\)\^n\ 6\^m + \((\(-6\))\)\^n\ 7\^m + 
          \((\(-7\))\)\^n\ 8\^m + \((\(-8\))\)\^n\ 9\^m + 
          \((\(-9\))\)\^n\ 10\^m, 
      summe[x\^m_.] \[RuleDelayed] 
        1 + 2\^m + 3\^m + 4\^m + 5\^m + 6\^m + 7\^m + 8\^m + 9\^m + 10\^m, 
      summe[y\^n_.] \[RuleDelayed] 
        \((\(-9\))\)\^n + \((\(-8\))\)\^n + \((\(-7\))\)\^n + 
          \((\(-6\))\)\^n + \((\(-5\))\)\^n + \((\(-4\))\)\^n + 
          \((\(-3\))\)\^n + \((\(-2\))\)\^n + \((\(-1\))\)\^n + 0\^n, 
      summe[1] \[RuleDelayed] 10}\)], "Output"]
}, Open  ]],

Cell["\<\
Damit k\[ODoubleDot]nnen die beiden Parameter einer \
bestangepa\[SZ]ten Gerade bestimmt werden:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \({summe[1], summe[x], summe[x\^2], summe[y], summe[x\ y]} /. summenregel
      \), 
    \(b = 
      \(summe[1]\ summe[x\ y] - summe[x] summe[y]\)\/\(summe[1] summe[x\^2] - 
            summe[x]\^2\) /. summenregel\), 
    \(a = summe[y]\/summe[1] - \(summe[x]\/summe[1]\) b /. summenregel\)}], 
  "Input"],

Cell[BoxData[
    \({10, 55, 385, \(-45\), \(-330\)}\)], "Output"],

Cell[BoxData[
    \(\(-1\)\)], "Output"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell["Das sind in der Tat die Parameter der verwendeten Gerade.", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Toleranzbestimmung"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Eventuell unn\[ODoubleDot]tig?"
}], "Subsubsection"],

Cell["\<\
Eine berechtigte Frage ist die nach den Toleranzen f\[UDoubleDot]r \
die ermittelten Parameter.\
\>", "Text"],

Cell["\<\
Zun\[ADoubleDot]chst einmal ist die Toleranz Null, denn die \
ermittelten Parameter stellen ein Optimum dar.\
\>", "Text"],

Cell["\<\
Es stellt sich also die Frage, ob Toleranzen zu den Parametern \
nicht unn\[ODoubleDot]tig sind.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Ansatz mit Fehlerfortpflanzung"
}], "Subsubsection"],

Cell[TextData[{
  "Eine Anwendung der Fehlerfortpflanzung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fehlerfortpflanzung"],
  ") ist der folgende Ansatz:"
}], "Text"],

Cell[BoxData[
    \(\((y\_i - f\_i)\)\^2 \[Equal] 
      \((y\_i - \[Sum]\+\(\[Mu]\  = \ 0\)\%n\( a\_\[Mu]\) x\_i\%\[Mu])\)\^2
        \( \[Equal] \&! \)\[Sum]\+\(\[Mu]\  = \ 0\)\%n
          \(\((\[PartialD]f\_i\/\[PartialD]a\_\[Mu])\)\^2\) 
          \[CapitalDelta][a\_\[Mu]]\^2 \[Equal] 
      \[Sum]\+\(\[Mu]\  = \ 0\)\%n\( x\_i\%\(2  \[Mu]\)\) 
          \[CapitalDelta][a\_\[Mu]]\^2\)], "NumberedEquation"],

Cell[TextData[{
  "\[CapitalUDoubleDot]ber diesen Ansatz kann mit dem Laufindex ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " summiert werden, wobei es nun gleichg\[UDoubleDot]ltig ist, ob durch ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " oder ",
  Cell[BoxData[
      \(TraditionalForm\`N(N - 1)\)]],
  " usw. geteilt wird, da dieser Teiler auf beiden Seiten angewandt wird:"
}], "Text"],

Cell[BoxData[
    \(\[Sum]\+\(i\  = \ 1\)\%N
          \((y\_i - \[Sum]\+\(\[Mu]\  = \ 0\)\%n\( a\_\[Mu]\) x\_i\%\[Mu])
            \)\^2\( \[Equal] \&! \)\[Sum]\+\(\[Mu]\  = \ 0\)\%n
          \( \[CapitalDelta][a\_\[Mu]]\^2\) 
          \(\[Sum]\+\(i\  = \ 1\)\%N x\_i\%\(2  \[Mu]\)\)\)], 
  "NumberedEquation",
  CellTags->"Fehlerfortpflanzung?"],

Cell[TextData[{
  "Dies ist eine Gleichung f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " Unbekannte, also sind Zusatzbedingungen n\[ODoubleDot]tig, die auf die \
Einzeltoleranzen f\[UDoubleDot]hren."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Ansatz des gleichverteilten Beitrags"
}], "Subsubsection"],

Cell[TextData[{
  "Nun wird angesetzt, da\[SZ] die ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta][a\_\[Mu]]\^2\)]],
  " so zu w\[ADoubleDot]hlen seien, da\[SZ] die sich ergebenden Summanden auf \
der rechten Seite von Gleichung (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fehlerfortpflanzung?"],
  ") jeweils gleich gro\[SZ] seien. Auf diese Weise wird die \
Fehlerquadratsumme durch gleiche Beitr\[ADoubleDot]ge aller Toleranzen \
erzeugt."
}], "Text"],

Cell[TextData[{
  "Dies liefert folgende Aufl\[ODoubleDot]sung nach der Toleranz ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta][a\_\[Mu]]\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta][a\_\[Mu]]
        \( \[Equal] \&! 
          \)\@\(\(\[Sum]\+\(i\  = \ 1\)\%N
                \((y\_i - 
                    \[Sum]\+\(\[Mu]\  = \ 0\)\%n\( a\_\[Mu]\) x\_i\%\[Mu])
                  \)\^2\)\/\(\((n + 1)\) 
              \(\[Sum]\+\(i\  = \ 1\)\%N x\_i\%\(2  \[Mu]\)\)\)\)\)], 
  "NumberedEquation",
  CellFrame->True],

Cell["\<\
Die auf diese Weise ermittelten Toleranzen liefern gute Sch\
\[ADoubleDot]tzwerte, da sie die Fehlerquadratsumme konkret ausdeuten. Ist \
die Fehlerquadratsumme Null, so werden auch die Einzeltoleranzen Null. Das \
kommt vor, wenn zum Beispiel ein Polynom von mindestens zweitem Grade an die \
Wertepaare einer Parabel angepa\[SZ]t wird.\
\>", "Text"],

Cell["\<\
Andere Ans\[ADoubleDot]tze liefern andere Toleranzformeln. Wichtig \
ist vor allem, da\[SZ] der Rechnende noch wei\[SZ], was er tut. \
Abgeschriebene Formeln bringen mehr Verwirrung als Nutzen.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Schlechtes und besseres Beispiel"
}], "Subsubsection"],

Cell[TextData[{
  "Werden die Zahlenwerte der bereits diskutierten Geraden bearbeitet, so \
ergeben die Toleranzen nach einer Mathematik-Enzyklop\[ADoubleDot]die (",
  ButtonBox["[GKHK1974]",
    ButtonData:>"[GKHK1974]",
    ButtonStyle->"Hyperlink"],
  ", Seite 637):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \({HoldForm[\[CapitalDelta][a]] \[Rule] 
          \@\(summe[x\^2]\/\(summe[1] summe[x\^2] - summe[x]\^2\)\), 
        HoldForm[\[CapitalDelta][b]] \[Rule] 
          \@\(summe[1]\/\(summe[1] summe[x\^2] - summe[x]\^2\)\)} /. 
      summenregel\), 
    \(% // N\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          TagBox[\(\[CapitalDelta][a]\),
            HoldForm], "\[Rule]", \(\@\(7\/15\)\)}], ",", 
        RowBox[{
          TagBox[\(\[CapitalDelta][b]\),
            HoldForm], "\[Rule]", \(\@\(2\/165\)\)}]}], "}"}]], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          TagBox[\(\[CapitalDelta][a]\),
            HoldForm], "\[Rule]", "0.683130051063973198`"}], ",", 
        RowBox[{
          TagBox[\(\[CapitalDelta][b]\),
            HoldForm], "\[Rule]", "0.110096376512636062`"}]}], "}"}]], 
  "Output"]
}, Open  ]],

Cell["\<\
Damit ist gezeigt, da\[SZ] die abgeschriebene Toleranzformel keinen \
wissenschaftlichen N\[ADoubleDot]hrwert besitzt.\
\>", "Text"],

Cell[TextData[{
  "Eine andere Sch\[ADoubleDot]tzformel f\[UDoubleDot]r dasselbe Problem \
findet sich bei Hering et al. (",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", Bild 1-8, Seite 16):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({HoldForm[\[CapitalDelta][a]] \[Rule] 
          \[Sqrt]\((
              \((\((summe[y\^2] - 2  a\ summe[y] - 2  b\ summe[x\ y] + 
                        2  a\ b\ summe[x] + \(a\^2\) summe[1] + 
                        \(b\^2\) summe[x\^2])\) summe[x\^2])\)/
                \((\((summe[1] - 2)\) 
                    \((summe[1] summe[x\^2] - summe[x]\^2)\))\))\), 
        HoldForm[\[CapitalDelta][b]] \[Rule] 
          \[Sqrt]\((
              \((\((summe[y\^2] - 2  a\ summe[y] - 2  b\ summe[x\ y] + 
                        2  a\ b\ summe[x] + \(a\^2\) summe[1] + 
                        \(b\^2\) summe[x\^2])\) summe[1])\)/
                \((\((summe[1] - 2)\) 
                    \((summe[1] summe[x\^2] - summe[x]\^2)\))\))\)} /. 
      summenregel\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          TagBox[\(\[CapitalDelta][a]\),
            HoldForm], "\[Rule]", "0"}], ",", 
        RowBox[{
          TagBox[\(\[CapitalDelta][b]\),
            HoldForm], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Hinter dieser Formel steckt also schon mehr. Leider ist die Quelle \
oder Herleitung nicht angegeben. Bei dieser Formel taucht die \
ausmultiplizierte Fehlerquadratsumme jedenfalls konkret auf:\
\>", "Text"],

Cell[BoxData[
    \(Clear[a, b]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((y\_i - \[Sum]\+\(\[Mu]\  = \ 0\)\%n\( a\_\[Mu]\) x\_i\%\[Mu])\)\^2
           /. n \[Rule] 1 // ExpandAll\)], "Input"],

Cell[BoxData[
    \(a\_0\%2 + 2\ a\_0\ a\_1\ x\_i + a\_1\%2\ x\_i\%2 - 2\ a\_0\ y\_i - 
      2\ a\_1\ x\_i\ y\_i + y\_i\%2\)], "Output"]
}, Open  ]],

Cell["\<\
Auf diese Weise wird wenigstens verst\[ADoubleDot]ndlich, wieso die \
Toleranzen korrekt verschwinden.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Gr\[ODoubleDot]\[SZ]tfehler"
}], "Subsection"],

Cell[TextData[{
  "Au\[SZ]erdem kann \[UDoubleDot]ber die Gr\[ODoubleDot]\[SZ]tfehler der \
gefundenen Parameter diskutiert werden. Das konsequente Anwenden von Formel \
(",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Groesstfehler"],
  ") ergibt mit ",
  Cell[BoxData[
      \(TraditionalForm\`f\_i\)]],
  " folgenden Ansatz:"
}], "Text"],

Cell[BoxData[
    \(\(|\((y\_i - f\_i)\) | 
       \[Equal]  | 
        \((y\_i - \[Sum]\+\(\[Mu]\  = \ 0\)\%n\( a\_\[Mu]\) x\_i\%\[Mu])\) | 
      \( \[Equal] \&! \)\[Sum]\+\(\[Mu]\  = \ 0\)\%n | 
      \[PartialD]f\_i\/\[PartialD]x\_\[Mu] | 
      \[CapitalDelta]x\_\[Mu] \[Equal] \[Sum]\+\(\[Mu]\  = \ 0\)\%n | 
      x\_i\%\[Mu] | \[CapitalDelta]x\_\[Mu]\)\)], "NumberedEquation"],

Cell["\<\
Die Summation \[UDoubleDot]ber diesen Ansatz und das beidseitige \
Teilen durch einen beliebigen Faktor ergibt:\
\>", "Text"],

Cell[BoxData[
    \(\[Sum]\+\(i\  = \ 1\)\%N|\((y\_i - f\_i)\) | 
      \( \[Equal] 
        \[Sum]\+\(i\  = \ 1\)\%N|
          \((y\_i - \[Sum]\+\(\[Mu]\  = \ 0\)\%n\( a\_\[Mu]\) x\_i\%\[Mu])
            \)\) | \(\( \[Equal] \&! \)\[Sum]\+\(i\  = \ 1\)\%N
            \(\[Sum]\+\(\[Mu]\  = \ 0\)\%n
              \(( | \[PartialD]f\_i\/\[PartialD]x\_\[Mu] | )\) 
              \[CapitalDelta]x\_\[Mu]\) \[Equal] 
        \[Sum]\+\(\[Mu]\  = \ 0\)\%n\( \[CapitalDelta]x\_\[Mu]\) 
            \(\[Sum]\+\(i\  = \ 1\)\%N|\((x\_i\%\[Mu])\)\)\) | \)], 
  "NumberedEquation"],

Cell["Der Ansatz der gleichm\[ADoubleDot]\[SZ]igen Fehlerbeitr\[ADoubleDot]ge \
ergibt:", "Text"],

Cell[BoxData[
    \(\[CapitalDelta]a
        \_\[Mu]\( \[Equal] \&! 
          \)\(\[Sum]\+\(i\  = \ 1\)\%N\(|
            \((y\_i - \[Sum]\+\(\[Mu]\  = \ 0\)\%n\( a\_\[Mu]\) x\_i\%\[Mu])
              \) | \)\)\/\(\((n + 1)\)\ 
            \(\[Sum]\+\(i\  = \ 1\)\%N\(|\((x\_i\%\[Mu])\)\)\) | \)\)], 
  "NumberedEquation",
  CellFrame->True],

Cell["\<\
F\[UDoubleDot]r das gew\[ADoubleDot]hlte Beispiel sind auch die \
Fehlerbeitr\[ADoubleDot]ge Null, so da\[SZ] auch ein \
Gr\[ODoubleDot]\[SZ]tfehler von Null resultiert. F\[UDoubleDot]r \
mathematische Kurvenanpassungen kann also im Gegensatz zur Physik eine \
Toleranz Null resultieren.\
\>", "Text"],

Cell["\<\
Die gefundenen Toleranzformeln m\[UDoubleDot]ssen sich in der \
Praxis bew\[ADoubleDot]hren. Sie wurden anl\[ADoubleDot]\[SZ]lich der \
Vorlesung erarbeitet und lassen sich auf beliebig komplizierte \
Kurvenanpassungen verallgemeinern.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Protokoll"
}], "Section"],

Cell[TextData[{
  "Die Version von ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " lautet:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({$Version, $ReleaseNumber, $LicenseID}\)], "Input"],

Cell[BoxData[
    \({"Microsoft Windows 3.0 (October 6, 1996)", 0, "0"}\)], "Output"]
}, Open  ]],

Cell["Die Berechnungszeit betrug (in Sekunden):", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimeUsed[]\)], "Input"],

Cell[BoxData[
    \(5.44000000000000039`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Literatur", "Subtitle"],

Cell[TextData[{
  "[Baul1956]\nBaule B ",
  StyleBox["Die Mathematik des Naturforschers und Ingenieurs",
    FontSlant->"Italic"],
  " ",
  StyleBox["Band II Ausgleichs- und N\[ADoubleDot]herungsrechnung",
    FontWeight->"Bold"],
  ", S. Hirzel Verlag Leipzig, 5. erweiterte Auflage, (1956)"
}], "Text",
  CellTags->"[Baul1956]"],

Cell[TextData[{
  "[BrS1987]\nBronstein I. N., Semendjajew K. A. ",
  StyleBox["Taschenbuch der Mathematik",
    FontSlant->"Italic"],
  ", Gemeinschaftsausgabe Verlag Nauka, Moskau und BSB B. G. Teubner \
Verlagsgesellschaft Leipzig, 23. Auflage, (1987)"
}], "Text",
  CellTags->"[BrS1987]"],

Cell[TextData[{
  "[GKHK1974]\nGellert W., K\[UDoubleDot]stner H., Hellwich M., \
K\[ADoubleDot]stner H. ",
  StyleBox["Kleine Enzyklop\[ADoubleDot]die Mathematik",
    FontSlant->"Italic"],
  ",  VEB Bibliographisches Institut Leipzig, 9. gek\[UDoubleDot]rzte \
Auflage, (1974)"
}], "Text",
  CellTags->"[GKHK1974]"],

Cell[TextData[{
  "[Haw1995]\nHawlitschek K. ",
  StyleBox[
  "Johann Faulhaber 1580 - 1635 Eine Bl\[UDoubleDot]tezeit der mathematischen \
Wissenschaften in Ulm",
    FontSlant->"Italic"],
  ", Ver\[ODoubleDot]ffentlichungen der Stadtbibliothek Ulm, Band 18, (1995)"
}], "Text",
  CellTags->"[Haw1995]"],

Cell[TextData[{
  "[HMS2004]\nHering E., Martin R., Stohrer M. ",
  StyleBox["Physik f\[UDoubleDot]r Ingenieure",
    FontSlant->"Italic"],
  ", Springer-Verlag Berlin etc., 9. Auflage, (2004)"
}], "Text",
  CellTags->"[HMS2004]"],

Cell[TextData[{
  "[Mor1987]\nMortimer Ch. ",
  StyleBox["Chemie \[Dash] Das Basiswissen der Chemie",
    FontSlant->"Italic"],
  ", Georg Thieme Verlag Stuttgart, 5. v\[ODoubleDot]llig neu bearbeitete und \
erweiterte Auflage, (1987)"
}], "Text",
  CellTags->"[Mor1987]"],

Cell[TextData[{
  "[N\[OSlash]r1924]\nN\[OSlash]rlund N. E. ",
  StyleBox["Differenzenrechnung",
    FontSlant->"Italic"],
  ", Berlin, (1924)"
}], "Text",
  CellTags->"[Noer1924]"],

Cell[TextData[{
  "[Smi1988]\nSmirnov W. I. ",
  StyleBox["Lehrgang der h\[ODoubleDot]heren Mathematik",
    FontSlant->"Italic"],
  ", Teil IV/1, VEB Deutscher Verlag der Wissenschaften, Berlin, (1988)"
}], "Text",
  CellTags->"[Smi1988]"],

Cell[TextData[{
  "[Spie1982]\nSpiegel M. R., ",
  StyleBox["Endliche Differenzen und Differenzengleichungen",
    FontSlant->"Italic"],
  ", McGraw-Hill Book Company Hamburg etc., (1982)"
}], "Text",
  CellTags->"[Spie1982]"],

Cell[TextData[{
  "[ZF1984]\nZurm\[UDoubleDot]hl R., Falk S. ",
  StyleBox[
  "Matrizen und ihre Anwendungen f\[UDoubleDot]r Angewandte Mathematiker, \
Physiker und Ingenieure",
    FontSlant->"Italic"],
  ", Teil 1: Grundlagen, Springer-Verlag Berlin etc., 5. erweiterte und \
\[UDoubleDot]berarbeitete Auflage, (1984)"
}], "Text",
  CellTags->"[ZF1984]"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
Evaluator->"Local",
CellGrouping->Automatic,
WindowSize->{752, 505},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ "\[Copyright] Norbert S\[UDoubleDot]dland"], "Header"], 
      Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Cell[ 
        TextData[ "\[Copyright] Norbert S\[UDoubleDot]dland"], "Header"], 
      Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.996109],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0.8, 0.300008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Equation", 0}, {"Figure", 0}, {"Table", 0}, {
        "Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0.500008, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0.500008, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    TextJustification->1,
    FontFamily->"Arial"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontSize->7]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Printout"],
    CellFrame->True,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.8]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    FontSize->11],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Times",
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{Inherited, 5}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedEquation"], ")"}], FormatType -> TextForm, 
            FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation1"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")  "}], FormatType -> 
            TextForm, FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation1", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure1"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure1", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable1"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable1", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    FormatType->InputForm,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    ZeroWidthTimes->True,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    ShowCellBracket->False,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    TextAlignment->Center,
    FormatType->InputForm,
    ScriptLevel->0,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->15],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->10.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->9.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Equation"],
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Equation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Equation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Equation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Presentation"],
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Condensed"],
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Presentation"],
    FontSize->16,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Condensed"],
    FontSize->11,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.8]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Centered Headings", "Section",
    CellFrame->{{0, 0}, {0, 2}}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredTitle"],
    CellMargins->{{12, 12}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredTitle", "Presentation"],
    CellMargins->{{24, 24}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["CenteredTitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["CenteredTitle", "Printout"],
    CellMargins->{{2, 2}, {15, 30}},
    FontSize->24]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubtitle"],
    CellMargins->{{12, 12}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubtitle", "Presentation"],
    CellMargins->{{24, 24}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["CenteredSubtitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["CenteredSubtitle", "Printout"],
    CellMargins->{{2, 2}, {10, 15}},
    FontSize->18]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubtitle"],
    CellMargins->{{12, 12}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubtitle", "Presentation"],
    CellMargins->{{24, 24}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSubsubtitle", "Condensed"],
    CellMargins->{{8, 8}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsubtitle", "Printout"],
    CellMargins->{{2, 2}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSection"],
    CellMargins->{{12, 12}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsection"],
    CellMargins->{{12, 12}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["CenteredSubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubsection"],
    CellMargins->{{12, 12}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["CenteredSubsubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["CenteredSubsubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 14}},
    FontSize->11]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Binomische Differenzengleichung"->{
    Cell[279495, 6850, 433, 15, 57, "NumberedEquation",
      CellTags->"Binomische Differenzengleichung"]},
  "Berechnung der Binomial-Koeffizienten"->{
    Cell[280808, 6904, 360, 11, 58, "NumberedEquation",
      CellTags->"Berechnung der Binomial-Koeffizienten"]},
  "Arithmetisches Mittel"->{
    Cell[435063, 10739, 172, 4, 76, "NumberedEquation",
      CellTags->"Arithmetisches Mittel"]},
  "mittlerer Fehler"->{
    Cell[443888, 11067, 199, 5, 86, "NumberedEquation",
      CellTags->"mittlerer Fehler"]},
  "falsche Standardabweichung"->{
    Cell[446694, 11167, 220, 5, 86, "NumberedEquation",
      CellTags->"falsche Standardabweichung"]},
  "Fehlerfortpflanzung"->{
    Cell[455168, 11465, 204, 5, 86, "NumberedEquation",
      CellTags->"Fehlerfortpflanzung"]},
  "Groesstfehler"->{
    Cell[456539, 11518, 203, 4, 76, "NumberedEquation",
      CellTags->"Groesstfehler"]},
  "Euler-Ostrogradskische Gleichungen"->{
    Cell[498160, 12687, 781, 14, 73, "NumberedEquation",
      CellTags->"Euler-Ostrogradskische Gleichungen"]},
  "Fehlerfortpflanzung?"->{
    Cell[525230, 13647, 349, 7, 76, "NumberedEquation",
      CellTags->"Fehlerfortpflanzung?"]},
  "[Baul1956]"->{
    Cell[534789, 13972, 330, 9, 93, "Text",
      CellTags->"[Baul1956]"]},
  "[BrS1987]"->{
    Cell[535122, 13983, 292, 7, 117, "Text",
      CellTags->"[BrS1987]"]},
  "[GKHK1974]"->{
    Cell[535417, 13992, 317, 8, 93, "Text",
      CellTags->"[GKHK1974]"]},
  "[Haw1995]"->{
    Cell[535737, 14002, 304, 8, 93, "Text",
      CellTags->"[Haw1995]"]},
  "[HMS2004]"->{
    Cell[536044, 14012, 230, 6, 93, "Text",
      CellTags->"[HMS2004]"]},
  "[Mor1987]"->{
    Cell[536277, 14020, 272, 7, 93, "Text",
      CellTags->"[Mor1987]"]},
  "[Noer1924]"->{
    Cell[536552, 14029, 181, 6, 69, "Text",
      CellTags->"[Noer1924]"]},
  "[Smi1988]"->{
    Cell[536736, 14037, 240, 6, 93, "Text",
      CellTags->"[Smi1988]"]},
  "[Spie1982]"->{
    Cell[536979, 14045, 226, 6, 93, "Text",
      CellTags->"[Spie1982]"]},
  "[ZF1984]"->{
    Cell[537208, 14053, 356, 9, 117, "Text",
      CellTags->"[ZF1984]"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Binomische Differenzengleichung", 579052, 15543},
  {"Berechnung der Binomial-Koeffizienten", 579206, 15546},
  {"Arithmetisches Mittel", 579350, 15549},
  {"mittlerer Fehler", 579473, 15552},
  {"falsche Standardabweichung", 579601, 15555},
  {"Fehlerfortpflanzung", 579732, 15558},
  {"Groesstfehler", 579850, 15561},
  {"Euler-Ostrogradskische Gleichungen", 579983, 15564},
  {"Fehlerfortpflanzung?", 580124, 15567},
  {"[Baul1956]", 580240, 15570},
  {"[BrS1987]", 580333, 15573},
  {"[GKHK1974]", 580427, 15576},
  {"[Haw1995]", 580520, 15579},
  {"[HMS2004]", 580612, 15582},
  {"[Mor1987]", 580704, 15585},
  {"[Noer1924]", 580797, 15588},
  {"[Smi1988]", 580890, 15591},
  {"[Spie1982]", 580983, 15594},
  {"[ZF1984]", 581075, 15597}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 265, 3, 218, "Title",
  CounterAssignments->{{"Title", 7}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],
Cell[1999, 56, 117, 4, 80, "Subtitle"],
Cell[2119, 62, 330, 5, 145, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2474, 71, 105, 5, 76, "Section"],

Cell[CellGroupData[{
Cell[2604, 80, 142, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[2771, 91, 184, 9, 61, "Subsubsection"],
Cell[2958, 102, 153, 3, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3148, 110, 184, 9, 61, "Subsubsection"],
Cell[3335, 121, 216, 5, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3588, 131, 184, 9, 61, "Subsubsection"],
Cell[3775, 142, 343, 7, 93, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4167, 155, 138, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[4330, 166, 195, 9, 61, "Subsubsection"],
Cell[4528, 177, 303, 6, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4868, 188, 178, 9, 61, "Subsubsection"],
Cell[5049, 199, 142, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[5216, 208, 81, 3, 91, "Input"],
Cell[5300, 213, 35, 1, 41, "Output"],
Cell[5338, 216, 35, 1, 41, "Output"]
}, Open  ]],
Cell[5388, 220, 415, 12, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5840, 237, 194, 9, 61, "Subsubsection"],
Cell[6037, 248, 191, 7, 45, "Text"],
Cell[6231, 257, 119, 3, 94, "Input"],
Cell[6353, 262, 38, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6416, 266, 51, 1, 41, "Input"],
Cell[6470, 269, 134, 3, 60, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6653, 278, 211, 10, 61, "Subsubsection"],
Cell[6867, 290, 199, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[7091, 298, 85, 1, 41, "Input"],
Cell[7179, 301, 42, 1, 41, "Output"]
}, Open  ]],
Cell[7236, 305, 171, 4, 69, "Text"],
Cell[7410, 311, 140, 4, 94, "Input"],
Cell[7553, 317, 193, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[7771, 329, 85, 1, 41, "Input"],
Cell[7859, 332, 149, 3, 67, "Output"]
}, Open  ]],
Cell[8023, 338, 517, 12, 117, "Text"],

Cell[CellGroupData[{
Cell[8565, 354, 724, 16, 312, "Input"],
Cell[9292, 372, 55609, 1361, 279, 16755, 877, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[64916, 1736, 384, 11, 93, "Text"],
Cell[65303, 1749, 404, 7, 117, "Text"],
Cell[65710, 1758, 125, 3, 45, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[65884, 1767, 146, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[66055, 1778, 185, 9, 61, "Subsubsection"],
Cell[66243, 1789, 123, 3, 45, "Text"],
Cell[66369, 1794, 208, 4, 69, "Text"],
Cell[66580, 1800, 563, 10, 141, "Text"],
Cell[67146, 1812, 302, 6, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67485, 1823, 187, 10, 61, "Subsubsection"],
Cell[67675, 1835, 151, 3, 69, "Text"],
Cell[67829, 1840, 361, 8, 93, "Text"],
Cell[68193, 1850, 116, 3, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68346, 1858, 191, 9, 61, "Subsubsection"],
Cell[68540, 1869, 115, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[68680, 1878, 100, 4, 116, "Input"],
Cell[68783, 1884, 35, 1, 41, "Output"],
Cell[68821, 1887, 35, 1, 41, "Output"],
Cell[68859, 1890, 35, 1, 41, "Output"]
}, Open  ]],
Cell[68909, 1894, 164, 5, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69110, 1904, 194, 9, 61, "Subsubsection"],
Cell[69307, 1915, 145, 4, 45, "Text"],
Cell[69455, 1921, 262, 5, 69, "Input"],
Cell[69720, 1928, 38, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[69783, 1932, 57, 1, 41, "Input"],
Cell[69843, 1935, 343, 7, 63, "Output"]
}, Open  ]],
Cell[70201, 1945, 110, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[70336, 1952, 635, 15, 234, "Input"],
Cell[70974, 1969, 32443, 855, 279, 12338, 602, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[103432, 2827, 328, 12, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103797, 2844, 196, 9, 61, "Subsubsection"],
Cell[103996, 2855, 338, 11, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104371, 2871, 194, 9, 61, "Subsubsection"],
Cell[104568, 2882, 137, 4, 45, "Text"],
Cell[104708, 2888, 437, 9, 122, "Input"],
Cell[105148, 2899, 308, 9, 69, "Text"],
Cell[105459, 2910, 88, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[105572, 2917, 76, 2, 66, "Input"],
Cell[105651, 2921, 46, 1, 41, "Output"],
Cell[105700, 2924, 1128, 21, 219, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[106889, 2952, 162, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[107076, 2963, 178, 9, 61, "Subsubsection"],
Cell[107257, 2974, 561, 12, 117, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107855, 2991, 194, 9, 61, "Subsubsection"],
Cell[108052, 3002, 163, 4, 45, "Text"],
Cell[108218, 3008, 1394, 23, 399, "Input"],
Cell[109615, 3033, 72, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[109712, 3037, 59, 1, 41, "Input"],
Cell[109774, 3040, 63, 1, 35, "Print"],
Cell[109840, 3043, 1127, 25, 185, "Print"]
}, Open  ]],
Cell[110982, 3071, 67, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[111074, 3075, 104, 2, 41, "Input"],
Cell[111181, 3079, 333, 6, 63, "Output"]
}, Open  ]],
Cell[111529, 3088, 399, 8, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111965, 3101, 197, 9, 61, "Subsubsection"],
Cell[112165, 3112, 267, 6, 69, "Text"],
Cell[112435, 3120, 107, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[112567, 3127, 149, 4, 66, "Input"],
Cell[112719, 3133, 301, 4, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113057, 3142, 180, 3, 97, "Input"],
Cell[113240, 3147, 65279, 1405, 363, 19012, 829, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[178534, 4555, 165, 4, 69, "Text"],
Cell[178702, 4561, 124, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[178851, 4568, 134, 3, 55, "Input"],
Cell[178988, 4573, 25755, 639, 279, 8054, 416, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[204758, 5215, 91, 3, 45, "Text"],
Cell[204852, 5220, 226, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[205103, 5228, 199, 5, 74, "Input"],
Cell[205305, 5235, 376, 7, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[205718, 5247, 208, 3, 97, "Input"],
Cell[205929, 5252, 72539, 1551, 363, 20160, 900, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[278529, 6810, 198, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[278752, 6821, 181, 9, 61, "Subsubsection"],
Cell[278936, 6832, 224, 5, 69, "Text"],
Cell[279163, 6839, 329, 9, 69, "Text"],
Cell[279495, 6850, 433, 15, 57, "NumberedEquation",
  CellTags->"Binomische Differenzengleichung"],
Cell[279931, 6867, 607, 26, 69, "Text"],
Cell[280541, 6895, 264, 7, 69, "Text"],
Cell[280808, 6904, 360, 11, 58, "NumberedEquation",
  CellTags->"Berechnung der Binomial-Koeffizienten"],
Cell[281171, 6917, 382, 10, 69, "Text"],
Cell[281556, 6929, 176, 4, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[281769, 6938, 189, 9, 61, "Subsubsection"],
Cell[281961, 6949, 239, 11, 61, "Text"],

Cell[CellGroupData[{
Cell[282225, 6964, 56, 1, 41, "Input"],
Cell[282284, 6967, 65, 1, 41, "Output"]
}, Open  ]],
Cell[282364, 6971, 63, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[282452, 6975, 159, 3, 41, "Input"],
Cell[282614, 6980, 71, 1, 41, "Output"]
}, Open  ]],
Cell[282700, 6984, 319, 12, 61, "Text"],
Cell[283022, 6998, 435, 14, 85, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[283494, 7017, 188, 9, 61, "Subsubsection"],
Cell[283685, 7028, 62, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[283772, 7032, 69, 1, 43, "Input"],
Cell[283844, 7035, 72, 1, 41, "Output"]
}, Open  ]],
Cell[283931, 7039, 187, 6, 45, "Text"],
Cell[284121, 7047, 294, 8, 69, "Text"],

Cell[CellGroupData[{
Cell[284440, 7059, 121, 2, 41, "Input"],
Cell[284564, 7063, 38, 1, 43, "Output"]
}, Open  ]],
Cell[284617, 7067, 215, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[284857, 7077, 110, 2, 41, "Input"],
Cell[284970, 7081, 58, 1, 64, "Output"]
}, Open  ]],
Cell[285043, 7085, 272, 12, 69, "Text"],
Cell[285318, 7099, 103, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[285446, 7106, 145, 3, 41, "Input"],
Cell[285594, 7111, 76, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[285707, 7117, 92, 1, 41, "Input"],
Cell[285802, 7120, 58, 1, 64, "Output"]
}, Open  ]],
Cell[285875, 7124, 70, 0, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[285982, 7129, 220, 9, 61, "Subsubsection"],
Cell[286205, 7140, 113, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[286343, 7147, 73, 1, 46, "Input"],
Cell[286419, 7150, 93, 1, 41, "Output"]
}, Open  ]],
Cell[286527, 7154, 69, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[286621, 7158, 167, 3, 91, "Input"],
Cell[286791, 7163, 1347, 28, 213, "Output"]
}, Open  ]],
Cell[288153, 7194, 51, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[288229, 7198, 89, 1, 41, "Input"],
Cell[288321, 7201, 61, 1, 41, "Output"]
}, Open  ]],
Cell[288397, 7205, 76, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[288498, 7209, 102, 2, 41, "Input"],
Cell[288603, 7213, 38, 1, 43, "Output"]
}, Open  ]],
Cell[288656, 7217, 255, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[288936, 7228, 102, 2, 41, "Input"],
Cell[289041, 7232, 89, 1, 64, "Output"]
}, Open  ]],
Cell[289145, 7236, 577, 14, 117, "Text"],
Cell[289725, 7252, 91, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[289841, 7257, 187, 3, 91, "Input"],
Cell[290031, 7262, 89, 1, 64, "Output"]
}, Open  ]],
Cell[290135, 7266, 763, 17, 141, "Text"],
Cell[290901, 7285, 178, 4, 69, "Text"],
Cell[291082, 7291, 326, 9, 93, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[291457, 7306, 155, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[291637, 7317, 215, 9, 61, "Subsubsection"],
Cell[291855, 7328, 654, 16, 141, "Text"],
Cell[292512, 7346, 424, 12, 93, "Text"],
Cell[292939, 7360, 446, 11, 93, "Text"],

Cell[CellGroupData[{
Cell[293410, 7375, 123, 2, 71, "Input"],
Cell[293536, 7379, 48, 1, 41, "Output"]
}, Open  ]],
Cell[293599, 7383, 781, 14, 165, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[294417, 7402, 193, 9, 61, "Subsubsection"],
Cell[294613, 7413, 598, 19, 117, "Text"],
Cell[295214, 7434, 640, 18, 141, "Text"],
Cell[295857, 7454, 371, 11, 69, "Text"],
Cell[296231, 7467, 219, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[296475, 7477, 144, 3, 66, "Input"],
Cell[296622, 7482, 240, 3, 66, "Output"]
}, Open  ]],
Cell[296877, 7488, 164, 3, 66, "Input"],
Cell[297044, 7493, 104, 3, 45, "Text"],
Cell[297151, 7498, 203, 4, 66, "Input"],

Cell[CellGroupData[{
Cell[297379, 7506, 111, 2, 41, "Input"],
Cell[297493, 7510, 75373, 1549, 279, 14322, 791, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[372881, 9062, 133, 3, 69, "Text"],

Cell[CellGroupData[{
Cell[373039, 9069, 197, 4, 91, "Input"],
Cell[373239, 9075, 782, 10, 191, "Output"]
}, Open  ]],
Cell[374036, 9088, 213, 4, 66, "Input"],

Cell[CellGroupData[{
Cell[374274, 9096, 116, 2, 41, "Input"],
Cell[374393, 9100, 56943, 1481, 279, 17150, 985, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[431351, 10584, 298, 9, 69, "Text"],
Cell[431652, 10595, 630, 19, 93, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[432343, 10621, 106, 5, 76, "Section"],

Cell[CellGroupData[{
Cell[432474, 10630, 151, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[432650, 10641, 181, 9, 61, "Subsubsection"],
Cell[432834, 10652, 233, 6, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[433104, 10663, 181, 9, 61, "Subsubsection"],
Cell[433288, 10674, 357, 8, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[433682, 10687, 183, 9, 61, "Subsubsection"],
Cell[433868, 10698, 298, 7, 93, "Text"],
Cell[434169, 10707, 92, 3, 45, "Text"],
Cell[434264, 10712, 366, 8, 114, "NumberedTable"],
Cell[434633, 10722, 166, 4, 69, "Text"],
Cell[434802, 10728, 258, 9, 70, "Text"],
Cell[435063, 10739, 172, 4, 76, "NumberedEquation",
  CellTags->"Arithmetisches Mittel"],
Cell[435238, 10745, 124, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[435387, 10752, 430, 8, 208, "Input"],
Cell[435820, 10762, 1372, 38, 108, "Output"],
Cell[437195, 10802, 148, 4, 60, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[437404, 10813, 200, 9, 68, "Subsection"],

Cell[CellGroupData[{
Cell[437629, 10826, 181, 9, 61, "Subsubsection"],
Cell[437813, 10837, 119, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[437957, 10844, 93, 1, 41, "Input"],
Cell[438053, 10847, 1509, 42, 108, "Output"]
}, Open  ]],
Cell[439577, 10892, 116, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[439718, 10899, 74, 2, 66, "Input"],
Cell[439795, 10903, 153, 4, 64, "Output"],
Cell[439951, 10909, 35, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[440035, 10916, 188, 9, 61, "Subsubsection"],
Cell[440226, 10927, 151, 3, 69, "Text"],

Cell[CellGroupData[{
Cell[440402, 10934, 552, 14, 99, "Input"],
Cell[440957, 10950, 149, 4, 60, "Output"]
}, Open  ]],
Cell[441121, 10957, 112, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[441258, 10964, 82, 1, 41, "Input"],
Cell[441343, 10967, 321, 9, 60, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[441713, 10982, 190, 9, 61, "Subsubsection"],
Cell[441906, 10993, 132, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[442063, 11000, 98, 2, 53, "Input"],
Cell[442164, 11004, 88, 1, 41, "Output"]
}, Open  ]],
Cell[442267, 11008, 233, 6, 69, "Text"],
Cell[442503, 11016, 238, 4, 76, "NumberedEquation"],

Cell[CellGroupData[{
Cell[442766, 11024, 123, 2, 75, "Input"],
Cell[442892, 11028, 189, 5, 64, "Output"]
}, Open  ]],
Cell[443096, 11036, 185, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[443306, 11044, 103, 2, 45, "Input"],
Cell[443412, 11048, 321, 9, 60, "Output"]
}, Open  ]],
Cell[443748, 11060, 137, 5, 45, "Text"],
Cell[443888, 11067, 199, 5, 86, "NumberedEquation",
  CellTags->"mittlerer Fehler"]
}, Open  ]],

Cell[CellGroupData[{
Cell[444124, 11077, 191, 9, 61, "Subsubsection"],
Cell[444318, 11088, 385, 10, 102, "Text"],
Cell[444706, 11100, 580, 17, 117, "Text"],
Cell[445289, 11119, 525, 13, 117, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[445851, 11137, 197, 9, 61, "Subsubsection"],
Cell[446051, 11148, 640, 17, 117, "Text"],
Cell[446694, 11167, 220, 5, 86, "NumberedEquation",
  CellTags->"falsche Standardabweichung"],
Cell[446917, 11174, 1380, 39, 197, "Text"],
Cell[448300, 11215, 521, 16, 93, "Text"],
Cell[448824, 11233, 183, 4, 86, "NumberedEquation"],
Cell[449010, 11239, 221, 5, 69, "Text"],
Cell[449234, 11246, 607, 15, 117, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[449878, 11266, 211, 9, 61, "Subsubsection"],
Cell[450092, 11277, 497, 12, 117, "Text"],

Cell[CellGroupData[{
Cell[450614, 11293, 139, 3, 106, "Input"],
Cell[450756, 11298, 128, 2, 91, "Output"]
}, Open  ]],
Cell[450899, 11303, 298, 8, 69, "Text"],

Cell[CellGroupData[{
Cell[451222, 11315, 205, 3, 106, "Input"],
Cell[451430, 11320, 123, 2, 84, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[451590, 11327, 77, 1, 41, "Input"],
Cell[451670, 11330, 63, 1, 41, "Output"]
}, Open  ]],
Cell[451748, 11334, 270, 9, 69, "Text"],

Cell[CellGroupData[{
Cell[452043, 11347, 66, 1, 61, "Input"],
Cell[452112, 11350, 116, 2, 77, "Output"]
}, Open  ]],
Cell[452243, 11355, 146, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[452414, 11364, 205, 3, 90, "Input"],
Cell[452622, 11369, 45, 1, 65, "Output"],
Cell[452670, 11372, 181, 3, 41, "Output"]
}, Open  ]],
Cell[452866, 11378, 500, 14, 93, "Text"],
Cell[453369, 11394, 551, 10, 117, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[453969, 11410, 157, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[454151, 11421, 181, 9, 61, "Subsubsection"],
Cell[454335, 11432, 276, 5, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[454648, 11442, 190, 9, 61, "Subsubsection"],
Cell[454841, 11453, 324, 10, 69, "Text"],
Cell[455168, 11465, 204, 5, 86, "NumberedEquation",
  CellTags->"Fehlerfortpflanzung"],
Cell[455375, 11472, 420, 14, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[455832, 11491, 210, 10, 61, "Subsubsection"],
Cell[456045, 11503, 317, 7, 69, "Text"],
Cell[456365, 11512, 171, 4, 69, "Text"],
Cell[456539, 11518, 203, 4, 76, "NumberedEquation",
  CellTags->"Groesstfehler"],
Cell[456745, 11524, 262, 5, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[457044, 11534, 179, 9, 61, "Subsubsection"],
Cell[457226, 11545, 420, 11, 69, "Text"],
Cell[457649, 11558, 126, 2, 54, "NumberedEquation"],
Cell[457778, 11562, 216, 5, 69, "Text"],

Cell[CellGroupData[{
Cell[458019, 11571, 325, 6, 132, "Input"],
Cell[458347, 11579, 57, 1, 41, "Output"]
}, Open  ]],
Cell[458419, 11583, 175, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[458619, 11593, 88, 1, 77, "Input"],
Cell[458710, 11596, 56, 1, 41, "Output"]
}, Open  ]],
Cell[458781, 11600, 350, 6, 93, "Text"],
Cell[459134, 11608, 78, 0, 45, "Text"],
Cell[459215, 11610, 152, 4, 66, "Input"],
Cell[459370, 11616, 245, 5, 118, "Input"],
Cell[459618, 11623, 439, 9, 188, "Input"],

Cell[CellGroupData[{
Cell[460082, 11636, 111, 2, 41, "Input"],
Cell[460196, 11640, 35273, 929, 237, 12555, 644, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[495484, 12572, 127, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[495636, 12579, 103, 2, 45, "Input"],
Cell[495742, 12583, 321, 9, 60, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[496136, 12600, 110, 5, 76, "Section"],

Cell[CellGroupData[{
Cell[496271, 12609, 142, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[496438, 12620, 179, 9, 61, "Subsubsection"],
Cell[496620, 12631, 122, 3, 69, "Text"],
Cell[496745, 12636, 179, 4, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[496961, 12645, 184, 10, 61, "Subsubsection"],
Cell[497148, 12657, 220, 6, 69, "Text"],
Cell[497371, 12665, 368, 9, 93, "Text"],
Cell[497742, 12676, 415, 9, 117, "Text"],
Cell[498160, 12687, 781, 14, 73, "NumberedEquation",
  CellTags->"Euler-Ostrogradskische Gleichungen"],
Cell[498944, 12703, 689, 26, 93, "Text"],
Cell[499636, 12731, 172, 4, 69, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[499857, 12741, 153, 8, 68, "Subsection"],

Cell[CellGroupData[{
Cell[500035, 12753, 183, 10, 61, "Subsubsection"],
Cell[500221, 12765, 134, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[500380, 12774, 183, 4, 83, "Input"],
Cell[500566, 12780, 141, 3, 69, "Output"]
}, Open  ]],
Cell[500722, 12786, 169, 5, 45, "Text"],
Cell[500894, 12793, 237, 6, 69, "Text"],
Cell[501134, 12801, 293, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[501452, 12812, 97, 2, 47, "Input"],
Cell[501552, 12816, 198, 4, 71, "Output"]
}, Open  ]],
Cell[501765, 12823, 476, 14, 71, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[502278, 12842, 199, 10, 61, "Subsubsection"],
Cell[502480, 12854, 388, 10, 93, "Text"],
Cell[502871, 12866, 897, 18, 151, "NumberedEquation"],
Cell[503771, 12886, 41, 0, 45, "Text"],
Cell[503815, 12888, 190, 3, 76, "NumberedEquation"],
Cell[504008, 12893, 274, 8, 71, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[504319, 12906, 202, 10, 61, "Subsubsection"],
Cell[504524, 12918, 231, 4, 69, "Text"],
Cell[504758, 12924, 192, 4, 76, "NumberedEquation"],
Cell[504953, 12930, 113, 3, 45, "Text"],
Cell[505069, 12935, 742, 22, 119, "NumberedEquation"],
Cell[505814, 12959, 180, 5, 45, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[506043, 12970, 148, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[506216, 12981, 189, 9, 61, "Subsubsection"],
Cell[506408, 12992, 257, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[506690, 13002, 122, 3, 82, "Input"],
Cell[506815, 13007, 88, 1, 68, "Output"]
}, Open  ]],
Cell[506918, 13011, 291, 11, 45, "Text"],

Cell[CellGroupData[{
Cell[507234, 13026, 143, 3, 66, "Input"],
Cell[507380, 13031, 100, 2, 82, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[507517, 13038, 143, 3, 66, "Input"],
Cell[507663, 13043, 110, 2, 82, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[507822, 13051, 211, 9, 61, "Subsubsection"],
Cell[508036, 13062, 54, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[508115, 13066, 342, 6, 157, "Input"],
Cell[508460, 13074, 982, 31, 79, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[509491, 13111, 218, 9, 61, "Subsubsection"],
Cell[509712, 13122, 342, 11, 69, "Text"],
Cell[510057, 13135, 165, 4, 53, "NumberedEquation"],
Cell[510225, 13141, 431, 10, 117, "Text"],
Cell[510659, 13153, 188, 4, 56, "NumberedEquation"],
Cell[510850, 13159, 454, 9, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[511341, 13173, 223, 9, 61, "Subsubsection"],
Cell[511567, 13184, 244, 6, 69, "Text"],
Cell[511814, 13192, 200, 4, 35, "NumberedEquation"],
Cell[512017, 13198, 415, 11, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[512469, 13214, 221, 9, 61, "Subsubsection"],
Cell[512693, 13225, 627, 14, 141, "Text"],
Cell[513323, 13241, 317, 6, 93, "Text"],
Cell[513643, 13249, 184, 5, 69, "Text"],
Cell[513830, 13256, 413, 14, 74, "NumberedEquation"],
Cell[514246, 13272, 178, 5, 45, "Text"],
Cell[514427, 13279, 449, 14, 88, "NumberedEquation"],
Cell[514879, 13295, 72, 0, 45, "Text"],
Cell[514954, 13297, 446, 14, 90, "NumberedEquation"],
Cell[515403, 13313, 167, 5, 45, "Text"],
Cell[515573, 13320, 552, 17, 95, "NumberedEquation"],
Cell[516128, 13339, 473, 13, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[516638, 13357, 211, 9, 61, "Subsubsection"],
Cell[516852, 13368, 109, 3, 45, "Text"],
Cell[516964, 13373, 148, 2, 104, "NumberedEquation"],
Cell[517115, 13377, 156, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[517296, 13386, 171, 3, 66, "Input"],
Cell[517470, 13391, 2761, 79, 137, "Output"]
}, Open  ]],
Cell[520246, 13473, 502, 8, 141, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[520785, 13486, 189, 9, 61, "Subsubsection"],
Cell[520977, 13497, 120, 3, 69, "Text"],

Cell[CellGroupData[{
Cell[521122, 13504, 412, 7, 166, "Input"],
Cell[521537, 13513, 172, 3, 41, "Output"],
Cell[521712, 13518, 729, 13, 141, "Output"]
}, Open  ]],
Cell[522456, 13534, 120, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[522601, 13541, 326, 7, 162, "Input"],
Cell[522930, 13550, 66, 1, 41, "Output"],
Cell[522999, 13553, 40, 1, 41, "Output"],
Cell[523042, 13556, 35, 1, 41, "Output"]
}, Open  ]],
Cell[523092, 13560, 73, 0, 45, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[523214, 13566, 148, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[523387, 13577, 201, 9, 61, "Subsubsection"],
Cell[523591, 13588, 119, 3, 45, "Text"],
Cell[523713, 13593, 132, 3, 45, "Text"],
Cell[523848, 13598, 120, 3, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[524005, 13606, 201, 9, 61, "Subsubsection"],
Cell[524209, 13617, 191, 6, 45, "Text"],
Cell[524403, 13625, 413, 7, 76, "NumberedEquation"],
Cell[524819, 13634, 408, 11, 69, "Text"],
Cell[525230, 13647, 349, 7, 76, "NumberedEquation",
  CellTags->"Fehlerfortpflanzung?"],
Cell[525582, 13656, 236, 6, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[525855, 13667, 207, 9, 61, "Subsubsection"],
Cell[526065, 13678, 490, 12, 93, "Text"],
Cell[526558, 13692, 173, 5, 46, "Text"],
Cell[526734, 13699, 369, 9, 110, "NumberedEquation"],
Cell[527106, 13710, 361, 6, 117, "Text"],
Cell[527470, 13718, 217, 4, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[527724, 13727, 203, 9, 61, "Subsubsection"],
Cell[527930, 13738, 282, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[528237, 13749, 294, 6, 217, "Input"],
Cell[528534, 13757, 295, 8, 74, "Output"],
Cell[528832, 13767, 313, 9, 41, "Output"]
}, Open  ]],
Cell[529160, 13779, 142, 3, 69, "Text"],
Cell[529305, 13784, 248, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[529578, 13795, 795, 15, 276, "Input"],
Cell[530376, 13812, 270, 8, 41, "Output"]
}, Open  ]],
Cell[530661, 13823, 217, 4, 93, "Text"],
Cell[530881, 13829, 44, 1, 41, "Input"],

Cell[CellGroupData[{
Cell[530950, 13834, 141, 2, 83, "Input"],
Cell[531094, 13838, 137, 2, 44, "Output"]
}, Open  ]],
Cell[531246, 13843, 126, 3, 45, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[531421, 13852, 157, 7, 68, "Subsection"],
Cell[531581, 13861, 359, 11, 69, "Text"],
Cell[531943, 13874, 384, 7, 75, "NumberedEquation"],
Cell[532330, 13883, 135, 3, 69, "Text"],
Cell[532468, 13888, 571, 11, 76, "NumberedEquation"],
Cell[533042, 13901, 97, 1, 45, "Text"],
Cell[533142, 13904, 342, 8, 93, "NumberedEquation"],
Cell[533487, 13914, 311, 6, 93, "Text"],
Cell[533801, 13922, 259, 5, 93, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[534109, 13933, 101, 5, 76, "Section"],
Cell[534213, 13940, 114, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[534352, 13949, 71, 1, 41, "Input"],
Cell[534426, 13952, 85, 1, 41, "Output"]
}, Open  ]],
Cell[534526, 13956, 57, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[534608, 13960, 43, 1, 41, "Input"],
Cell[534654, 13963, 54, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[534757, 13970, 29, 0, 80, "Subtitle"],
Cell[534789, 13972, 330, 9, 93, "Text",
  CellTags->"[Baul1956]"],
Cell[535122, 13983, 292, 7, 117, "Text",
  CellTags->"[BrS1987]"],
Cell[535417, 13992, 317, 8, 93, "Text",
  CellTags->"[GKHK1974]"],
Cell[535737, 14002, 304, 8, 93, "Text",
  CellTags->"[Haw1995]"],
Cell[536044, 14012, 230, 6, 93, "Text",
  CellTags->"[HMS2004]"],
Cell[536277, 14020, 272, 7, 93, "Text",
  CellTags->"[Mor1987]"],
Cell[536552, 14029, 181, 6, 69, "Text",
  CellTags->"[Noer1924]"],
Cell[536736, 14037, 240, 6, 93, "Text",
  CellTags->"[Smi1988]"],
Cell[536979, 14045, 226, 6, 93, "Text",
  CellTags->"[Spie1982]"],
Cell[537208, 14053, 356, 9, 117, "Text",
  CellTags->"[ZF1984]"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

